* ===================== Program: PDI_ALL_CONTROL.SAS ======================== ;
*  VERSION: SAS QI v2018 (ICD-10 CM/PCS)
*  RELEASE DATE: JUNE 2018
* =========================================================================== ;
* The Pediatric Quality Indicator (PDI) module of the AHRQ Quality
   Indicators software includes the following programs:
   
   1. PDI_ALL_CONTROL.SAS   Assigns user inputs required by other programs
                            and optional output options. 
                  
   2. PDI_ALL_FORMATS.SAS   Creates SAS format library used by other programs.

   3. PDI_ALL_MEASURES.SAS  Assigns Pediatric Quality Indicators to 
                            inpatient records.

   4. PDI_PROV_OBSERVED.SAS Calculates observed rates for provider level indicators.

   5. PDI_AREA_OBSERVED.SAS Calculates observed rates for area level indicators.

   6. PDI_STRATIFIED.SAS    Calculates observed rates stratified by risk group
                            categories that are specific to each indicator.
 
* The software also requires the following files:
 
   1. discharges.sas7bdat  User supplied discharge level file organized according 
                           to the software instructions.
                           The file name is up to the user but must be listed below.
                     
   2. PDI_Dx_Px_Macros.SAS Standard processes used by the other SAS programs.
                           The user does not need to open.
                     
    3. 1995-2017_Population_Files_V2018.txt  Population file with counts by area, age, and sex.
                           Required for area rate calculation. Available as a 
                           separate download from the AHRQ website.

***************************************************************************** ;
******************************* PLEASE READ ********************************* ;
***************************************************************************** ;
 * The AHRQ Quality Indicator software is intended for use with discharges
   coded according to the standards in place at the date of the discharge. 
   Discharges should be classified under the ICD-10-CM/PCS specifications 
   effective 10/1/2015. All diagnosis codes require a corresponding Present
   on admission, POA, value coded according to UB04 standards. 
   Although results can be generated with inputs coded under ICD9 and 
   converted to ICD10 with General Equivalence Mappings, the mapping process
   may produce unrepresentative results. ICD10 observed rate calculations
   should not be used to produce ICD9 risk adjusted outputs.
   
 * The USER MUST modify portions of the following code in order to
   run this software.  With one exception (see NOTE immediately
   following this paragraph), the only changes necessary to run
   this software are changes in this program (PDI_ALL_CONTROL.SAS). 
   The modifications include such items as specifying the name and location
   of the input data set, the year of population data to be used, and the 
   name and location of output data sets.
 
 * NOTE:  PDI_ALL_CONTROL.SAS provides the option to read data in and write 
          data out to different locations.  For example, "libname INMSR" points
        to the location of the input data set for the PDI_ALL_MEASURES program
        and "libname OUTMSR" points to the location of the output data set
        created by the PDI_ALL_MEASURES program.  The location and file name of 
        each input and output can be assigned separately below. The default 
        values will place output in a SASData folder with standard names for
        each file based on the location of the PDI folder listed in the 
        PATHNAME variable.
        
 * NOTE:  In the other programs included with this package there is a 
        line of code that begins with "filename CONTROL".  
        The USER MUST include after "filename CONTROL" the location
        of the PDI_ALL_CONTROL.SAS file.

 Generally speaking, a first-time user of this software would proceed 
 as outlined below:

    1.  Modify and save PDI_ALL_CONTROL.SAS (This program. - MUST be done.)
    2.  Open PDI_ALL_FORMATS.SAS and specify location (path name) of
        PDI_ALL_CONTROL.SAS. (MUST be done.)
    3.  Run PDI_ALL_FORMATS.SAS.  (MUST be done.) 
    4.  Open PDI_MEASURES.SAS and specify location of PDI_ALL_CONTROL.SAS
      program.  (MUST be done.)
    5.  Run PDI_ALL_MEASURES.SAS.  (MUST be done.)
    6.  To calculate observed rates for Provider Level Inpatient 
      Quality Indicators:
         a.  Open PDI_PROV_OBSERVED.SAS and specify location
             of PDI_ALL_CONTROL.SAS program. (MUST be done.) 
         b.  Run PDI_PROV_OBSERVED.SAS. (MUST have run PDI_ALL_MEASURES.SAS.)
         c.  Run PDI_STRATIFIED.SAS. (MUST have run PDI_ALL_MEASURES.SAS.) 
    7.  To calculate observed rates for Area Level npatient 
      Quality Indicators:
         a.  Open PDI_AREA_OBSERVED.SAS and specify location
             of PDI_ALL_CONTROL.SAS program.  (MUST be done.) 
         b.  Run PDI_AREA_OBSERVED.SAS.  (MUST have run PDI_ALL_MEASURES.SAS.)

* ---------------------------------------------------------------- ;
* -------------    Inputs For All Programs    -------------------- ;
* ---------------------------------------------------------------- ;

*PATHNAME specifies the location of the PDI folder which includes the
          Programs, Macros, and SASdata subfolders;
%LET PATHNAME=C:\Pathname\PDI;                        *<===USER MUST modify;
*DISFOLDER specifies the folder that contains the discharge data;
%LET DISFOLDER=C:\Pathname;                           *<===USER MUST modify;
*DISCHARGE specifies the name of the discharge data file;
%LET DISCHARGE= discharges;                           *<===USER MUST modify;
*SUFX specifies an identifier suffix to be placed on output datasets;
%LET SUFX = SAS18_ICD10;                                  *<===USER may modify;

*LIBRARY is where formats generated by PDI_ALL_FORMATS will be saved.;    
LIBNAME LIBRARY  "&PATHNAME.\SASData";                *<===USER may modify;

 * ---------------------------------------------------------------- ;
 * --- INDICATE IF COUNTY-LEVEL AREAS SHOULD BE CONVERTED TO MAs -- ;
 * ---     0 - County level with U.S. Census FIPS                -- ;
 * ---     1 - County level with Modified FIPS                   -- ;
 * ---     2 - Metro Area level with OMB 1999 definition         -- ;
 * ---     3 - Metro Area level with OMB 2003 definition         -- ;
 * ---------------------------------------------------------------- ;
%LET MALEVL = 0;                                *<===USER may modify;
 * ---------------------------------------------------------------- ;
 * NOTE:  SELECT THE POPULATION DATA FOR THE YEAR THAT BEST MATCHES ;
 *        THE DISCHARGE DATA. POPYEAR WILL IDENTIFY POPULATION USED ;
 *        BY THE PDI_AREA_OBSERVED PROGRAM.                         ;
 * ---------------------------------------------------------------- ;
%LET POPYEAR = 2017;                            *<===USER may modify;
 * ---------------------------------------------------------------- ;
 * --- SET LOCATION OF POPULATION FILE                          --- ;
 * ---------------------------------------------------------------- ;
filename POPFILE  "&PATHNAME.\1995-2017_Population_Files_V2018.txt";  *<===USER may modify;

 * ---------------------------------------------------------------- ;
 * --- INDICATE IF RECORDS SHOULD BE PRINTED IN SAS OUTPUT AT   --- ;
 * --- END OF EACH PROGRAM.  0 = NO, 1 = YES                    --- ;
 * ---------------------------------------------------------------- ;
%LET PRINT = 0;                                 *<===USER may modify;
  * --------------------------------------------------------------- ;
 * --- ADD OPTIONS TO COMPRESS OUTPUT AND SUPPRESS SOURCE CODE  --- ;
 * --- IN LOG. RECOMMENDED WITH LARGE FILES. TO RESTORE, RUN:   --- ;
 * --- options source compress = no                             --- ;
 * ---------------------------------------------------------------- ;
options compress = YES ;
 * ---------------------------------------------------------------- ;
 * --- SET LOCATION OF SAS MACRO LIBRARY                        --- ;
 * ---------------------------------------------------------------- ;
filename MacLib "&PATHNAME.\Macros\" ;          *<===USER may modify;
 * ---------------------------------------------------------------- ;
 * ---             Program : PDI_ALL_MEASURES                   --- ;
 * ---------------------------------------------------------------- ;
 * ---------------------------------------------------------------- ;   
 * --- SET LOCATION OF PDI_ALL_MEASURES INPUT DATA              --- ;   
 * ---------------------------------------------------------------- ;   
libname INMSR  "&DISFOLDER.";                    *<==USER may modify; 
 * ---------------------------------------------------------------- ;
 * --- SET LOCATION OF PDI_ALL_MEASURES OUTPUT DATA             --- ;
 * ---------------------------------------------------------------- ;
libname OUTMSR "&PATHNAME.\SASdata";             *<==USER may modify;
 * --- SET NAME OF OUTPUT FILE FROM PDI_ALL_MEASURES.SAS        --- ;    
%LET OUTFILE_MEAS = PDMSR_&SUFX;                 *<==USER may modify;
 * ---------------------------------------------------------------- ;
 * --- MODIFY INPUT AND OUTPUT FILE                             --- ;
 * ---------------------------------------------------------------- ;
 * --- PROGRAM DEFAULT ASSUMES THERE ARE                        --- ;
 * ---     35 DIAGNOSES (DX1-DX35)                              --- ;
 * ---     30 PROCEDURES (PR1-PR30)                             --- ;
 * ---------------------------------------------------------------- ;
 * --- MODIFY NUMBER OF DIAGNOSIS AND PROCEDURE VARIABLES TO    --- ;
 * --- MATCH USER DISCHARGE INPUT DATA                          --- ;
 * ---------------------------------------------------------------- ;
%LET NDX = 35;                                  *<===USER MUST modify;
%LET NPR = 30;                                  *<===USER MUST modify;
 * ---------------------------------------------------------------- ;
 * - INDICATE IF DATA AVAILABLE REGARDING NUMBER OF DAYS        --- ;
 * - FROM ADMISSION TO SECONDARY PROCEDURES                     --- ;
 * - 0 = PRDAY IS NOT INCLUDED, 1 = PRDAY IS INCLUDED           --- ;
 * ---------------------------------------------------------------- ;
%LET PRDAY  = 1;                                *<===USER may modify; 

* ----------------------------------------------------------------- ;
 * - CREATE PERMANENT SAS DATASET TO STORE RECORDS THAT WILL    --- ;
 * - NOT BE INCLUDED IN CALCULATIONS BECAUSE KEY VARIABLE       --- ;
 * - VALUES ARE MISSING.  THIS DATASET SHOULD BE REVIEWED AFTER --- ;
 * - RUNNING PDI_ALL_MEASURES.                              --- ;
 * ---------------------------------------------------------------- ;
%LET DELFILE  = PDI_DELETED_&SUFX;              *<===USER may modify;

 * =================================================================;
 * ============PROVIDER-LEVEL INPATIENT QUALITY INDICATORS==========;
 * =================================================================;
 * ---       Program: PDI_PROV_OBSERVED.SAS                     --- ;
 * ---------------------------------------------------------------- ;
 * ---------------------------------------------------------------- ;
 * --- SET LOCATION OF PDI_PROV_OBSERVED OUTPUT DATA            --- ;
 * ---------------------------------------------------------------- ;
libname OUTPOBS "&PATHNAME.\SASdata";           *<===USER may modify;

 * ----------------------------------------------------------------------- ;    
 * --- TYPELVLP indicates the levels (or _TYPE_) of                    --- ;    
 * --- summarization to be kept in the output.                         --- ;    
 * ---                                                                 --- ;    
 * ---  TYPELVLP      stratification                                   --- ;    
 * ---  --------  ---------------------------------------------------- --- ;    
 * ---     0      overall                                              --- ;    
 * ---     1                                                      race --- ;    
 * ---     2                                              payer        --- ;    
 * ---     3                                              payer * race --- ;    
 * ---     4                                        sex                --- ;    
 * ---     5                                        sex         * race --- ;    
 * ---     6                                        sex * payer        --- ;    
 * ---     7                                        sex * payer * race --- ;    
 * ---     8                                  age                      --- ;    
 * ---     9                                  age               * race --- ;    
 * ---    10                                  age       * payer        --- ;    
 * ---    11                                  age       * payer * race --- ;    
 * ---    12                                  age * sex                --- ;    
 * ---    13                                  age * sex         * race --- ;    
 * ---    14                                  age * sex * payer        --- ;    
 * ---    15                                  age * sex * payer * race --- ;    
 * ---    16                         ageday                            --- ;    
 * ---    17                         ageday                     * race --- ;    
 * ---    18                         ageday             * payer        --- ;    
 * ---    19                         ageday             * payer * race --- ;    
 * ---    20                         ageday       * sex                --- ;    
 * ---    21                         ageday       * sex         * race --- ;    
 * ---    22                         ageday       * sex * payer        --- ;    
 * ---    23                         ageday       * sex * payer * race --- ;    
 * ---    24                         ageday * age                      --- ;    
 * ---    25                         ageday * age               * race --- ;    
 * ---    26                         ageday * age       * payer        --- ;    
 * ---    27                         ageday * age       * payer * race --- ;    
 * ---    28                         ageday * age * sex                --- ;    
 * ---    29                         ageday * age * sex         * race --- ;    
 * ---    30                         ageday * age * sex * payer        --- ;    
 * ---    31                         ageday * age * sex * payer * race --- ;    
 * ---    32                  bwht                                     --- ;    
 * ---    33                  bwht                              * race --- ;    
 * ---    34                  bwht                      * payer        --- ;    
 * ---    35                  bwht                      * payer * race --- ;    
 * ---    36                  bwht                * sex                --- ;    
 * ---    37                  bwht                * sex         * race --- ;    
 * ---    38                  bwht                * sex * payer        --- ;    
 * ---    39                  bwht                * sex * payer * race --- ;    
 * ---    40                  bwht          * age                      --- ;    
 * ---    41                  bwht          * age               * race --- ;    
 * ---    42                  bwht          * age       * payer        --- ;    
 * ---    43                  bwht          * age       * payer * race --- ;    
 * ---    44                  bwht          * age * sex                --- ;    
 * ---    45                  bwht          * age * sex         * race --- ;    
 * ---    46                  bwht          * age * sex * payer        --- ;    
 * ---    47                  bwht          * age * sex * payer * race --- ;    
 * ---    48                  bwht * ageday                            --- ;    
 * ---    49                  bwht * ageday                     * race --- ;    
 * ---    50                  bwht * ageday             * payer        --- ;    
 * ---    51                  bwht * ageday             * payer * race --- ;    
 * ---    52                  bwht * ageday       * sex                --- ;    
 * ---    53                  bwht * ageday       * sex         * race --- ;    
 * ---    54                  bwht * ageday       * sex * payer        --- ;    
 * ---    55                  bwht * ageday       * sex * payer * race --- ;    
 * ---    56                  bwht * ageday * age                      --- ;    
 * ---    57                  bwht * ageday * age               * race --- ;    
 * ---    58                  bwht * ageday * age       * payer        --- ;    
 * ---    59                  bwht * ageday * age       * payer * race --- ;    
 * ---    60                  bwht * ageday * age * sex                --- ;    
 * ---    61                  bwht * ageday * age * sex         * race --- ;    
 * ---    62                  bwht * ageday * age * sex * payer        --- ;    
 * ---    63                  bwht * ageday * age * sex * payer * race --- ;    
 * ---    64       provider                                            --- ;    
 * ---    65       provider                                     * race --- ;    
 * ---    66       provider                             * payer        --- ;    
 * ---    67       provider                             * payer * race --- ;    
 * ---    68       provider                       * sex                --- ;    
 * ---    69       provider                       * sex         * race --- ;    
 * ---    70       provider                       * sex * payer        --- ;    
 * ---    71       provider                       * sex * payer * race --- ;    
 * ---    72       provider                 * age                      --- ;    
 * ---    73       provider                 * age               * race --- ;    
 * ---    74       provider                 * age       * payer        --- ;    
 * ---    75       provider                 * age       * payer * race --- ;    
 * ---    76       provider                 * age * sex                --- ;    
 * ---    77       provider                 * age * sex         * race --- ;    
 * ---    78       provider                 * age * sex * payer        --- ;    
 * ---    79       provider                 * age * sex * payer * race --- ;    
 * ---    80       provider        * ageday                            --- ;    
 * ---    81       provider        * ageday                     * race --- ;    
 * ---    82       provider        * ageday             * payer        --- ;    
 * ---    83       provider        * ageday             * payer * race --- ;    
 * ---    84       provider        * ageday       * sex                --- ;    
 * ---    85       provider        * ageday       * sex         * race --- ;    
 * ---    86       provider        * ageday       * sex * payer        --- ;    
 * ---    87       provider        * ageday       * sex * payer * race --- ;    
 * ---    88       provider        * ageday * age                      --- ;    
 * ---    89       provider        * ageday * age               * race --- ;    
 * ---    90       provider        * ageday * age       * payer        --- ;    
 * ---    91       provider        * ageday * age       * payer * race --- ;    
 * ---    92       provider        * ageday * age * sex                --- ;    
 * ---    93       provider        * ageday * age * sex         * race --- ;    
 * ---    94       provider        * ageday * age * sex * payer        --- ;    
 * ---    95       provider        * ageday * age * sex * payer * race --- ;    
 * ---    96       provider * bwht                                     --- ;    
 * ---    97       provider * bwht                              * race --- ;    
 * ---    98       provider * bwht                      * payer        --- ;    
 * ---    99       provider * bwht                      * payer * race --- ;    
 * ---   100       provider * bwht                * sex                --- ;    
 * ---   101       provider * bwht                * sex         * race --- ;    
 * ---   102       provider * bwht                * sex * payer        --- ;    
 * ---   103       provider * bwht                * sex * payer * race --- ;    
 * ---   104       provider * bwht          * age                      --- ;    
 * ---   105       provider * bwht          * age               * race --- ;    
 * ---   106       provider * bwht          * age       * payer        --- ;    
 * ---   107       provider * bwht          * age       * payer * race --- ;    
 * ---   108       provider * bwht          * age * sex                --- ;    
 * ---   109       provider * bwht          * age * sex         * race --- ;    
 * ---   110       provider * bwht          * age * sex * payer        --- ;    
 * ---   111       provider * bwht          * age * sex * payer * race --- ;    
 * ---   112       provider * bwht * ageday                            --- ;    
 * ---   113       provider * bwht * ageday                     * race --- ;    
 * ---   114       provider * bwht * ageday             * payer        --- ;    
 * ---   115       provider * bwht * ageday             * payer * race --- ;    
 * ---   116       provider * bwht * ageday       * sex                --- ;    
 * ---   117       provider * bwht * ageday       * sex         * race --- ;    
 * ---   118       provider * bwht * ageday       * sex * payer        --- ;    
 * ---   119       provider * bwht * ageday       * sex * payer * race --- ;    
 * ---   120       provider * bwht * ageday * age                      --- ;    
 * ---   121       provider * bwht * ageday * age               * race --- ;    
 * ---   122       provider * bwht * ageday * age       * payer        --- ;    
 * ---   123       provider * bwht * ageday * age       * payer * race --- ;    
 * ---   124       provider * bwht * ageday * age * sex                --- ;    
 * ---   125       provider * bwht * ageday * age * sex         * race --- ;    
 * ---   126       provider * bwht * ageday * age * sex * payer        --- ;    
 * ---   127       provider * bwht * ageday * age * sex * payer * race --- ;    
 * ---                                                                 --- ;    
 * --- The default TYPELVLP (0,64) will provide an overall             --- :    
 * --- and provider-level totals. If you run stratifications that      --- ;
 * --- include Age and/or Sex, be aware that the numerical             --- ;
 * --- results for non-Age/Sex categories will be incorrect.           --- ;
 * ----------------------------------------------------------------------- ;
%LET TYPELVLP = IN (0,64);                        *<===USER may modify;

* ------------------------------------------------------------------- ;
 * --- NAME SAS DATASET OUTPUT FROM PROGRAM PDI_PROV_OBSERVED.SAS --- ;
 * --- SUMMARY OUTPUT FILE OF OBSERVED PROVIDER RATES.            --- ;
 * ------------------------------------------------------------------ ;
%LET  OUTFILE_PROVOBS  = PDPO_&SUFX.;      *<===USER may modify;
 * ------------------------------------------------------------------ ;
 * --- INDICATE IF A COMMA-DELIMITED FILE SHOULD BE GENERATED FOR --- ;
 * --- EXPORT INTO A SPREADSHEET. 0 = NO, 1 = YES.                --- ;
 * ------------------------------------------------------------------ ;
%LET TXTPOBS=0;                                   *<===USER may modify;

 * ------------------------------------------------------------------ ;
 * --- IF YOU CREATE A COMMA-DELIMITED FILE, SPECIFY THE LOCATION --- ;
 * --- OF THE FILE.                                               --- ;
 * ------------------------------------------------------------------ ;
filename PDTXTPOB "&PATHNAME.\SASData\PDPO_&SUFX..TXT";  *<===USER may modify;

 * ------------------------------------------------------------------ ;           
 * ---       Program : PDI_STRATIFIED Stratified Rates            --- ;           
 * ------------------------------------------------------------------ ;           
libname OUTST "&PATHNAME.\SASData";               *<==USER MUST modify;  
* ------------------------------------------------------------------- ;
 * --- NAME OF SAS DATASET OUTPUT FROM PROGRAM PDI_STRATIFIED     --- ;
 * --- SUMMARY OUTPUT FILE OF PROVIDER RATES BY RISK CATEGORY.    --- ;
 * ------------------------------------------------------------------ ;
%LET  OUTFILE_STRAT = PDSTRAT_&SUFX;              *<===USER may modify;
 * ------------------------------------------------------------------ ;
 * --- INDICATE IF A COMMA-DELIMITED FILE SHOULD BE GENERATED FOR --- ;
 * --- EXPORT INTO A SPREADSHEET. 0 = NO, 1 = YES.                --- ;
 * ------------------------------------------------------------------ ;
%LET TXTSTRAT=0;                                  *<===USER may modify;

 * ------------------------------------------------------------------ ;
 * --- IF YOU CREATE A COMMA-DELIMITED FILE, SPECIFY THE LOCATION --- ;
 * --- OF THE FILE.                                               --- ;
 * ------------------------------------------------------------------ ;
filename PDTXTSTR "&PATHNAME.\SASdata\PDST_&SUFX..TXT";  *<===USER may modify;

* ==================================================================;
* =========== AREA-LEVEL INPATIENT QUALITY INDICATORS ==============;
* ==================================================================;
* ---          Program Inputs: PDI_AREA_OBSERVED.SAS           ---- ;
* ----------------------------------------------------------------- ;
libname OUTAOBS "&PATHNAME.\SASdata";           *<===USER may modify;

 * ---------------------------------------------------------------- ;
 * --- TYPELVLA indicates the levels (or _TYPE_) of             --- ;
 * --- summarization to be kept in the output.                  --- ;
 * ---                                                          --- ;
 * ---  TYPELVLA      stratification                            --- ;
 * ---  --------  -------------------------                     --- ;
 * ---     0      overall                                       --- ;
 * ---     1                           race                     --- ;
 * ---     2                     sex                            --- ;
 * ---     3                     sex * race                     --- ;
 * ---     4               age                                  --- ;
 * ---     5               age *       race                     --- ;
 * ---     6               age * sex                            --- ;
 * ---     7               age * sex * race                     --- ;
 * ---     8       area                                         --- ;
 * ---     9       area  *             race                     --- ;
 * ---    10       area  *       sex                            --- ;
 * ---    11       area  *       sex * race                     --- ;
 * ---    12       area  * age                                  --- ;
 * ---    13       area  * age *       race                     --- ;
 * ---    14       area  * age * sex                            --- ;
 * ---    15       area  * age * sex * race                     --- ;
 * ---                                                          --- ;
 * --- The default TYPELVLA (0,8) will provide an overall       --- :
 * --- total and an area-level total.                           --- ;
 * ---                                                          --- ;
 * ---------------------------------------------------------------- ;
%LET TYPELVLA = IN (0,8);             *<===USER may modify;

* ------------------------------------------------------------------ ;
 * --- NAME OF SAS DATASET OUTPUT FROM PROGRAM PDI_AREA_OBSERVED --- ;
 * --- SUMMARY OUTPUT FILE OF OBSERVED AREA RATES.               --- ;
 * ----------------------------------------------------------------- ;
%LET  OUTFILE_AREAOBS = PDAO_&SUFX;     *<===USER may modify;

 * ----------------------------------------------------------------- ;
 * --- INDICATE IF A COMMA-DELIMITED FILE SHOULD BE GENERATED FOR--- ;
 * --- EXPORT INTO A SPREADSHEET. 0 = NO, 1 = YES.               --- ;
 * ----------------------------------------------------------------- ;
%LET TXTAOBS=0;                                  *<===USER may modify;

 * ----------------------------------------------------------------- ;
 * --- IF YOU CREATE A COMMA-DELIMITED FILE, SPECIFY THE LOCATION -- ;
 * --- OF THE FILE.                                              --- ;
 * ----------------------------------------------------------------- ;
filename PDTXTAOB "&PATHNAME.\SASdata\PDAO_&SUFX..TXT";  *<===USER may modify;

************************** END USER INPUT ************************** ;
