*======================= Program: PDI_PROV_OBSERVED.SAS ======================;
*
*  Title:  Provider Level Observed Rates for AHRQ Pediatric Quality Indicators
*
*  Description:
*     Calculates observed rates for provider level Pediatric Quality Indicators
*     using output from PDI_ALL_MEASURES.sas.
*     Output stratified by HOSPID, AGECAT, SEXCAT, PAYCAT and RACECAT.
*     Variables created by this program are PPPDXX, PPNQXX, OPPDXX, AND OPNQXX.
*
 *  VERSION: SAS QI v2018 (ICD-10 CM/PCS)
 *  RELEASE DATE: JUNE 2018
 *
*=============================================================================;

*PATHNAME specifies the location of the PDI folder which includes 
          Programs, SASdata, and Macros subfolders;
%LET PATHNAME=C:\Pathname\PDI;                        *<==USER MUST modify;
filename CONTROL "&PATHNAME.\Programs\PDI_ALL_CONTROL.SAS"; 

%include CONTROL;

 title2 'PROGRAM: PDI_PROVIDER_OBSERVED';
 title3 'AHRQ PEDIATRIC QUALITY INDICATORS: CALCULATE OBSERVED PROVIDER LEVEL RATES';

* -------------------------------------------------------------- ;
* --- PROVIDER LEVEL MEANS ON PEDIATRIC DATA FILE  ------------- ;
* -------------------------------------------------------------- ;
* -------------------------------------------------------------- ;
* --- PEDIATRIC QUALITY INDICATOR (PDI) NAMING CONVENTION:      --- ;
* --- THE FIRST LETTER IDENTIFIES THE PEDIATRIC QUALITY         --- ;
* --- INDICATOR AS ONE OF THE FOLLOWING:
                (T) NUMERATOR ("TOP") - FROM PDI_ALL_MEASURES
                (P) DENOMINATOR ("POPULATION")
                (O) OBSERVED RATES (T/P)
* --- THE SECOND LETTER IDENTIFIES THE INDICATOR AS A PROVIDER  --- ;
* --- (P) LEVEL INDICATOR.  THE NEXT TWO CHARACTERS ARE ALWAYS  --- ;
* --- 'PD' OR 'NQ'. THE LAST TWO DIGITS ARE THE INDICATOR NUMBER. - ;
* ----------------------------------------------------------------- ;

 proc   Summary data=OUTMSR.&OUTFILE_MEAS.;
 class  HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT;
 var    TPPD01-TPPD03 TPPD05-TPPD13 TPNQ01 TPNQ03 TPPS17;
 output out=&OUTFILE_PROVOBS.
        sum (TPPD01-TPPD03 TPPD05-TPPD13 TPNQ01 TPNQ03 TPPS17)=
        n   (TPPD01-TPPD03 TPPD05-TPPD06 TPPD08-TPPD13 TPNQ01 TPNQ03 TPPS17)=
             PPPD01-PPPD03 PPPD05-PPPD06 PPPD08-PPPD13 PPNQ01 PPNQ03 PPPS17
        mean (TPPD01-TPPD03 TPPD05-TPPD06 TPPD08-TPPD13 TPNQ01 TPNQ03 TPPS17)=
              OPPD01-OPPD03 OPPD05-OPPD06 OPPD08-OPPD13 OPNQ01 OPNQ03 OPPS17;
 run;

 proc   Sort data=&OUTFILE_PROVOBS.;
 by HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT;
 run;

 data   OUTPOBS.&OUTFILE_PROVOBS.;
 set    &OUTFILE_PROVOBS. (where=(_TYPE_ &TYPELVLP));

 array PPPD PPPD01-PPPD03 PPPD05-PPPD06 PPPD08-PPPD13 PPNQ01 PPNQ03 PPPS17;

 do over PPPD;
    if PPPD eq 0 then PPPD = .;
 end;

 label
 TPPD01 = 'PDI 01 Accidental Puncture or Laceration Rate (Numerator)'
 TPPD02 = 'PDI 02 Pressure Ulcer Rate (Numerator)'
 TPPD03 = 'PDI 03 Retained Surgical Item or Unretrieved Device Fragment Count (Numerator)'
 TPPD05 = 'PDI 05 Iatrogenic Pneumothorax Rate (Numerator)'
 TPPD06 = 'PDI 06 RACHS-1 Pediatric Heart Surgery Mortality Rate (Numerator) - Measure not calculated in SAS 2018 QI software'
 TPPD07 = 'PDI 07 RACHS-1 Pediatric Heart Surgery Volume (Numerator) - Measure not calculated in SAS 2018 QI software'
 TPPD08 = 'PDI 08 Perioperative Hemorrhage or Hematoma Rate (Numerator)'
 TPPD09 = 'PDI 09 Postoperative Respiratory Failure Rate (Numerator)'
 TPPD10 = 'PDI 10 Postoperative Sepsis Rate (Numerator)'
 TPPD11 = 'PDI 11 Postoperative Wound Dehiscence Rate (Numerator)'
 TPPD12 = 'PDI 12 Central Venous Catheter-Related Blood Stream Infection Rate (Numerator)'
 TPPD13 = 'PDI 13 Transfusion Reaction Count (Numerator)'
 TPNQ01 = 'NQI 01 Neonatal Iatrogenic Pneumothorax Rate (Numerator)'
 /*TPNQ02 = 'NQI 02 Neonatal Mortality Rate (Numerator)'*/
 TPNQ03 = 'NQI 03 Neonatal Blood Stream Infection Rate (Numerator)'
 TPPS17 = 'PSI 17 Birth Trauma Rate - Injury to Neonate (Numerator)'
 PPPD01 = 'PDI 01 Accidental Puncture or Laceration Rate (Population)'
 PPPD02 = 'PDI 02 Pressure Ulcer Rate (Population)'
 PPPD03 = 'PDI 03 Retained Surgical Item or Unretrieved Device Fragment Count (Population)'
 PPPD05 = 'PDI 05 Iatrogenic Pneumothorax Rate (Population)'
 PPPD06 = 'PDI 06 RACHS-1 Pediatric Heart Surgery Mortality Rate (Population) - Measure not calculated in SAS 2018 QI software'
 PPPD08 = 'PDI 08 Perioperative Hemorrhage or Hematoma Rate (Population)'
 PPPD09 = 'PDI 09 Postoperative Respiratory Failure Rate (Population)'
 PPPD10 = 'PDI 10 Postoperative Sepsis Rate (Population)'
 PPPD11 = 'PDI 11 Postoperative Wound Dehiscence Rate (Population)'
 PPPD12 = 'PDI 12 Central Venous Catheter-Related Blood Stream Infection Rate (Population)'
 PPPD13 = 'PDI 13 Transfusion Reaction Count (Population)'
 PPNQ01 = 'NQI 01 Neonatal Iatrogenic Pneumothorax Rate (Population)'
 /*PPNQ02 = 'NQI 02 Neonatal Mortality Rate (Population)'*/
 PPNQ03 = 'NQI 03 Neonatal Blood Stream Infection Rate (Population)'
 PPPS17 = 'PSI 17 Birth Trauma Rate - Injury to Neonate (Population)'
 OPPD01 = 'PDI 01 Accidental Puncture or Laceration Rate (Observed)'
 OPPD02 = 'PDI 02 Pressure Ulcer Rate (Observed)'
 OPPD03 = 'PDI 03 Retained Surgical Item or Unretrieved Device Fragment Count (Observed)'
 OPPD05 = 'PDI 05 Iatrogenic Pneumothorax Rate (Observed)'
 OPPD06 = 'PDI 06 RACHS-1 Pediatric Heart Surgery Mortality Rate (Observed) - Measure not calculated in SAS 2018 QI software'
 OPPD08 = 'PDI 08 Perioperative Hemorrhage or Hematoma Rate (Observed)'
 OPPD09 = 'PDI 09 Postoperative Respiratory Failure Rate (Observed)'
 OPPD10 = 'PDI 10 Postoperative Sepsis Rate (Observed)'
 OPPD11 = 'PDI 11 Postoperative Wound Dehiscence Rate (Observed)'
 OPPD12 = 'PDI 12 Central Venous Catheter-Related Blood Stream Infection Rate (Observed)'
 OPPD13 = 'PDI 13 Transfusion Reaction Count (Observed)'
 OPNQ01 = 'NQI 01 Neonatal Iatrogenic Pneumothorax Rate (Observed)'
 /*OPNQ02 = 'NQI 02 Neonatal Mortality Rate (Observed)'*/
 OPNQ03 = 'NQI 03 Neonatal Blood Stream Infection Rate (Observed)'
 OPPS17 = 'PSI 17 Birth Trauma Rate - Injury to Neonate (Observed)'
 _TYPE_ = 'STRATIFICATION LEVEL'
;
 DROP _FREQ_ ;

 run;

 * -------------------------------------------------------------- ;
 * --- CONTENTS AND MEANS OF PROVIDER OBSERVED MEANS FILE ------- ;
 * -------------------------------------------------------------- ;

 proc   Contents data=OUTPOBS.&OUTFILE_PROVOBS. position;
 run;

 ***----- TO PRINT VARIABLE LABLES COMMENT (DELETE) "NOLABELS" FROM PROC MEANS STATEMENTS -------***;
proc Means data=OUTPOBS.&OUTFILE_PROVOBS. (WHERE=(_TYPE_ IN (64))) n nmiss min max sum nolabels;
   var TPPD01-TPPD03 TPPD05-TPPD13 TPNQ01 TPNQ03 TPPS17;
   title  'SUMMARY OF PEDIATRIC PROVIDER-LEVEL INDICATOR OVERALL NUMERATOR (SUM) WHEN _TYPE_=64';
run; quit;

proc Means data=OUTPOBS.&OUTFILE_PROVOBS. (WHERE=(_TYPE_ IN (64))) n nmiss min max sum nolabels;
   var PPPD01-PPPD03 PPPD05-PPPD06 PPPD08-PPPD13 PPNQ01 PPNQ03 PPPS17 ;
   title  'SUMMARY OF PEDIATRIC PROVIDER-LEVEL INDICATOR OVERALL DENOMINATOR (SUM) WHEN _TYPE_=64';
run; quit;

proc Means data=OUTPOBS.&OUTFILE_PROVOBS. (WHERE=(_TYPE_ IN (64))) n nmiss min max mean nolabels;
   var OPPD01-OPPD03 OPPD05-OPPD06 OPPD08-OPPD13 OPNQ01 OPNQ03 OPPS17;
   title  'SUMMARY OF PEDIATRIC PROVIDER-LEVEL OBSERVED INDICATOR AVERAGE RATES(MEAN) WHEN _TYPE_=64';
run; quit;

* -------------------------------------------------------------- ;
* --- PRINT PROVIDER OBSERVED MEANS FILE TO SAS OUTPUT  -------- ;
* -------------------------------------------------------------- ;

 %MACRO PRT2;

 %IF &PRINT. = 1 %THEN %DO;

 %MACRO PRT(PD,TEXT,VOLUME);

 proc   Print data=OUTPOBS.&OUTFILE_PROVOBS. label SPLIT='*';
 %IF &VOLUME=0 %THEN %DO;
 var    HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT TP&PD. PP&PD. OP&PD. ;
 label HOSPID  = "HOSPID"
       BWHTCAT = "BWHTCAT"
       AGEDCAT = "AGEDCAT"
       PAGECAT = "PAGECAT"
       SEXCAT  = "SEXCAT"
       PAYCAT  = "PAYCAT"
       RACECAT = "RACECAT"
       TP&PD.   = "TP&PD.*(Numerator)"
       PP&PD.   = "PP&PD.*(Denominator)"
       OP&PD.   = "OP&PD.*(Observed)"
       ;
 format BWHTCAT BWHTCAT.
        AGEDCAT AGEDCAT.
        PAGECAT PAGECAT.
        SEXCAT SEXCAT.
        PAYCAT PAYCAT.
        RACECAT RACECAT.
        TP&PD. PP&PD. 13.0 OP&PD. 8.6;
 %END;
 %ELSE %DO;
 var    HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT TP&PD.  ;
 label HOSPID  = "HOSPID"
       BWHTCAT = "BWHTCAT"
       AGEDCAT = "AGEDCAT"
       PAGECAT = "PAGECAT"
       SEXCAT  = "SEXCAT"
       PAYCAT  = "PAYCAT"
       RACECAT = "RACECAT"
       TP&PD.   = "TP&PD.*(Numerator)"
       ;
 format BWHTCAT BWHTCAT.
        AGEDCAT AGEDCAT.
        PAGECAT PAGECAT.
        SEXCAT SEXCAT.
        PAYCAT PAYCAT.
        RACECAT RACECAT.
        TP&PD. 13.0;
 %END;
 title4 "Indicator &PD.: &TEXT";

 run;

 %MEND PRT;

 %PRT(PD01,Accidental Puncture or Laceration Rate,0);
 %PRT(PD02,Pressure Ulcer Rate,0);
 %PRT(PD03,Retained Surgical Item or Unretrieved Device Fragment Count,0);
 %PRT(PD05,Iatrogenic Pneumothorax Rate,0);
 %PRT(PD06,RACHS-1 Pediatric Heart Surgery Mortality Rate - Measure not calculated in SAS 2018 QI software,0);
 %PRT(PD07,RACHS-1 Pediatric Heart Surgery Volume - Measure not calculated in SAS 2018 QI  software,1);
 %PRT(PD08,Perioperative Hemorrhage or Hematoma Rate,0);
 %PRT(PD09,Postoperative Respiratory Failure Rate,0);
 %PRT(PD10,Postoperative Sepsis Rate,0);
 %PRT(PD11,Postoperative Wound Dehiscence Rate,0);
 %PRT(PD12,Central Venous Catheter-Related Blood Stream Infection Rate,0);
 %PRT(PD13,Transfusion Reaction Count,0);
 %PRT(NQ01,Neonatal Iatrogenic Pneumothorax Rate,0);
 /*%PRT(NQ02,Neonatal Mortality Rate,0);*/
 %PRT(NQ03,Neonatal Blood Stream Infection Rate,0);
 %PRT(PS17,Birth Trauma Rate - Injury to Neonate,0);

 %END;

 %MEND PRT2;

 %PRT2;


* -------------------------------------------------------------- ;
* --- WRITE SAS OUTPUT DATA SET TO COMMA-DELIMITED TEXT FILE --- ;
* --- FOR EXPORT INTO SPREADSHEETS ----------------------------- ;
* -------------------------------------------------------------- ;

 %MACRO TEXTP1;

 %if &TXTPOBS. = 1  %then %do;

    data _NULL_;
 set  OUTPOBS.&OUTFILE_PROVOBS.;
 file  PDTXTPOB lrecl=2000 ;
 if _N_=1 then do;
  put "Hosp Id" "," "BWht" "," "AgeD" "," "Age"  "," "Sex"  "," "Payer" "," "Race" "," "Type" ","
 "TPPD01" "," "TPPD02" "," "TPPD03" "," 
 "TPPD05" "," "TPPD06" "," "TPPD07" "," "TPPD08" ","
 "TPPD09" "," "TPPD10" "," "TPPD11" "," "TPPD12" ","
 "TPPD13" "," "TPNQ01" "," "TPNQ03" "," "TPPS17" "," 
 "PPPD01" "," "PPPD02" "," "PPPD03" "," 
 "PPPD05" "," "PPPD06" ","              "PPPD08" ","
 "PPPD09" "," "PPPD10" "," "PPPD11" "," "PPPD12" ","
 "PPPD13" "," "PPNQ01" "," "PPNQ03" "," "PPPS17" "," 
 "OPPD01" "," "OPPD02" "," "OPPD03" "," 
 "OPPD05" "," "OPPD06" ","              "OPPD08" ","
 "OPPD09" "," "OPPD10" "," "OPPD11" "," "OPPD12" ","
 "OPPD13" "," "OPNQ01" "," "OPNQ03" "," "OPPS17" 
 ;
 end;
 put HOSPID 13. "," BWHTCAT 3. "," AGEDCAT 3. "," PAGECAT 3. "," SEXCAT 3. "," PAYCAT 3. "," RACECAT 3. "," _TYPE_ 2.  ","
 (TPPD01-TPPD03 TPPD05-TPPD13 TPNQ01 TPNQ03 TPPS17) (7.0 ",")
  ","
 (PPPD01-PPPD03 PPPD05-PPPD06 PPPD08-PPPD13 PPNQ01 PPNQ03 PPPS17) (13.2 ",")
 ","
 (OPPD01-OPPD03 OPPD05-OPPD06 OPPD08-OPPD13 OPNQ01 OPNQ03 OPPS17) (12.10 ",")
 ;
 run;

 %END;

 %MEND TEXTP1;

 %TEXTP1;
