*======================PROGRAM: PQI09_ALL_FORMATS.SAS =========================;
 *
 * DESCRIPTION: Creates format library for AHRQ Patient Quality Indicator 09; 
 *  VERSION: SAS QI v2018 (ICD-10 CM/PCS)
 * RELEASE DATE: JUNE 2018
 * 
 *============================================================================;
 *PATHNAME specifies the location of the PQI09 folder which includes the
     Programs, Macros, and SASdata subfolders; 
 %LET  PATHNAME=C:\PATHNAME\PQI09;         *<===USER MUST modify; 

 filename CONTROL '&PATHNAME.\Programs\PQI09_ALL_CONTROL.SAS';
 %INCLUDE CONTROL;

 proc format LIBRARY=LIBRARY;

/* FORMAT FOR Low birth weight (<2,500 grams) diagnosis codes */
Value $ACSLBWD
"P0501" = '1' /*Newborn light for gestational age, less than 500 grams */
"P0502" = '1' /*Newborn light for gestational age, 500-749 grams */
"P0503" = '1' /*Newborn light for gestational age, 750-999 grams */
"P0504" = '1' /*Newborn light for gestational age, 1000-1249 grams */
"P0505" = '1' /*Newborn light for gestational age, 1250-1499 grams */
"P0506" = '1' /*Newborn light for gestational age, 1500-1749 grams */
"P0507" = '1' /*Newborn light for gestational age, 1750-1999 grams */
"P0508" = '1' /*Newborn light for gestational age, 2000-2499 grams */
"P0511" = '1' /*Newborn small for gestational age, less than 500 grams */
"P0512" = '1' /*Newborn small for gestational age, 500-749 grams */
"P0513" = '1' /*Newborn small for gestational age, 750-999 grams */
"P0514" = '1' /*Newborn small for gestational age, 1000-1249 grams */
"P0515" = '1' /*Newborn small for gestational age, 1250-1499 grams */
"P0516" = '1' /*Newborn small for gestational age, 1500-1749 grams */
"P0517" = '1' /*Newborn small for gestational age, 1750-1999 grams */
"P0518" = '1' /*Newborn small for gestational age, 2000-2499 grams */
"P0700" = '1' /*Extremely low birth weight newborn, unspecified weight */
"P0701" = '1' /*Extremely low birth weight newborn, less than 500 grams */
"P0702" = '1' /*Extremely low birth weight newborn, 500-749 grams */
"P0703" = '1' /*Extremely low birth weight newborn, 750-999 grams */
"P0710" = '1' /*Other low birth weight newborn, unspecified weight */
"P0714" = '1' /*Other low birth weight newborn, 1000-1249 grams */
"P0715" = '1' /*Other low birth weight newborn, 1250-1499 grams */
"P0716" = '1' /*Other low birth weight newborn, 1500-1749 grams */
"P0717" = '1' /*Other low birth weight newborn, 1750-1999 grams */
"P0718" = '1' /*Other low birth weight newborn, 2000-2499 grams */
OTHER = '0'
;

/* FORMAT FOR AGE STRATIFIERS */
Value AGEFMT
5  - 9  = 2
10  - 14  = 3
15  - 17  = 4
18  - 24  = 5
25  - 29  = 6
30  - 34  = 7
35  - 39  = 8
40  - 44  = 9
45  - 49  = 10
50  - 54  = 11
55  - 59  = 12
60  - 64  = 13
65  - 69  = 14
70  - 74  = 15
75  - 79  = 16
80  - 84  = 17
85  - HIGH  = 18
LOW  - 4  = 1
;

/* FORMAT FOR Out-of-hospital live birth diagnosis codes */
Value $LIVEB2D
"Z381" = '1' /*Single liveborninfant, bornoutsidehospital */
"Z384" = '1' /*Twin liveborninfant, bornoutsidehospital */
"Z387" = '1' /*Other multipleliveborn infant,born outsidehospital */
OTHER = '0'
;

/* FORMAT FOR In-hospital live birth diagnosis codes */
Value $LIVEBND
"Z3800" = '1' /*Single liveborn infant, delivered vaginally */
"Z3801" = '1' /*Single liveborn infant, delivered by cesarean */
"Z3830" = '1' /*Twin liveborn infant, delivered vaginally */
"Z3831" = '1' /*Twin liveborn infant, delivered by cesarean */
"Z3861" = '1' /*Triplet liveborn infant, delivered vaginally */
"Z3862" = '1' /*Triplet liveborn infant, delivered by cesarean */
"Z3863" = '1' /*Quadruplet liveborn infant, delivered vaginally */
"Z3864" = '1' /*Quadruplet liveborn infant, delivered by cesarean */
"Z3865" = '1' /*Quintuplet liveborn infant, delivered vaginally */
"Z3866" = '1' /*Quintuplet liveborn infant, delivered by cesarean */
"Z3868" = '1' /*Other multiple liveborn infant, delivered vaginally */
"Z3869" = '1' /*Other multiple liveborn infant, delivered by cesarean */
OTHER = '0'
;

/* FORMAT FOR Pediatric population categories */
Value POPCAT
1 = '0 to 4' /*Population Category 0 To 4 */
2 = '5 to 9' /*Population Category 5 To 9 */
3 = '10 to 14' /*Population Category 10 To 14 */
4 = '15 to 17' /*Population Category 15 To 17 */
;

/* FORMAT FOR Race/ethnicity categories */
Value RACECAT
1 = 'White' /*White */
2 = 'Black' /*Black */
3 = 'Hispanic' /*Hispanic */
4 = 'Asian and NH/PI' /*Asian and NH/PI */
5 = 'Amer Indian/AN' /*American Indian /AN */
6 = 'Other' /*Other */
;

/* FORMAT FOR Sex categories */
Value SEXCAT
1 = 'Male' /*Male */
2 = 'Female' /*Female */
;

run;
