*======================PROGRAM: PSI17_ALL_FORMATS.SAS =========================;
 *
 * DESCRIPTION: Creates format library for AHRQ Patient Safety Indicator 17; 
 *  VERSION: SAS QI v2018 (ICD-10 CM/PCS)
 * RELEASE DATE: JUNE 2018
 * 
 *============================================================================;
 *PATHNAME specifies the location of the PSI17 folder which includes the
     Programs, Macros, and SASdata subfolders; 
 %LET  PATHNAME=C:\PATHNAME\PSI17;         *<===USER MUST modify; 

 filename CONTROL '&PATHNAME.\Programs\PSI17_ALL_CONTROL.SAS';
 %INCLUDE CONTROL;

 proc format LIBRARY=LIBRARY;

/* FORMAT FOR AGE STRATIFIERS */
Value AGEFMT
LOW  - 4  = 1
5  - 9  = 2
10  - 14  = 3
15  - 17  = 4
18  - 24  = 5
25  - 29  = 6
30  - 34  = 7
35  - 39  = 8
40  - 44  = 9
45  - 49  = 10
50  - 54  = 11
55  - 59  = 12
60  - 64  = 13
65  - 69  = 14
70  - 74  = 15
75  - 79  = 16
80  - 84  = 17
85  - HIGH  = 18
;

/* FORMAT FOR Birth trauma diagnosis codes */
Value $BIRTHID
"P100" = '1' /*Subdural hemorrhage due to birth injury */
"P101" = '1' /*Cerebral hemorrhage due to birth injury */
"P102" = '1' /*Intraventricular hemorrhage due to birth injury */
"P103" = '1' /*Subarachnoid hemorrhage due to birth injury */
"P104" = '1' /*Tentorial tear due to birth injury */
"P108" = '1' /*Other intracranial lacerations and hemorrhages due to birth injury */
"P109" = '1' /*Unspecified intracranial laceration and hemorrhage due to birth injury */
"P110" = '1' /*Cerebral edema due to birth injury */
"P111" = '1' /*Other specified brain damage due to birth injury */
"P112" = '1' /*Unspecified brain damage due to birth injury */
"P113" = '1' /*Birth injury to facial nerve */
"P114" = '1' /*Birth injury to other cranial nerves */
"P115" = '1' /*Birth injury to spine and spinal cord */
"P119" = '1' /*Birth injury to central nervous system, unspecified */
"P122" = '1' /*Epicranial subaponeurotic hemorrhage due to birth injury */
"P130" = '1' /*Fracture of skull due to birth injury */
"P131" = '1' /*Other birth injuries to skull */
"P132" = '1' /*Birth injury to femur */
"P133" = '1' /*Birth injury to other long bones */
"P138" = '1' /*Birth injuries to other parts of skeleton */
"P139" = '1' /*Birth injury to skeleton, unspecified */
"P142" = '1' /*Phrenic nerve paralysis due to birth injury */
"P148" = '1' /*Birth injuries to other parts of peripheral nervous system */
"P149" = '1' /*Birth injury to peripheral nervous system, unspecified */
"P150" = '1' /*Birth injury to liver */
"P151" = '1' /*Birth injury to spleen */
"P152" = '1' /*Sternomastoid injury due to birth injury */
"P153" = '1' /*Birth injury to eye */
"P154" = '1' /*Birth injury to face */
"P155" = '1' /*Birth injury to external genitalia */
"P156" = '1' /*Subcutaneous fat necrosis due to birth injury */
"P158" = '1' /*Other specified birth injuries */
OTHER = '0'
;

/* FORMAT FOR Birth weight categories */
Value BWHTCAT
0 = 'NA' /*Unknown */
1 = '0 TO 499g' /*Birthweight less than 499g */
2 = '500 TO 749g' /*Birthweight 500 to 749g */
3 = '750 TO 999g' /*Birthweight 750 to 999g */
4 = '1000 TO 1249g' /*Birthweight 1000 to 1249 */
5 = '1250 TO 1499g' /*Birthweight 1250 to 1499 */
6 = '1500 TO 1749g' /*Birthweight 1500 to 1749 */
7 = '1750 TO 1999g' /*Birthweight 1740 to 1999 */
8 = '2000 TO 2499g' /*Birthweight 2000 to 24999 */
9 = '2500g or more' /*Birthweight 2500 or more. */
;

/* FORMAT FOR Out-of-hospital live birth diagnosis codes */
Value $LIVEB2D
"Z381" = '1' /*Single liveborninfant, bornoutsidehospital */
"Z384" = '1' /*Twin liveborninfant, bornoutsidehospital */
"Z387" = '1' /*Other multipleliveborn infant,born outsidehospital */
OTHER = '0'
;

/* FORMAT FOR In-hospital live birth diagnosis codes */
Value $LIVEBND
"Z3800" = '1' /*Single liveborn infant, delivered vaginally */
"Z3801" = '1' /*Single liveborn infant, delivered by cesarean */
"Z3830" = '1' /*Twin liveborn infant, delivered vaginally */
"Z3831" = '1' /*Twin liveborn infant, delivered by cesarean */
"Z3861" = '1' /*Triplet liveborn infant, delivered vaginally */
"Z3862" = '1' /*Triplet liveborn infant, delivered by cesarean */
"Z3863" = '1' /*Quadruplet liveborn infant, delivered vaginally */
"Z3864" = '1' /*Quadruplet liveborn infant, delivered by cesarean */
"Z3865" = '1' /*Quintuplet liveborn infant, delivered vaginally */
"Z3866" = '1' /*Quintuplet liveborn infant, delivered by cesarean */
"Z3868" = '1' /*Other multiple liveborn infant, delivered vaginally */
"Z3869" = '1' /*Other multiple liveborn infant, delivered by cesarean */
OTHER = '0'
;

/* FORMAT FOR ICD10 Diagnosis */
Value $LW1000G
"P0503" = '1' /*Newborn light for gestational age, 750-999 grams */
"P0513" = '1' /*Newborn small for gestational age, 750-999 grams */
"P0703" = '1' /*Extremely low birth weight newborn, 750-999 grams */
OTHER = '0'
;

/* FORMAT FOR Birth weight 1,000 to 1,249 grams diagnosis codes (Category 4) */
Value $LW1250G
"P0504" = '1' /*Newborn light for gestational age, 1000-1249 grams */
"P0514" = '1' /*Newborn small for gestational age, 1000-1249 grams */
"P0714" = '1' /*Other low birth weight newborn, 1000-1249 grams */
OTHER = '0'
;

/* FORMAT FOR Birth weight 1,250 to 1,499 grams diagnosis codes (Category 5) */
Value $LW1500G
"P0505" = '1' /*Newborn light for gestational age, 1250-1499 grams */
"P0515" = '1' /*Newborn small for gestational age, 1250-1499 grams */
"P0715" = '1' /*Other low birth weight newborn, 1250-1499 grams */
OTHER = '0'
;

/* FORMAT FOR Birth weight 1,500 to 1,749 grams diagnosis codes (Category 6) */
Value $LW1750G
"P0506" = '1' /*Newborn light for gestational age, 1500-1749 grams */
"P0516" = '1' /*Newborn small for gestational age, 1500-1749 grams */
"P0716" = '1' /*Other low birth weight newborn, 1500-1749 grams */
OTHER = '0'
;

/* FORMAT FOR Birth weight 1,750 to 1,999 grams diagnosis codes (Category 7) */
Value $LW2000G
"P0507" = '1' /*Newborn light for gestational age, 1750-1999 grams */
"P0517" = '1' /*Newborn small for gestational age, 1750-1999 grams */
"P0717" = '1' /*Other low birth weight newborn, 1750-1999 grams */
OTHER = '0'
;

/* FORMAT FOR Birth weight 2,000 to 2,499 grams diagnosis codes (Category 8) */
Value $LW2500G
"P0508" = '1' /*Newborn light for gestational age, 2000-2499 grams */
"P0518" = '1' /*Newborn small for gestational age, 2000-2499 grams */
"P0718" = '1' /*Other low birth weight newborn, 2000-2499 grams */
OTHER = '0'
;

/* FORMAT FOR Birth weight less than 500 grams diagnosis codes (Category 1) */
Value $LW500G
"P0501" = '1' /*Newborn light for gestational age, less than 500 grams */
"P0511" = '1' /*Newborn small for gestational age, less than 500 grams */
"P0701" = '1' /*Extremely low birth weight newborn, less than 500 grams */
OTHER = '0'
;

/* FORMAT FOR Birth weight 500 to 749 grams diagnosis codes (Category 2) */
Value $LW750G
"P0502" = '1' /*Newborn light for gestational age, 500-749 grams */
"P0512" = '1' /*Newborn small for gestational age, 500-749 grams */
"P0702" = '1' /*Extremely low birth weight newborn, 500-749 grams */
OTHER = '0'
;

/* FORMAT FOR Osteogenesis imperfecta diagnosis codes */
Value $OSTEOID
"Q780" = '1' /*Osteogenesisimperfecta */
OTHER = '0'
;

/* FORMAT FOR Pediatric age group categories */
Value PAGECAT
1 = '<1'
2 = '1 TO 2'
3 = '3 TO 5'
4 = '6 TO 12'
5 = '13 TO 17'
;

/* FORMAT FOR Primary expected payer categories */
Value PAYCAT
1 = 'Medicare' /*Medicare */
2 = 'Medicaid' /*Medicaid */
3 = 'Private' /*Private */
4 = 'Self Pay' /*Self Pay */
5 = 'No Charge' /*No Charge */
6 = 'Other' /*Other */
;

/* FORMAT FOR Pediatric population categories */
Value POPCAT
1 = '0 to 4' /*Population Category 0 To 4 */
2 = '5 to 9' /*Population Category 5 To 9 */
3 = '10 to 14' /*Population Category 10 To 14 */
4 = '15 to 17' /*Population Category 15 To 17 */
;

/* FORMAT FOR Preterm infant with birth weight less than 2000g diagnosis codes */
Value $PRETEID
"P0700" = '1' /*Extremely low birth weight newborn, unspecified weight */
"P0701" = '1' /*Extremely low birth weight newborn, less than 500 grams */
"P0702" = '1' /*Extremely low birth weight newborn, 500-749 grams */
"P0703" = '1' /*Extremely low birth weight newborn, 750-999 grams */
"P0710" = '1' /*Other low birth weight newborn, unspecified weight */
"P0714" = '1' /*Other low birth weight newborn, 1000-1249 grams */
"P0715" = '1' /*Other low birth weight newborn, 1250-1499 grams */
"P0716" = '1' /*Other low birth weight newborn, 1500-1749 grams */
"P0717" = '1' /*Other low birth weight newborn, 1750-1999 grams */
OTHER = '0'
;

/* FORMAT FOR Race/ethnicity categories */
Value RACECAT
1 = 'White' /*White */
2 = 'Black' /*Black */
3 = 'Hispanic' /*Hispanic */
4 = 'Asian and NH/PI' /*Asian and NH/PI */
5 = 'Amer Indian/AN' /*American Indian /AN */
6 = 'Other' /*Other */
;

/* FORMAT FOR Sex categories */
Value SEXCAT
1 = 'Male' /*Male */
2 = 'Female' /*Female */
;

run;
