*======================PROGRAM: IQI_ALL_FORMATS.SAS =========================;
 *
 * DESCRIPTION: Creates format library for AHRQ Inpatient Quality Indicators; 
 *  VERSION: SAS QI v2018 (ICD-10 CM/PCS)
 * RELEASE DATE: JUNE 2018
 * 
 *============================================================================;
 *PATHNAME specifies the location of the IQI folder which includes the
     Programs, Macros, and SASdata subfolders; 
 %LET  PATHNAME=C:\PATHNAME\IQI;         *<===USER MUST modify; 

 filename CONTROL "&PATHNAME.\Programs\IQI_ALL_CONTROL.SAS";
 %INCLUDE CONTROL;

 *SAS option to print program text to log disabled to avoid filling log window;
 %let orgoptionValue = %sysfunc(getoption(source));  
 option nosource; 

 proc format LIBRARY=LIBRARY;

/* FORMAT FOR Age Category */
Value AGECAT
0 = '00 to 17' /*Newborns to Age 17 */
1 = '18 to 39' /*Age 18 to 39 */
2 = '40 to 64' /*Age 40 to 64 */
3 = '65 to 74' /*Age 65 to 74 */
4 = '75+' /*Age 75+ */
;

/* FORMAT FOR Craniotomy MS-DRG codes */
Value $CRANIO2G
"020" = '1' /*INTRACRANIAL VASCULAR PROCEDURES WITH PDX HEMORRHAGE WITH MCC */
"021" = '1' /*INTRACRANIAL VASCULAR PROCEDURES WITH PDX HEMORRHAGE WITH CC */
"022" = '1' /*INTRACRANIAL VASCULAR PROCEDURES WITH PDX HEMORRHAGE WITHOUT CC/MCC */
"023" = '1' /*CRANIOTOMY WITH MAJOR DEVICE IMPLANT OR ACUTE COMPLEX CNS PDX WITH MCC OR CHEMOTHERAPY IMPLANT */
"024" = '1' /*CRANIOTOMY WITH MAJOR DEVICE IMPLANT OR ACUTE COMPLEX CNS PDX WITHOUT MCC */
"025" = '1' /*CRANIOTOMY AND ENDOVASCULAR INTRACRANIAL PROCEDURES WITH MCC */
"026" = '1' /*CRANIOTOMY AND ENDOVASCULAR INTRACRANIAL PROCEDURES WITH CC */
"027" = '1' /*CRANIOTOMY AND ENDOVASCULAR INTRACRANIAL PROCEDURES WITHOUT CC/MCC */
"031" = '1' /*VENTRICULAR SHUNT PROCEDURES WITH MCC */
"032" = '1' /*VENTRICULAR SHUNT PROCEDURES WITH CC */
"033" = '1' /*VENTRICULAR SHUNT PROCEDURES WITHOUT CC/MCC */
OTHER = '0'
;

/* FORMAT FOR Outcome of delivery diagnosis codes */
Value $DELOCMD
"Z370" = '1' /*Single live birth */
"Z371" = '1' /*Single stillbirth */
"Z372" = '1' /*Twins, both liveborn */
"Z373" = '1' /*Twins, one liveborn and one stillborn */
"Z374" = '1' /*Twins, both stillborn */
"Z3750" = '1' /*Multiple births, unspecified, all liveborn */
"Z3751" = '1' /*Triplets, all liveborn */
"Z3752" = '1' /*Quadruplets, all liveborn */
"Z3753" = '1' /*Quintuplets, all liveborn */
"Z3754" = '1' /*Sextuplets, all liveborn */
"Z3759" = '1' /*Other multiple births, all liveborn */
"Z3760" = '1' /*Multiple births, unspecified, some liveborn */
"Z3761" = '1' /*Triplets, some liveborn */
"Z3762" = '1' /*Quadruplets, some liveborn */
"Z3763" = '1' /*Quintuplets, some liveborn */
"Z3764" = '1' /*Sextuplets, some liveborn */
"Z3769" = '1' /*Other multiple births, some liveborn */
"Z377" = '1' /*Other multiple births, all stillborn */
"Z379" = '1' /*Outcome of delivery, unspecified */
OTHER = '0'
;

/* FORMAT FOR Esophageal varices with bleeding */
Value $FTR6GV
"I8511" = '1' /*Secondary esophageal varices with bleeding */
OTHER = '0'
;

/* FORMAT FOR Qualifying diagnoses associated with a diagnosis of esophageal varicies with bleeding */
Value $FTR6QD
"B180" = '1' /*Chronic viral hepatitis B with delta-agent */
"B181" = '1' /*Chronic viral hepatitis B without delta-agent */
"B182" = '1' /*Chronic viral hepatitis C */
"B188" = '1' /*Other chronic viral hepatitis */
"B189" = '1' /*Chronic viral hepatitis, unspecified */
"B190" = '1' /*Unspecified viral hepatitis with hepatic coma */
"B1910" = '1' /*Unspecified viral hepatitis B without hepatic coma */
"B1911" = '1' /*Unspecified viral hepatitis B with hepatic coma */
"B1920" = '1' /*Unspecified viral hepatitis C without hepatic coma */
"B1921" = '1' /*Unspecified viral hepatitis C with hepatic coma */
"B199" = '1' /*Unspecified viral hepatitis without hepatic coma */
"B651" = '1' /*Schistosomiasis due to Schistosoma mansoni [intestinal schistosomiasis] */
"B652" = '1' /*Schistosomiasis due to Schistosoma japonicum */
"B658" = '1' /*Other schistosomiasis */
"B659" = '1' /*Schistosomiasis, unspecified */
"C220" = '1' /*Liver cell carcinoma */
"C221" = '1' /*Intrahepatic bile duct carcinoma */
"C222" = '1' /*Hepatoblastoma */
"C223" = '1' /*Angiosarcoma of liver */
"C224" = '1' /*Other sarcomas of liver */
"C227" = '1' /*Other specified carcinomas of liver */
"C228" = '1' /*Malignant neoplasm of liver, primary, unspecified as to type */
"C229" = '1' /*Malignant neoplasm of liver, not specified as primary or secondary */
"C787" = '1' /*Secondary malignant neoplasm of liver and intrahepatic bile duct */
"C7B02" = '1' /*Secondary carcinoid tumors of liver */
"C861" = '1' /*Hepatosplenic T-cell lymphoma */
"D015" = '1' /*Carcinoma in situ of liver, gallbladder and bile ducts */
"D376" = '1' /*Neoplasm of uncertain behavior of liver, gallbladder and bile ducts */
"I81" = '1' /*Portal vein thrombosis */
"I820" = '1' /*Budd-Chiari syndrome */
"K7011" = '1' /*Alcoholic hepatitis with ascites */
"K702" = '1' /*Alcoholic fibrosis and sclerosis of liver */
"K7030" = '1' /*Alcoholic cirrhosis of liver without ascites */
"K7031" = '1' /*Alcoholic cirrhosis of liver with ascites */
"K7040" = '1' /*Alcoholic hepatic failure without coma */
"K7041" = '1' /*Alcoholic hepatic failure with coma */
"K709" = '1' /*Alcoholic liver disease, unspecified */
"K710" = '1' /*Toxic liver disease with cholestasis */
"K7110" = '1' /*Toxic liver disease with hepatic necrosis, without coma */
"K7111" = '1' /*Toxic liver disease with hepatic necrosis, with coma */
"K712" = '1' /*Toxic liver disease with acute hepatitis */
"K713" = '1' /*Toxic liver disease with chronic persistent hepatitis */
"K714" = '1' /*Toxic liver disease with chronic lobular hepatitis */
"K7150" = '1' /*Toxic liver disease with chronic active hepatitis without ascites */
"K7151" = '1' /*Toxic liver disease with chronic active hepatitis with ascites */
"K716" = '1' /*Toxic liver disease with hepatitis, not elsewhere classified */
"K717" = '1' /*Toxic liver disease with fibrosis and cirrhosis of liver */
"K718" = '1' /*Toxic liver disease with other disorders of liver */
"K719" = '1' /*Toxic liver disease, unspecified */
"K7200" = '1' /*Acute and subacute hepatic failure without coma */
"K7201" = '1' /*Acute and subacute hepatic failure with coma */
"K7210" = '1' /*Chronic hepatic failure without coma */
"K7211" = '1' /*Chronic hepatic failure with coma */
"K7290" = '1' /*Hepatic failure, unspecified without coma */
"K7291" = '1' /*Hepatic failure, unspecified with coma */
"K730" = '1' /*Chronic persistent hepatitis, not elsewhere classified */
"K731" = '1' /*Chronic lobular hepatitis, not elsewhere classified */
"K732" = '1' /*Chronic active hepatitis, not elsewhere classified */
"K738" = '1' /*Other chronic hepatitis, not elsewhere classified */
"K739" = '1' /*Chronic hepatitis, unspecified */
"K740" = '1' /*Hepatic fibrosis */
"K741" = '1' /*Hepatic sclerosis */
"K742" = '1' /*Hepatic fibrosis with hepatic sclerosis */
"K743" = '1' /*Primary biliary cirrhosis */
"K744" = '1' /*Secondary biliary cirrhosis */
"K745" = '1' /*Biliary cirrhosis, unspecified */
"K7460" = '1' /*Unspecified cirrhosis of liver */
"K7469" = '1' /*Other cirrhosis of liver */
"K751" = '1' /*Phlebitis of portal vein */
"K752" = '1' /*Nonspecific reactive hepatitis */
"K753" = '1' /*Granulomatous hepatitis, not elsewhere classified */
"K754" = '1' /*Autoimmune hepatitis */
"K7581" = '1' /*Nonalcoholic steatohepatitis (NASH) */
"K7589" = '1' /*Other specified inflammatory liver diseases */
"K759" = '1' /*Inflammatory liver disease, unspecified */
"K760" = '1' /*Fatty (change of) liver, not elsewhere classified */
"K761" = '1' /*Chronic passive congestion of liver */
"K762" = '1' /*Central hemorrhagic necrosis of liver */
"K763" = '1' /*Infarction of liver */
"K765" = '1' /*Hepatic veno-occlusive disease */
"K766" = '1' /*Portal hypertension */
"K767" = '1' /*Hepatorenal syndrome */
"K7681" = '1' /*Hepatopulmonary syndrome */
"K7689" = '1' /*Other specified diseases of liver */
"K769" = '1' /*Liver disease, unspecified */
"K77" = '1' /*Liver disorders in diseases classified elsewhere */
"K830" = '1' /*Cholangitis */
"K9182" = '1' /*Postprocedural hepatic failure */
"Q265" = '1' /*Anomalous portal venous connection */
"Q266" = '1' /*Portal vein-hepatic artery fistula */
"T8642" = '1' /*Liver transplant failure */
"T8643" = '1' /*Liver transplant infection */
"T8649" = '1' /*Other complications of liver transplant */
OTHER = '0'
;

/* FORMAT FOR Heart transplant procedure codes */
Value $HEARTTRP
"02HA0QZ" = '1' /*Insertion of Implantable Heart Assist System into Heart, Open Approach */
"02HA0RJ" = '1' /*Insertion of Short-term External Heart Assist System into Heart, Intraoperative, Open Approach */
"02HA0RS" = '1' /*Insertion of Biventricular Short-term External Heart Assist System into Heart, Open Approach */
"02HA0RZ" = '1' /*Insertion of Short-term External Heart Assist System into Heart, Open Approach */
"02HA3QZ" = '1' /*Insertion of Implantable Heart Assist System into Heart, Percutaneous Approach */
"02HA3RJ" = '1' /*Insertion of Short-term External Heart Assist System into Heart, Intraoperative, Percutaneous Approach */
"02HA3RS" = '1' /*Insertion of Biventricular Short-term External Heart Assist System into Heart, Percutaneous Approach */
"02HA3RZ" = '1' /*Insertion of Short-term External Heart Assist System into Heart, Percutaneous Approach */
"02HA4QZ" = '1' /*Insertion of Implantable Heart Assist System into Heart, Percutaneous Endoscopic Approach */
"02HA4RJ" = '1' /*Insertion of Short-term External Heart Assist System into Heart, Intraoperative, Percutaneous Endoscopic Approach */
"02HA4RS" = '1' /*Insertion of Biventricular Short-term External Heart Assist System into Heart, Percutaneous Endoscopic Approach */
"02HA4RZ" = '1' /*Insertion of Short-term External Heart Assist System into Heart, Percutaneous Endoscopic Approach */
"02YA0Z0" = '1' /*Transplantation of Heart, Allogeneic, Open Approach */
"02YA0Z1" = '1' /*Transplantation of Heart, Syngeneic, Open Approach */
"02YA0Z2" = '1' /*Transplantation of Heart, Zooplastic, Open Approach */
"5A02116" = '1' /*Assistance with Cardiac Output using Other Pump, Intermittent */
"5A02216" = '1' /*Assistance with Cardiac Output using Other Pump, Continuous */
OTHER = '0'
;

/* FORMAT FOR Head trauma diagnosis codes */
Value $HTRAUID
"S020XXA" = '1' /*Fracture of vault of skull, initial encounter for closedfracture */
"S020XXB" = '1' /*Fracture of vault of skull, initial encounter for openfracture */
"S02101A" = '1' /*Fracture of base of skull, right side, initial encounter for closed fracture */
"S02101B" = '1' /*Fracture of base of skull, right side, initial encounter for open fracture */
"S02102A" = '1' /*Fracture of base of skull, left side, initial encounter for closed fracture */
"S02102B" = '1' /*Fracture of base of skull, left side, initial encounter for open fracture */
"S02109A" = '1' /*Fracture of base of skull, unspecified side, initial encounter for closed fracture */
"S02109B" = '1' /*Fracture of base of skull, unspecified side, initial encounter for open fracture */
"S0210XA" = '1' /*Unspecified fracture of base of skull, initial encounter for closed fracture */
"S0210XB" = '1' /*Unspecified fracture of base of skull, initial encounter for open fracture */
"S02110A" = '1' /*Type I occipital condyle fracture, unspecified side, initial encounter for closed fracture */
"S02110B" = '1' /*Type I occipital condyle fracture, unspecified side, initial encounter for open fracture */
"S02111A" = '1' /*Type II occipital condyle fracture, unspecified side, initial encounter for closed fracture */
"S02111B" = '1' /*Type II occipital condyle fracture, unspecified side, initial encounter for open fracture */
"S02112A" = '1' /*Type III occipital condyle fracture, unspecified side, initial encounter for closed fracture */
"S02112B" = '1' /*Type III occipital condyle fracture, unspecified side, initial encounter for open fracture */
"S02113A" = '1' /*Unspecified occipital condyle fracture, initial encounterfor closed fracture */
"S02113B" = '1' /*Unspecified occipital condyle fracture, initial encounterfor open fracture */
"S02118A" = '1' /*Other fracture of occiput, unspecified side, initial encounter for closed fracture */
"S02118B" = '1' /*Other fracture of occiput, unspecified side, initial encounter for open fracture */
"S02119A" = '1' /*Unspecified fracture of occiput, initial encounter forclosed fracture */
"S02119B" = '1' /*Unspecified fracture of occiput, initial encounter foropen fracture */
"S0211AA" = '1' /*Type I occipital condyle fracture, right side, initial encounter for closed fracture */
"S0211AB" = '1' /*Type I occipital condyle fracture, right side, initial encounter for open fracture */
"S0211BA" = '1' /*Type I occipital condyle fracture, left side, initial encounter for closed fracture */
"S0211BB" = '1' /*Type I occipital condyle fracture, left side, initial encounter for open fracture */
"S0211CA" = '1' /*Type II occipital condyle fracture, right side, initial encounter for closed fracture */
"S0211CB" = '1' /*Type II occipital condyle fracture, right side, initial encounter for open fracture */
"S0211DA" = '1' /*Type II occipital condyle fracture, left side, initial encounter for closed fracture */
"S0211DB" = '1' /*Type II occipital condyle fracture, left side, initial encounter for open fracture */
"S0211EA" = '1' /*Type III occipital condyle fracture, right side, initial encounter for closed fracture */
"S0211EB" = '1' /*Type III occipital condyle fracture, right side, initial encounter for open fracture */
"S0211FA" = '1' /*Type III occipital condyle fracture, left side, initial encounter for closed fracture */
"S0211FB" = '1' /*Type III occipital condyle fracture, left side, initial encounter for open fracture */
"S0211GA" = '1' /*Other fracture of occiput, right side, initial encounter for closed fracture */
"S0211GB" = '1' /*Other fracture of occiput, right side, initial encounter for open fracture */
"S0211HA" = '1' /*Other fracture of occiput, left side, initial encounter for closed fracture */
"S0211HB" = '1' /*Other fracture of occiput, left side, initial encounter for open fracture */
"S0219XA" = '1' /*Other fracture of base of skull, initial encounter forclosed fracture */
"S0219XB" = '1' /*Other fracture of base of skull, initial encounter foropen fracture */
"S022XXA" = '1' /*Fracture of nasal bones, initial encounter for closedfracture */
"S022XXB" = '1' /*Fracture of nasal bones, initial encounter for openfracture */
"S0230XA" = '1' /*Fracture of orbital floor, unspecified side, initial encounter for closed fracture */
"S0230XB" = '1' /*Fracture of orbital floor, unspecified side, initial encounter for open fracture */
"S0231XA" = '1' /*Fracture of orbital floor, right side, initial encounter for closed fracture */
"S0231XB" = '1' /*Fracture of orbital floor, right side, initial encounter for open fracture */
"S0232XA" = '1' /*Fracture of orbital floor, left side, initial encounter for closed fracture */
"S0232XB" = '1' /*Fracture of orbital floor, left side, initial encounter for open fracture */
"S023XXA" = '1' /*Fracture of orbital floor, initial encounter for closed fracture */
"S023XXB" = '1' /*Fracture of orbital floor, initial encounter for open fracture */
"S02400A" = '1' /*Malar fracture, unspecified side, initial encounter for closed fracture */
"S02400B" = '1' /*Malar fracture, unspecified side, initial encounter for open fracture */
"S02401A" = '1' /*Maxillary fracture, unspecified side, initial encounter for closed fracture */
"S02401B" = '1' /*Maxillary fracture, unspecified side, initial encounter for open fracture */
"S02402A" = '1' /*Zygomatic fracture, unspecified side, initial encounter for closed fracture */
"S02402B" = '1' /*Zygomatic fracture, unspecified side, initial encounter for open fracture */
"S0240AA" = '1' /*Malar fracture, right side, initial encounter for closed fracture */
"S0240AB" = '1' /*Malar fracture, right side, initial encounter for open fracture */
"S0240BA" = '1' /*Malar fracture, left side, initial encounter for closed fracture */
"S0240BB" = '1' /*Malar fracture, left side, initial encounter for open fracture */
"S0240CA" = '1' /*Maxillary fracture, right side, initial encounter for closed fracture */
"S0240CB" = '1' /*Maxillary fracture, right side, initial encounter for open fracture */
"S0240DA" = '1' /*Maxillary fracture, left side, initial encounter for closed fracture */
"S0240DB" = '1' /*Maxillary fracture, left side, initial encounter for open fracture */
"S0240EA" = '1' /*Zygomatic fracture, right side, initial encounter for closed fracture */
"S0240EB" = '1' /*Zygomatic fracture, right side, initial encounter for open fracture */
"S0240FA" = '1' /*Zygomatic fracture, left side, initial encounter for closed fracture */
"S0240FB" = '1' /*Zygomatic fracture, left side, initial encounter for open fracture */
"S02411A" = '1' /*LeFort I fracture, initial encounter for closed fracture */
"S02411B" = '1' /*LeFort I fracture, initial encounter for open fracture */
"S02412A" = '1' /*LeFort II fracture, initial encounter for closed fracture */
"S02412B" = '1' /*LeFort II fracture, initial encounter for open fracture */
"S02413A" = '1' /*LeFort III fracture, initial encounter for closed fracture */
"S02413B" = '1' /*LeFort III fracture, initial encounter for open fracture */
"S0242XA" = '1' /*Fracture of alveolus of maxilla, initial encounter forclosed fracture */
"S0242XB" = '1' /*Fracture of alveolus of maxilla, initial encounter foropen fracture */
"S02600A" = '1' /*Fracture of unspecified part of body of mandible, unspecified side, initial encounter for closed fracture */
"S02600B" = '1' /*Fracture of unspecified part of body of mandible, unspecified side, initial encounter for open fracture */
"S02601A" = '1' /*Fracture of unspecified part of body of right mandible, initial encounter for closed fracture */
"S02601B" = '1' /*Fracture of unspecified part of body of right mandible, initial encounter for open fracture */
"S02602A" = '1' /*Fracture of unspecified part of body of left mandible, initial encounter for closed fracture */
"S02602B" = '1' /*Fracture of unspecified part of body of left mandible, initial encounter for open fracture */
"S02609A" = '1' /*Fracture of mandible, unspecified, initial encounter forclosed fracture */
"S02609B" = '1' /*Fracture of mandible, unspecified, initial encounter foropen fracture */
"S02610A" = '1' /*Fracture of condylar process of mandible, unspecified side, initial encounter for closed fracture */
"S02610B" = '1' /*Fracture of condylar process of mandible, unspecified side, initial encounter for open fracture */
"S02611A" = '1' /*Fracture of condylar process of right mandible, initial encounter for closed fracture */
"S02611B" = '1' /*Fracture of condylar process of right mandible, initial encounter for open fracture */
"S02612A" = '1' /*Fracture of condylar process of left mandible, initial encounter for closed fracture */
"S02612B" = '1' /*Fracture of condylar process of left mandible, initial encounter for open fracture */
"S0261XA" = '1' /*Fracture of condylar process of mandible, initial encounter for closed fracture */
"S0261XB" = '1' /*Fracture of condylar process of mandible, initial encounter for open fracture */
"S02620A" = '1' /*Fracture of subcondylar process of mandible, unspecified side, initial encounter for closed fracture */
"S02620B" = '1' /*Fracture of subcondylar process of mandible, unspecified side, initial encounter for open fracture */
"S02621A" = '1' /*Fracture of subcondylar process of right mandible, initial encounter for closed fracture */
"S02621B" = '1' /*Fracture of subcondylar process of right mandible, initial encounter for open fracture */
"S02622A" = '1' /*Fracture of subcondylar process of left mandible, initial encounter for closed fracture */
"S02622B" = '1' /*Fracture of subcondylar process of left mandible, initial encounter for open fracture */
"S0262XA" = '1' /*Fracture of subcondylar process of mandible, initial encounter for closed fracture */
"S0262XB" = '1' /*Fracture of subcondylar process of mandible, initial encounter for open fracture */
"S02630A" = '1' /*Fracture of coronoid process of mandible, unspecified side, initial encounter for closed fracture */
"S02630B" = '1' /*Fracture of coronoid process of mandible, unspecified side, initial encounter for open fracture */
"S02631A" = '1' /*Fracture of coronoid process of right mandible, initial encounter for closed fracture */
"S02631B" = '1' /*Fracture of coronoid process of right mandible, initial encounter for open fracture */
"S02632A" = '1' /*Fracture of coronoid process of left mandible, initial encounter for closed fracture */
"S02632B" = '1' /*Fracture of coronoid process of left mandible, initial encounter for open fracture */
"S0263XA" = '1' /*Fracture of coronoid process of mandible, initial encounter for closed fracture */
"S0263XB" = '1' /*Fracture of coronoid process of mandible, initial encounter for open fracture */
"S02640A" = '1' /*Fracture of ramus of mandible, unspecified side, initial encounter for closed fracture */
"S02640B" = '1' /*Fracture of ramus of mandible, unspecified side, initial encounter for open fracture */
"S02641A" = '1' /*Fracture of ramus of right mandible, initial encounter for closed fracture */
"S02641B" = '1' /*Fracture of ramus of right mandible, initial encounter for open fracture */
"S02642A" = '1' /*Fracture of ramus of left mandible, initial encounter for closed fracture */
"S02642B" = '1' /*Fracture of ramus of left mandible, initial encounter for open fracture */
"S0264XA" = '1' /*Fracture of ramus of mandible, initial encounter for closed fracture */
"S0264XB" = '1' /*Fracture of ramus of mandible, initial encounter for open fracture */
"S02650A" = '1' /*Fracture of angle of mandible, unspecified side, initial encounter for closed fracture */
"S02650B" = '1' /*Fracture of angle of mandible, unspecified side, initial encounter for open fracture */
"S02651A" = '1' /*Fracture of angle of right mandible, initial encounter for closed fracture */
"S02651B" = '1' /*Fracture of angle of right mandible, initial encounter for open fracture */
"S02652A" = '1' /*Fracture of angle of left mandible, initial encounter for closed fracture */
"S02652B" = '1' /*Fracture of angle of left mandible, initial encounter for open fracture */
"S0265XA" = '1' /*Fracture of angle of mandible, initial encounter for closed fracture */
"S0265XB" = '1' /*Fracture of angle of mandible, initial encounter for open fracture */
"S0266XA" = '1' /*Fracture of symphysis of mandible, initial encounterfor closed fracture */
"S0266XB" = '1' /*Fracture of symphysis of mandible, initial encounterfor open fracture */
"S02670A" = '1' /*Fracture of alveolus of mandible, unspecified side, initial encounter for closed fracture */
"S02670B" = '1' /*Fracture of alveolus of mandible, unspecified side, initial encounter for open fracture */
"S02671A" = '1' /*Fracture of alveolus of right mandible, initial encounter for closed fracture */
"S02671B" = '1' /*Fracture of alveolus of right mandible, initial encounter for open fracture */
"S02672A" = '1' /*Fracture of alveolus of left mandible, initial encounter for closed fracture */
"S02672B" = '1' /*Fracture of alveolus of left mandible, initial encounter for open fracture */
"S0267XA" = '1' /*Fracture of alveolus of mandible, initial encounter for closed fracture */
"S0267XB" = '1' /*Fracture of alveolus of mandible, initial encounter for open fracture */
"S0269XA" = '1' /*Fracture of mandible of other specified site, initialencounter for closed fracture */
"S0269XB" = '1' /*Fracture of mandible of other specified site, initialencounter for open fracture */
"S0280XA" = '1' /*Fracture of other specified skull and facial bones, unspecified side, initial encounter for closed fracture */
"S0280XB" = '1' /*Fracture of other specified skull and facial bones, unspecified side, initial encounter for open fracture */
"S0281XA" = '1' /*Fracture of other specified skull and facial bones, right side, initial encounter for closed fracture */
"S0281XB" = '1' /*Fracture of other specified skull and facial bones, right side, initial encounter for open fracture */
"S0282XA" = '1' /*Fracture of other specified skull and facial bones, left side, initial encounter for closed fracture */
"S0282XB" = '1' /*Fracture of other specified skull and facial bones, left side, initial encounter for open fracture */
"S028XXA" = '1' /*Fractures of other specified skull and facial bones, initial encounter for closed fracture */
"S028XXB" = '1' /*Fractures of other specified skull and facial bones, initial encounter for open fracture */
"S0291XA" = '1' /*Unspecified fracture of skull, initial encounter forclosed fracture */
"S0291XB" = '1' /*Unspecified fracture of skull, initial encounter for openfracture */
"S0292XA" = '1' /*Unspecified fracture of facial bones, initial encounterfor closed fracture */
"S0292XB" = '1' /*Unspecified fracture of facial bones, initial encounterfor open fracture */
"S04011A" = '1' /*Injury of optic nerve, right eye, initial encounter */
"S04012A" = '1' /*Injury of optic nerve, left eye, initial encounter */
"S04019A" = '1' /*Injury of optic nerve, unspecified eye, initial encounter */
"S0402XA" = '1' /*Injury of optic chiasm, initial encounter */
"S04031A" = '1' /*Injury of optic tract and pathways, right side, initial encounter */
"S04032A" = '1' /*Injury of optic tract and pathways, left side, initial encounter */
"S04039A" = '1' /*Injury of optic tract and pathways, unspecified side, initial encounter */
"S04041A" = '1' /*Injury of visual cortex, right side, initial encounter */
"S04042A" = '1' /*Injury of visual cortex, left side, initial encounter */
"S04049A" = '1' /*Injury of visual cortex, unspecified side, initial encounter */
"S0410XA" = '1' /*Injury of oculomotor nerve, unspecified side, initialencounter */
"S0411XA" = '1' /*Injury of oculomotor nerve, right side, initial encounter */
"S0412XA" = '1' /*Injury of oculomotor nerve, left side, initial encounter */
"S0420XA" = '1' /*Injury of trochlear nerve, unspecified side, initialencounter */
"S0421XA" = '1' /*Injury of trochlear nerve, right side, initial encounter */
"S0422XA" = '1' /*Injury of trochlear nerve, left side, initial encounter */
"S0430XA" = '1' /*Injury of trigeminal nerve, unspecified side, initialencounter */
"S0431XA" = '1' /*Injury of trigeminal nerve, right side, initial encounter */
"S0432XA" = '1' /*Injury of trigeminal nerve, left side, initial encounter */
"S0440XA" = '1' /*Injury of abducent nerve, unspecified side, initialencounter */
"S0441XA" = '1' /*Injury of abducent nerve, right side, initial encounter */
"S0442XA" = '1' /*Injury of abducent nerve, left side, initial encounter */
"S0450XA" = '1' /*Injury of facial nerve, unspecified side, initialencounter */
"S0451XA" = '1' /*Injury of facial nerve, right side, initial encounter */
"S0452XA" = '1' /*Injury of facial nerve, left side, initial encounter */
"S0460XA" = '1' /*Injury of acoustic nerve, unspecified side, initialencounter */
"S0461XA" = '1' /*Injury of acoustic nerve, right side, initial encounter */
"S0462XA" = '1' /*Injury of acoustic nerve, left side, initial encounter */
"S0470XA" = '1' /*Injury of accessory nerve, unspecified side, initialencounter */
"S0471XA" = '1' /*Injury of accessory nerve, right side, initial encounter */
"S0472XA" = '1' /*Injury of accessory nerve, left side, initial encounter */
"S04811A" = '1' /*Injury of olfactory [1st ] nerve, right side, initialencounter */
"S04812A" = '1' /*Injury of olfactory [1st ] nerve, left side, initialencounter */
"S04819A" = '1' /*Injury of olfactory [1st ] nerve, unspecified side, initialencounter */
"S04891A" = '1' /*Injury of other cranial nerves, right side, initialencounter */
"S04892A" = '1' /*Injury of other cranial nerves, left side, initial encounter */
"S04899A" = '1' /*Injury of other cranial nerves, unspecified side, initialencounter */
"S049XXA" = '1' /*Injury of unspecified cranial nerve, initial encounter */
"S060X0A" = '1' /*Concussion without loss of consciousness, initialencounter */
"S060X1A" = '1' /*Concussion with loss of consciousness of 30 minutesor less, initial encounter */
"S060X2A" = '1' /*Concussion with loss of consciousness of 31 minutes to 59 minutes, initial encounter */
"S060X3A" = '1' /*Concussion with loss of consciousness of 1 hour to 5 hours 59 minutes, initial encounter */
"S060X4A" = '1' /*Concussion with loss of consciousness of 6 hours to 24 hours, initial encounter */
"S060X5A" = '1' /*Concussion with loss of consciousness greater than 24 hours with return to pre-existing conscious level, initial encounter */
"S060X6A" = '1' /*Concussion with loss of consciousness greater than 24 hours without return to pre-existing conscious level with patient surviving, initial encounter */
"S060X7A" = '1' /*Concussion with loss of consciousness of any duration with death due to brain injury prior to regaining consciousness, initial encounter */
"S060X8A" = '1' /*Concussion with loss of consciousness of any duration with death due to other cause prior to regaining consciousness, initial encounter */
"S060X9A" = '1' /*Concussion with loss of consciousness of unspecifiedduration, initial encounter */
"S061X0A" = '1' /*Traumatic cerebral edema without loss ofconsciousness, initial encounter */
"S061X1A" = '1' /*Traumatic cerebral edema with loss of consciousnessof 30 minutes or less, initial encounter */
"S061X2A" = '1' /*Traumatic cerebral edema with loss of consciousnessof 31 minutes to 59 minutes, initial encounter */
"S061X3A" = '1' /*Traumatic cerebral edema with loss of consciousnessof 1 hour to 5 hours 59 minutes, initial encounter */
"S061X4A" = '1' /*Traumatic cerebral edema with loss of consciousnessof 6 hours to 24 hours, initial encounter */
"S061X5A" = '1' /*Traumatic cerebral edema with loss of consciousnessgreater than 24 hours with return to pre-existingconscious level, initial encounter */
"S061X6A" = '1' /*Traumatic cerebral edema with loss of consciousnessgreater than 24 hours without return to pre-existingconscious level with patient surviving, initial encounter */
"S061X7A" = '1' /*Traumatic cerebral edema with loss of consciousnessof any duration with death due to brain injury prior toregaining consciousness, initial encounter */
"S061X8A" = '1' /*Traumatic cerebral edema with loss of consciousnessof any duration with death due to other cause prior toregaining consciousness, initial encounter */
"S061X9A" = '1' /*Traumatic cerebral edema with loss of consciousnessof unspecified duration, initial encounter */
"S062X0A" = '1' /*Diffuse traumatic brain injury without loss ofconsciousness, initial encounter */
"S062X1A" = '1' /*Diffuse traumatic brain injury with loss ofconsciousness of 30 minutes or less, initial encounter */
"S062X2A" = '1' /*Diffuse traumatic brain injury with loss ofconsciousness of 31 minutes to 59 minutes, initialencounter */
"S062X3A" = '1' /*Diffuse traumatic brain injury with loss ofconsciousness of 1 hour to 5 hours 59 minutes, initialencounter */
"S062X4A" = '1' /*Diffuse traumatic brain injury with loss ofconsciousness of 6 hours to 24 hours, initial encounter */
"S062X5A" = '1' /*Diffuse traumatic brain injury with loss ofconsciousness greater than 24 hours with return topre-existing conscious levels, initial encounter */
"S062X6A" = '1' /*Diffuse traumatic brain injury with loss ofconsciousness greater than 24 hours without return topre-existing conscious level with patient surviving,initial encounter */
"S062X7A" = '1' /*Diffuse traumatic brain injury with loss ofconsciousness of any duration with death due to braininjury prior to regaining consciousness, initialencounter */
"S062X8A" = '1' /*Diffuse traumatic brain injury with loss ofconsciousness of any duration with death due to othercause prior to regaining consciousness, initialencounter */
"S062X9A" = '1' /*Diffuse traumatic brain injury with loss ofconsciousness of unspecified duration, initialencounter */
"S06300A" = '1' /*Unspecified focal traumatic brain injury without loss ofconsciousness, initial encounter */
"S06301A" = '1' /*Unspecified focal traumatic brain injury with loss ofconsciousness of 30 minutes or less, initial encounter */
"S06302A" = '1' /*Unspecified focal traumatic brain injury with loss ofconsciousness of 31 minutes to 59 minutes, initialencounter */
"S06303A" = '1' /*Unspecified focal traumatic brain injury with loss ofconsciousness of 1 hour to 5 hours 59 minutes, initialencounter */
"S06304A" = '1' /*Unspecified focal traumatic brain injury with loss ofconsciousness of 6 hours to 24 hours, initial encounter */
"S06305A" = '1' /*Unspecified focal traumatic brain injury with loss ofconsciousness greater than 24 hours with return topre-existing conscious level, initial encounter */
"S06306A" = '1' /*Unspecified focal traumatic brain injury with loss ofconsciousness greater than 24 hours without return topre-existing conscious level with patient surviving,initial encounter */
"S06307A" = '1' /*Unspecified focal traumatic brain injury with loss ofconsciousness of any duration with death due to braininjury prior to regaining consciousness, initialencounter */
"S06308A" = '1' /*Unspecified focal traumatic brain injury with loss ofconsciousness of any duration with death due to othercause prior to regaining consciousness, initialencounter */
"S06309A" = '1' /*Unspecified focal traumatic brain injury with loss ofconsciousness of unspecified duration, initialencounter */
"S06310A" = '1' /*Contusion and laceration of right cerebrum withoutloss of consciousness, initial encounter */
"S06311A" = '1' /*Contusion and laceration of right cerebrum with loss ofconsciousness of 30 minutes or less, initial encounter */
"S06312A" = '1' /*Contusion and laceration of right cerebrum with loss ofconsciousness of 31 minutes to 59 minutes, initialencounter */
"S06313A" = '1' /*Contusion and laceration of right cerebrum with loss ofconsciousness of 1 hour to 5 hours 59 minutes, initialencounter */
"S06314A" = '1' /*Contusion and laceration of right cerebrum with loss ofconsciousness of 6 hours to 24 hours, initial encounter */
"S06315A" = '1' /*Contusion and laceration of right cerebrum with loss ofconsciousness greater than 24 hours with return topre-existing conscious level, initial encounter */
"S06316A" = '1' /*Contusion and laceration of right cerebrum with loss ofconsciousness greater than 24 hours without return topre-existing conscious level with patient surviving,initial encounter */
"S06317A" = '1' /*Contusion and laceration of right cerebrum with loss ofconsciousness of any duration with death due to braininjury prior to regaining consciousness, initialencounter */
"S06318A" = '1' /*Contusion and laceration of right cerebrum with loss ofconsciousness of any duration with death due to othercause prior to regaining consciousness, initialencounter */
"S06319A" = '1' /*Contusion and laceration of right cerebrum with loss ofconsciousness of unspecified duration, initialencounter */
"S06320A" = '1' /*Contusion and laceration of left cerebrum without lossof consciousness, initial encounter */
"S06321A" = '1' /*Contusion and laceration of left cerebrum with loss ofconsciousness of 30 minutes or less, initial encounter */
"S06322A" = '1' /*Contusion and laceration of left cerebrum with loss ofconsciousness of 31 minutes to 59 minutes, initialencounter */
"S06323A" = '1' /*Contusion and laceration of left cerebrum with loss ofconsciousness of 1 hour to 5 hours 59 minutes, initialencounter */
"S06324A" = '1' /*Contusion and laceration of left cerebrum with loss ofconsciousness of 6 hours to 24 hours, initial encounter */
"S06325A" = '1' /*Contusion and laceration of left cerebrum with loss ofconsciousness greater than 24 hours with return topre-existing conscious level, initial encounter */
"S06326A" = '1' /*Contusion and laceration of left cerebrum with loss ofconsciousness greater than 24 hours without return topre-existing conscious level with patient surviving,initial encounter */
"S06327A" = '1' /*Contusion and laceration of left cerebrum with loss ofconsciousness of any duration with death due to braininjury prior to regaining consciousness, initialencounter */
"S06328A" = '1' /*Contusion and laceration of left cerebrum with loss ofconsciousness of any duration with death due to othercause prior to regaining consciousness, initialencounter */
"S06329A" = '1' /*Contusion and laceration of left cerebrum with loss ofconsciousness of unspecified duration, initialencounter */
"S06330A" = '1' /*Contusion and laceration of cerebrum, unspecified,without loss of consciousness, initial encounter */
"S06331A" = '1' /*Contusion and laceration of cerebrum, unspecified,with loss of consciousness of 30 minutes or less, initialencounter */
"S06332A" = '1' /*Contusion and laceration of cerebrum, unspecified,with loss of consciousness of 31 minutes to 59minutes, initial encounter */
"S06333A" = '1' /*Contusion and laceration of cerebrum, unspecified,with loss of consciousness of 1 hour to 5 hours 59minutes, initial encounter */
"S06334A" = '1' /*Contusion and laceration of cerebrum, unspecified,with loss of consciousness of 6 hours to 24 hours,initial encounter */
"S06335A" = '1' /*Contusion and laceration of cerebrum, unspecified,with loss of consciousness greater than 24 hours withreturn to pre-existing conscious level, initial encounter */
"S06336A" = '1' /*Contusion and laceration of cerebrum, unspecified,with loss of consciousness greater than 24 hourswithout return to pre-existing conscious level withpatient surviving, initial encounter */
"S06337A" = '1' /*Contusion and laceration of cerebrum, unspecified,with loss of consciousness of any duration with deathdue to brain injury prior to regaining consciousness,initial encounter */
"S06338A" = '1' /*Contusion and laceration of cerebrum, unspecified,with loss of consciousness of any duration with deathdue to other cause prior to regaining consciousness,initial encounter */
"S06339A" = '1' /*Contusion and laceration of cerebrum, unspecified,with loss of consciousness of unspecified duration,initial encounter */
"S06340A" = '1' /*Traumatic hemorrhage of right cerebrum without lossof consciousness, initial encounter */
"S06341A" = '1' /*Traumatic hemorrhage of right cerebrum with loss ofconsciousness of 30 minutes or less, initial encounter */
"S06342A" = '1' /*Traumatic hemorrhage of right cerebrum with loss ofconsciousness of 31 minutes to 59 minutes, initialencounter */
"S06343A" = '1' /*Traumatic hemorrhage of right cerebrum with loss ofconsciousness of 1 hours to 5 hours 59 minutes, initialencounter */
"S06344A" = '1' /*Traumatic hemorrhage of right cerebrum with loss ofconsciousness of 6 hours to 24 hours, initial encounter */
"S06345A" = '1' /*Traumatic hemorrhage of right cerebrum with loss ofconsciousness greater than 24 hours with return topre-existing conscious level, initial encounter */
"S06346A" = '1' /*Traumatic hemorrhage of right cerebrum with loss ofconsciousness greater than 24 hours without return topre-existing conscious level with patient surviving,initial encounter */
"S06347A" = '1' /*Traumatic hemorrhage of right cerebrum with loss ofconsciousness of any duration with death due to braininjury prior to regaining consciousness, initialencounter */
"S06348A" = '1' /*Traumatic hemorrhage of right cerebrum with loss ofconsciousness of any duration with death due to othercause prior to regaining consciousness, initialencounter */
"S06349A" = '1' /*Traumatic hemorrhage of right cerebrum with loss ofconsciousness of unspecified duration, initialencounter */
"S06350A" = '1' /*Traumatic hemorrhage of left cerebrum without loss ofconsciousness, initial encounter */
"S06351A" = '1' /*Traumatic hemorrhage of left cerebrum with loss ofconsciousness of 30 minutes or less, initial encounter */
"S06352A" = '1' /*Traumatic hemorrhage of left cerebrum with loss ofconsciousness of 31 minutes to 59 minutes, initialencounter */
"S06353A" = '1' /*Traumatic hemorrhage of left cerebrum with loss ofconsciousness of 1 hours to 5 hours 59 minutes, initialencounter */
"S06354A" = '1' /*Traumatic hemorrhage of left cerebrum with loss ofconsciousness of 6 hours to 24 hours, initial encounter */
"S06355A" = '1' /*Traumatic hemorrhage of left cerebrum with loss ofconsciousness greater than 24 hours with return topre-existing conscious level, initial encounter */
"S06356A" = '1' /*Traumatic hemorrhage of left cerebrum with loss ofconsciousness greater than 24 hours without return topre-existing conscious level with patient surviving,initial encounter */
"S06357A" = '1' /*Traumatic hemorrhage of left cerebrum with loss ofconsciousness of any duration with death due to braininjury prior to regaining consciousness, initialencounter */
"S06358A" = '1' /*Traumatic hemorrhage of left cerebrum with loss ofconsciousness of any duration with death due to othercause prior to regaining consciousness, initialencounter */
"S06359A" = '1' /*Traumatic hemorrhage of left cerebrum with loss ofconsciousness of unspecified duration, initialencounter */
"S06360A" = '1' /*Traumatic hemorrhage of cerebrum, unspecified,without loss of consciousness, initial encounter */
"S06361A" = '1' /*Traumatic hemorrhage of cerebrum, unspecified, withloss of consciousness of 30 minutes or less, initialencounter */
"S06362A" = '1' /*Traumatic hemorrhage of cerebrum, unspecified, withloss of consciousness of 31 minutes to 59 minutes,initial encounter */
"S06363A" = '1' /*Traumatic hemorrhage of cerebrum, unspecified, withloss of consciousness of 1 hours to 5 hours 59minutes, initial encounter */
"S06364A" = '1' /*Traumatic hemorrhage of cerebrum, unspecified, withloss of consciousness of 6 hours to 24 hours, initialencounter */
"S06365A" = '1' /*Traumatic hemorrhage of cerebrum, unspecified, withloss of consciousness greater than 24 hours withreturn to pre-existing conscious level, initial encounter */
"S06366A" = '1' /*Traumatic hemorrhage of cerebrum, unspecified, withloss of consciousness greater than 24 hours withoutreturn to pre-existing conscious level with patientsurviving, initial encounter */
"S06367A" = '1' /*Traumatic hemorrhage of cerebrum, unspecified, withloss of consciousness of any duration with death dueto brain injury prior to regaining consciousness, initialencounter */
"S06368A" = '1' /*Traumatic hemorrhage of cerebrum, unspecified, withloss of consciousness of any duration with death dueto other cause prior to regaining consciousness, initialencounter */
"S06369A" = '1' /*Traumatic hemorrhage of cerebrum, unspecified, withloss of consciousness of unspecified duration, initialencounter */
"S06370A" = '1' /*Contusion, laceration, and hemorrhage of cerebellumwithout loss of consciousness, initial encounter */
"S06371A" = '1' /*Contusion, laceration, and hemorrhage of cerebellumwith loss of consciousness of 30 minutes or less, initialencounter */
"S06372A" = '1' /*Contusion, laceration, and hemorrhage of cerebellumwith loss of consciousness of 31 minutes to 59minutes, initial encounter */
"S06373A" = '1' /*Contusion, laceration, and hemorrhage of cerebellumwith loss of consciousness of 1 hour to 5 hours 59minutes, initial encounter */
"S06374A" = '1' /*Contusion, laceration, and hemorrhage of cerebellumwith loss of consciousness of 6 hours to 24 hours,initial encounter */
"S06375A" = '1' /*Contusion, laceration, and hemorrhage of cerebellumwith loss of consciousness greater than 24 hours withreturn to pre-existing conscious level, initial encounter */
"S06376A" = '1' /*Contusion, laceration, and hemorrhage of cerebellumwith loss of consciousness greater than 24 hourswithout return to pre-existing conscious level withpatient surviving, initial encounter */
"S06377A" = '1' /*Contusion, laceration, and hemorrhage of cerebellumwith loss of consciousness of any duration with deathdue to brain injury prior to regaining consciousness,initial encounter */
"S06378A" = '1' /*Contusion, laceration, and hemorrhage of cerebellumwith loss of consciousness of any duration with deathdue to other cause prior to regaining consciousness,initial encounter */
"S06379A" = '1' /*Contusion, laceration, and hemorrhage of cerebellumwith loss of consciousness of unspecified duration,initial encounter */
"S06380A" = '1' /*Contusion, laceration, and hemorrhage of brainstemwithout loss of consciousness, initial encounter */
"S06381A" = '1' /*Contusion, laceration, and hemorrhage of brainstemwith loss of consciousness of 30 minutes or less, initialencounter */
"S06382A" = '1' /*Contusion, laceration, and hemorrhage of brainstemwith loss of consciousness of 31 minutes to 59minutes, initial encounter */
"S06383A" = '1' /*Contusion, laceration, and hemorrhage of brainstemwith loss of consciousness of 1 hour to 5 hours 59minutes, initial encounter */
"S06384A" = '1' /*Contusion, laceration, and hemorrhage of brainstemwith loss of consciousness of 6 hours to 24 hours,initial encounter */
"S06385A" = '1' /*Contusion, laceration, and hemorrhage of brainstemwith loss of consciousness greater than 24 hours withreturn to pre-existing conscious level, initial encounter */
"S06386A" = '1' /*Contusion, laceration, and hemorrhage of brainstemwith loss of consciousness greater than 24 hourswithout return to pre-existing conscious level withpatient surviving, initial encounter */
"S06387A" = '1' /*Contusion, laceration, and hemorrhage of brainstemwith loss of consciousness of any duration with deathdue to brain injury prior to regaining consciousness,initial encounter */
"S06388A" = '1' /*Contusion, laceration, and hemorrhage of brainstemwith loss of consciousness of any duration with deathdue to other cause prior to regaining consciousness,initial encounter */
"S06389A" = '1' /*Contusion, laceration, and hemorrhage of brainstemwith loss of consciousness of unspecified duration,initial encounter */
"S064X0A" = '1' /*Epidural hemorrhage without loss of consciousness,initial encounter */
"S064X1A" = '1' /*Epidural hemorrhage with loss of consciousness of 30minutes or less, initial encounter */
"S064X2A" = '1' /*Epidural hemorrhage with loss of consciousness of 31minutes to 59 minutes, initial encounter */
"S064X3A" = '1' /*Epidural hemorrhage with loss of consciousness of 1hour to 5 hours 59 minutes, initial encounter */
"S064X4A" = '1' /*Epidural hemorrhage with loss of consciousness of 6hours to 24 hours, initial encounter */
"S064X5A" = '1' /*Epidural hemorrhage with loss of consciousnessgreater than 24 hours with return to pre-existingconscious level, initial encounter */
"S064X6A" = '1' /*Epidural hemorrhage with loss of consciousnessgreater than 24 hours without return to pre-existingconscious level with patient surviving, initial encounter */
"S064X7A" = '1' /*Epidural hemorrhage with loss of consciousness ofany duration with death due to brain injury prior toregaining consciousness, initial encounter */
"S064X8A" = '1' /*Epidural hemorrhage with loss of consciousness ofany duration with death due to other causes prior toregaining consciousness, initial encounter */
"S064X9A" = '1' /*Epidural hemorrhage with loss of consciousness ofunspecified duration, initial encounter */
"S065X0A" = '1' /*Traumatic subdural hemorrhage without loss ofconsciousness, initial encounter */
"S065X1A" = '1' /*Traumatic subdural hemorrhage with loss ofconsciousness of 30 minutes or less, initial encounter */
"S065X2A" = '1' /*Traumatic subdural hemorrhage with loss ofconsciousness of 31 minutes to 59 minutes, initialencounter */
"S065X3A" = '1' /*Traumatic subdural hemorrhage with loss ofconsciousness of 1 hour to 5 hours 59 minutes, initialencounter */
"S065X4A" = '1' /*Traumatic subdural hemorrhage with loss ofconsciousness of 6 hours to 24 hours, initial encounter */
"S065X5A" = '1' /*Traumatic subdural hemorrhage with loss ofconsciousness greater than 24 hours with return topre-existing conscious level, initial encounter */
"S065X6A" = '1' /*Traumatic subdural hemorrhage with loss ofconsciousness greater than 24 hours without return topre-existing conscious level with patient surviving,initial encounter */
"S065X7A" = '1' /*Traumatic subdural hemorrhage with loss ofconsciousness of any duration with death due to braininjury before regaining consciousness, initialencounter */
"S065X8A" = '1' /*Traumatic subdural hemorrhage with loss ofconsciousness of any duration with death due to othercause before regaining consciousness, initialencounter */
"S065X9A" = '1' /*Traumatic subdural hemorrhage with loss ofconsciousness of unspecified duration, initialencounter */
"S066X0A" = '1' /*Traumatic subarachnoid hemorrhage without loss ofconsciousness, initial encounter */
"S066X1A" = '1' /*Traumatic subarachnoid hemorrhage with loss ofconsciousness of 30 minutes or less, initial encounter */
"S066X2A" = '1' /*Traumatic subarachnoid hemorrhage with loss ofconsciousness of 31 minutes to 59 minutes, initialencounter */
"S066X3A" = '1' /*Traumatic subarachnoid hemorrhage with loss ofconsciousness of 1 hour to 5 hours 59 minutes, initialencounter */
"S066X4A" = '1' /*Traumatic subarachnoid hemorrhage with loss ofconsciousness of 6 hours to 24 hours, initial encounter */
"S066X5A" = '1' /*Traumatic subarachnoid hemorrhage with loss ofconsciousness greater than 24 hours with return topre-existing conscious level, initial encounter */
"S066X6A" = '1' /*Traumatic subarachnoid hemorrhage with loss ofconsciousness greater than 24 hours without return topre-existing conscious level with patient surviving,initial encounter */
"S066X7A" = '1' /*Traumatic subarachnoid hemorrhage with loss ofconsciousness of any duration with death due to braininjury prior to regaining consciousness, initialencounter */
"S066X8A" = '1' /*Traumatic subarachnoid hemorrhage with loss ofconsciousness of any duration with death due to othercause prior to regaining consciousness, initialencounter */
"S066X9A" = '1' /*Traumatic subarachnoid hemorrhage with loss ofconsciousness of unspecified duration, initialencounter */
"S06810A" = '1' /*Injury of right internal carotid artery, intracranialportion, not elsewhere classified without loss ofconsciousness, initial encounter */
"S06811A" = '1' /*Injury of right internal carotid artery, intracranialportion, not elsewhere classified with loss ofconsciousness of 30 minutes or less, initial encounter */
"S06812A" = '1' /*Injury of right internal carotid artery, intracranialportion, not elsewhere classified with loss ofconsciousness of 31 minutes to 59 minutes, initialencounter */
"S06813A" = '1' /*Injury of right internal carotid artery, intracranialportion, not elsewhere classified with loss ofconsciousness of 1 hour to 5 hours 59 minutes, initialencounter */
"S06814A" = '1' /*Injury of right internal carotid artery, intracranialportion, not elsewhere classified with loss ofconsciousness of 6 hours to 24 hours, initial encounter */
"S06815A" = '1' /*Injury of right internal carotid artery, intracranialportion, not elsewhere classified with loss ofconsciousness greater than 24 hours with return topre-existing conscious level, initial encounter */
"S06816A" = '1' /*Injury of right internal carotid artery, intracranialportion, not elsewhere classified with loss ofconsciousness greater than 24 hours without return topre-existing conscious level with patient sur */
"S06817A" = '1' /*Injury of right internal carotid artery, intracranialportion, not elsewhere classified with loss ofconsciousness of any duration with death due to braininjury prior to regaining consciousness, init */
"S06818A" = '1' /*Injury of right internal carotid artery, intracranialportion, not elsewhere classified with loss ofconsciousness of any duration with death due to othercause prior to regaining consciousness, initi */
"S06819A" = '1' /*Injury of right internal carotid artery, intracranialportion, not elsewhere classified with loss ofconsciousness of unspecified duration, initialencounter */
"S06820A" = '1' /*Injury of left internal carotid artery, intracranial portion,not elsewhere classified without loss ofconsciousness, initial encounter */
"S06821A" = '1' /*Injury of left internal carotid artery, intracranial portion,not elsewhere classified with loss of consciousness of30 minutes or less, initial encounter */
"S06822A" = '1' /*Injury of left internal carotid artery, intracranial portion,not elsewhere classified with loss of consciousness of31 minutes to 59 minutes, initial encounter */
"S06823A" = '1' /*Injury of left internal carotid artery, intracranial portion,not elsewhere classified with loss of consciousness of1 hour to 5 hours 59 minutes, initial encounter */
"S06824A" = '1' /*Injury of left internal carotid artery, intracranial portion,not elsewhere classified with loss of consciousness of6 hours to 24 hours, initial encounter */
"S06825A" = '1' /*Injury of left internal carotid artery, intracranial portion,not elsewhere classified with loss of consciousnessgreater than 24 hours with return to pre-existingconscious level, initial encounter */
"S06826A" = '1' /*Injury of left internal carotid artery, intracranial portion,not elsewhere classified with loss of consciousnessgreater than 24 hours without return to pre-existingconscious level with patient surv */
"S06827A" = '1' /*Injury of left internal carotid artery, intracranial portion,not elsewhere classified with loss of consciousness ofany duration with death due to brain injury prior toregaining consciousness, initi */
"S06828A" = '1' /*Injury of left internal carotid artery, intracranial portion,not elsewhere classified with loss of consciousness ofany duration with death due to other cause prior toregaining consciousness, initia */
"S06829A" = '1' /*Injury of left internal carotid artery, intracranial portion,not elsewhere classified with loss of consciousness ofunspecified duration, initial encounter */
"S06890A" = '1' /*Other specified intracranial injury without loss ofconsciousness, initial encounter */
"S06891A" = '1' /*Other specified intracranial injury with loss ofconsciousness of 30 minutes or less, initial encounter */
"S06892A" = '1' /*Other specified intracranial injury with loss ofconsciousness of 31 minutes to 59 minutes, initialencounter */
"S06893A" = '1' /*Other specified intracranial injury with loss ofconsciousness of 1 hour to 5 hours 59 minutes, initialencounter */
"S06894A" = '1' /*Other specified intracranial injury with loss ofconsciousness of 6 hours to 24 hours, initial encounter */
"S06895A" = '1' /*Other specified intracranial injury with loss ofconsciousness greater than 24 hours with return topre-existing conscious level, initial encounter */
"S06896A" = '1' /*Other specified intracranial injury with loss ofconsciousness greater than 24 hours without return topre-existing conscious level with patient surviving,initial encounter */
"S06897A" = '1' /*Other specified intracranial injury with loss ofconsciousness of any duration with death due to braininjury prior to regaining consciousness, initialencounter */
"S06898A" = '1' /*Other specified intracranial injury with loss ofconsciousness of any duration with death due to othercause prior to regaining consciousness, initialencounter */
"S06899A" = '1' /*Other specified intracranial injury with loss ofconsciousness of unspecified duration, initialencounter */
"S069X0A" = '1' /*Unspecified intracranial injury without loss ofconsciousness, initial encounter */
"S069X1A" = '1' /*Unspecified intracranial injury with loss ofconsciousness of 30 minutes or less, initial encounter */
"S069X2A" = '1' /*Unspecified intracranial injury with loss ofconsciousness of 31 minutes to 59 minutes, initialencounter */
"S069X3A" = '1' /*Unspecified intracranial injury with loss ofconsciousness of 1 hour to 5 hours 59 minutes, initialencounter */
"S069X4A" = '1' /*Unspecified intracranial injury with loss ofconsciousness of 6 hours to 24 hours, initial encounter */
"S069X5A" = '1' /*Unspecified intracranial injury with loss ofconsciousness greater than 24 hours with return topre-existing conscious level, initial encounter */
"S069X6A" = '1' /*Unspecified intracranial injury with loss ofconsciousness greater than 24 hours without return topre-existing conscious level with patient surviving,initial encounter */
"S069X7A" = '1' /*Unspecified intracranial injury with loss ofconsciousness of any duration with death due to braininjury prior to regaining consciousness, initialencounter */
"S069X8A" = '1' /*Unspecified intracranial injury with loss ofconsciousness of any duration with death due to othercause prior to regaining consciousness, initialencounter */
"S069X9A" = '1' /*Unspecified intracranial injury with loss ofconsciousness of unspecified duration, initialencounter */
"S12000A" = '1' /*Unspecified displaced fracture of first cervicalvertebra, initial encounter for closed fracture */
"S12000B" = '1' /*Unspecified displaced fracture of first cervicalvertebra, initial encounter for open fracture */
"S12001A" = '1' /*Unspecified nondisplaced fracture of first cervicalvertebra, initial encounter for closed fracture */
"S12001B" = '1' /*Unspecified nondisplaced fracture of first cervicalvertebra, initial encounter for open fracture */
"S1201XA" = '1' /*Stable burst fracture of first cervical vertebra, initialencounter for closed fracture */
"S1201XB" = '1' /*Stable burst fracture of first cervical vertebra, initialencounter for open fracture */
"S1202XA" = '1' /*Unstable burst fracture of first cervical vertebra, initialencounter for closed fracture */
"S1202XB" = '1' /*Unstable burst fracture of first cervical vertebra, initialencounter for open fracture */
"S12030A" = '1' /*Displaced posterior arch fracture of first cervicalvertebra, initial encounter for closed fracture */
"S12030B" = '1' /*Displaced posterior arch fracture of first cervicalvertebra, initial encounter for open fracture */
"S12031A" = '1' /*Nondisplaced posterior arch fracture of first cervicalvertebra, initial encounter for closed fracture */
"S12031B" = '1' /*Nondisplaced posterior arch fracture of first cervicalvertebra, initial encounter for open fracture */
"S12040A" = '1' /*Displaced lateral mass fracture of first cervicalvertebra, initial encounter for closed fracture */
"S12040B" = '1' /*Displaced lateral mass fracture of first cervicalvertebra, initial encounter for open fracture */
"S12041A" = '1' /*Nondisplaced lateral mass fracture of first cervicalvertebra, initial encounter for closed fracture */
"S12041B" = '1' /*Nondisplaced lateral mass fracture of first cervicalvertebra, initial encounter for open fracture */
"S12090A" = '1' /*Other displaced fracture of first cervical vertebra, initialencounter for closed fracture */
"S12090B" = '1' /*Other displaced fracture of first cervical vertebra, initialencounter for open fracture */
"S12091A" = '1' /*Other nondisplaced fracture of first cervical vertebra,initial encounter for closed fracture */
"S12091B" = '1' /*Other nondisplaced fracture of first cervical vertebra,initial encounter for open fracture */
"S12100A" = '1' /*Unspecified displaced fracture of second cervicalvertebra, initial encounter for closed fracture */
"S12100B" = '1' /*Unspecified displaced fracture of second cervicalvertebra, initial encounter for open fracture */
"S12101A" = '1' /*Unspecified nondisplaced fracture of second cervicalvertebra, initial encounter for closed fracture */
"S12101B" = '1' /*Unspecified nondisplaced fracture of second cervicalvertebra, initial encounter for open fracture */
"S12110A" = '1' /*Anterior displaced Type II dens fracture, initialencounter for closed fracture */
"S12110B" = '1' /*Anterior displaced Type II dens fracture, initialencounter for open fracture */
"S12111A" = '1' /*Posterior displaced Type II dens fracture, initialencounter for closed fracture */
"S12111B" = '1' /*Posterior displaced Type II dens fracture, initialencounter for open fracture */
"S12112A" = '1' /*Nondisplaced Type II dens fracture, initial encounterfor closed fracture */
"S12112B" = '1' /*Nondisplaced Type II dens fracture, initial encounterfor open fracture */
"S12120A" = '1' /*Other displaced dens fracture, initial encounter forclosed fracture */
"S12120B" = '1' /*Other displaced dens fracture, initial encounter foropen fracture */
"S12121A" = '1' /*Other nondisplaced dens fracture, initial encounter forclosed fracture */
"S12121B" = '1' /*Other nondisplaced dens fracture, initial encounter foropen fracture */
"S12130A" = '1' /*Unspecified traumatic displaced spondylolisthesis ofsecond cervical vertebra, initial encounter for closedfracture */
"S12130B" = '1' /*Unspecified traumatic displaced spondylolisthesis ofsecond cervical vertebra, initial encounter for openfracture */
"S12131A" = '1' /*Unspecified traumatic nondisplaced spondylolisthesisof second cervical vertebra, initial encounter for closedfracture */
"S12131B" = '1' /*Unspecified traumatic nondisplaced spondylolisthesisof second cervical vertebra, initial encounter for openfracture */
"S1214XA" = '1' /*Type III traumatic spondylolisthesis of second cervicalvertebra, initial encounter for closed fracture */
"S1214XB" = '1' /*Type III traumatic spondylolisthesis of second cervicalvertebra, initial encounter for open fracture */
"S12150A" = '1' /*Other traumatic displaced spondylolisthesis of secondcervical vertebra, initial encounter for closed fracture */
"S12150B" = '1' /*Other traumatic displaced spondylolisthesis of secondcervical vertebra, initial encounter for open fracture */
"S12151A" = '1' /*Other traumatic nondisplaced spondylolisthesis ofsecond cervical vertebra, initial encounter for closedfracture */
"S12151B" = '1' /*Other traumatic nondisplaced spondylolisthesis ofsecond cervical vertebra, initial encounter for openfracture */
"S12190A" = '1' /*Other displaced fracture of second cervical vertebra,initial encounter for closed fracture */
"S12190B" = '1' /*Other displaced fracture of second cervical vertebra,initial encounter for open fracture */
"S12191A" = '1' /*Other nondisplaced fracture of second cervicalvertebra, initial encounter for closed fracture */
"S12191B" = '1' /*Other nondisplaced fracture of second cervicalvertebra, initial encounter for open fracture */
"S12200A" = '1' /*Unspecified displaced fracture of third cervicalvertebra, initial encounter for closed fracture */
"S12200B" = '1' /*Unspecified displaced fracture of third cervicalvertebra, initial encounter for open fracture */
"S12201A" = '1' /*Unspecified nondisplaced fracture of third cervicalvertebra, initial encounter for closed fracture */
"S12201B" = '1' /*Unspecified nondisplaced fracture of third cervicalvertebra, initial encounter for open fracture */
"S12230A" = '1' /*Unspecified traumatic displaced spondylolisthesis ofthird cervical vertebra, initial encounter for closedfracture */
"S12230B" = '1' /*Unspecified traumatic displaced spondylolisthesis ofthird cervical vertebra, initial encounter for openfracture */
"S12231A" = '1' /*Unspecified traumatic nondisplaced spondylolisthesisof third cervical vertebra, initial encounter for closedfracture */
"S12231B" = '1' /*Unspecified traumatic nondisplaced spondylolisthesisof third cervical vertebra, initial encounter for openfracture */
"S1224XA" = '1' /*Type III traumatic spondylolisthesis of third cervicalvertebra, initial encounter for closed fracture */
"S1224XB" = '1' /*Type III traumatic spondylolisthesis of third cervicalvertebra, initial encounter for open fracture */
"S12250A" = '1' /*Other traumatic displaced spondylolisthesis of thirdcervical vertebra, initial encounter for closed fracture */
"S12250B" = '1' /*Other traumatic displaced spondylolisthesis of thirdcervical vertebra, initial encounter for open fracture */
"S12251A" = '1' /*Other traumatic nondisplaced spondylolisthesis ofthird cervical vertebra, initial encounter for closedfracture */
"S12251B" = '1' /*Other traumatic nondisplaced spondylolisthesis ofthird cervical vertebra, initial encounter for openfracture */
"S12290A" = '1' /*Other displaced fracture of third cervical vertebra,initial encounter for closed fracture */
"S12290B" = '1' /*Other displaced fracture of third cervical vertebra,initial encounter for open fracture */
"S12291A" = '1' /*Other nondisplaced fracture of third cervical vertebra,initial encounter for closed fracture */
"S12291B" = '1' /*Other nondisplaced fracture of third cervical vertebra,initial encounter for open fracture */
"S12300A" = '1' /*Unspecified displaced fracture of fourth cervicalvertebra, initial encounter for closed fracture */
"S12300B" = '1' /*Unspecified displaced fracture of fourth cervicalvertebra, initial encounter for open fracture */
"S12301A" = '1' /*Unspecified nondisplaced fracture of fourth cervicalvertebra, initial encounter for closed fracture */
"S12301B" = '1' /*Unspecified nondisplaced fracture of fourth cervicalvertebra, initial encounter for open fracture */
"S12330A" = '1' /*Unspecified traumatic displaced spondylolisthesis offourth cervical vertebra, initial encounter for closedfracture */
"S12330B" = '1' /*Unspecified traumatic displaced spondylolisthesis offourth cervical vertebra, initial encounter for openfracture */
"S12331A" = '1' /*Unspecified traumatic nondisplaced spondylolisthesisof fourth cervical vertebra, initial encounter for closedfracture */
"S12331B" = '1' /*Unspecified traumatic nondisplaced spondylolisthesisof fourth cervical vertebra, initial encounter for openfracture */
"S1234XA" = '1' /*Type III traumatic spondylolisthesis of fourth cervicalvertebra, initial encounter for closed fracture */
"S1234XB" = '1' /*Type III traumatic spondylolisthesis of fourth cervicalvertebra, initial encounter for open fracture */
"S12350A" = '1' /*Other traumatic displaced spondylolisthesis of fourthcervical vertebra, initial encounter for closed fracture */
"S12350B" = '1' /*Other traumatic displaced spondylolisthesis of fourthcervical vertebra, initial encounter for open fracture */
"S12351A" = '1' /*Other traumatic nondisplaced spondylolisthesis offourth cervical vertebra, initial encounter for closedfracture */
"S12351B" = '1' /*Other traumatic nondisplaced spondylolisthesis offourth cervical vertebra, initial encounter for openfracture */
"S12390A" = '1' /*Other displaced fracture of fourth cervical vertebra,initial encounter for closed fracture */
"S12390B" = '1' /*Other displaced fracture of fourth cervical vertebra,initial encounter for open fracture */
"S12391A" = '1' /*Other nondisplaced fracture of fourth cervical vertebra,initial encounter for closed fracture */
"S12391B" = '1' /*Other nondisplaced fracture of fourth cervical vertebra,initial encounter for open fracture */
"S12400A" = '1' /*Unspecified displaced fracture of fifth cervicalvertebra, initial encounter for closed fracture */
"S12400B" = '1' /*Unspecified displaced fracture of fifth cervicalvertebra, initial encounter for open fracture */
"S12401A" = '1' /*Unspecified nondisplaced fracture of fifth cervicalvertebra, initial encounter for closed fracture */
"S12401B" = '1' /*Unspecified nondisplaced fracture of fifth cervicalvertebra, initial encounter for open fracture */
"S12430A" = '1' /*Unspecified traumatic displaced spondylolisthesis offifth cervical vertebra, initial encounter for closedfracture */
"S12430B" = '1' /*Unspecified traumatic displaced spondylolisthesis offifth cervical vertebra, initial encounter for openfracture */
"S12431A" = '1' /*Unspecified traumatic nondisplaced spondylolisthesisof fifth cervical vertebra, initial encounter for closedfracture */
"S12431B" = '1' /*Unspecified traumatic nondisplaced spondylolisthesisof fifth cervical vertebra, initial encounter for openfracture */
"S1244XA" = '1' /*Type III traumatic spondylolisthesis of fifth cervicalvertebra, initial encounter for closed fracture */
"S1244XB" = '1' /*Type III traumatic spondylolisthesis of fifth cervicalvertebra, initial encounter for open fracture */
"S12450A" = '1' /*Other traumatic displaced spondylolisthesis of fifthcervical vertebra, initial encounter for closed fracture */
"S12450B" = '1' /*Other traumatic displaced spondylolisthesis of fifthcervical vertebra, initial encounter for open fracture */
"S12451A" = '1' /*Other traumatic nondisplaced spondylolisthesis of fifthcervical vertebra, initial encounter for closed fracture */
"S12451B" = '1' /*Other traumatic nondisplaced spondylolisthesis of fifthcervical vertebra, initial encounter for open fracture */
"S12490A" = '1' /*Other displaced fracture of fifth cervical vertebra, initialencounter for closed fracture */
"S12490B" = '1' /*Other displaced fracture of fifth cervical vertebra, initialencounter for open fracture */
"S12491A" = '1' /*Other nondisplaced fracture of fifth cervical vertebra,initial encounter for closed fracture */
"S12491B" = '1' /*Other nondisplaced fracture of fifth cervical vertebra,initial encounter for open fracture */
"S12500A" = '1' /*Unspecified displaced fracture of sixth cervicalvertebra, initial encounter for closed fracture */
"S12500B" = '1' /*Unspecified displaced fracture of sixth cervicalvertebra, initial encounter for open fracture */
"S12501A" = '1' /*Unspecified nondisplaced fracture of sixth cervicalvertebra, initial encounter for closed fracture */
"S12501B" = '1' /*Unspecified nondisplaced fracture of sixth cervicalvertebra, initial encounter for open fracture */
"S12530A" = '1' /*Unspecified traumatic displaced spondylolisthesis ofsixth cervical vertebra, initial encounter for closedfracture */
"S12530B" = '1' /*Unspecified traumatic displaced spondylolisthesis ofsixth cervical vertebra, initial encounter for openfracture */
"S12531A" = '1' /*Unspecified traumatic nondisplaced spondylolisthesisof sixth cervical vertebra, initial encounter for closedfracture */
"S12531B" = '1' /*Unspecified traumatic nondisplaced spondylolisthesisof sixth cervical vertebra, initial encounter for openfracture */
"S1254XA" = '1' /*Type III traumatic spondylolisthesis of sixth cervicalvertebra, initial encounter for closed fracture */
"S1254XB" = '1' /*Type III traumatic spondylolisthesis of sixth cervicalvertebra, initial encounter for open fracture */
"S12550A" = '1' /*Other traumatic displaced spondylolisthesis of sixthcervical vertebra, initial encounter for closed fracture */
"S12550B" = '1' /*Other traumatic displaced spondylolisthesis of sixthcervical vertebra, initial encounter for open fracture */
"S12551A" = '1' /*Other traumatic nondisplaced spondylolisthesis ofsixth cervical vertebra, initial encounter for closedfracture */
"S12551B" = '1' /*Other traumatic nondisplaced spondylolisthesis ofsixth cervical vertebra, initial encounter for openfracture */
"S12590A" = '1' /*Other displaced fracture of sixth cervical vertebra,initial encounter for closed fracture */
"S12590B" = '1' /*Other displaced fracture of sixth cervical vertebra,initial encounter for open fracture */
"S12591A" = '1' /*Other nondisplaced fracture of sixth cervical vertebra,initial encounter for closed fracture */
"S12591B" = '1' /*Other nondisplaced fracture of sixth cervical vertebra,initial encounter for open fracture */
"S12600A" = '1' /*Unspecified displaced fracture of seventh cervicalvertebra, initial encounter for closed fracture */
"S12600B" = '1' /*Unspecified displaced fracture of seventh cervicalvertebra, initial encounter for open fracture */
"S12601A" = '1' /*Unspecified nondisplaced fracture of seventh cervicalvertebra, initial encounter for closed fracture */
"S12601B" = '1' /*Unspecified nondisplaced fracture of seventh cervicalvertebra, initial encounter for open fracture */
"S12630A" = '1' /*Unspecified traumatic displaced spondylolisthesis ofseventh cervical vertebra, initial encounter for closedfracture */
"S12630B" = '1' /*Unspecified traumatic displaced spondylolisthesis ofseventh cervical vertebra, initial encounter for openfracture */
"S12631A" = '1' /*Unspecified traumatic nondisplaced spondylolisthesisof seventh cervical vertebra, initial encounter forclosed fracture */
"S12631B" = '1' /*Unspecified traumatic nondisplaced spondylolisthesisof seventh cervical vertebra, initial encounter for openfracture */
"S1264XA" = '1' /*Type III traumatic spondylolisthesis of seventh cervicalvertebra, initial encounter for closed fracture */
"S1264XB" = '1' /*Type III traumatic spondylolisthesis of seventh cervicalvertebra, initial encounter for open fracture */
"S12650A" = '1' /*Other traumatic displaced spondylolisthesis of seventhcervical vertebra, initial encounter for closed fracture */
"S12650B" = '1' /*Other traumatic displaced spondylolisthesis of seventhcervical vertebra, initial encounter for open fracture */
"S12651A" = '1' /*Other traumatic nondisplaced spondylolisthesis ofseventh cervical vertebra, initial encounter for closedfracture */
"S12651B" = '1' /*Other traumatic nondisplaced spondylolisthesis ofseventh cervical vertebra, initial encounter for openfracture */
"S12690A" = '1' /*Other displaced fracture of seventh cervical vertebra,initial encounter for closed fracture */
"S12690B" = '1' /*Other displaced fracture of seventh cervical vertebra,initial encounter for open fracture */
"S12691A" = '1' /*Other nondisplaced fracture of seventh cervicalvertebra, initial encounter for closed fracture */
"S12691B" = '1' /*Other nondisplaced fracture of seventh cervicalvertebra, initial encounter for open fracture */
"S129XXA" = '1' /*Fracture of neck, unspecified, initial encounter */
"S140XXA" = '1' /*Concussion and edema of cervical spinal cord, initialencounter */
"S14101A" = '1' /*Unspecified injury at C1 level of cervical spinal cord,initial encounter */
"S14102A" = '1' /*Unspecified injury at C2 level of cervical spinal cord,initial encounter */
"S14103A" = '1' /*Unspecified injury at C3 level of cervical spinal cord,initial encounter */
"S14104A" = '1' /*Unspecified injury at C4 level of cervical spinal cord,initial encounter */
"S14105A" = '1' /*Unspecified injury at C5 level of cervical spinal cord,initial encounter */
"S14106A" = '1' /*Unspecified injury at C6 level of cervical spinal cord,initial encounter */
"S14107A" = '1' /*Unspecified injury at C7 level of cervical spinal cord,initial encounter */
"S14108A" = '1' /*Unspecified injury at C8 level of cervical spinal cord,initial encounter */
"S14111A" = '1' /*Complete lesion at C1 level of cervical spinal cord,initial encounter */
"S14112A" = '1' /*Complete lesion at C2 level of cervical spinal cord,initial encounter */
"S14113A" = '1' /*Complete lesion at C3 level of cervical spinal cord,initial encounter */
"S14114A" = '1' /*Complete lesion at C4 level of cervical spinal cord,initial encounter */
"S14115A" = '1' /*Complete lesion at C5 level of cervical spinal cord,initial encounter */
"S14116A" = '1' /*Complete lesion at C6 level of cervical spinal cord,initial encounter */
"S14117A" = '1' /*Complete lesion at C7 level of cervical spinal cord,initial encounter */
"S14118A" = '1' /*Complete lesion at C8 level of cervical spinal cord,initial encounter */
"S14121A" = '1' /*Central cord syndrome at C1 level of cervical spinalcord, initial encounter */
"S14122A" = '1' /*Central cord syndrome at C2 level of cervical spinalcord, initial encounter */
"S14123A" = '1' /*Central cord syndrome at C3 level of cervical spinalcord, initial encounter */
"S14124A" = '1' /*Central cord syndrome at C4 level of cervical spinalcord, initial encounter */
"S14125A" = '1' /*Central cord syndrome at C5 level of cervical spinalcord, initial encounter */
"S14126A" = '1' /*Central cord syndrome at C6 level of cervical spinalcord, initial encounter */
"S14127A" = '1' /*Central cord syndrome at C7 level of cervical spinalcord, initial encounter */
"S14128A" = '1' /*Central cord syndrome at C8 level of cervical spinalcord, initial encounter */
"S14131A" = '1' /*Anterior cord syndrome at C1 level of cervical spinalcord, initial encounter */
"S14132A" = '1' /*Anterior cord syndrome at C2 level of cervical spinalcord, initial encounter */
"S14133A" = '1' /*Anterior cord syndrome at C3 level of cervical spinalcord, initial encounter */
"S14134A" = '1' /*Anterior cord syndrome at C4 level of cervical spinalcord, initial encounter */
"S14135A" = '1' /*Anterior cord syndrome at C5 level of cervical spinalcord, initial encounter */
"S14136A" = '1' /*Anterior cord syndrome at C6 level of cervical spinalcord, initial encounter */
"S14137A" = '1' /*Anterior cord syndrome at C7 level of cervical spinalcord, initial encounter */
"S14138A" = '1' /*Anterior cord syndrome at C8 level of cervical spinalcord, initial encounter */
"S14141A" = '1' /*Brown-Sequard syndrome at C1 level of cervicalspinal cord, initial encounter */
"S14142A" = '1' /*Brown-Sequard syndrome at C2 level of cervicalspinal cord, initial encounter */
"S14143A" = '1' /*Brown-Sequard syndrome at C3 level of cervicalspinal cord, initial encounter */
"S14144A" = '1' /*Brown-Sequard syndrome at C4 level of cervicalspinal cord, initial encounter */
"S14145A" = '1' /*Brown-Sequard syndrome at C5 level of cervicalspinal cord, initial encounter */
"S14146A" = '1' /*Brown-Sequard syndrome at C6 level of cervicalspinal cord, initial encounter */
"S14147A" = '1' /*Brown-Sequard syndrome at C7 level of cervicalspinal cord, initial encounter */
"S14148A" = '1' /*Brown-Sequard syndrome at C8 level of cervicalspinal cord, initial encounter */
"S14151A" = '1' /*Other incomplete lesion at C1 level of cervical spinalcord, initial encounter */
"S14152A" = '1' /*Other incomplete lesion at C2 level of cervical spinalcord, initial encounter */
"S14153A" = '1' /*Other incomplete lesion at C3 level of cervical spinalcord, initial encounter */
"S14154A" = '1' /*Other incomplete lesion at C4 level of cervical spinalcord, initial encounter */
"S14155A" = '1' /*Other incomplete lesion at C5 level of cervical spinalcord, initial encounter */
"S14156A" = '1' /*Other incomplete lesion at C6 level of cervical spinalcord, initial encounter */
"S14157A" = '1' /*Other incomplete lesion at C7 level of cervical spinalcord, initial encounter */
"S14158A" = '1' /*Other incomplete lesion at C8 level of cervical spinalcord, initial encounter */
"S240XXA" = '1' /*Concussion and edema of thoracic spinal cord, initialencounter */
"S24101A" = '1' /*Unspecified injury at T1 level of thoracic spinal cord,initial encounter */
"S24102A" = '1' /*Unspecified injury at T2-T6 level of thoracic spinalcord, initial encounter */
"S24103A" = '1' /*Unspecified injury at T7-T10 level of thoracic spinalcord, initial encounter */
"S24104A" = '1' /*Unspecified injury at T11-T12 level of thoracic spinalcord, initial encounter */
"S24111A" = '1' /*Complete lesion at T1 level of thoracic spinal cord,initial encounter */
"S24112A" = '1' /*Complete lesion at T2-T6 level of thoracic spinal cord,initial encounter */
"S24113A" = '1' /*Complete lesion at T7-T10 level of thoracic spinalcord, initial encounter */
"S24114A" = '1' /*Complete lesion at T11-T12 level of thoracic spinalcord, initial encounter */
"S24131A" = '1' /*Anterior cord syndrome at T1 level of thoracic spinalcord, initial encounter */
"S24132A" = '1' /*Anterior cord syndrome at T2-T6 level of thoracicspinal cord, initial encounter */
"S24133A" = '1' /*Anterior cord syndrome at T7-T10 level of thoracicspinal cord, initial encounter */
"S24134A" = '1' /*Anterior cord syndrome at T11-T12 level of thoracicspinal cord, initial encounter */
"S24141A" = '1' /*Brown-Sequard syndrome at T1 level of thoracicspinal cord, initial encounter */
"S24142A" = '1' /*Brown-Sequard syndrome at T2-T6 level of thoracicspinal cord, initial encounter */
"S24143A" = '1' /*Brown-Sequard syndrome at T7-T10 level of thoracicspinal cord, initial encounter */
"S24144A" = '1' /*Brown-Sequard syndrome at T11-T12 level of thoracicspinal cord, initial encounter */
"S24151A" = '1' /*Other incomplete lesion at T1 level of thoracic spinalcord, initial encounter */
"S24152A" = '1' /*Other incomplete lesion at T2-T6 level of thoracicspinal cord, initial encounter */
"S24153A" = '1' /*Other incomplete lesion at T7-T10 level of thoracicspinal cord, initial encounter */
"S24154A" = '1' /*Other incomplete lesion at T11-T12 level of thoracicspinal cord, initial encounter */
OTHER = '0'
;

/* FORMAT FOR Liver transplant procedure codes */
Value $LIVERTRP
"0FY00Z0" = '1' /*Transplantation of Liver, Allogeneic, Open Approach */
"0FY00Z1" = '1' /*Transplantation of Liver, Syngeneic, Open Approach */
"0FY00Z2" = '1' /*Transplantation of Liver, Zooplastic, Open Approach */
OTHER = '0'
;

/* FORMAT FOR MS-DRG (V25) TO MDC */
Value MDCF2T
001 = 77
002 = 77
003 = 77
004 = 77
005 = 77
006 = 77
007 = 77
008 = 77
009 = 77
010 = 77
011 = 77
012 = 77
013 = 77
014 = 77
015 = 77
016 = 77
017 = 77
020 = 01
021 = 01
022 = 01
023 = 01
024 = 01
025 = 01
026 = 01
027 = 01
028 = 01
029 = 01
030 = 01
031 = 01
032 = 01
033 = 01
034 = 01
035 = 01
036 = 01
037 = 01
038 = 01
039 = 01
040 = 01
041 = 01
042 = 01
052 = 01
053 = 01
054 = 01
055 = 01
056 = 01
057 = 01
058 = 01
059 = 01
060 = 01
061 = 01
062 = 01
063 = 01
064 = 01
065 = 01
066 = 01
067 = 01
068 = 01
069 = 01
070 = 01
071 = 01
072 = 01
073 = 01
074 = 01
075 = 01
076 = 01
077 = 01
078 = 01
079 = 01
080 = 01
081 = 01
082 = 01
083 = 01
084 = 01
085 = 01
086 = 01
087 = 01
088 = 01
089 = 01
090 = 01
091 = 01
092 = 01
093 = 01
094 = 01
095 = 01
096 = 01
097 = 01
098 = 01
099 = 01
100 = 01
101 = 01
102 = 01
103 = 01
113 = 02
114 = 02
115 = 02
116 = 02
117 = 02
121 = 02
122 = 02
123 = 02
124 = 02
125 = 02
129 = 03
130 = 03
131 = 03
132 = 03
133 = 03
134 = 03
135 = 03
136 = 03
137 = 03
138 = 03
139 = 03
146 = 03
147 = 03
148 = 03
149 = 03
150 = 03
151 = 03
152 = 03
153 = 03
154 = 03
155 = 03
156 = 03
157 = 03
158 = 03
159 = 03
163 = 04
164 = 04
165 = 04
166 = 04
167 = 04
168 = 04
175 = 04
176 = 04
177 = 04
178 = 04
179 = 04
180 = 04
181 = 04
182 = 04
183 = 04
184 = 04
185 = 04
186 = 04
187 = 04
188 = 04
189 = 04
190 = 04
191 = 04
192 = 04
193 = 04
194 = 04
195 = 04
196 = 04
197 = 04
198 = 04
199 = 04
200 = 04
201 = 04
202 = 04
203 = 04
204 = 04
205 = 04
206 = 04
207 = 04
208 = 04
215 = 05
216 = 05
217 = 05
218 = 05
219 = 05
220 = 05
221 = 05
222 = 05
223 = 05
224 = 05
225 = 05
226 = 05
227 = 05
228 = 05
229 = 05
230 = 05
231 = 05
232 = 05
233 = 05
234 = 05
235 = 05
236 = 05
237 = 05
238 = 05
239 = 05
240 = 05
241 = 05
242 = 05
243 = 05
244 = 05
245 = 05
246 = 05
247 = 05
248 = 05
249 = 05
250 = 05
251 = 05
252 = 05
253 = 05
254 = 05
255 = 05
256 = 05
257 = 05
258 = 05
259 = 05
260 = 05
261 = 05
262 = 05
263 = 05
264 = 05
265 = 05
266 = 05
267 = 05
268 = 05
269 = 05
270 = 05
271 = 05
272 = 05
273 = 05
274 = 05
280 = 05
281 = 05
282 = 05
283 = 05
284 = 05
285 = 05
286 = 05
287 = 05
288 = 05
289 = 05
290 = 05
291 = 05
292 = 05
293 = 05
294 = 05
295 = 05
296 = 05
297 = 05
298 = 05
299 = 05
300 = 05
301 = 05
302 = 05
303 = 05
304 = 05
305 = 05
306 = 05
307 = 05
308 = 05
309 = 05
310 = 05
311 = 05
312 = 05
313 = 05
314 = 05
315 = 05
316 = 05
326 = 06
327 = 06
328 = 06
329 = 06
330 = 06
331 = 06
332 = 06
333 = 06
334 = 06
335 = 06
336 = 06
337 = 06
338 = 06
339 = 06
340 = 06
341 = 06
342 = 06
343 = 06
344 = 06
345 = 06
346 = 06
347 = 06
348 = 06
349 = 06
350 = 06
351 = 06
352 = 06
353 = 06
354 = 06
355 = 06
356 = 06
357 = 06
358 = 06
368 = 06
369 = 06
370 = 06
371 = 06
372 = 06
373 = 06
374 = 06
375 = 06
376 = 06
377 = 06
378 = 06
379 = 06
380 = 06
381 = 06
382 = 06
383 = 06
384 = 06
385 = 06
386 = 06
387 = 06
388 = 06
389 = 06
390 = 06
391 = 06
392 = 06
393 = 06
394 = 06
395 = 06
405 = 07
406 = 07
407 = 07
408 = 07
409 = 07
410 = 07
411 = 07
412 = 07
413 = 07
414 = 07
415 = 07
416 = 07
417 = 07
418 = 07
419 = 07
420 = 07
421 = 07
422 = 07
423 = 07
424 = 07
425 = 07
432 = 07
433 = 07
434 = 07
435 = 07
436 = 07
437 = 07
438 = 07
439 = 07
440 = 07
441 = 07
442 = 07
443 = 07
444 = 07
445 = 07
446 = 07
453 = 08
454 = 08
455 = 08
456 = 08
457 = 08
458 = 08
459 = 08
460 = 08
461 = 08
462 = 08
463 = 08
464 = 08
465 = 08
466 = 08
467 = 08
468 = 08
469 = 08
470 = 08
471 = 08
472 = 08
473 = 08
474 = 08
475 = 08
476 = 08
477 = 08
478 = 08
479 = 08
480 = 08
481 = 08
482 = 08
483 = 08
484 = 08
485 = 08
486 = 08
487 = 08
488 = 08
489 = 08
490 = 08
491 = 08
492 = 08
493 = 08
494 = 08
495 = 08
496 = 08
497 = 08
498 = 08
499 = 08
500 = 08
501 = 08
502 = 08
503 = 08
504 = 08
505 = 08
506 = 08
507 = 08
508 = 08
509 = 08
510 = 08
511 = 08
512 = 08
513 = 08
514 = 08
515 = 08
516 = 08
517 = 08
518 = 08
519 = 08
520 = 08
533 = 08
534 = 08
535 = 08
536 = 08
537 = 08
538 = 08
539 = 08
540 = 08
541 = 08
542 = 08
543 = 08
544 = 08
545 = 08
546 = 08
547 = 08
548 = 08
549 = 08
550 = 08
551 = 08
552 = 08
553 = 08
554 = 08
555 = 08
556 = 08
557 = 08
558 = 08
559 = 08
560 = 08
561 = 08
562 = 08
563 = 08
564 = 08
565 = 08
566 = 08
570 = 09
571 = 09
572 = 09
573 = 09
574 = 09
575 = 09
576 = 09
577 = 09
578 = 09
579 = 09
580 = 09
581 = 09
582 = 09
583 = 09
584 = 09
585 = 09
592 = 09
593 = 09
594 = 09
595 = 09
596 = 09
597 = 09
598 = 09
599 = 09
600 = 09
601 = 09
602 = 09
603 = 09
604 = 09
605 = 09
606 = 09
607 = 09
614 = 10
615 = 10
616 = 10
617 = 10
618 = 10
619 = 10
620 = 10
621 = 10
622 = 10
623 = 10
624 = 10
625 = 10
626 = 10
627 = 10
628 = 10
629 = 10
630 = 10
637 = 10
638 = 10
639 = 10
640 = 10
641 = 10
642 = 10
643 = 10
644 = 10
645 = 10
652 = 11
653 = 11
654 = 11
655 = 11
656 = 11
657 = 11
658 = 11
659 = 11
660 = 11
661 = 11
662 = 11
663 = 11
664 = 11
665 = 11
666 = 11
667 = 11
668 = 11
669 = 11
670 = 11
671 = 11
672 = 11
673 = 11
674 = 11
675 = 11
682 = 11
683 = 11
684 = 11
685 = 11
686 = 11
687 = 11
688 = 11
689 = 11
690 = 11
691 = 11
692 = 11
693 = 11
694 = 11
695 = 11
696 = 11
697 = 11
698 = 11
699 = 11
700 = 11
707 = 12
708 = 12
709 = 12
710 = 12
711 = 12
712 = 12
713 = 12
714 = 12
715 = 12
716 = 12
717 = 12
718 = 12
722 = 12
723 = 12
724 = 12
725 = 12
726 = 12
727 = 12
728 = 12
729 = 12
730 = 12
734 = 13
735 = 13
736 = 13
737 = 13
738 = 13
739 = 13
740 = 13
741 = 13
742 = 13
743 = 13
744 = 13
745 = 13
746 = 13
747 = 13
748 = 13
749 = 13
750 = 13
754 = 13
755 = 13
756 = 13
757 = 13
758 = 13
759 = 13
760 = 13
761 = 13
765 = 14
766 = 14
767 = 14
768 = 14
769 = 14
770 = 14
774 = 14
775 = 14
776 = 14
777 = 14
778 = 14
779 = 14
780 = 14
781 = 14
782 = 14
789 = 15
790 = 15
791 = 15
792 = 15
793 = 15
794 = 15
795 = 15
799 = 16
800 = 16
801 = 16
802 = 16
803 = 16
804 = 16
808 = 16
809 = 16
810 = 16
811 = 16
812 = 16
813 = 16
814 = 16
815 = 16
816 = 16
820 = 17
821 = 17
822 = 17
823 = 17
824 = 17
825 = 17
826 = 17
827 = 17
828 = 17
829 = 17
830 = 17
834 = 17
835 = 17
836 = 17
837 = 17
838 = 17
839 = 17
840 = 17
841 = 17
842 = 17
843 = 17
844 = 17
845 = 17
846 = 17
847 = 17
848 = 17
849 = 17
853 = 18
854 = 18
855 = 18
856 = 18
857 = 18
858 = 18
862 = 18
863 = 18
864 = 18
865 = 18
866 = 18
867 = 18
868 = 18
869 = 18
870 = 18
871 = 18
872 = 18
876 = 19
880 = 19
881 = 19
882 = 19
883 = 19
884 = 19
885 = 19
886 = 19
887 = 19
894 = 20
895 = 20
896 = 20
897 = 20
901 = 21
902 = 21
903 = 21
904 = 21
905 = 21
906 = 21
907 = 21
908 = 21
909 = 21
913 = 21
914 = 21
915 = 21
916 = 21
917 = 21
918 = 21
919 = 21
920 = 21
921 = 21
922 = 21
923 = 21
927 = 22
928 = 22
929 = 22
933 = 22
934 = 22
935 = 22
939 = 23
940 = 23
941 = 23
945 = 23
946 = 23
947 = 23
948 = 23
949 = 23
950 = 23
951 = 23
955 = 24
956 = 24
957 = 24
958 = 24
959 = 24
963 = 24
964 = 24
965 = 24
969 = 25
970 = 25
974 = 25
975 = 25
976 = 25
977 = 25
981 = 88
982 = 88
983 = 88
984 = 88
985 = 88
986 = 88
987 = 88
988 = 88
989 = 88
998 = 88
999 = 88
OTHER = 99
;

/* FORMAT FOR Acute myocardial infarction (AMI) diagnosis codes */
Value $MRTAMID
"I2101" = '1' /*ST elevation (STEMI) myocardial infarction involving leftmain coronary artery */
"I2102" = '1' /*ST elevation (STEMI) myocardial infarction involving leftanterior descending coronary artery */
"I2109" = '1' /*ST elevation (STEMI) myocardial infarction involving othercoronary artery of anterior wall */
"I2111" = '1' /*ST elevation (STEMI) myocardial infarction involving rightcoronary artery */
"I2119" = '1' /*ST elevation (STEMI) myocardial infarction involving othercoronary artery of inferior wall */
"I2121" = '1' /*ST elevation (STEMI) myocardial infarction involving leftcircumflex coronary artery */
"I2129" = '1' /*ST elevation (STEMI) myocardial infarction involving othersites */
"I213" = '1' /*ST elevation (STEMI) myocardial infarction of unspecifiedsite */
"I214" = '1' /*Non-ST elevation (NSTEMI) myocardial infarction */
"I219" = '1' /*Acute myocardial infarction, unspecified */
"I21A1" = '1' /*Myocardial infarction type 2 */
"I21A9" = '1' /*Other myocardial infarction type */
"I220" = '1' /*Subsequent ST elevation (STEMI) myocardial infarction ofanterior wall */
"I221" = '1' /*Subsequent ST elevation (STEMI) myocardial infarction ofinferior wall */
"I222" = '1' /*Subsequent non-ST elevation (NSTEMI) myocardialinfarction */
"I228" = '1' /*Subsequent ST elevation (STEMI) myocardial infarction ofother sites */
"I229" = '1' /*Subsequent ST elevation (STEMI) myocardial infarction ofunspecified site */
OTHER = '0'
;

/* FORMAT FOR Heart failure diagnosis codes */
Value $MRTCHFD
"I0981" = '1' /*Rheumatic heart failure */
"I110" = '1' /*Hypertensive heart disease with heart failure */
"I130" = '1' /*Hypertensive heart and chronic kidney diseasewith heart failure and stage 1 through stage 4chronic kidney disease, or unspecified chronickidney disease */
"I132" = '1' /*Hypertensive heart and chronic kidney diseasewith heart failure and with stage 5 chronickidney disease, or end stage renal disease */
"I501" = '1' /*Left ventricular failure, unspecified */
"I5020" = '1' /*Unspecified systolic (congestive) heart failure */
"I5021" = '1' /*Acute systolic (congestive) heart failure */
"I5022" = '1' /*Chronic systolic (congestive) heart failure */
"I5023" = '1' /*Acute on chronic systolic (congestive) heartfailure */
"I5030" = '1' /*Unspecified diastolic (congestive) heart failure */
"I5031" = '1' /*Acute diastolic (congestive) heart failure */
"I5032" = '1' /*Chronic diastolic (congestive) heart failure */
"I5033" = '1' /*Acute on chronic diastolic (congestive) heartfailure */
"I5040" = '1' /*Unspecified combined systolic (congestive) anddiastolic (congestive) heart failure */
"I5041" = '1' /*Acute combined systolic (congestive) anddiastolic (congestive) heart failure */
"I5042" = '1' /*Chronic combined systolic (congestive) anddiastolic (congestive) heart failure */
"I5043" = '1' /*Acute on chronic combined systolic (congestive)and diastolic (congestive) heart failure */
"I50810" = '1' /*Right heart failure, unspecified */
"I50811" = '1' /*Acute right heart failure */
"I50812" = '1' /*Chronic right heart failure */
"I50813" = '1' /*Acute on chronic right heart failure */
"I50814" = '1' /*Right heart failure due to left heart failure */
"I5082" = '1' /*Biventricular heart failure */
"I5083" = '1' /*High output heart failure */
"I5084" = '1' /*End stage heart failure */
"I5089" = '1' /*Other heart failure */
"I509" = '1' /*Heart failure, unspecified */
OTHER = '0'
;

/* FORMAT FOR Subarachnoid hemorrhage diagnosis codes */
Value $MRTCV2A
"I6000" = '1' /*Nontraumatic subarachnoid hemorrhage from unspecified carotidsiphon and bifurcation */
"I6001" = '1' /*Nontraumatic subarachnoid hemorrhage from right carotid siphon andbifurcation */
"I6002" = '1' /*Nontraumatic subarachnoid hemorrhage from left carotid siphon andbifurcation */
"I6010" = '1' /*Nontraumatic subarachnoid hemorrhage from unspecified middlecerebral artery */
"I6011" = '1' /*Nontraumatic subarachnoid hemorrhage from right middle cerebralartery */
"I6012" = '1' /*Nontraumatic subarachnoid hemorrhage from left middle cerebralartery */
"I602" = '1' /*Nontraumatic subarachnoid hemorrhage from anterior communicating artery */
"I6020" = '1' /*Nontraumatic subarachnoid hemorrhage from unspecified anteriorcommunicating artery */
"I6021" = '1' /*Nontraumatic subarachnoid hemorrhage from right anteriorcommunicating artery */
"I6022" = '1' /*Nontraumatic subarachnoid hemorrhage from left anteriorcommunicating artery */
"I6030" = '1' /*Nontraumatic subarachnoid hemorrhage from unspecified posteriorcommunicating artery */
"I6031" = '1' /*Nontraumatic subarachnoid hemorrhage from right posteriorcommunicating artery */
"I6032" = '1' /*Nontraumatic subarachnoid hemorrhage from left posteriorcommunicating artery */
"I604" = '1' /*Nontraumatic subarachnoid hemorrhage from basilar artery */
"I6050" = '1' /*Nontraumatic subarachnoid hemorrhage from unspecified vertebralartery */
"I6051" = '1' /*Nontraumatic subarachnoid hemorrhage from right vertebral artery */
"I6052" = '1' /*Nontraumatic subarachnoid hemorrhage from left vertebral artery */
"I606" = '1' /*Nontraumatic subarachnoid hemorrhage from other intracranialarteries */
"I607" = '1' /*Nontraumatic subarachnoid hemorrhage from unspecified intracranialartery */
"I608" = '1' /*Other nontraumatic subarachnoid hemorrhage */
"I609" = '1' /*Nontraumatic subarachnoid hemorrhage, unspecified */
OTHER = '0'
;

/* FORMAT FOR Intracerebral hemorrhage diagnosis codes */
Value $MRTCV3D
"I610" = '1' /*Nontraumatic intracerebral hemorrhage in hemisphere, subcortical */
"I611" = '1' /*Nontraumatic intracerebral hemorrhage in hemisphere, cortical */
"I612" = '1' /*Nontraumatic intracerebral hemorrhage in hemisphere, unspecified */
"I613" = '1' /*Nontraumatic intracerebral hemorrhage in brain stem */
"I614" = '1' /*Nontraumatic intracerebral hemorrhage in cerebellum */
"I615" = '1' /*Nontraumatic intracerebral hemorrhage, intraventricular */
"I616" = '1' /*Nontraumatic intracerebral hemorrhage, multiple localized */
"I618" = '1' /*Other nontraumatic intracerebral hemorrhage */
"I619" = '1' /*Nontraumatic intracerebral hemorrhage, unspecified */
"I6200" = '1' /*Nontraumatic subdural hemorrhage, unspecified */
"I6201" = '1' /*Nontraumatic acute subdural hemorrhage */
"I6202" = '1' /*Nontraumatic subacute subdural hemorrhage */
"I6203" = '1' /*Nontraumatic chronic subdural hemorrhage */
"I621" = '1' /*Nontraumatic extradural hemorrhage */
"I629" = '1' /*Nontraumatic intracranial hemorrhage, unspecified */
OTHER = '0'
;

/* FORMAT FOR Ischemic stroke diagnosis codes */
Value $MRTCV4D
"I6300" = '1' /*Cerebral infarction due to thrombosis of unspecifiedprecerebral artery */
"I63011" = '1' /*Cerebral infarction due to thrombosis of right vertebralartery */
"I63012" = '1' /*Cerebral infarction due to thrombosis of left vertebralartery */
"I63013" = '1' /*Cerebral infarction due to thrombosis of bilateral vertebral arteries */
"I63019" = '1' /*Cerebral infarction due to thrombosis of unspecifiedvertebral artery */
"I6302" = '1' /*Cerebral infarction due to thrombosis of basilar artery */
"I63031" = '1' /*Cerebral infarction due to thrombosis of right carotid artery */
"I63032" = '1' /*Cerebral infarction due to thrombosis of left carotid artery */
"I63033" = '1' /*Cerebral infarction due to thrombosis of bilateral carotid arteries */
"I63039" = '1' /*Cerebral infarction due to thrombosis of unspecifiedcarotid artery */
"I6309" = '1' /*Cerebral infarction due to thrombosis of other precerebralartery */
"I6310" = '1' /*Cerebral infarction due to embolism of unspecifiedprecerebral artery */
"I63111" = '1' /*Cerebral infarction due to embolism of right vertebralartery */
"I63112" = '1' /*Cerebral infarction due to embolism of left vertebral artery */
"I63113" = '1' /*Cerebral infarction due to embolism of bilateral vertebral arteries */
"I63119" = '1' /*Cerebral infarction due to embolism of unspecifiedvertebral artery */
"I6312" = '1' /*Cerebral infarction due to embolism of basilar artery */
"I63131" = '1' /*Cerebral infarction due to embolism of right carotid artery */
"I63132" = '1' /*Cerebral infarction due to embolism of left carotid artery */
"I63133" = '1' /*Cerebral infarction due to embolism of bilateral carotid arteries */
"I63139" = '1' /*Cerebral infarction due to embolism of unspecified carotidartery */
"I6319" = '1' /*Cerebral infarction due to embolism of other precerebralartery */
"I6320" = '1' /*Cerebral infarction due to unspecified occlusion orstenosis of unspecified precerebral arteries */
"I63211" = '1' /*Cerebral infarction due to unspecified occlusion or stenosis of right vertebral artery */
"I63212" = '1' /*Cerebral infarction due to unspecified occlusion or stenosis of left vertebral artery */
"I63213" = '1' /*Cerebral infarction due to unspecified occlusion or stenosis of bilateral vertebral arteries */
"I63219" = '1' /*Cerebral infarction due to unspecified occlusion orstenosis of unspecified vertebral arteries */
"I6322" = '1' /*Cerebral infarction due to unspecified occlusion or stenosis of basilar artery */
"I63231" = '1' /*Cerebral infarction due to unspecified occlusion orstenosis of right carotid arteries */
"I63232" = '1' /*Cerebral infarction due to unspecified occlusion orstenosis of left carotid arteries */
"I63233" = '1' /*Cerebral infarction due to unspecified occlusion or stenosis of bilateral carotid arteries */
"I63239" = '1' /*Cerebral infarction due to unspecified occlusion orstenosis of unspecified carotid arteries */
"I6329" = '1' /*Cerebral infarction due to unspecified occlusion orstenosis of other precerebral arteries */
"I6330" = '1' /*Cerebral infarction due to thrombosis of unspecifiedcerebral artery */
"I63311" = '1' /*Cerebral infarction due to thrombosis of right middlecerebral artery */
"I63312" = '1' /*Cerebral infarction due to thrombosis of left middlecerebral artery */
"I63313" = '1' /*Cerebral infarction due to thrombosis of bilateral middle cerebral arteries */
"I63319" = '1' /*Cerebral infarction due to thrombosis of unspecifiedmiddle cerebral artery */
"I63321" = '1' /*Cerebral infarction due to thrombosis of right anteriorcerebral artery */
"I63322" = '1' /*Cerebral infarction due to thrombosis of left anteriorcerebral artery */
"I63323" = '1' /*Cerebral infarction due to thrombosis of bilateral anterior cerebral arteries */
"I63329" = '1' /*Cerebral infarction due to thrombosis of unspecifiedanterior cerebral artery */
"I63331" = '1' /*Cerebral infarction due to thrombosis of right posteriorcerebral artery */
"I63332" = '1' /*Cerebral infarction due to thrombosis of left posteriorcerebral artery */
"I63333" = '1' /*Cerebral infarction to thrombosis of bilateral posterior cerebral arteries */
"I63339" = '1' /*Cerebral infarction due to thrombosis of unspecifiedposterior cerebral artery */
"I63341" = '1' /*Cerebral infarction due to thrombosis of right cerebellarartery */
"I63342" = '1' /*Cerebral infarction due to thrombosis of left cerebellarartery */
"I63343" = '1' /*Cerebral infarction to thrombosis of bilateral cerebellar arteries */
"I63349" = '1' /*Cerebral infarction due to thrombosis of unspecifiedcerebellar artery */
"I6339" = '1' /*Cerebral infarction due to thrombosis of other cerebralartery */
"I6340" = '1' /*Cerebral infarction due to embolism of unspecifiedcerebral artery */
"I63411" = '1' /*Cerebral infarction due to embolism of right middlecerebral artery */
"I63412" = '1' /*Cerebral infarction due to embolism of left middle cerebralartery */
"I63413" = '1' /*Cerebral infarction due to embolism of bilateral middle cerebral arteries */
"I63419" = '1' /*Cerebral infarction due to embolism of unspecified middlecerebral artery */
"I63421" = '1' /*Cerebral infarction due to embolism of right anteriorcerebral artery */
"I63422" = '1' /*Cerebral infarction due to embolism of left anteriorcerebral artery */
"I63423" = '1' /*Cerebral infarction due to embolism of bilateral anterior cerebral arteries */
"I63429" = '1' /*Cerebral infarction due to embolism of unspecified anteriorcerebral artery */
"I63431" = '1' /*Cerebral infarction due to embolism of right posteriorcerebral artery */
"I63432" = '1' /*Cerebral infarction due to embolism of left posteriorcerebral artery */
"I63433" = '1' /*Cerebral infarction due to embolism of bilateral posterior cerebral arteries */
"I63439" = '1' /*Cerebral infarction due to embolism of unspecifiedposterior cerebral artery */
"I63441" = '1' /*Cerebral infarction due to embolism of right cerebellarartery */
"I63442" = '1' /*Cerebral infarction due to embolism of left cerebellar artery */
"I63443" = '1' /*Cerebral infarction due to embolism of bilateral cerebellar arteries */
"I63449" = '1' /*Cerebral infarction due to embolism of unspecifiedcerebellar artery */
"I6349" = '1' /*Cerebral infarction due to embolism of other cerebralartery */
"I6350" = '1' /*Cerebral infarction due to unspecified occlusion orstenosis of unspecified cerebral artery */
"I63511" = '1' /*Cerebral infarction due to unspecified occlusion orstenosis of right middle cerebral artery */
"I63512" = '1' /*Cerebral infarction due to unspecified occlusion orstenosis of left middle cerebral artery */
"I63513" = '1' /*Cerebral infarction due to unspecified occlusion or stenosis of bilateral middle cerebral arteries */
"I63519" = '1' /*Cerebral infarction due to unspecified occlusion orstenosis of unspecified middle cerebral artery */
"I63521" = '1' /*Cerebral infarction due to unspecified occlusion orstenosis of right anterior cerebral artery */
"I63522" = '1' /*Cerebral infarction due to unspecified occlusion orstenosis of left anterior cerebral artery */
"I63523" = '1' /*Cerebral infarction due to unspecified occlusion or stenosis of bilateral anterior cerebral arteries */
"I63529" = '1' /*Cerebral infarction due to unspecified occlusion orstenosis of unspecified anterior cerebral artery */
"I63531" = '1' /*Cerebral infarction due to unspecified occlusion orstenosis of right posterior cerebral artery */
"I63532" = '1' /*Cerebral infarction due to unspecified occlusion orstenosis of left posterior cerebral artery */
"I63533" = '1' /*Cerebral infarction due to unspecified occlusion or stenosis of bilateral posterior cerebral arteries */
"I63539" = '1' /*Cerebral infarction due to unspecified occlusion orstenosis of unspecified posterior cerebral artery */
"I63541" = '1' /*Cerebral infarction due to unspecified occlusion orstenosis of right cerebellar artery */
"I63542" = '1' /*Cerebral infarction due to unspecified occlusion orstenosis of left cerebellar artery */
"I63543" = '1' /*Cerebral infarction due to unspecified occlusion or stenosis of bilateral cerebellar arteries */
"I63549" = '1' /*Cerebral infarction due to unspecified occlusion orstenosis of unspecified cerebellar artery */
"I6359" = '1' /*Cerebral infarction due to unspecified occlusion orstenosis of other cerebral artery */
"I636" = '1' /*Cerebral infarction due to cerebral venous thrombosis,nonpyogenic */
"I638" = '1' /*Other cerebral infarction */
"I639" = '1' /*Cerebral infarction, unspecified */
OTHER = '0'
;

/* FORMAT FOR Gastrointestinal hemorrhage diagnosis codes */
Value $MRTGIHD
"I8501" = '1' /*Esophageal varices with bleeding */
"I8511" = '1' /*Secondary esophageal varices with bleeding */
"K2211" = '1' /*Ulcer of esophagus with bleeding */
"K226" = '1' /*Gastro-esophageal laceration-hemorrhage syndrome */
"K250" = '1' /*Acute gastric ulcer with hemorrhage */
"K252" = '1' /*Acute gastric ulcer with both hemorrhage and perforation */
"K254" = '1' /*Chronic or unspecified gastric ulcer with hemorrhage */
"K256" = '1' /*Chronic or unspecified gastric ulcer with both hemorrhage andperforation */
"K260" = '1' /*Acute duodenal ulcer with hemorrhage */
"K262" = '1' /*Acute duodenal ulcer with both hemorrhage and perforation */
"K264" = '1' /*Chronic or unspecified duodenal ulcer with hemorrhage */
"K266" = '1' /*Chronic or unspecified duodenal ulcer with both hemorrhage andperforation */
"K270" = '1' /*Acute peptic ulcer, site unspecified, with hemorrhage */
"K272" = '1' /*Acute peptic ulcer, site unspecified, with both hemorrhage andperforation */
"K274" = '1' /*Chronic or unspecified peptic ulcer, site unspecified, withhemorrhage */
"K276" = '1' /*Chronic or unspecified peptic ulcer, site unspecified, with bothhemorrhage and perforation */
"K280" = '1' /*Acute gastrojejunal ulcer with hemorrhage */
"K282" = '1' /*Acute gastrojejunal ulcer with both hemorrhage and perforation */
"K284" = '1' /*Chronic or unspecified gastrojejunal ulcer with hemorrhage */
"K286" = '1' /*Chronic or unspecified gastrojejunal ulcer with both hemorrhage andperforation */
"K2901" = '1' /*Acute gastritis with bleeding */
"K2921" = '1' /*Alcoholic gastritis with bleeding */
"K2931" = '1' /*Chronic superficial gastritis with bleeding */
"K2941" = '1' /*Chronic atrophic gastritis with bleeding */
"K2951" = '1' /*Unspecified chronic gastritis with bleeding */
"K2961" = '1' /*Other gastritis with bleeding */
"K2971" = '1' /*Gastritis, unspecified, with bleeding */
"K2981" = '1' /*Duodenitis with bleeding */
"K2991" = '1' /*Gastroduodenitis, unspecified, with bleeding */
"K31811" = '1' /*Angiodysplasia of stomach and duodenum with bleeding */
"K3182" = '1' /*Dieulafoy lesion (hemorrhagic) of stomach and duodenum */
"K50011" = '1' /*Crohn's disease of small intestine with rectal bleeding */
"K50111" = '1' /*Crohn's disease of large intestine with rectal bleeding */
"K50811" = '1' /*Crohn's disease of both small and large intestine with rectal bleeding */
"K50911" = '1' /*Crohn's disease, unspecified, with rectal bleeding */
"K51011" = '1' /*Ulcerative (chronic) pancolitis with rectal bleeding */
"K51211" = '1' /*Ulcerative (chronic) proctitis with rectal bleeding */
"K51311" = '1' /*Ulcerative (chronic) rectosigmoiditis with rectal bleeding */
"K51411" = '1' /*Inflammatory polyps of colon with rectal bleeding */
"K51511" = '1' /*Left sided colitis with rectal bleeding */
"K51811" = '1' /*Other ulcerative colitis with rectal bleeding */
"K51911" = '1' /*Ulcerative colitis, unspecified with rectal bleeding */
"K5521" = '1' /*Angiodysplasia of colon with hemorrhage */
"K5701" = '1' /*Diverticulitis of small intestine with perforation and abscess withbleeding */
"K5711" = '1' /*Diverticulosis of small intestine without perforation or abscess withbleeding */
"K5713" = '1' /*Diverticulitis of small intestine without perforation or abscess withbleeding */
"K5721" = '1' /*Diverticulitis of large intestine with perforation and abscess withbleeding */
"K5731" = '1' /*Diverticulosis of large intestine without perforation or abscess withbleeding */
"K5733" = '1' /*Diverticulitis of large intestine without perforation or abscess withbleeding */
"K5741" = '1' /*Diverticulitis of both small and large intestine with perforation andabscess with bleeding */
"K5751" = '1' /*Diverticulosis of both small and large intestine without perforation orabscess with bleeding */
"K5753" = '1' /*Diverticulitis of both small and large intestine without perforation orabscess with bleeding */
"K5781" = '1' /*Diverticulitis of intestine, part unspecified, with perforation andabscess with bleeding */
"K5791" = '1' /*Diverticulosis of intestine, part unspecified, without perforation orabscess with bleeding */
"K5793" = '1' /*Diverticulitis of intestine, part unspecified, without perforation orabscess with bleeding */
"K625" = '1' /*Hemorrhage of anus and rectum */
"K6381" = '1' /*Dieulafoy lesion of intestine */
"K920" = '1' /*Hematemesis */
"K921" = '1' /*Melena */
"K922" = '1' /*Gastrointestinal hemorrhage, unspecified */
OTHER = '0'
;

/* FORMAT FOR Periprosthetic fracture diagnosis codes */
Value $MTHIP2D
"M9701XA" = '1' /*Periprosthetic fracture around internal prosthetic right hip joint, initial encounter */
"M9702XA" = '1' /*Periprosthetic fracture around internal prosthetic left hip joint, initial encounter */
"T84040A" = '1' /*Periprosthetic fracture around internal prosthetic right hip joint, initialencounter */
"T84041A" = '1' /*Periprosthetic fracture around internal prosthetic left hip joint, initialencounter */
OTHER = '0'
;

/* FORMAT FOR Hip fracture diagnosis codes */
Value $MTHIPFD
"M80051A" = '1' /*Age-related osteoporosis with current pathologicalfracture, right femur */
"M80052A" = '1' /*Age-related osteoporosis with current pathologicalfracture, left femur */
"M80059A" = '1' /*Age-related osteoporosis with current pathologicalfracture, unspecified femur */
"M80851A" = '1' /*Other osteoporosis with current pathological fracture,right femur */
"M80852A" = '1' /*Other osteoporosis with current pathological fracture, leftfemur */
"M80859A" = '1' /*Other osteoporosis with current pathological fracture,unspecified femur */
"S72001A" = '1' /*Fracture of unspecified part of neck of right femur, initialencounter for closed fracture */
"S72001B" = '1' /*Fracture of unspecified part of neck of right femur, initialencounter for open fracture type I or II */
"S72001C" = '1' /*Fracture of unspecified part of neck of right femur, initialencounter for open fracture type IIIA, IIIB, or IIIC */
"S72002A" = '1' /*Fracture of unspecified part of neck of left femur, initialencounter for closed fracture */
"S72002B" = '1' /*Fracture of unspecified part of neck of left femur, initialencounter for open fracture type I or II */
"S72002C" = '1' /*Fracture of unspecified part of neck of left femur, initialencounter for open fracture type IIIA, IIIB, or IIIC */
"S72009A" = '1' /*Fracture of unspecified part of neck of unspecifiedfemur, initial encounter for closed fracture */
"S72009B" = '1' /*Fracture of unspecified part of neck of unspecifiedfemur, initial encounter for open fracture type I or II */
"S72009C" = '1' /*Fracture of unspecified part of neck of unspecifiedfemur, initial encounter for open fracture type IIIA, IIIB,or IIIC */
"S72011A" = '1' /*Unspecified intracapsular fracture of right femur, initialencounter for closed fracture */
"S72011B" = '1' /*Unspecified intracapsular fracture of right femur, initialencounter for open fracture type I or II */
"S72011C" = '1' /*Unspecified intracapsular fracture of right femur, initialencounter for open fracture type IIIA, IIIB, or IIIC */
"S72012A" = '1' /*Unspecified intracapsular fracture of left femur, initialencounter for closed fracture */
"S72012B" = '1' /*Unspecified intracapsular fracture of left femur, initialencounter for open fracture type I or II */
"S72012C" = '1' /*Unspecified intracapsular fracture of left femur, initialencounter for open fracture type IIIA, IIIB, or IIIC */
"S72019A" = '1' /*Unspecified intracapsular fracture of unspecified femur,initial encounter for closed fracture */
"S72019B" = '1' /*Unspecified intracapsular fracture of unspecified femur,initial encounter for open fracture type I or II */
"S72019C" = '1' /*Unspecified intracapsular fracture of unspecified femur,initial encounter for open fracture type IIIA, IIIB, or IIIC */
"S72031A" = '1' /*Displaced midcervical fracture of right femur, initialencounter for closed fracture */
"S72031B" = '1' /*Displaced midcervical fracture of right femur, initialencounter for open fracture type I or II */
"S72031C" = '1' /*Displaced midcervical fracture of right femur, initialencounter for open fracture type IIIA, IIIB, or IIIC */
"S72032A" = '1' /*Displaced midcervical fracture of left femur, initialencounter for closed fracture */
"S72032B" = '1' /*Displaced midcervical fracture of left femur, initialencounter for open fracture type I or II */
"S72032C" = '1' /*Displaced midcervical fracture of left femur, initialencounter for open fracture type IIIA, IIIB, or IIIC */
"S72033A" = '1' /*Displaced midcervical fracture of unspecified femur,initial encounter for closed fracture */
"S72033B" = '1' /*Displaced midcervical fracture of unspecified femur,initial encounter for open fracture type I or II */
"S72033C" = '1' /*Displaced midcervical fracture of unspecified femur,initial encounter for open fracture type IIIA, IIIB, or IIIC */
"S72034A" = '1' /*Nondisplaced midcervical fracture of right femur, initialencounter for closed fracture */
"S72034B" = '1' /*Nondisplaced midcervical fracture of right femur, initialencounter for open fracture type I or II */
"S72034C" = '1' /*Nondisplaced midcervical fracture of right femur, initialencounter for open fracture type IIIA, IIIB, or IIIC */
"S72035A" = '1' /*Nondisplaced midcervical fracture of left femur, initialencounter for closed fracture */
"S72035B" = '1' /*Nondisplaced midcervical fracture of left femur, initialencounter for open fracture type I or II */
"S72035C" = '1' /*Nondisplaced midcervical fracture of left femur, initialencounter for open fracture type IIIA, IIIB, or IIIC */
"S72036A" = '1' /*Nondisplaced midcervical fracture of unspecified femur,initial encounter for closed fracture */
"S72036B" = '1' /*Nondisplaced midcervical fracture of unspecified femur,initial encounter for open fracture type I or II */
"S72036C" = '1' /*Nondisplaced midcervical fracture of unspecified femur,initial encounter for open fracture type IIIA, IIIB, or IIIC */
"S72041A" = '1' /*Displaced fracture of base of neck of right femur, initialencounter for closed fracture */
"S72041B" = '1' /*Displaced fracture of base of neck of right femur, initialencounter for open fracture type I or II */
"S72041C" = '1' /*Displaced fracture of base of neck of right femur, initialencounter for open fracture type IIIA, IIIB, or IIIC */
"S72042A" = '1' /*Displaced fracture of base of neck of left femur, initialencounter for closed fracture */
"S72042B" = '1' /*Displaced fracture of base of neck of left femur, initialencounter for open fracture type I or II */
"S72042C" = '1' /*Displaced fracture of base of neck of left femur, initialencounter for open fracture type IIIA, IIIB, or IIIC */
"S72043A" = '1' /*Displaced fracture of base of neck of unspecified femur,initial encounter for closed fracture */
"S72043B" = '1' /*Displaced fracture of base of neck of unspecified femur,initial encounter for open fracture type I or II */
"S72043C" = '1' /*Displaced fracture of base of neck of unspecified femur,initial encounter for open fracture type IIIA, IIIB, or IIIC */
"S72044A" = '1' /*Nondisplaced fracture of base of neck of right femur,initial encounter for closed fracture */
"S72044B" = '1' /*Nondisplaced fracture of base of neck of right femur,initial encounter for open fracture type I or II */
"S72044C" = '1' /*Nondisplaced fracture of base of neck of right femur,initial encounter for open fracture type IIIA, IIIB, or IIIC */
"S72045A" = '1' /*Nondisplaced fracture of base of neck of left femur,initial encounter for closed fracture */
"S72045B" = '1' /*Nondisplaced fracture of base of neck of left femur,initial encounter for open fracture type I or II */
"S72045C" = '1' /*Nondisplaced fracture of base of neck of left femur,initial encounter for open fracture type IIIA, IIIB, or IIIC */
"S72046A" = '1' /*Nondisplaced fracture of base of neck of unspecifiedfemur, initial encounter for closed fracture */
"S72046B" = '1' /*Nondisplaced fracture of base of neck of unspecifiedfemur, initial encounter for open fracture type I or II */
"S72046C" = '1' /*Nondisplaced fracture of base of neck of unspecifiedfemur, initial encounter for open fracture type IIIA, IIIB,or IIIC */
"S72051A" = '1' /*Unspecified fracture of head of right femur, initialencounter for closed fracture */
"S72051B" = '1' /*Unspecified fracture of head of right femur, initialencounter for open fracture type I or II */
"S72051C" = '1' /*Unspecified fracture of head of right femur, initialencounter for open fracture type IIIA, IIIB, or IIIC */
"S72052A" = '1' /*Unspecified fracture of head of left femur, initialencounter for closed fracture */
"S72052B" = '1' /*Unspecified fracture of head of left femur, initialencounter for open fracture type I or II */
"S72052C" = '1' /*Unspecified fracture of head of left femur, initialencounter for open fracture type IIIA, IIIB, or IIIC */
"S72059A" = '1' /*Unspecified fracture of head of unspecified femur, initialencounter for closed fracture */
"S72059B" = '1' /*Unspecified fracture of head of unspecified femur, initialencounter for open fracture type I or II */
"S72059C" = '1' /*Unspecified fracture of head of unspecified femur, initialencounter for open fracture type IIIA, IIIB, or IIIC */
"S72061A" = '1' /*Displaced articular fracture of head of right femur, initialencounter for closed fracture */
"S72061B" = '1' /*Displaced articular fracture of head of right femur, initialencounter for open fracture type I or II */
"S72061C" = '1' /*Displaced articular fracture of head of right femur, initialencounter for open fracture type IIIA, IIIB, or IIIC */
"S72062A" = '1' /*Displaced articular fracture of head of left femur, initialencounter for closed fracture */
"S72062B" = '1' /*Displaced articular fracture of head of left femur, initialencounter for open fracture type I or II */
"S72062C" = '1' /*Displaced articular fracture of head of left femur, initialencounter for open fracture type IIIA, IIIB, or IIIC */
"S72063A" = '1' /*Displaced articular fracture of head of unspecified femur,initial encounter for closed fracture */
"S72063B" = '1' /*Displaced articular fracture of head of unspecified femur,initial encounter for open fracture type I or II */
"S72063C" = '1' /*Displaced articular fracture of head of unspecified femur,initial encounter for open fracture type IIIA, IIIB, or IIIC */
"S72064A" = '1' /*Nondisplaced articular fracture of head of right femur,initial encounter for closed fracture */
"S72064B" = '1' /*Nondisplaced articular fracture of head of right femur,initial encounter for open fracture type I or II */
"S72064C" = '1' /*Nondisplaced articular fracture of head of right femur,initial encounter for open fracture type IIIA, IIIB, or IIIC */
"S72065A" = '1' /*Nondisplaced articular fracture of head of left femur,initial encounter for closed fracture */
"S72065B" = '1' /*Nondisplaced articular fracture of head of left femur,initial encounter for open fracture type I or II */
"S72065C" = '1' /*Nondisplaced articular fracture of head of left femur,initial encounter for open fracture type IIIA, IIIB, or IIIC */
"S72066A" = '1' /*Nondisplaced articular fracture of head of unspecifiedfemur, initial encounter for closed fracture */
"S72066B" = '1' /*Nondisplaced articular fracture of head of unspecifiedfemur, initial encounter for open fracture type I or II */
"S72066C" = '1' /*Nondisplaced articular fracture of head of unspecifiedfemur, initial encounter for open fracture type IIIA, IIIB,or IIIC */
"S72091A" = '1' /*Other fracture of head and neck of right femur, initialencounter for closed fracture */
"S72091B" = '1' /*Other fracture of head and neck of right femur, initialencounter for open fracture type I or II */
"S72091C" = '1' /*Other fracture of head and neck of right femur, initialencounter for open fracture type IIIA, IIIB, or IIIC */
"S72092A" = '1' /*Other fracture of head and neck of left femur, initialencounter for closed fracture */
"S72092B" = '1' /*Other fracture of head and neck of left femur, initialencounter for open fracture type I or II */
"S72092C" = '1' /*Other fracture of head and neck of left femur, initialencounter for open fracture type IIIA, IIIB, or IIIC */
"S72099A" = '1' /*Other fracture of head and neck of unspecified femur,initial encounter for closed fracture */
"S72099B" = '1' /*Other fracture of head and neck of unspecified femur,initial encounter for open fracture type I or II */
"S72099C" = '1' /*Other fracture of head and neck of unspecified femur,initial encounter for open fracture type IIIA, IIIB, or IIIC */
"S72101A" = '1' /*Unspecified trochanteric fracture of right femur, initialencounter for closed fracture */
"S72101B" = '1' /*Unspecified trochanteric fracture of right femur, initialencounter for open fracture type I or II */
"S72101C" = '1' /*Unspecified trochanteric fracture of right femur, initialencounter for open fracture type IIIA, IIIB, or IIIC */
"S72102A" = '1' /*Unspecified trochanteric fracture of left femur, initialencounter for closed fracture */
"S72102B" = '1' /*Unspecified trochanteric fracture of left femur, initialencounter for open fracture type I or II */
"S72102C" = '1' /*Unspecified trochanteric fracture of left femur, initialencounter for open fracture type IIIA, IIIB, or IIIC */
"S72109A" = '1' /*Unspecified trochanteric fracture of unspecified femur,initial encounter for closed fracture */
"S72109B" = '1' /*Unspecified trochanteric fracture of unspecified femur,initial encounter for open fracture type I or II */
"S72109C" = '1' /*Unspecified trochanteric fracture of unspecified femur,initial encounter for open fracture type IIIA, IIIB, or IIIC */
"S72111A" = '1' /*Displaced fracture of greater trochanter of right femur,initial encounter for closed fracture */
"S72111B" = '1' /*Displaced fracture of greater trochanter of right femur,initial encounter for open fracture type I or II */
"S72111C" = '1' /*Displaced fracture of greater trochanter of right femur,initial encounter for open fracture type IIIA, IIIB, or IIIC */
"S72112A" = '1' /*Displaced fracture of greater trochanter of left femur,initial encounter for closed fracture */
"S72112B" = '1' /*Displaced fracture of greater trochanter of left femur,initial encounter for open fracture type I or II */
"S72112C" = '1' /*Displaced fracture of greater trochanter of left femur,initial encounter for open fracture type IIIA, IIIB, or IIIC */
"S72113A" = '1' /*Displaced fracture of greater trochanter of unspecifiedfemur, initial encounter for closed fracture */
"S72113B" = '1' /*Displaced fracture of greater trochanter of unspecifiedfemur, initial encounter for open fracture type I or II */
"S72113C" = '1' /*Displaced fracture of greater trochanter of unspecifiedfemur, initial encounter for open fracture type IIIA, IIIB,or IIIC */
"S72114A" = '1' /*Nondisplaced fracture of greater trochanter of rightfemur, initial encounter for closed fracture */
"S72114B" = '1' /*Nondisplaced fracture of greater trochanter of rightfemur, initial encounter for open fracture type I or II */
"S72114C" = '1' /*Nondisplaced fracture of greater trochanter of rightfemur, initial encounter for open fracture type IIIA, IIIB,or IIIC */
"S72115A" = '1' /*Nondisplaced fracture of greater trochanter of left femur,initial encounter for closed fracture */
"S72115B" = '1' /*Nondisplaced fracture of greater trochanter of left femur,initial encounter for open fracture type I or II */
"S72115C" = '1' /*Nondisplaced fracture of greater trochanter of left femur,initial encounter for open fracture type IIIA, IIIB, or IIIC */
"S72116A" = '1' /*Nondisplaced fracture of greater trochanter ofunspecified femur, initial encounter for closed fracture */
"S72116B" = '1' /*Nondisplaced fracture of greater trochanter ofunspecified femur, initial encounter for open fracturetype I or II */
"S72116C" = '1' /*Nondisplaced fracture of greater trochanter ofunspecified femur, initial encounter for open fracturetype IIIA, IIIB, or IIIC */
"S72121A" = '1' /*Displaced fracture of lesser trochanter of right femur,initial encounter for closed fracture */
"S72121B" = '1' /*Displaced fracture of lesser trochanter of right femur,initial encounter for open fracture type I or II */
"S72121C" = '1' /*Displaced fracture of lesser trochanter of right femur,initial encounter for open fracture type IIIA, IIIB, or IIIC */
"S72122A" = '1' /*Displaced fracture of lesser trochanter of left femur,initial encounter for closed fracture */
"S72122B" = '1' /*Displaced fracture of lesser trochanter of left femur,initial encounter for open fracture type I or II */
"S72122C" = '1' /*Displaced fracture of lesser trochanter of left femur,initial encounter for open fracture type IIIA, IIIB, or IIIC */
"S72123A" = '1' /*Displaced fracture of lesser trochanter of unspecifiedfemur, initial encounter for closed fracture */
"S72123B" = '1' /*Displaced fracture of lesser trochanter of unspecifiedfemur, initial encounter for open fracture type I or II */
"S72123C" = '1' /*Displaced fracture of lesser trochanter of unspecifiedfemur, initial encounter for open fracture type IIIA, IIIB,or IIIC */
"S72124A" = '1' /*Nondisplaced fracture of lesser trochanter of right femur,initial encounter for closed fracture */
"S72124B" = '1' /*Nondisplaced fracture of lesser trochanter of right femur,initial encounter for open fracture type I or II */
"S72124C" = '1' /*Nondisplaced fracture of lesser trochanter of right femur,initial encounter for open fracture type IIIA, IIIB, or IIIC */
"S72125A" = '1' /*Nondisplaced fracture of lesser trochanter of left femur,initial encounter for closed fracture */
"S72125B" = '1' /*Nondisplaced fracture of lesser trochanter of left femur,initial encounter for open fracture type I or II */
"S72125C" = '1' /*Nondisplaced fracture of lesser trochanter of left femur,initial encounter for open fracture type IIIA, IIIB, or IIIC */
"S72126A" = '1' /*Nondisplaced fracture of lesser trochanter of unspecifiedfemur, initial encounter for closed fracture */
"S72126B" = '1' /*Nondisplaced fracture of lesser trochanter of unspecifiedfemur, initial encounter for open fracture type I or II */
"S72126C" = '1' /*Nondisplaced fracture of lesser trochanter of unspecifiedfemur, initial encounter for open fracture type IIIA, IIIB,or IIIC */
"S72131A" = '1' /*Displaced apophyseal fracture of right femur, initialencounter for closed fracture */
"S72131B" = '1' /*Displaced apophyseal fracture of right femur, initialencounter for open fracture type I or II */
"S72131C" = '1' /*Displaced apophyseal fracture of right femur, initialencounter for open fracture type IIIA, IIIB, or IIIC */
"S72132A" = '1' /*Displaced apophyseal fracture of left femur, initialencounter for closed fracture */
"S72132B" = '1' /*Displaced apophyseal fracture of left femur, initialencounter for open fracture type I or II */
"S72132C" = '1' /*Displaced apophyseal fracture of left femur, initialencounter for open fracture type IIIA, IIIB, or IIIC */
"S72133A" = '1' /*Displaced apophyseal fracture of unspecified femur,initial encounter for closed fracture */
"S72133B" = '1' /*Displaced apophyseal fracture of unspecified femur,initial encounter for open fracture type I or II */
"S72133C" = '1' /*Displaced apophyseal fracture of unspecified femur,initial encounter for open fracture type IIIA, IIIB, or IIIC */
"S72134A" = '1' /*Nondisplaced apophyseal fracture of right femur, initialencounter for closed fracture */
"S72134B" = '1' /*Nondisplaced apophyseal fracture of right femur, initialencounter for open fracture type I or II */
"S72134C" = '1' /*Nondisplaced apophyseal fracture of right femur, initialencounter for open fracture type IIIA, IIIB, or IIIC */
"S72135A" = '1' /*Nondisplaced apophyseal fracture of left femur, initialencounter for closed fracture */
"S72135B" = '1' /*Nondisplaced apophyseal fracture of left femur, initialencounter for open fracture type I or II */
"S72135C" = '1' /*Nondisplaced apophyseal fracture of left femur, initialencounter for open fracture type IIIA, IIIB, or IIIC */
"S72136A" = '1' /*Nondisplaced apophyseal fracture of unspecified femur,initial encounter for closed fracture */
"S72136B" = '1' /*Nondisplaced apophyseal fracture of unspecified femur,initial encounter for open fracture type I or II */
"S72136C" = '1' /*Nondisplaced apophyseal fracture of unspecified femur,initial encounter for open fracture type IIIA, IIIB, or IIIC */
"S72141A" = '1' /*Displaced intertrochanteric fracture of right femur, initialencounter for closed fracture */
"S72141B" = '1' /*Displaced intertrochanteric fracture of right femur, initialencounter for open fracture type I or II */
"S72141C" = '1' /*Displaced intertrochanteric fracture of right femur, initialencounter for open fracture type IIIA, IIIB, or IIIC */
"S72142A" = '1' /*Displaced intertrochanteric fracture of left femur, initialencounter for closed fracture */
"S72142B" = '1' /*Displaced intertrochanteric fracture of left femur, initialencounter for open fracture type I or II */
"S72142C" = '1' /*Displaced intertrochanteric fracture of left femur, initialencounter for open fracture type IIIA, IIIB, or IIIC */
"S72143A" = '1' /*Displaced intertrochanteric fracture of unspecified femur,initial encounter for closed fracture */
"S72143B" = '1' /*Displaced intertrochanteric fracture of unspecified femur,initial encounter for open fracture type I or II */
"S72143C" = '1' /*Displaced intertrochanteric fracture of unspecified femur,initial encounter for open fracture type IIIA, IIIB, or IIIC */
"S72144A" = '1' /*Nondisplaced intertrochanteric fracture of right femur,initial encounter for closed fracture */
"S72144B" = '1' /*Nondisplaced intertrochanteric fracture of right femur,initial encounter for open fracture type I or II */
"S72144C" = '1' /*Nondisplaced intertrochanteric fracture of right femur,initial encounter for open fracture type IIIA, IIIB, or IIIC */
"S72145A" = '1' /*Nondisplaced intertrochanteric fracture of left femur,initial encounter for closed fracture */
"S72145B" = '1' /*Nondisplaced intertrochanteric fracture of left femur,initial encounter for open fracture type I or II */
"S72145C" = '1' /*Nondisplaced intertrochanteric fracture of left femur,initial encounter for open fracture type IIIA, IIIB, or IIIC */
"S72146A" = '1' /*Nondisplaced intertrochanteric fracture of unspecifiedfemur, initial encounter for closed fracture */
"S72146B" = '1' /*Nondisplaced intertrochanteric fracture of unspecifiedfemur, initial encounter for open fracture type I or II */
"S72146C" = '1' /*Nondisplaced intertrochanteric fracture of unspecifiedfemur, initial encounter for open fracture type IIIA, IIIB,or IIIC */
"S7221XA" = '1' /*Displaced subtrochanteric fracture of right femur, initialencounter for closed fracture */
"S7221XB" = '1' /*Displaced subtrochanteric fracture of right femur, initialencounter for open fracture type I or II */
"S7221XC" = '1' /*Displaced subtrochanteric fracture of right femur, initialencounter for open fracture type IIIA, IIIB, or IIIC */
"S7222XA" = '1' /*Displaced subtrochanteric fracture of left femur, initialencounter for closed fracture */
"S7222XB" = '1' /*Displaced subtrochanteric fracture of left femur, initialencounter for open fracture type I or II */
"S7222XC" = '1' /*Displaced subtrochanteric fracture of left femur, initialencounter for open fracture type IIIA, IIIB, or IIIC */
"S7223XA" = '1' /*Displaced subtrochanteric fracture of unspecified femur,initial encounter for closed fracture */
"S7223XB" = '1' /*Displaced subtrochanteric fracture of unspecified femur,initial encounter for open fracture type I or II */
"S7223XC" = '1' /*Displaced subtrochanteric fracture of unspecified femur,initial encounter for open fracture type IIIA, IIIB, or IIIC */
"S7224XA" = '1' /*Nondisplaced subtrochanteric fracture of right femur,initial encounter for closed fracture */
"S7224XB" = '1' /*Nondisplaced subtrochanteric fracture of right femur,initial encounter for open fracture type I or II */
"S7224XC" = '1' /*Nondisplaced subtrochanteric fracture of right femur,initial encounter for open fracture type IIIA, IIIB, or IIIC */
"S7225XA" = '1' /*Nondisplaced subtrochanteric fracture of left femur,initial encounter for closed fracture */
"S7225XB" = '1' /*Nondisplaced subtrochanteric fracture of left femur,initial encounter for open fracture type I or II */
"S7225XC" = '1' /*Nondisplaced subtrochanteric fracture of left femur,initial encounter for open fracture type IIIA, IIIB, or IIIC */
"S7226XA" = '1' /*Nondisplaced subtrochanteric fracture of unspecifiedfemur, initial encounter for closed fracture */
"S7226XB" = '1' /*Nondisplaced subtrochanteric fracture of unspecifiedfemur, initial encounter for open fracture type I or II */
"S7226XC" = '1' /*Nondisplaced subtrochanteric fracture of unspecifiedfemur, initial encounter for open fracture type IIIA, IIIB,or IIIC */
OTHER = '0'
;

/* FORMAT FOR Osteoarthrosis for pelvic region and thigh (or site unspecified or multiple sites) diagnosis codes */
Value $MTHIPRD
"M129" = '1' /*Arthropathy, unspecified */
"M130" = '1' /*Polyarthritis, unspecified */
"M1310" = '1' /*Monoarthritis, not elsewhere classified, unspecified site */
"M13151" = '1' /*Monoarthritis, not elsewhere classified, right hip */
"M13152" = '1' /*Monoarthritis, not elsewhere classified, left hip */
"M13159" = '1' /*Monoarthritis, not elsewhere classified, unspecified hip */
"M150" = '1' /*Primary generalized (osteo)arthritis */
"M153" = '1' /*Secondary multiple arthritis */
"M154" = '1' /*Erosive (osteo)arthritis */
"M158" = '1' /*Other polyosteoarthritis */
"M159" = '1' /*Polyosteoarthritis, unspecified */
"M160" = '1' /*Bilateral primary osteoarthritis of hip */
"M1610" = '1' /*Unilateral primary osteoarthritis, unspecified hip */
"M1611" = '1' /*Unilateral primary osteoarthritis, right hip */
"M1612" = '1' /*Unilateral primary osteoarthritis, left hip */
"M162" = '1' /*Bilateral osteoarthritis resulting from hip dysplasia */
"M1630" = '1' /*Unilateral osteoarthritis resulting from hip dysplasia, unspecified hip */
"M1631" = '1' /*Unilateral osteoarthritis resulting from hip dysplasia, right hip */
"M1632" = '1' /*Unilateral osteoarthritis resulting from hip dysplasia, left hip */
"M164" = '1' /*Bilateral post-traumatic osteoarthritis of hip */
"M1650" = '1' /*Unilateral post-traumatic osteoarthritis, unspecified hip */
"M1651" = '1' /*Unilateral post-traumatic osteoarthritis, right hip */
"M1652" = '1' /*Unilateral post-traumatic osteoarthritis, left hip */
"M166" = '1' /*Other bilateral secondary osteoarthritis of hip */
"M167" = '1' /*Other unilateral secondary osteoarthritis of hip */
"M169" = '1' /*Osteoarthritis of hip, unspecified */
"M1990" = '1' /*Unspecified osteoarthritis, unspecified site */
"M1991" = '1' /*Primary osteoarthritis, unspecified site */
"M1992" = '1' /*Post-traumatic osteoarthritis, unspecified site */
"M1993" = '1' /*Secondary osteoarthritis, unspecified site */
OTHER = '0'
;

/* FORMAT FOR Partial or full hip replacement procedure codes */
Value $MTHIPRP
"0SR9019" = '1' /*Replacement of Right Hip Joint with Metal SyntheticSubstitute, Cemented, Open Approach */
"0SR901A" = '1' /*Replacement of Right Hip Joint with Metal SyntheticSubstitute, Uncemented, Open Approach */
"0SR901Z" = '1' /*Replacement of Right Hip Joint with Metal SyntheticSubstitute, Open Approach */
"0SR9029" = '1' /*Replacement of Right Hip Joint with Metal onPolyethylene Synthetic Substitute, Cemented, OpenApproach */
"0SR902A" = '1' /*Replacement of Right Hip Joint with Metal onPolyethylene Synthetic Substitute, Uncemented, OpenApproach */
"0SR902Z" = '1' /*Replacement of Right Hip Joint with Metal onPolyethylene Synthetic Substitute, Open Approach */
"0SR9039" = '1' /*Replacement of Right Hip Joint with Ceramic SyntheticSubstitute, Cemented, Open Approach */
"0SR903A" = '1' /*Replacement of Right Hip Joint with Ceramic SyntheticSubstitute, Uncemented, Open Approach */
"0SR903Z" = '1' /*Replacement of Right Hip Joint with Ceramic SyntheticSubstitute, Open Approach */
"0SR9049" = '1' /*Replacement of Right Hip Joint with Ceramic onPolyethylene Synthetic Substitute, Cemented, OpenApproach */
"0SR904A" = '1' /*Replacement of Right Hip Joint with Ceramic onPolyethylene Synthetic Substitute, Uncemented, OpenApproach */
"0SR904Z" = '1' /*Replacement of Right Hip Joint with Ceramic onPolyethylene Synthetic Substitute, Open Approach */
"0SR9069" = '1' /*Replacement of Right Hip Joint with Oxidized Zirconium on Polyethylene Synthetic Substitute, Cemented, Open Approach */
"0SR906A" = '1' /*Replacement of Right Hip Joint with Oxidized Zirconium on Polyethylene Synthetic Substitute, Uncemented, Open Approach */
"0SR906Z" = '1' /*Replacement of Right Hip Joint with Oxidized Zirconium on Polyethylene Synthetic Substitute, Open Approach */
"0SR907Z" = '1' /*Replacement of Right Hip Joint with Autologous TissueSubstitute, Open Approach */
"0SR90J9" = '1' /*Replacement of Right Hip Joint with SyntheticSubstitute, Cemented, Open Approach */
"0SR90JA" = '1' /*Replacement of Right Hip Joint with SyntheticSubstitute, Uncemented, Open Approach */
"0SR90JZ" = '1' /*Replacement of Right Hip Joint with SyntheticSubstitute, Open Approach */
"0SR90KZ" = '1' /*Replacement of Right Hip Joint with NonautologousTissue Substitute, Open Approach */
"0SRA009" = '1' /*Replacement of Right Hip Joint, Acetabular Surfacewith Polyethylene Synthetic Substitute, Cemented,Open Approach */
"0SRA00A" = '1' /*Replacement of Right Hip Joint, Acetabular Surfacewith Polyethylene Synthetic Substitute, Uncemented,Open Approach */
"0SRA00Z" = '1' /*Replacement of Right Hip Joint, Acetabular Surfacewith Polyethylene Synthetic Substitute, Open Approach */
"0SRA019" = '1' /*Replacement of Right Hip Joint, Acetabular Surfacewith Metal Synthetic Substitute, Cemented, OpenApproach */
"0SRA01A" = '1' /*Replacement of Right Hip Joint, Acetabular Surfacewith Metal Synthetic Substitute, Uncemented, OpenApproach */
"0SRA01Z" = '1' /*Replacement of Right Hip Joint, Acetabular Surfacewith Metal Synthetic Substitute, Open Approach */
"0SRA039" = '1' /*Replacement of Right Hip Joint, Acetabular Surfacewith Ceramic Synthetic Substitute, Cemented, OpenApproach */
"0SRA03A" = '1' /*Replacement of Right Hip Joint, Acetabular Surfacewith Ceramic Synthetic Substitute, Uncemented, OpenApproach */
"0SRA03Z" = '1' /*Replacement of Right Hip Joint, Acetabular Surfacewith Ceramic Synthetic Substitute, Open Approach */
"0SRA07Z" = '1' /*Replacement of Right Hip Joint, Acetabular Surfacewith Autologous Tissue Substitute, Open Approach */
"0SRA0J9" = '1' /*Replacement of Right Hip Joint, Acetabular Surfacewith Synthetic Substitute, Cemented, Open Approach */
"0SRA0JA" = '1' /*Replacement of Right Hip Joint, Acetabular Surfacewith Synthetic Substitute, Uncemented, Open Approach */
"0SRA0JZ" = '1' /*Replacement of Right Hip Joint, Acetabular Surfacewith Synthetic Substitute, Open Approach */
"0SRA0KZ" = '1' /*Replacement of Right Hip Joint, Acetabular Surfacewith Nonautologous Tissue Substitute, Open Approach */
"0SRB019" = '1' /*Replacement of Left Hip Joint with Metal SyntheticSubstitute, Cemented, Open Approach */
"0SRB01A" = '1' /*Replacement of Left Hip Joint with Metal SyntheticSubstitute, Uncemented, Open Approach */
"0SRB01Z" = '1' /*Replacement of Left Hip Joint with Metal SyntheticSubstitute, Open Approach */
"0SRB029" = '1' /*Replacement of Left Hip Joint with Metal onPolyethylene Synthetic Substitute, Cemented, OpenApproach */
"0SRB02A" = '1' /*Replacement of Left Hip Joint with Metal onPolyethylene Synthetic Substitute, Uncemented, OpenApproach */
"0SRB02Z" = '1' /*Replacement of Left Hip Joint with Metal onPolyethylene Synthetic Substitute, Open Approach */
"0SRB039" = '1' /*Replacement of Left Hip Joint with Ceramic SyntheticSubstitute, Cemented, Open Approach */
"0SRB03A" = '1' /*Replacement of Left Hip Joint with Ceramic SyntheticSubstitute, Uncemented, Open Approach */
"0SRB03Z" = '1' /*Replacement of Left Hip Joint with Ceramic SyntheticSubstitute, Open Approach */
"0SRB049" = '1' /*Replacement of Left Hip Joint with Ceramic onPolyethylene Synthetic Substitute, Cemented, OpenApproach */
"0SRB04A" = '1' /*Replacement of Left Hip Joint with Ceramic onPolyethylene Synthetic Substitute, Uncemented, OpenApproach */
"0SRB04Z" = '1' /*Replacement of Left Hip Joint with Ceramic onPolyethylene Synthetic Substitute, Open Approach */
"0SRB069" = '1' /*Replacement of Left Hip Joint with Oxidized Zirconium on Polyethylene Synthetic Substitute, Cemented, Open Approach */
"0SRB06A" = '1' /*Replacement of Left Hip Joint with Oxidized Zirconium on Polyethylene Synthetic Substitute, Uncemented, Open Approach */
"0SRB06Z" = '1' /*Replacement of Left Hip Joint with Oxidized Zirconium on Polyethylene Synthetic Substitute, Open Approach */
"0SRB07Z" = '1' /*Replacement of Left Hip Joint with Autologous TissueSubstitute, Open Approach */
"0SRB0J9" = '1' /*Replacement of Left Hip Joint with Synthetic Substitute,Cemented, Open Approach */
"0SRB0JA" = '1' /*Replacement of Left Hip Joint with Synthetic Substitute,Uncemented, Open Approach */
"0SRB0JZ" = '1' /*Replacement of Left Hip Joint with Synthetic Substitute,Open Approach */
"0SRB0KZ" = '1' /*Replacement of Left Hip Joint with NonautologousTissue Substitute, Open Approach */
"0SRE009" = '1' /*Replacement of Left Hip Joint, Acetabular Surface withPolyethylene Synthetic Substitute, Cemented, OpenApproach */
"0SRE00A" = '1' /*Replacement of Left Hip Joint, Acetabular Surface withPolyethylene Synthetic Substitute, Uncemented, OpenApproach */
"0SRE00Z" = '1' /*Replacement of Left Hip Joint, Acetabular Surface withPolyethylene Synthetic Substitute, Open Approach */
"0SRE019" = '1' /*Replacement of Left Hip Joint, Acetabular Surface withMetal Synthetic Substitute, Cemented, Open Approach */
"0SRE01A" = '1' /*Replacement of Left Hip Joint, Acetabular Surface withMetal Synthetic Substitute, Uncemented, OpenApproach */
"0SRE01Z" = '1' /*Replacement of Left Hip Joint, Acetabular Surface withMetal Synthetic Substitute, Open Approach */
"0SRE039" = '1' /*Replacement of Left Hip Joint, Acetabular Surface withCeramic Synthetic Substitute, Cemented, OpenApproach */
"0SRE03A" = '1' /*Replacement of Left Hip Joint, Acetabular Surface withCeramic Synthetic Substitute, Uncemented, OpenApproach */
"0SRE03Z" = '1' /*Replacement of Left Hip Joint, Acetabular Surface withCeramic Synthetic Substitute, Open Approach */
"0SRE07Z" = '1' /*Replacement of Left Hip Joint, Acetabular Surface withAutologous Tissue Substitute, Open Approach */
"0SRE0J9" = '1' /*Replacement of Left Hip Joint, Acetabular Surface withSynthetic Substitute, Cemented, Open Approach */
"0SRE0JA" = '1' /*Replacement of Left Hip Joint, Acetabular Surface withSynthetic Substitute, Uncemented, Open Approach */
"0SRE0JZ" = '1' /*Replacement of Left Hip Joint, Acetabular Surface withSynthetic Substitute, Open Approach */
"0SRE0KZ" = '1' /*Replacement of Left Hip Joint, Acetabular Surface withNonautologous Tissue Substitute, Open Approach */
"0SRR019" = '1' /*Replacement of Right Hip Joint, Femoral Surface withMetal Synthetic Substitute, Cemented, Open Approach */
"0SRR01A" = '1' /*Replacement of Right Hip Joint, Femoral Surface withMetal Synthetic Substitute, Uncemented, OpenApproach */
"0SRR01Z" = '1' /*Replacement of Right Hip Joint, Femoral Surface withMetal Synthetic Substitute, Open Approach */
"0SRR039" = '1' /*Replacement of Right Hip Joint, Femoral Surface withCeramic Synthetic Substitute, Cemented, OpenApproach */
"0SRR03A" = '1' /*Replacement of Right Hip Joint, Femoral Surface withCeramic Synthetic Substitute, Uncemented, OpenApproach */
"0SRR03Z" = '1' /*Replacement of Right Hip Joint, Femoral Surface withCeramic Synthetic Substitute, Open Approach */
"0SRR07Z" = '1' /*Replacement of Right Hip Joint, Femoral Surface withAutologous Tissue Substitute, Open Approach */
"0SRR0J9" = '1' /*Replacement of Right Hip Joint, Femoral Surface withSynthetic Substitute, Cemented, Open Approach */
"0SRR0JA" = '1' /*Replacement of Right Hip Joint, Femoral Surface withSynthetic Substitute, Uncemented, Open Approach */
"0SRR0JZ" = '1' /*Replacement of Right Hip Joint, Femoral Surface withSynthetic Substitute, Open Approach */
"0SRR0KZ" = '1' /*Replacement of Right Hip Joint, Femoral Surface withNonautologous Tissue Substitute, Open Approach */
"0SRS019" = '1' /*Replacement of Left Hip Joint, Femoral Surface withMetal Synthetic Substitute, Cemented, Open Approach */
"0SRS01A" = '1' /*Replacement of Left Hip Joint, Femoral Surface withMetal Synthetic Substitute, Uncemented, OpenApproach */
"0SRS01Z" = '1' /*Replacement of Left Hip Joint, Femoral Surface withMetal Synthetic Substitute, Open Approach */
"0SRS039" = '1' /*Replacement of Left Hip Joint, Femoral Surface withCeramic Synthetic Substitute, Cemented, OpenApproach */
"0SRS03A" = '1' /*Replacement of Left Hip Joint, Femoral Surface withCeramic Synthetic Substitute, Uncemented, OpenApproach */
"0SRS03Z" = '1' /*Replacement of Left Hip Joint, Femoral Surface withCeramic Synthetic Substitute, Open Approach */
"0SRS07Z" = '1' /*Replacement of Left Hip Joint, Femoral Surface withAutologous Tissue Substitute, Open Approach */
"0SRS0J9" = '1' /*Replacement of Left Hip Joint, Femoral Surface withSynthetic Substitute, Cemented, Open Approach */
"0SRS0JA" = '1' /*Replacement of Left Hip Joint, Femoral Surface withSynthetic Substitute, Uncemented, Open Approach */
"0SRS0JZ" = '1' /*Replacement of Left Hip Joint, Femoral Surface withSynthetic Substitute, Open Approach */
"0SRS0KZ" = '1' /*Replacement of Left Hip Joint, Femoral Surface withNonautologous Tissue Substitute, Open Approach */
"0SU909Z" = '1' /*Supplement Right Hip Joint with Liner, Open Approach */
"0SUA09Z" = '1' /*Supplement Right Hip Joint, Acetabular Surface withLiner, Open Approach */
"0SUB09Z" = '1' /*Supplement Left Hip Joint with Liner, Open Approach */
"0SUE09Z" = '1' /*Supplement Left Hip Joint, Acetabular Surface withLiner, Open Approach */
"0SUR09Z" = '1' /*Supplement Right Hip Joint, Femoral Surface withLiner, Open Approach */
"0SUS09Z" = '1' /*Supplement Left Hip Joint, Femoral Surface with Liner,Open Approach */
"0SW90JZ" = '1' /*Revision of Synthetic Substitute in Right Hip Joint,Open Approach */
"0SWA0JZ" = '1' /*Revision of Synthetic Substitute in Right Hip Joint, Acetabular Surface, Open Approach */
"0SWB0JZ" = '1' /*Revision of Synthetic Substitute in Left Hip Joint, OpenApproach */
"0SWE0JZ" = '1' /*Revision of Synthetic Substitute in Left Hip Joint, Acetabular Surface, Open Approach */
"0SWR0JZ" = '1' /*Revision of Synthetic Substitute in Right Hip Joint, Femoral Surface, Open Approach */
"0SWS0JZ" = '1' /*Revision of Synthetic Substitute in Left Hip Joint, Femoral Surface, Open Approach */
OTHER = '0'
;

/* FORMAT FOR Pneumonia diagnosis codes */
Value $MTPNEUD
"A0222" = '1' /*Salmonella pneumonia */
"A212" = '1' /*Pulmonary tularemia */
"A221" = '1' /*Pulmonary anthrax */
"A3701" = '1' /*Whooping cough due to Bordetella pertussis withpneumonia */
"A3711" = '1' /*Whooping cough due to Bordetella parapertussis withpneumonia */
"A3781" = '1' /*Whooping cough due to other Bordetella species withpneumonia */
"A3791" = '1' /*Whooping cough, unspecified species with pneumonia */
"A420" = '1' /*Pulmonary actinomycosis */
"A430" = '1' /*Pulmonary nocardiosis */
"A481" = '1' /*Legionnaires' disease */
"B012" = '1' /*Varicella pneumonia */
"B052" = '1' /*Measles complicated by pneumonia */
"B250" = '1' /*Cytomegaloviral pneumonitis */
"B371" = '1' /*Pulmonary candidiasis */
"B380" = '1' /*Acute pulmonary coccidioidomycosis */
"B381" = '1' /*Chronic pulmonary coccidioidomycosis */
"B382" = '1' /*Pulmonary coccidioidomycosis, unspecified */
"B390" = '1' /*Acute pulmonary histoplasmosis capsulati */
"B391" = '1' /*Chronic pulmonary histoplasmosis capsulati */
"B392" = '1' /*Pulmonary histoplasmosis capsulati, unspecified */
"B440" = '1' /*Invasive pulmonary aspergillosis */
"B583" = '1' /*Pulmonary toxoplasmosis */
"B59" = '1' /*Pneumocystosis */
"B7781" = '1' /*Ascariasis pneumonia */
"J09X1" = '1' /*Influenza due to identified novel influenza A virus withpneumonia */
"J1000" = '1' /*Influenza due to other identified influenza virus withunspecified type of pneumonia */
"J1001" = '1' /*Influenza due to other identified influenza virus with thesame other identified influenza virus pneumonia */
"J1008" = '1' /*Influenza due to other identified influenza virus with otherspecified pneumonia */
"J1100" = '1' /*Influenza due to unidentified influenza virus withunspecified type of pneumonia */
"J1108" = '1' /*Influenza due to unidentified influenza virus with specifiedpneumonia */
"J120" = '1' /*Adenoviral pneumonia */
"J121" = '1' /*Respiratory syncytial virus pneumonia */
"J122" = '1' /*Parainfluenza virus pneumonia */
"J123" = '1' /*Human metapneumovirus pneumonia */
"J1281" = '1' /*Pneumonia due to SARS-associated coronavirus */
"J1289" = '1' /*Other viral pneumonia */
"J129" = '1' /*Viral pneumonia, unspecified */
"J13" = '1' /*Pneumonia due to Streptococcus pneumoniae */
"J14" = '1' /*Pneumonia due to Hemophilus influenzae */
"J150" = '1' /*Pneumonia due to Klebsiella pneumoniae */
"J151" = '1' /*Pneumonia due to Pseudomonas */
"J1520" = '1' /*Pneumonia due to staphylococcus, unspecified */
"J15211" = '1' /*Pneumonia due to Methicillin susceptible Staphylococcusaureus */
"J15212" = '1' /*Pneumonia due to Methicillin resistant Staphylococcusaureus */
"J1529" = '1' /*Pneumonia due to other staphylococcus */
"J153" = '1' /*Pneumonia due to streptococcus, group B */
"J154" = '1' /*Pneumonia due to other streptococci */
"J155" = '1' /*Pneumonia due to Escherichia coli */
"J156" = '1' /*Pneumonia due to other Gram-negative bacteria */
"J157" = '1' /*Pneumonia due to Mycoplasma pneumoniae */
"J158" = '1' /*Pneumonia due to other specified bacteria */
"J159" = '1' /*Unspecified bacterial pneumonia */
"J160" = '1' /*Chlamydial pneumonia */
"J168" = '1' /*Pneumonia due to other specified infectious organisms */
"J17" = '1' /*Pneumonia in diseases classified elsewhere */
"J180" = '1' /*Bronchopneumonia, unspecified organism */
"J181" = '1' /*Lobar pneumonia, unspecified organism */
"J188" = '1' /*Other pneumonia, unspecified organism */
"J189" = '1' /*Pneumonia, unspecified organism */
OTHER = '0'
;

/* FORMAT FOR Primary expected payer categories */
Value PAYCAT
1 = 'Medicare' /*Medicare */
2 = 'Medicaid' /*Medicaid */
3 = 'Private' /*Private */
4 = 'Self Pay' /*Self Pay */
5 = 'No Charge' /*No Charge */
6 = 'Other' /*Other */
;

/* FORMAT FOR Unruptured abdominal aortic (AAA) aneurysm diagnosis codes */
Value $PRAAA2D
"I714" = '1' /*Abdominal aortic aneurysm, without rupture */
OTHER = '0'
;

/* FORMAT FOR Endovascular abdominal aortic (AAA) aneurysm repair procedure codes */
Value $PRAAA2P
"0410490" = '1' /*Bypass Abdominal Aorta to Abdominal Aorta with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0410496" = '1' /*Bypass Abdominal Aorta to Right Common Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0410497" = '1' /*Bypass Abdominal Aorta to Left Common Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0410498" = '1' /*Bypass Abdominal Aorta to Bilateral Common Iliac Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0410499" = '1' /*Bypass Abdominal Aorta to Right Internal Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041049B" = '1' /*Bypass Abdominal Aorta to Left Internal Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041049C" = '1' /*Bypass Abdominal Aorta to Bilateral Internal Iliac Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041049D" = '1' /*Bypass Abdominal Aorta to Right External Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041049F" = '1' /*Bypass Abdominal Aorta to Left External Iliac Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041049G" = '1' /*Bypass Abdominal Aorta to Bilateral External Iliac Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041049H" = '1' /*Bypass Abdominal Aorta to Right Femoral Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041049J" = '1' /*Bypass Abdominal Aorta to Left Femoral Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041049K" = '1' /*Bypass Abdominal Aorta to Bilateral Femoral Arteries with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041049Q" = '1' /*Bypass Abdominal Aorta to Lower Extremity Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"041049R" = '1' /*Bypass Abdominal Aorta to Lower Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"04104A0" = '1' /*Bypass Abdominal Aorta to Abdominal Aorta with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104A6" = '1' /*Bypass Abdominal Aorta to Right Common Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104A7" = '1' /*Bypass Abdominal Aorta to Left Common Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104A8" = '1' /*Bypass Abdominal Aorta to Bilateral Common Iliac Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104A9" = '1' /*Bypass Abdominal Aorta to Right Internal Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104AB" = '1' /*Bypass Abdominal Aorta to Left Internal Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104AC" = '1' /*Bypass Abdominal Aorta to Bilateral Internal Iliac Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104AD" = '1' /*Bypass Abdominal Aorta to Right External Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104AF" = '1' /*Bypass Abdominal Aorta to Left External Iliac Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104AG" = '1' /*Bypass Abdominal Aorta to Bilateral External Iliac Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104AH" = '1' /*Bypass Abdominal Aorta to Right Femoral Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104AJ" = '1' /*Bypass Abdominal Aorta to Left Femoral Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104AK" = '1' /*Bypass Abdominal Aorta to Bilateral Femoral Arteries with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104AQ" = '1' /*Bypass Abdominal Aorta to Lower Extremity Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104AR" = '1' /*Bypass Abdominal Aorta to Lower Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"04104J0" = '1' /*Bypass Abdominal Aorta to Abdominal Aorta with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104J6" = '1' /*Bypass Abdominal Aorta to Right Common Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104J7" = '1' /*Bypass Abdominal Aorta to Left Common Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104J8" = '1' /*Bypass Abdominal Aorta to Bilateral Common Iliac Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104J9" = '1' /*Bypass Abdominal Aorta to Right Internal Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104JB" = '1' /*Bypass Abdominal Aorta to Left Internal Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104JC" = '1' /*Bypass Abdominal Aorta to Bilateral Internal Iliac Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104JD" = '1' /*Bypass Abdominal Aorta to Right External Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104JF" = '1' /*Bypass Abdominal Aorta to Left External Iliac Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104JG" = '1' /*Bypass Abdominal Aorta to Bilateral External Iliac Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104JH" = '1' /*Bypass Abdominal Aorta to Right Femoral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104JJ" = '1' /*Bypass Abdominal Aorta to Left Femoral Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104JK" = '1' /*Bypass Abdominal Aorta to Bilateral Femoral Arteries with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104JQ" = '1' /*Bypass Abdominal Aorta to Lower Extremity Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104JR" = '1' /*Bypass Abdominal Aorta to Lower Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04104K0" = '1' /*Bypass Abdominal Aorta to Abdominal Aorta with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104K6" = '1' /*Bypass Abdominal Aorta to Right Common Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104K7" = '1' /*Bypass Abdominal Aorta to Left Common Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104K8" = '1' /*Bypass Abdominal Aorta to Bilateral Common Iliac Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104K9" = '1' /*Bypass Abdominal Aorta to Right Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104KB" = '1' /*Bypass Abdominal Aorta to Left Internal Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104KC" = '1' /*Bypass Abdominal Aorta to Bilateral Internal Iliac Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104KD" = '1' /*Bypass Abdominal Aorta to Right External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104KF" = '1' /*Bypass Abdominal Aorta to Left External Iliac Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104KG" = '1' /*Bypass Abdominal Aorta to Bilateral External Iliac Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104KH" = '1' /*Bypass Abdominal Aorta to Right Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104KJ" = '1' /*Bypass Abdominal Aorta to Left Femoral Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104KK" = '1' /*Bypass Abdominal Aorta to Bilateral Femoral Arteries with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104KQ" = '1' /*Bypass Abdominal Aorta to Lower Extremity Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104KR" = '1' /*Bypass Abdominal Aorta to Lower Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04104Z0" = '1' /*Bypass Abdominal Aorta to Abdominal Aorta, Percutaneous Endoscopic Approach */
"04104Z6" = '1' /*Bypass Abdominal Aorta to Right Common Iliac Artery, Percutaneous Endoscopic Approach */
"04104Z7" = '1' /*Bypass Abdominal Aorta to Left Common Iliac Artery, Percutaneous Endoscopic Approach */
"04104Z8" = '1' /*Bypass Abdominal Aorta to Bilateral Common Iliac Arteries, Percutaneous Endoscopic Approach */
"04104Z9" = '1' /*Bypass Abdominal Aorta to Right Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04104ZB" = '1' /*Bypass Abdominal Aorta to Left Internal Iliac Artery, Percutaneous Endoscopic Approach */
"04104ZC" = '1' /*Bypass Abdominal Aorta to Bilateral Internal Iliac Arteries, Percutaneous Endoscopic Approach */
"04104ZD" = '1' /*Bypass Abdominal Aorta to Right External Iliac Artery, Percutaneous Endoscopic Approach */
"04104ZF" = '1' /*Bypass Abdominal Aorta to Left External Iliac Artery, Percutaneous Endoscopic Approach */
"04104ZG" = '1' /*Bypass Abdominal Aorta to Bilateral External Iliac Arteries, Percutaneous Endoscopic Approach */
"04104ZH" = '1' /*Bypass Abdominal Aorta to Right Femoral Artery, Percutaneous Endoscopic Approach */
"04104ZJ" = '1' /*Bypass Abdominal Aorta to Left Femoral Artery, Percutaneous Endoscopic Approach */
"04104ZK" = '1' /*Bypass Abdominal Aorta to Bilateral Femoral Arteries, Percutaneous Endoscopic Approach */
"04104ZQ" = '1' /*Bypass Abdominal Aorta to Lower Extremity Artery, Percutaneous Endoscopic Approach */
"04104ZR" = '1' /*Bypass Abdominal Aorta to Lower Artery, Percutaneous Endoscopic Approach */
"04503ZZ" = '1' /*Destruction of Abdominal Aorta, Percutaneous Approach */
"04504ZZ" = '1' /*Destruction of Abdominal Aorta, Percutaneous Endoscopic Approach */
"04B03ZZ" = '1' /*Excision of Abdominal Aorta, Percutaneous Approach */
"04B04ZZ" = '1' /*Excision of Abdominal Aorta, Percutaneous Endoscopic Approach */
"04H03DZ" = '1' /*Insertion of Intraluminal Device into Abdominal Aorta, Percutaneous Approach */
"04H04DZ" = '1' /*Insertion of Intraluminal Device into Abdominal Aorta, Percutaneous Endoscopic Approach */
"04L03DJ" = '1' /*Occlusion of Abdominal Aorta with Intraluminal Device, Temporary, Percutaneous Approach */
"04L03DZ" = '1' /*Occlusion of Abdominal Aorta with Intraluminal Device, Percutaneous Approach */
"04L03ZZ" = '1' /*Occlusion of Abdominal Aorta, Percutaneous Approach */
"04L04DZ" = '1' /*Occlusion of Abdominal Aorta with Intraluminal Device, Percutaneous Endoscopic Approach */
"04L04ZZ" = '1' /*Occlusion of Abdominal Aorta, Percutaneous Endoscopic Approach */
"04Q03ZZ" = '1' /*Repair Abdominal Aorta, Percutaneous Approach */
"04Q04ZZ" = '1' /*Repair Abdominal Aorta, Percutaneous Endoscopic Approach */
"04R047Z" = '1' /*Replacement of Abdominal Aorta with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04R04JZ" = '1' /*Replacement of Abdominal Aorta with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04R04KZ" = '1' /*Replacement of Abdominal Aorta with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U037Z" = '1' /*Supplement Abdominal Aorta with Autologous Tissue Substitute, Percutaneous Approach */
"04U03JZ" = '1' /*Supplement Abdominal Aorta with Synthetic Substitute, Percutaneous Approach */
"04U03KZ" = '1' /*Supplement Abdominal Aorta with Nonautologous Tissue Substitute, Percutaneous Approach */
"04U047Z" = '1' /*Supplement Abdominal Aorta with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04U04JZ" = '1' /*Supplement Abdominal Aorta with Synthetic Substitute, Percutaneous Endoscopic Approach */
"04U04KZ" = '1' /*Supplement Abdominal Aorta with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"04V03D6" = '1' /*Restriction of Abdominal Aorta, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"04V03DJ" = '1' /*Restriction of Abdominal Aorta with Intraluminal Device, Temporary, Percutaneous Approach */
"04V03DZ" = '1' /*Restriction of Abdominal Aorta with Intraluminal Device, Percutaneous Approach */
"04V03E6" = '1' /*Restriction of Abdominal Aorta, Bifurcation, with Branched or Fenestrated Intraluminal Device, One or Two Arteries, Percutaneous Approach */
"04V03EZ" = '1' /*Restriction of Abdominal Aorta with Branched or Fenestrated Intraluminal Device, One or Two Arteries, Percutaneous Approach */
"04V03F6" = '1' /*Restriction of Abdominal Aorta, Bifurcation, with Branched or Fenestrated Intraluminal Device, Three or More Arteries, Percutaneous Approach */
"04V03FZ" = '1' /*Restriction of Abdominal Aorta with Branched or Fenestrated Intraluminal Device, Three or More Arteries, Percutaneous Approach */
"04V03Z6" = '1' /*Restriction of Abdominal Aorta, Bifurcation, Percutaneous Approach */
"04V03ZZ" = '1' /*Restriction of Abdominal Aorta, Percutaneous Approach */
"04V04D6" = '1' /*Restriction of Abdominal Aorta, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"04V04DJ" = '1' /*Restriction of Abdominal Aorta with Intraluminal Device, Temporary, Percutaneous Endoscopic Approach */
"04V04DZ" = '1' /*Restriction of Abdominal Aorta with Intraluminal Device, Percutaneous Endoscopic Approach */
"04V04E6" = '1' /*Restriction of Abdominal Aorta, Bifurcation, with Branched or Fenestrated Intraluminal Device, One or Two Arteries, Percutaneous Endoscopic Approach */
"04V04EZ" = '1' /*Restriction of Abdominal Aorta with Branched or Fenestrated Intraluminal Device, One or Two Arteries, Percutaneous Endoscopic Approach */
"04V04F6" = '1' /*Restriction of Abdominal Aorta, Bifurcation, with Branched or Fenestrated Intraluminal Device, Three or More Arteries, Percutaneous Endoscopic Approach */
"04V04FZ" = '1' /*Restriction of Abdominal Aorta with Branched or Fenestrated Intraluminal Device, Three or More Arteries, Percutaneous Endoscopic Approach */
"04V04Z6" = '1' /*Restriction of Abdominal Aorta, Bifurcation, Percutaneous Endoscopic Approach */
"04V04ZZ" = '1' /*Restriction of Abdominal Aorta, Percutaneous Endoscopic Approach */
OTHER = '0'
;

/* FORMAT FOR Ruptured abdominal aortic aneurysm (AAA) diagnosis codes */
Value $PRAAARD
"I713" = '1' /*Abdominal aortic aneurysm, ruptured */
OTHER = '0'
;

/* FORMAT FOR Open abdominal aortic aneurysm (AAA) repair procedure codes */
Value $PRAAARP
"0410090" = '1' /*Bypass Abdominal Aorta to Abdominal Aorta with Autologous Venous Tissue, Open Approach */
"0410096" = '1' /*Bypass Abdominal Aorta to Right Common Iliac Artery with Autologous Venous Tissue, Open Approach */
"0410097" = '1' /*Bypass Abdominal Aorta to Left Common Iliac Artery with Autologous Venous Tissue, Open Approach */
"0410098" = '1' /*Bypass Abdominal Aorta to Bilateral Common Iliac Arteries with Autologous Venous Tissue, Open Approach */
"0410099" = '1' /*Bypass Abdominal Aorta to Right Internal Iliac Artery with Autologous Venous Tissue, Open Approach */
"041009B" = '1' /*Bypass Abdominal Aorta to Left Internal Iliac Artery with Autologous Venous Tissue, Open Approach */
"041009C" = '1' /*Bypass Abdominal Aorta to Bilateral Internal Iliac Arteries with Autologous Venous Tissue, Open Approach */
"041009D" = '1' /*Bypass Abdominal Aorta to Right External Iliac Artery with Autologous Venous Tissue, Open Approach */
"041009F" = '1' /*Bypass Abdominal Aorta to Left External Iliac Artery with Autologous Venous Tissue, Open Approach */
"041009G" = '1' /*Bypass Abdominal Aorta to Bilateral External Iliac Arteries with Autologous Venous Tissue, Open Approach */
"041009H" = '1' /*Bypass Abdominal Aorta to Right Femoral Artery with Autologous Venous Tissue, Open Approach */
"041009J" = '1' /*Bypass Abdominal Aorta to Left Femoral Artery with Autologous Venous Tissue, Open Approach */
"041009K" = '1' /*Bypass Abdominal Aorta to Bilateral Femoral Arteries with Autologous Venous Tissue, Open Approach */
"041009Q" = '1' /*Bypass Abdominal Aorta to Lower Extremity Artery with Autologous Venous Tissue, Open Approach */
"041009R" = '1' /*Bypass Abdominal Aorta to Lower Artery with Autologous Venous Tissue, Open Approach */
"04100A0" = '1' /*Bypass Abdominal Aorta to Abdominal Aorta with Autologous Arterial Tissue, Open Approach */
"04100A6" = '1' /*Bypass Abdominal Aorta to Right Common Iliac Artery with Autologous Arterial Tissue, Open Approach */
"04100A7" = '1' /*Bypass Abdominal Aorta to Left Common Iliac Artery with Autologous Arterial Tissue, Open Approach */
"04100A8" = '1' /*Bypass Abdominal Aorta to Bilateral Common Iliac Arteries with Autologous Arterial Tissue, Open Approach */
"04100A9" = '1' /*Bypass Abdominal Aorta to Right Internal Iliac Artery with Autologous Arterial Tissue, Open Approach */
"04100AB" = '1' /*Bypass Abdominal Aorta to Left Internal Iliac Artery with Autologous Arterial Tissue, Open Approach */
"04100AC" = '1' /*Bypass Abdominal Aorta to Bilateral Internal Iliac Arteries with Autologous Arterial Tissue, Open Approach */
"04100AD" = '1' /*Bypass Abdominal Aorta to Right External Iliac Artery with Autologous Arterial Tissue, Open Approach */
"04100AF" = '1' /*Bypass Abdominal Aorta to Left External Iliac Artery with Autologous Arterial Tissue, Open Approach */
"04100AG" = '1' /*Bypass Abdominal Aorta to Bilateral External Iliac Arteries with Autologous Arterial Tissue, Open Approach */
"04100AH" = '1' /*Bypass Abdominal Aorta to Right Femoral Artery with Autologous Arterial Tissue, Open Approach */
"04100AJ" = '1' /*Bypass Abdominal Aorta to Left Femoral Artery with Autologous Arterial Tissue, Open Approach */
"04100AK" = '1' /*Bypass Abdominal Aorta to Bilateral Femoral Arteries with Autologous Arterial Tissue, Open Approach */
"04100AQ" = '1' /*Bypass Abdominal Aorta to Lower Extremity Artery with Autologous Arterial Tissue, Open Approach */
"04100AR" = '1' /*Bypass Abdominal Aorta to Lower Artery with Autologous Arterial Tissue, Open Approach */
"04100J0" = '1' /*Bypass Abdominal Aorta to Abdominal Aorta with Synthetic Substitute, Open Approach */
"04100J6" = '1' /*Bypass Abdominal Aorta to Right Common Iliac Artery with Synthetic Substitute, Open Approach */
"04100J7" = '1' /*Bypass Abdominal Aorta to Left Common Iliac Artery with Synthetic Substitute, Open Approach */
"04100J8" = '1' /*Bypass Abdominal Aorta to Bilateral Common Iliac Arteries with Synthetic Substitute, Open Approach */
"04100J9" = '1' /*Bypass Abdominal Aorta to Right Internal Iliac Artery with Synthetic Substitute, Open Approach */
"04100JB" = '1' /*Bypass Abdominal Aorta to Left Internal Iliac Artery with Synthetic Substitute, Open Approach */
"04100JC" = '1' /*Bypass Abdominal Aorta to Bilateral Internal Iliac Arteries with Synthetic Substitute, Open Approach */
"04100JD" = '1' /*Bypass Abdominal Aorta to Right External Iliac Artery with Synthetic Substitute, Open Approach */
"04100JF" = '1' /*Bypass Abdominal Aorta to Left External Iliac Artery with Synthetic Substitute, Open Approach */
"04100JG" = '1' /*Bypass Abdominal Aorta to Bilateral External Iliac Arteries with Synthetic Substitute, Open Approach */
"04100JH" = '1' /*Bypass Abdominal Aorta to Right Femoral Artery with Synthetic Substitute, Open Approach */
"04100JJ" = '1' /*Bypass Abdominal Aorta to Left Femoral Artery with Synthetic Substitute, Open Approach */
"04100JK" = '1' /*Bypass Abdominal Aorta to Bilateral Femoral Arteries with Synthetic Substitute, Open Approach */
"04100JQ" = '1' /*Bypass Abdominal Aorta to Lower Extremity Artery with Synthetic Substitute, Open Approach */
"04100JR" = '1' /*Bypass Abdominal Aorta to Lower Artery with Synthetic Substitute, Open Approach */
"04100K0" = '1' /*Bypass Abdominal Aorta to Abdominal Aorta with Nonautologous Tissue Substitute, Open Approach */
"04100K6" = '1' /*Bypass Abdominal Aorta to Right Common Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04100K7" = '1' /*Bypass Abdominal Aorta to Left Common Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04100K8" = '1' /*Bypass Abdominal Aorta to Bilateral Common Iliac Arteries with Nonautologous Tissue Substitute, Open Approach */
"04100K9" = '1' /*Bypass Abdominal Aorta to Right Internal Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04100KB" = '1' /*Bypass Abdominal Aorta to Left Internal Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04100KC" = '1' /*Bypass Abdominal Aorta to Bilateral Internal Iliac Arteries with Nonautologous Tissue Substitute, Open Approach */
"04100KD" = '1' /*Bypass Abdominal Aorta to Right External Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04100KF" = '1' /*Bypass Abdominal Aorta to Left External Iliac Artery with Nonautologous Tissue Substitute, Open Approach */
"04100KG" = '1' /*Bypass Abdominal Aorta to Bilateral External Iliac Arteries with Nonautologous Tissue Substitute, Open Approach */
"04100KH" = '1' /*Bypass Abdominal Aorta to Right Femoral Artery with Nonautologous Tissue Substitute, Open Approach */
"04100KJ" = '1' /*Bypass Abdominal Aorta to Left Femoral Artery with Nonautologous Tissue Substitute, Open Approach */
"04100KK" = '1' /*Bypass Abdominal Aorta to Bilateral Femoral Arteries with Nonautologous Tissue Substitute, Open Approach */
"04100KQ" = '1' /*Bypass Abdominal Aorta to Lower Extremity Artery with Nonautologous Tissue Substitute, Open Approach */
"04100KR" = '1' /*Bypass Abdominal Aorta to Lower Artery with Nonautologous Tissue Substitute, Open Approach */
"04100Z0" = '1' /*Bypass Abdominal Aorta to Abdominal Aorta, Open Approach */
"04100Z6" = '1' /*Bypass Abdominal Aorta to Right Common Iliac Artery, Open Approach */
"04100Z7" = '1' /*Bypass Abdominal Aorta to Left Common Iliac Artery, Open Approach */
"04100Z8" = '1' /*Bypass Abdominal Aorta to Bilateral Common Iliac Arteries, Open Approach */
"04100Z9" = '1' /*Bypass Abdominal Aorta to Right Internal Iliac Artery, Open Approach */
"04100ZB" = '1' /*Bypass Abdominal Aorta to Left Internal Iliac Artery, Open Approach */
"04100ZC" = '1' /*Bypass Abdominal Aorta to Bilateral Internal Iliac Arteries, Open Approach */
"04100ZD" = '1' /*Bypass Abdominal Aorta to Right External Iliac Artery, Open Approach */
"04100ZF" = '1' /*Bypass Abdominal Aorta to Left External Iliac Artery, Open Approach */
"04100ZG" = '1' /*Bypass Abdominal Aorta to Bilateral External Iliac Arteries, Open Approach */
"04100ZH" = '1' /*Bypass Abdominal Aorta to Right Femoral Artery, Open Approach */
"04100ZJ" = '1' /*Bypass Abdominal Aorta to Left Femoral Artery, Open Approach */
"04100ZK" = '1' /*Bypass Abdominal Aorta to Bilateral Femoral Arteries, Open Approach */
"04100ZQ" = '1' /*Bypass Abdominal Aorta to Lower Extremity Artery, Open Approach */
"04100ZR" = '1' /*Bypass Abdominal Aorta to Lower Artery, Open Approach */
"04500ZZ" = '1' /*Destruction of Abdominal Aorta, Open Approach */
"04B00ZZ" = '1' /*Excision of Abdominal Aorta, Open Approach */
"04H00DZ" = '1' /*Insertion of Intraluminal Device into Abdominal Aorta, Open Approach */
"04L00DZ" = '1' /*Occlusion of Abdominal Aorta with Intraluminal Device, Open Approach */
"04L00ZZ" = '1' /*Occlusion of Abdominal Aorta, Open Approach */
"04Q00ZZ" = '1' /*Repair Abdominal Aorta, Open Approach */
"04R007Z" = '1' /*Replacement of Abdominal Aorta with Autologous Tissue Substitute, Open Approach */
"04R00JZ" = '1' /*Replacement of Abdominal Aorta with Synthetic Substitute, Open Approach */
"04R00KZ" = '1' /*Replacement of Abdominal Aorta with Nonautologous Tissue Substitute, Open Approach */
"04U007Z" = '1' /*Supplement Abdominal Aorta with Autologous Tissue Substitute, Open Approach */
"04U00JZ" = '1' /*Supplement Abdominal Aorta with Synthetic Substitute, Open Approach */
"04U00KZ" = '1' /*Supplement Abdominal Aorta with Nonautologous Tissue Substitute, Open Approach */
"04V00D6" = '1' /*Restriction of Abdominal Aorta, Bifurcation, with Intraluminal Device, Open Approach */
"04V00DJ" = '1' /*Restriction of Abdominal Aorta with Intraluminal Device, Temporary, Open Approach */
"04V00DZ" = '1' /*Restriction of Abdominal Aorta with Intraluminal Device, Open Approach */
"04V00E6" = '1' /*Restriction of Abdominal Aorta, Bifurcation, with Branched or Fenestrated Intraluminal Device, One or Two Arteries, Open Approach */
"04V00EZ" = '1' /*Restriction of Abdominal Aorta with Branched or Fenestrated Intraluminal Device, One or Two Arteries, Open Approach */
"04V00F6" = '1' /*Restriction of Abdominal Aorta, Bifurcation, with Branched or Fenestrated Intraluminal Device, Three or More Arteries, Open Approach */
"04V00FZ" = '1' /*Restriction of Abdominal Aorta with Branched or Fenestrated Intraluminal Device, Three or More Arteries, Open Approach */
"04V00Z6" = '1' /*Restriction of Abdominal Aorta, Bifurcation, Open Approach */
"04V00ZZ" = '1' /*Restriction of Abdominal Aorta, Open Approach */
OTHER = '0'
;

/* FORMAT FOR Coronary artery bypass graft (CABG) procedure codes */
Value $PRCABGP
"0210083" = '1' /*Bypass Coronary Artery, One Artery from Coronary Artery with Zooplastic Tissue, Open Approach */
"0210088" = '1' /*Bypass Coronary Artery, One Artery from Right Internal Mammary with Zooplastic Tissue, Open Approach */
"0210089" = '1' /*Bypass Coronary Artery, One Artery from Left Internal Mammary with Zooplastic Tissue, Open Approach */
"021008C" = '1' /*Bypass Coronary Artery, One Artery from Thoracic Artery with Zooplastic Tissue, Open Approach */
"021008F" = '1' /*Bypass Coronary Artery, One Artery from Abdominal Artery with Zooplastic Tissue, Open Approach */
"021008W" = '1' /*Bypass Coronary Artery, One Artery from Aorta with Zooplastic Tissue, Open Approach */
"0210093" = '1' /*Bypass Coronary Artery, One Artery from Coronary Artery with Autologous Venous Tissue, Open Approach */
"0210098" = '1' /*Bypass Coronary Artery, One Artery from Right Internal Mammary with Autologous Venous Tissue, Open Approach */
"0210099" = '1' /*Bypass Coronary Artery, One Artery from Left Internal Mammary with Autologous Venous Tissue, Open Approach */
"021009C" = '1' /*Bypass Coronary Artery, One Artery from Thoracic Artery with Autologous Venous Tissue, Open Approach */
"021009F" = '1' /*Bypass Coronary Artery, One Artery from Abdominal Artery with Autologous Venous Tissue, Open Approach */
"021009W" = '1' /*Bypass Coronary Artery, One Artery from Aorta with Autologous Venous Tissue, Open Approach */
"02100A3" = '1' /*Bypass Coronary Artery, One Artery from Coronary Artery with Autologous Arterial Tissue, Open Approach */
"02100A8" = '1' /*Bypass Coronary Artery, One Artery from Right Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02100A9" = '1' /*Bypass Coronary Artery, One Artery from Left Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02100AC" = '1' /*Bypass Coronary Artery, One Artery from Thoracic Artery with Autologous Arterial Tissue, Open Approach */
"02100AF" = '1' /*Bypass Coronary Artery, One Artery from Abdominal Artery with Autologous Arterial Tissue, Open Approach */
"02100AW" = '1' /*Bypass Coronary Artery, One Artery from Aorta with Autologous Arterial Tissue, Open Approach */
"02100J3" = '1' /*Bypass Coronary Artery, One Artery from Coronary Artery with Synthetic Substitute, Open Approach */
"02100J8" = '1' /*Bypass Coronary Artery, One Artery from Right Internal Mammary with Synthetic Substitute, Open Approach */
"02100J9" = '1' /*Bypass Coronary Artery, One Artery from Left Internal Mammary with Synthetic Substitute, Open Approach */
"02100JC" = '1' /*Bypass Coronary Artery, One Artery from Thoracic Artery with Synthetic Substitute, Open Approach */
"02100JF" = '1' /*Bypass Coronary Artery, One Artery from Abdominal Artery with Synthetic Substitute, Open Approach */
"02100JW" = '1' /*Bypass Coronary Artery, One Artery from Aorta with Synthetic Substitute, Open Approach */
"02100K3" = '1' /*Bypass Coronary Artery, One Artery from Coronary Artery with Nonautologous Tissue Substitute, Open Approach */
"02100K8" = '1' /*Bypass Coronary Artery, One Artery from Right Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02100K9" = '1' /*Bypass Coronary Artery, One Artery from Left Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02100KC" = '1' /*Bypass Coronary Artery, One Artery from Thoracic Artery with Nonautologous Tissue Substitute, Open Approach */
"02100KF" = '1' /*Bypass Coronary Artery, One Artery from Abdominal Artery with Nonautologous Tissue Substitute, Open Approach */
"02100KW" = '1' /*Bypass Coronary Artery, One Artery from Aorta with Nonautologous Tissue Substitute, Open Approach */
"02100Z3" = '1' /*Bypass Coronary Artery, One Artery from Coronary Artery, Open Approach */
"02100Z8" = '1' /*Bypass Coronary Artery, One Artery from Right Internal Mammary, Open Approach */
"02100Z9" = '1' /*Bypass Coronary Artery, One Artery from Left Internal Mammary, Open Approach */
"02100ZC" = '1' /*Bypass Coronary Artery, One Artery from Thoracic Artery, Open Approach */
"02100ZF" = '1' /*Bypass Coronary Artery, One Artery from Abdominal Artery, Open Approach */
"0211083" = '1' /*Bypass Coronary Artery, Two Arteries from Coronary Artery with Zooplastic Tissue, Open Approach */
"0211088" = '1' /*Bypass Coronary Artery, Two Arteries from Right Internal Mammary with Zooplastic Tissue, Open Approach */
"0211089" = '1' /*Bypass Coronary Artery, Two Arteries from Left Internal Mammary with Zooplastic Tissue, Open Approach */
"021108C" = '1' /*Bypass Coronary Artery, Two Arteries from Thoracic Artery with Zooplastic Tissue, Open Approach */
"021108F" = '1' /*Bypass Coronary Artery, Two Arteries from Abdominal Artery with Zooplastic Tissue, Open Approach */
"021108W" = '1' /*Bypass Coronary Artery, Two Arteries from Aorta with Zooplastic Tissue, Open Approach */
"0211093" = '1' /*Bypass Coronary Artery, Two Arteries from Coronary Artery with Autologous Venous Tissue, Open Approach */
"0211098" = '1' /*Bypass Coronary Artery, Two Arteries from Right Internal Mammary with Autologous Venous Tissue, Open Approach */
"0211099" = '1' /*Bypass Coronary Artery, Two Arteries from Left Internal Mammary with Autologous Venous Tissue, Open Approach */
"021109C" = '1' /*Bypass Coronary Artery, Two Arteries from Thoracic Artery with Autologous Venous Tissue, Open Approach */
"021109F" = '1' /*Bypass Coronary Artery, Two Arteries from Abdominal Artery with Autologous Venous Tissue, Open Approach */
"021109W" = '1' /*Bypass Coronary Artery, Two Arteries from Aorta with Autologous Venous Tissue, Open Approach */
"02110A3" = '1' /*Bypass Coronary Artery, Two Arteries from Coronary Artery with Autologous Arterial Tissue, Open Approach */
"02110A8" = '1' /*Bypass Coronary Artery, Two Arteries from Right Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02110A9" = '1' /*Bypass Coronary Artery, Two Arteries from Left Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02110AC" = '1' /*Bypass Coronary Artery, Two Arteries from Thoracic Artery with Autologous Arterial Tissue, Open Approach */
"02110AF" = '1' /*Bypass Coronary Artery, Two Arteries from Abdominal Artery with Autologous Arterial Tissue, Open Approach */
"02110AW" = '1' /*Bypass Coronary Artery, Two Arteries from Aorta with Autologous Arterial Tissue, Open Approach */
"02110J3" = '1' /*Bypass Coronary Artery, Two Arteries from Coronary Artery with Synthetic Substitute, Open Approach */
"02110J8" = '1' /*Bypass Coronary Artery, Two Arteries from Right Internal Mammary with Synthetic Substitute, Open Approach */
"02110J9" = '1' /*Bypass Coronary Artery, Two Arteries from Left Internal Mammary with Synthetic Substitute, Open Approach */
"02110JC" = '1' /*Bypass Coronary Artery, Two Arteries from Thoracic Artery with Synthetic Substitute, Open Approach */
"02110JF" = '1' /*Bypass Coronary Artery, Two Arteries from Abdominal Artery with Synthetic Substitute, Open Approach */
"02110JW" = '1' /*Bypass Coronary Artery, Two Arteries from Aorta with Synthetic Substitute, Open Approach */
"02110K3" = '1' /*Bypass Coronary Artery, Two Arteries from Coronary Artery with Nonautologous Tissue Substitute, Open Approach */
"02110K8" = '1' /*Bypass Coronary Artery, Two Arteries from Right Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02110K9" = '1' /*Bypass Coronary Artery, Two Arteries from Left Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02110KC" = '1' /*Bypass Coronary Artery, Two Arteries from Thoracic Artery with Nonautologous Tissue Substitute, Open Approach */
"02110KF" = '1' /*Bypass Coronary Artery, Two Arteries from Abdominal Artery with Nonautologous Tissue Substitute, Open Approach */
"02110KW" = '1' /*Bypass Coronary Artery, Two Arteries from Aorta with Nonautologous Tissue Substitute, Open Approach */
"02110Z3" = '1' /*Bypass Coronary Artery, Two Arteries from Coronary Artery, Open Approach */
"02110Z8" = '1' /*Bypass Coronary Artery, Two Arteries from Right Internal Mammary, Open Approach */
"02110Z9" = '1' /*Bypass Coronary Artery, Two Arteries from Left Internal Mammary, Open Approach */
"02110ZC" = '1' /*Bypass Coronary Artery, Two Arteries from Thoracic Artery, Open Approach */
"02110ZF" = '1' /*Bypass Coronary Artery, Two Arteries from Abdominal Artery, Open Approach */
"0212083" = '1' /*Bypass Coronary Artery, Three Arteries from Coronary Artery with Zooplastic Tissue, Open Approach */
"0212088" = '1' /*Bypass Coronary Artery, Three Arteries from Right Internal Mammary with Zooplastic Tissue, Open Approach */
"0212089" = '1' /*Bypass Coronary Artery, Three Arteries from Left Internal Mammary with Zooplastic Tissue, Open Approach */
"021208C" = '1' /*Bypass Coronary Artery, Three Arteries from Thoracic Artery with Zooplastic Tissue, Open Approach */
"021208F" = '1' /*Bypass Coronary Artery, Three Arteries from Abdominal Artery with Zooplastic Tissue, Open Approach */
"021208W" = '1' /*Bypass Coronary Artery, Three Arteries from Aorta with Zooplastic Tissue, Open Approach */
"0212093" = '1' /*Bypass Coronary Artery, Three Arteries from Coronary Artery with Autologous Venous Tissue, Open Approach */
"0212098" = '1' /*Bypass Coronary Artery, Three Arteries from Right Internal Mammary with Autologous Venous Tissue, Open Approach */
"0212099" = '1' /*Bypass Coronary Artery, Three Arteries from Left Internal Mammary with Autologous Venous Tissue, Open Approach */
"021209C" = '1' /*Bypass Coronary Artery, Three Arteries from Thoracic Artery with Autologous Venous Tissue, Open Approach */
"021209F" = '1' /*Bypass Coronary Artery, Three Arteries from Abdominal Artery with Autologous Venous Tissue, Open Approach */
"021209W" = '1' /*Bypass Coronary Artery, Three Arteries from Aorta with Autologous Venous Tissue, Open Approach */
"02120A3" = '1' /*Bypass Coronary Artery, Three Arteries from Coronary Artery with Autologous Arterial Tissue, Open Approach */
"02120A8" = '1' /*Bypass Coronary Artery, Three Arteries from Right Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02120A9" = '1' /*Bypass Coronary Artery, Three Arteries from Left Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02120AC" = '1' /*Bypass Coronary Artery, Three Arteries from Thoracic Artery with Autologous Arterial Tissue, Open Approach */
"02120AF" = '1' /*Bypass Coronary Artery, Three Arteries from Abdominal Artery with Autologous Arterial Tissue, Open Approach */
"02120AW" = '1' /*Bypass Coronary Artery, Three Arteries from Aorta with Autologous Arterial Tissue, Open Approach */
"02120J3" = '1' /*Bypass Coronary Artery, Three Arteries from Coronary Artery with Synthetic Substitute, Open Approach */
"02120J8" = '1' /*Bypass Coronary Artery, Three Arteries from Right Internal Mammary with Synthetic Substitute, Open Approach */
"02120J9" = '1' /*Bypass Coronary Artery, Three Arteries from Left Internal Mammary with Synthetic Substitute, Open Approach */
"02120JC" = '1' /*Bypass Coronary Artery, Three Arteries from Thoracic Artery with Synthetic Substitute, Open Approach */
"02120JF" = '1' /*Bypass Coronary Artery, Three Arteries from Abdominal Artery with Synthetic Substitute, Open Approach */
"02120JW" = '1' /*Bypass Coronary Artery, Three Arteries from Aorta with Synthetic Substitute, Open Approach */
"02120K3" = '1' /*Bypass Coronary Artery, Three Arteries from Coronary Artery with Nonautologous Tissue Substitute, Open Approach */
"02120K8" = '1' /*Bypass Coronary Artery, Three Arteries from Right Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02120K9" = '1' /*Bypass Coronary Artery, Three Arteries from Left Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02120KC" = '1' /*Bypass Coronary Artery, Three Arteries from Thoracic Artery with Nonautologous Tissue Substitute, Open Approach */
"02120KF" = '1' /*Bypass Coronary Artery, Three Arteries from Abdominal Artery with Nonautologous Tissue Substitute, Open Approach */
"02120KW" = '1' /*Bypass Coronary Artery, Three Arteries from Aorta with Nonautologous Tissue Substitute, Open Approach */
"02120Z3" = '1' /*Bypass Coronary Artery, Three Arteries from Coronary Artery, Open Approach */
"02120Z8" = '1' /*Bypass Coronary Artery, Three Arteries from Right Internal Mammary, Open Approach */
"02120Z9" = '1' /*Bypass Coronary Artery, Three Arteries from Left Internal Mammary, Open Approach */
"02120ZC" = '1' /*Bypass Coronary Artery, Three Arteries from Thoracic Artery, Open Approach */
"02120ZF" = '1' /*Bypass Coronary Artery, Three Arteries from Abdominal Artery, Open Approach */
"0213083" = '1' /*Bypass Coronary Artery, Four or More Arteries from Coronary Artery with Zooplastic Tissue, Open Approach */
"0213088" = '1' /*Bypass Coronary Artery, Four or More Arteries from Right Internal Mammary with Zooplastic Tissue, Open Approach */
"0213089" = '1' /*Bypass Coronary Artery, Four or More Arteries from Left Internal Mammary with Zooplastic Tissue, Open Approach */
"021308C" = '1' /*Bypass Coronary Artery, Four or More Arteries from Thoracic Artery with Zooplastic Tissue, Open Approach */
"021308F" = '1' /*Bypass Coronary Artery, Four or More Arteries from Abdominal Artery with Zooplastic Tissue, Open Approach */
"021308W" = '1' /*Bypass Coronary Artery, Four or More Arteries from Aorta with Zooplastic Tissue, Open Approach */
"0213093" = '1' /*Bypass Coronary Artery, Four or More Arteries from Coronary Artery with Autologous Venous Tissue, Open Approach */
"0213098" = '1' /*Bypass Coronary Artery, Four or More Arteries from Right Internal Mammary with Autologous Venous Tissue, Open Approach */
"0213099" = '1' /*Bypass Coronary Artery, Four or More Arteries from Left Internal Mammary with Autologous Venous Tissue, Open Approach */
"021309C" = '1' /*Bypass Coronary Artery, Four or More Arteries from Thoracic Artery with Autologous Venous Tissue, Open Approach */
"021309F" = '1' /*Bypass Coronary Artery, Four or More Arteries from Abdominal Artery with Autologous Venous Tissue, Open Approach */
"021309W" = '1' /*Bypass Coronary Artery, Four or More Arteries from Aorta with Autologous Venous Tissue, Open Approach */
"02130A3" = '1' /*Bypass Coronary Artery, Four or More Arteries from Coronary Artery with Autologous Arterial Tissue, Open Approach */
"02130A8" = '1' /*Bypass Coronary Artery, Four or More Arteries from Right Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02130A9" = '1' /*Bypass Coronary Artery, Four or More Arteries from Left Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02130AC" = '1' /*Bypass Coronary Artery, Four or More Arteries from Thoracic Artery with Autologous Arterial Tissue, Open Approach */
"02130AF" = '1' /*Bypass Coronary Artery, Four or More Arteries from Abdominal Artery with Autologous Arterial Tissue, Open Approach */
"02130AW" = '1' /*Bypass Coronary Artery, Four or More Arteries from Aorta with Autologous Arterial Tissue, Open Approach */
"02130J3" = '1' /*Bypass Coronary Artery, Four or More Arteries from Coronary Artery with Synthetic Substitute, Open Approach */
"02130J8" = '1' /*Bypass Coronary Artery, Four or More Arteries from Right Internal Mammary with Synthetic Substitute, Open Approach */
"02130J9" = '1' /*Bypass Coronary Artery, Four or More Arteries from Left Internal Mammary with Synthetic Substitute, Open Approach */
"02130JC" = '1' /*Bypass Coronary Artery, Four or More Arteries from Thoracic Artery with Synthetic Substitute, Open Approach */
"02130JF" = '1' /*Bypass Coronary Artery, Four or More Arteries from Abdominal Artery with Synthetic Substitute, Open Approach */
"02130JW" = '1' /*Bypass Coronary Artery, Four or More Arteries from Aorta with Synthetic Substitute, Open Approach */
"02130K3" = '1' /*Bypass Coronary Artery, Four or More Arteries from Coronary Artery with Nonautologous Tissue Substitute, Open Approach */
"02130K8" = '1' /*Bypass Coronary Artery, Four or More Arteries from Right Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02130K9" = '1' /*Bypass Coronary Artery, Four or More Arteries from Left Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02130KC" = '1' /*Bypass Coronary Artery, Four or More Arteries from Thoracic Artery with Nonautologous Tissue Substitute, Open Approach */
"02130KF" = '1' /*Bypass Coronary Artery, Four or More Arteries from Abdominal Artery with Nonautologous Tissue Substitute, Open Approach */
"02130KW" = '1' /*Bypass Coronary Artery, Four or More Arteries from Aorta with Nonautologous Tissue Substitute, Open Approach */
"02130Z3" = '1' /*Bypass Coronary Artery, Four or More Arteries from Coronary Artery, Open Approach */
"02130Z8" = '1' /*Bypass Coronary Artery, Four or More Arteries from Right Internal Mammary, Open Approach */
"02130Z9" = '1' /*Bypass Coronary Artery, Four or More Arteries from Left Internal Mammary, Open Approach */
"02130ZC" = '1' /*Bypass Coronary Artery, Four or More Arteries from Thoracic Artery, Open Approach */
"02130ZF" = '1' /*Bypass Coronary Artery, Four or More Arteries from Abdominal Artery, Open Approach */
OTHER = '0'
;

/* FORMAT FOR Carotid endarterectomy procedure codes */
Value $PRCEATP
"03CH0Z6" = '1' /*Extirpation of Matter from Right Common Carotid Artery, Bifurcation, Open Approach */
"03CH0ZZ" = '1' /*Extirpation of Matter from Right Common Carotid Artery, OpenApproach */
"03CJ0Z6" = '1' /*Extirpation of Matter from Left Common Carotid Artery, Bifurcation, Open Approach */
"03CJ0ZZ" = '1' /*Extirpation of Matter from Left Common Carotid Artery, OpenApproach */
"03CK0Z6" = '1' /*Extirpation of Matter from Right Internal Carotid Artery, Bifurcation, Open Approach */
"03CK0ZZ" = '1' /*Extirpation of Matter from Right Internal Carotid Artery, OpenApproach */
"03CL0Z6" = '1' /*Extirpation of Matter from Left Internal Carotid Artery, Bifurcation, Open Approach */
"03CL0ZZ" = '1' /*Extirpation of Matter from Left Internal Carotid Artery, OpenApproach */
OTHER = '0'
;

/* FORMAT FOR Cesarean delivery MS-DRG codes */
Value $PRCSE2G
"765" = '1' /*CESAREAN SECTION WITH CC/MCC */
"766" = '1' /*CESAREAN SECTION WITHOUT CC/MCC */
OTHER = '0'
;

/* FORMAT FOR Hysterotomy procedure codes */
Value $PRCSE2P
"10A00ZZ" = '1' /*Abortion of Products of Conception, Open Approach */
"10A03ZZ" = '1' /*Abortion of Products of Conception, Percutaneous Approach */
"10A04ZZ" = '1' /*Abortion of Products of Conception, Percutaneous Endoscopic Approach */
OTHER = '0'
;

/* FORMAT FOR Abnormal presentation, fetal death, and multiple gestation diagnosis codes */
Value $PRCSECD
"O30001" = '1' /*Twin pregnancy, unspecified number of placenta andunspecified number of amniotic sacs, first trimester */
"O30002" = '1' /*Twin pregnancy, unspecified number of placenta andunspecified number of amniotic sacs, second trimester */
"O30003" = '1' /*Twin pregnancy, unspecified number of placenta andunspecified number of amniotic sacs, third trimester */
"O30009" = '1' /*Twin pregnancy, unspecified number of placenta andunspecified number of amniotic sacs, unspecifiedtrimester */
"O30011" = '1' /*Twin pregnancy, monochorionic/monoamniotic, firsttrimester */
"O30012" = '1' /*Twin pregnancy, monochorionic/monoamniotic, secondtrimester */
"O30013" = '1' /*Twin pregnancy, monochorionic/monoamniotic, thirdtrimester */
"O30019" = '1' /*Twin pregnancy, monochorionic/monoamniotic,unspecified trimester */
"O30021" = '1' /*Conjoined twin pregnancy, first trimester */
"O30022" = '1' /*Conjoined twin pregnancy, second trimester */
"O30023" = '1' /*Conjoined twin pregnancy, third trimester */
"O30029" = '1' /*Conjoined twin pregnancy, unspecified trimester */
"O30031" = '1' /*Twin pregnancy, monochorionic/diamniotic, firsttrimester */
"O30032" = '1' /*Twin pregnancy, monochorionic/diamniotic, secondtrimester */
"O30033" = '1' /*Twin pregnancy, monochorionic/diamniotic, thirdtrimester */
"O30039" = '1' /*Twin pregnancy, monochorionic/diamniotic, unspecifiedtrimester */
"O30041" = '1' /*Twin pregnancy, dichorionic/diamniotic, first trimester */
"O30042" = '1' /*Twin pregnancy, dichorionic/diamniotic, secondtrimester */
"O30043" = '1' /*Twin pregnancy, dichorionic/diamniotic, third trimester */
"O30049" = '1' /*Twin pregnancy, dichorionic/diamniotic, unspecifiedtrimester */
"O30091" = '1' /*Twin pregnancy, unable to determine number ofplacenta and number of amniotic sacs, first trimester */
"O30092" = '1' /*Twin pregnancy, unable to determine number ofplacenta and number of amniotic sacs, secondtrimester */
"O30093" = '1' /*Twin pregnancy, unable to determine number ofplacenta and number of amniotic sacs, third trimester */
"O30099" = '1' /*Twin pregnancy, unable to determine number ofplacenta and number of amniotic sacs, unspecifiedtrimester */
"O30101" = '1' /*Triplet pregnancy, unspecified number of placenta andunspecified number of amniotic sacs, first trimester */
"O30102" = '1' /*Triplet pregnancy, unspecified number of placenta andunspecified number of amniotic sacs, second trimester */
"O30103" = '1' /*Triplet pregnancy, unspecified number of placenta andunspecified number of amniotic sacs, third trimester */
"O30109" = '1' /*Triplet pregnancy, unspecified number of placenta andunspecified number of amniotic sacs, unspecifiedtrimester */
"O30111" = '1' /*Triplet pregnancy with two or more monochorionicfetuses, first trimester */
"O30112" = '1' /*Triplet pregnancy with two or more monochorionicfetuses, second trimester */
"O30113" = '1' /*Triplet pregnancy with two or more monochorionicfetuses, third trimester */
"O30119" = '1' /*Triplet pregnancy with two or more monochorionicfetuses, unspecified trimester */
"O30121" = '1' /*Triplet pregnancy with two or more monoamnioticfetuses, first trimester */
"O30122" = '1' /*Triplet pregnancy with two or more monoamnioticfetuses, second trimester */
"O30123" = '1' /*Triplet pregnancy with two or more monoamnioticfetuses, third trimester */
"O30129" = '1' /*Triplet pregnancy with two or more monoamnioticfetuses, unspecified trimester */
"O30191" = '1' /*Triplet pregnancy, unable to determine number ofplacenta and number of amniotic sacs, first trimester */
"O30192" = '1' /*Triplet pregnancy, unable to determine number ofplacenta and number of amniotic sacs, secondtrimester */
"O30193" = '1' /*Triplet pregnancy, unable to determine number ofplacenta and number of amniotic sacs, third trimester */
"O30199" = '1' /*Triplet pregnancy, unable to determine number ofplacenta and number of amniotic sacs, unspecifiedtrimester */
"O30201" = '1' /*Quadruplet pregnancy, unspecified number of placentaand unspecified number of amniotic sacs, first trimester */
"O30202" = '1' /*Quadruplet pregnancy, unspecified number of placentaand unspecified number of amniotic sacs, secondtrimester */
"O30203" = '1' /*Quadruplet pregnancy, unspecified number of placentaand unspecified number of amniotic sacs, thirdtrimester */
"O30209" = '1' /*Quadruplet pregnancy, unspecified number of placentaand unspecified number of amniotic sacs, unspecifiedtrimester */
"O30211" = '1' /*Quadruplet pregnancy with two or more monochorionicfetuses, first trimester */
"O30212" = '1' /*Quadruplet pregnancy with two or more monochorionicfetuses, second trimester */
"O30213" = '1' /*Quadruplet pregnancy with two or more monochorionicfetuses, third trimester */
"O30219" = '1' /*Quadruplet pregnancy with two or more monochorionicfetuses, unspecified trimester */
"O30221" = '1' /*Quadruplet pregnancy with two or more monoamnioticfetuses, first trimester */
"O30222" = '1' /*Quadruplet pregnancy with two or more monoamnioticfetuses, second trimester */
"O30223" = '1' /*Quadruplet pregnancy with two or more monoamnioticfetuses, third trimester */
"O30229" = '1' /*Quadruplet pregnancy with two or more monoamnioticfetuses, unspecified trimester */
"O30291" = '1' /*Quadruplet pregnancy, unable to determine number ofplacenta and number of amniotic sacs, first trimester */
"O30292" = '1' /*Quadruplet pregnancy, unable to determine number ofplacenta and number of amniotic sacs, secondtrimester */
"O30293" = '1' /*Quadruplet pregnancy, unable to determine number ofplacenta and number of amniotic sacs, third trimester */
"O30299" = '1' /*Quadruplet pregnancy, unable to determine number ofplacenta and number of amniotic sacs, unspecifiedtrimester */
"O30801" = '1' /*Other specified multiple gestation, unspecified numberof placenta and unspecified number of amniotic sacs,first trimester */
"O30802" = '1' /*Other specified multiple gestation, unspecified numberof placenta and unspecified number of amniotic sacs,second trimester */
"O30803" = '1' /*Other specified multiple gestation, unspecified numberof placenta and unspecified number of amniotic sacs,third trimester */
"O30809" = '1' /*Other specified multiple gestation, unspecified numberof placenta and unspecified number of amniotic sacs,unspecified trimester */
"O30811" = '1' /*Other specified multiple gestation with two or moremonochorionic fetuses, first trimester */
"O30812" = '1' /*Other specified multiple gestation with two or moremonochorionic fetuses, second trimester */
"O30813" = '1' /*Other specified multiple gestation with two or moremonochorionic fetuses, third trimester */
"O30819" = '1' /*Other specified multiple gestation with two or moremonochorionic fetuses, unspecified trimester */
"O30821" = '1' /*Other specified multiple gestation with two or moremonoamniotic fetuses, first trimester */
"O30822" = '1' /*Other specified multiple gestation with two or moremonoamniotic fetuses, second trimester */
"O30823" = '1' /*Other specified multiple gestation with two or moremonoamniotic fetuses, third trimester */
"O30829" = '1' /*Other specified multiple gestation with two or moremonoamniotic fetuses, unspecified trimester */
"O30891" = '1' /*Other specified multiple gestation, unable to determinenumber of placenta and number of amniotic sacs, firsttrimester */
"O30892" = '1' /*Other specified multiple gestation, unable to determinenumber of placenta and number of amniotic sacs,second trimester */
"O30893" = '1' /*Other specified multiple gestation, unable to determinenumber of placenta and number of amniotic sacs, thirdtrimester */
"O30899" = '1' /*Other specified multiple gestation, unable to determinenumber of placenta and number of amniotic sacs,unspecified trimester */
"O3090" = '1' /*Multiple gestation, unspecified, unspecified trimester */
"O3091" = '1' /*Multiple gestation, unspecified, first trimester */
"O3092" = '1' /*Multiple gestation, unspecified, second trimester */
"O3093" = '1' /*Multiple gestation, unspecified, third trimester */
"O3110X0" = '1' /*Continuing pregnancy after spontaneous abortion ofone fetus or more, unspecified trimester, not applicableor unspecified */
"O3110X1" = '1' /*Continuing pregnancy after spontaneous abortion ofone fetus or more, unspecified trimester, fetus 1 */
"O3110X2" = '1' /*Continuing pregnancy after spontaneous abortion ofone fetus or more, unspecified trimester, fetus 2 */
"O3110X3" = '1' /*Continuing pregnancy after spontaneous abortion ofone fetus or more, unspecified trimester, fetus 3 */
"O3110X4" = '1' /*Continuing pregnancy after spontaneous abortion ofone fetus or more, unspecified trimester, fetus 4 */
"O3110X5" = '1' /*Continuing pregnancy after spontaneous abortion ofone fetus or more, unspecified trimester, fetus 5 */
"O3110X9" = '1' /*Continuing pregnancy after spontaneous abortion ofone fetus or more, unspecified trimester, other fetus */
"O3111X0" = '1' /*Continuing pregnancy after spontaneous abortion ofone fetus or more, first trimester, not applicable orunspecified */
"O3111X1" = '1' /*Continuing pregnancy after spontaneous abortion ofone fetus or more, first trimester, fetus 1 */
"O3111X2" = '1' /*Continuing pregnancy after spontaneous abortion ofone fetus or more, first trimester, fetus 2 */
"O3111X3" = '1' /*Continuing pregnancy after spontaneous abortion ofone fetus or more, first trimester, fetus 3 */
"O3111X4" = '1' /*Continuing pregnancy after spontaneous abortion ofone fetus or more, first trimester, fetus 4 */
"O3111X5" = '1' /*Continuing pregnancy after spontaneous abortion ofone fetus or more, first trimester, fetus 5 */
"O3111X9" = '1' /*Continuing pregnancy after spontaneous abortion ofone fetus or more, first trimester, other fetus */
"O3112X0" = '1' /*Continuing pregnancy after spontaneous abortion ofone fetus or more, second trimester, not applicable orunspecified */
"O3112X1" = '1' /*Continuing pregnancy after spontaneous abortion ofone fetus or more, second trimester, fetus 1 */
"O3112X2" = '1' /*Continuing pregnancy after spontaneous abortion ofone fetus or more, second trimester, fetus 2 */
"O3112X3" = '1' /*Continuing pregnancy after spontaneous abortion ofone fetus or more, second trimester, fetus 3 */
"O3112X4" = '1' /*Continuing pregnancy after spontaneous abortion ofone fetus or more, second trimester, fetus 4 */
"O3112X5" = '1' /*Continuing pregnancy after spontaneous abortion ofone fetus or more, second trimester, fetus 5 */
"O3112X9" = '1' /*Continuing pregnancy after spontaneous abortion ofone fetus or more, second trimester, other fetus */
"O3113X0" = '1' /*Continuing pregnancy after spontaneous abortion ofone fetus or more, third trimester, not applicable orunspecified */
"O3113X1" = '1' /*Continuing pregnancy after spontaneous abortion ofone fetus or more, third trimester, fetus 1 */
"O3113X2" = '1' /*Continuing pregnancy after spontaneous abortion ofone fetus or more, third trimester, fetus 2 */
"O3113X3" = '1' /*Continuing pregnancy after spontaneous abortion ofone fetus or more, third trimester, fetus 3 */
"O3113X4" = '1' /*Continuing pregnancy after spontaneous abortion ofone fetus or more, third trimester, fetus 4 */
"O3113X5" = '1' /*Continuing pregnancy after spontaneous abortion ofone fetus or more, third trimester, fetus 5 */
"O3113X9" = '1' /*Continuing pregnancy after spontaneous abortion ofone fetus or more, third trimester, other fetus */
"O3120X0" = '1' /*Continuing pregnancy after intrauterine death of onefetus or more, unspecified trimester, not applicable orunspecified */
"O3120X1" = '1' /*Continuing pregnancy after intrauterine death of onefetus or more, unspecified trimester, fetus 1 */
"O3120X2" = '1' /*Continuing pregnancy after intrauterine death of onefetus or more, unspecified trimester, fetus 2 */
"O3120X3" = '1' /*Continuing pregnancy after intrauterine death of onefetus or more, unspecified trimester, fetus 3 */
"O3120X4" = '1' /*Continuing pregnancy after intrauterine death of onefetus or more, unspecified trimester, fetus 4 */
"O3120X5" = '1' /*Continuing pregnancy after intrauterine death of onefetus or more, unspecified trimester, fetus 5 */
"O3120X9" = '1' /*Continuing pregnancy after intrauterine death of onefetus or more, unspecified trimester, other fetus */
"O3121X0" = '1' /*Continuing pregnancy after intrauterine death of onefetus or more, first trimester, not applicable orunspecified */
"O3121X1" = '1' /*Continuing pregnancy after intrauterine death of onefetus or more, first trimester, fetus 1 */
"O3121X2" = '1' /*Continuing pregnancy after intrauterine death of onefetus or more, first trimester, fetus 2 */
"O3121X3" = '1' /*Continuing pregnancy after intrauterine death of onefetus or more, first trimester, fetus 3 */
"O3121X4" = '1' /*Continuing pregnancy after intrauterine death of onefetus or more, first trimester, fetus 4 */
"O3121X5" = '1' /*Continuing pregnancy after intrauterine death of onefetus or more, first trimester, fetus 5 */
"O3121X9" = '1' /*Continuing pregnancy after intrauterine death of onefetus or more, first trimester, other fetus */
"O3122X0" = '1' /*Continuing pregnancy after intrauterine death of onefetus or more, second trimester, not applicable orunspecified */
"O3122X1" = '1' /*Continuing pregnancy after intrauterine death of onefetus or more, second trimester, fetus 1 */
"O3122X2" = '1' /*Continuing pregnancy after intrauterine death of onefetus or more, second trimester, fetus 2 */
"O3122X3" = '1' /*Continuing pregnancy after intrauterine death of onefetus or more, second trimester, fetus 3 */
"O3122X4" = '1' /*Continuing pregnancy after intrauterine death of onefetus or more, second trimester, fetus 4 */
"O3122X5" = '1' /*Continuing pregnancy after intrauterine death of onefetus or more, second trimester, fetus 5 */
"O3122X9" = '1' /*Continuing pregnancy after intrauterine death of onefetus or more, second trimester, other fetus */
"O3123X0" = '1' /*Continuing pregnancy after intrauterine death of onefetus or more, third trimester, not applicable orunspecified */
"O3123X1" = '1' /*Continuing pregnancy after intrauterine death of onefetus or more, third trimester, fetus 1 */
"O3123X2" = '1' /*Continuing pregnancy after intrauterine death of onefetus or more, third trimester, fetus 2 */
"O3123X3" = '1' /*Continuing pregnancy after intrauterine death of onefetus or more, third trimester, fetus 3 */
"O3123X4" = '1' /*Continuing pregnancy after intrauterine death of onefetus or more, third trimester, fetus 4 */
"O3123X5" = '1' /*Continuing pregnancy after intrauterine death of onefetus or more, third trimester, fetus 5 */
"O3123X9" = '1' /*Continuing pregnancy after intrauterine death of onefetus or more, third trimester, other fetus */
"O318X10" = '1' /*Other complications specific to multiple gestation, firsttrimester, not applicable or unspecified */
"O318X11" = '1' /*Other complications specific to multiple gestation, firsttrimester, fetus 1 */
"O318X12" = '1' /*Other complications specific to multiple gestation, firsttrimester, fetus 2 */
"O318X13" = '1' /*Other complications specific to multiple gestation, firsttrimester, fetus 3 */
"O318X14" = '1' /*Other complications specific to multiple gestation, firsttrimester, fetus 4 */
"O318X15" = '1' /*Other complications specific to multiple gestation, firsttrimester, fetus 5 */
"O318X19" = '1' /*Other complications specific to multiple gestation, firsttrimester, other fetus */
"O318X20" = '1' /*Other complications specific to multiple gestation,second trimester, not applicable or unspecified */
"O318X21" = '1' /*Other complications specific to multiple gestation,second trimester, fetus 1 */
"O318X22" = '1' /*Other complications specific to multiple gestation,second trimester, fetus 2 */
"O318X23" = '1' /*Other complications specific to multiple gestation,second trimester, fetus 3 */
"O318X24" = '1' /*Other complications specific to multiple gestation,second trimester, fetus 4 */
"O318X25" = '1' /*Other complications specific to multiple gestation,second trimester, fetus 5 */
"O318X29" = '1' /*Other complications specific to multiple gestation,second trimester, other fetus */
"O318X30" = '1' /*Other complications specific to multiple gestation, thirdtrimester, not applicable or unspecified */
"O318X31" = '1' /*Other complications specific to multiple gestation, thirdtrimester, fetus 1 */
"O318X32" = '1' /*Other complications specific to multiple gestation, thirdtrimester, fetus 2 */
"O318X33" = '1' /*Other complications specific to multiple gestation, thirdtrimester, fetus 3 */
"O318X34" = '1' /*Other complications specific to multiple gestation, thirdtrimester, fetus 4 */
"O318X35" = '1' /*Other complications specific to multiple gestation, thirdtrimester, fetus 5 */
"O318X39" = '1' /*Other complications specific to multiple gestation, thirdtrimester, other fetus */
"O318X90" = '1' /*Other complications specific to multiple gestation,unspecified trimester, not applicable or unspecified */
"O318X91" = '1' /*Other complications specific to multiple gestation,unspecified trimester, fetus 1 */
"O318X92" = '1' /*Other complications specific to multiple gestation,unspecified trimester, fetus 2 */
"O318X93" = '1' /*Other complications specific to multiple gestation,unspecified trimester, fetus 3 */
"O318X94" = '1' /*Other complications specific to multiple gestation,unspecified trimester, fetus 4 */
"O318X95" = '1' /*Other complications specific to multiple gestation,unspecified trimester, fetus 5 */
"O318X99" = '1' /*Other complications specific to multiple gestation,unspecified trimester, other fetus */
"O321XX0" = '1' /*Maternal care for breech presentation, not applicableor unspecified */
"O321XX1" = '1' /*Maternal care for breech presentation, fetus 1 */
"O321XX2" = '1' /*Maternal care for breech presentation, fetus 2 */
"O321XX3" = '1' /*Maternal care for breech presentation, fetus 3 */
"O321XX4" = '1' /*Maternal care for breech presentation, fetus 4 */
"O321XX5" = '1' /*Maternal care for breech presentation, fetus 5 */
"O321XX9" = '1' /*Maternal care for breech presentation, other fetus */
"O322XX0" = '1' /*Maternal care for transverse and oblique lie, notapplicable or unspecified */
"O322XX1" = '1' /*Maternal care for transverse and oblique lie, fetus 1 */
"O322XX2" = '1' /*Maternal care for transverse and oblique lie, fetus 2 */
"O322XX3" = '1' /*Maternal care for transverse and oblique lie, fetus 3 */
"O322XX4" = '1' /*Maternal care for transverse and oblique lie, fetus 4 */
"O322XX5" = '1' /*Maternal care for transverse and oblique lie, fetus 5 */
"O322XX9" = '1' /*Maternal care for transverse and oblique lie, other fetus */
"O323XX0" = '1' /*Maternal care for face, brow and chin presentation, notapplicable or unspecified */
"O323XX1" = '1' /*Maternal care for face, brow and chin presentation,fetus 1 */
"O323XX2" = '1' /*Maternal care for face, brow and chin presentation,fetus 2 */
"O323XX3" = '1' /*Maternal care for face, brow and chin presentation,fetus 3 */
"O323XX4" = '1' /*Maternal care for face, brow and chin presentation,fetus 4 */
"O323XX5" = '1' /*Maternal care for face, brow and chin presentation,fetus 5 */
"O323XX9" = '1' /*Maternal care for face, brow and chin presentation,other fetus */
"O329XX0" = '1' /*Maternal care for malpresentation of fetus, unspecified,not applicable or unspecified */
"O329XX1" = '1' /*Maternal care for malpresentation of fetus, unspecified,fetus 1 */
"O329XX2" = '1' /*Maternal care for malpresentation of fetus, unspecified,fetus 2 */
"O329XX3" = '1' /*Maternal care for malpresentation of fetus, unspecified,fetus 3 */
"O329XX4" = '1' /*Maternal care for malpresentation of fetus, unspecified,fetus 4 */
"O329XX5" = '1' /*Maternal care for malpresentation of fetus, unspecified,fetus 5 */
"O329XX9" = '1' /*Maternal care for malpresentation of fetus, unspecified,other fetus */
"O364XX0" = '1' /*Maternal care for intrauterine death, not applicable orunspecified */
"O364XX1" = '1' /*Maternal care for intrauterine death, fetus 1 */
"O364XX2" = '1' /*Maternal care for intrauterine death, fetus 2 */
"O364XX3" = '1' /*Maternal care for intrauterine death, fetus 3 */
"O364XX4" = '1' /*Maternal care for intrauterine death, fetus 4 */
"O364XX5" = '1' /*Maternal care for intrauterine death, fetus 5 */
"O364XX9" = '1' /*Maternal care for intrauterine death, other fetus */
"O6010X0" = '1' /*Preterm labor with preterm delivery, unspecifiedtrimester, not applicable or unspecified */
"O6010X1" = '1' /*Preterm labor with preterm delivery, unspecifiedtrimester, fetus 1 */
"O6010X2" = '1' /*Preterm labor with preterm delivery, unspecifiedtrimester, fetus 2 */
"O6010X3" = '1' /*Preterm labor with preterm delivery, unspecifiedtrimester, fetus 3 */
"O6010X4" = '1' /*Preterm labor with preterm delivery, unspecifiedtrimester, fetus 4 */
"O6010X5" = '1' /*Preterm labor with preterm delivery, unspecifiedtrimester, fetus 5 */
"O6010X9" = '1' /*Preterm labor with preterm delivery, unspecifiedtrimester, other fetus */
"O6012X0" = '1' /*Preterm labor second trimester with preterm deliverysecond trimester, not applicable or unspecified */
"O6012X1" = '1' /*Preterm labor second trimester with preterm deliverysecond trimester, fetus 1 */
"O6012X2" = '1' /*Preterm labor second trimester with preterm deliverysecond trimester, fetus 2 */
"O6012X3" = '1' /*Preterm labor second trimester with preterm deliverysecond trimester, fetus 3 */
"O6012X4" = '1' /*Preterm labor second trimester with preterm deliverysecond trimester, fetus 4 */
"O6012X5" = '1' /*Preterm labor second trimester with preterm deliverysecond trimester, fetus 5 */
"O6012X9" = '1' /*Preterm labor second trimester with preterm deliverysecond trimester, other fetus */
"O6013X0" = '1' /*Preterm labor second trimester with preterm deliverythird trimester, not applicable or unspecified */
"O6013X1" = '1' /*Preterm labor second trimester with preterm deliverythird trimester, fetus 1 */
"O6013X2" = '1' /*Preterm labor second trimester with preterm deliverythird trimester, fetus 2 */
"O6013X3" = '1' /*Preterm labor second trimester with preterm deliverythird trimester, fetus 3 */
"O6013X4" = '1' /*Preterm labor second trimester with preterm deliverythird trimester, fetus 4 */
"O6013X5" = '1' /*Preterm labor second trimester with preterm deliverythird trimester, fetus 5 */
"O6013X9" = '1' /*Preterm labor second trimester with preterm deliverythird trimester, other fetus */
"O6014X0" = '1' /*Preterm labor third trimester with preterm delivery thirdtrimester, not applicable or unspecified */
"O6014X1" = '1' /*Preterm labor third trimester with preterm delivery thirdtrimester, fetus 1 */
"O6014X2" = '1' /*Preterm labor third trimester with preterm delivery thirdtrimester, fetus 2 */
"O6014X3" = '1' /*Preterm labor third trimester with preterm delivery thirdtrimester, fetus 3 */
"O6014X4" = '1' /*Preterm labor third trimester with preterm delivery thirdtrimester, fetus 4 */
"O6014X5" = '1' /*Preterm labor third trimester with preterm delivery thirdtrimester, fetus 5 */
"O6014X9" = '1' /*Preterm labor third trimester with preterm delivery thirdtrimester, other fetus */
"O632" = '1' /*Delayed delivery of second twin, triplet, etc. */
"O641XX0" = '1' /*Obstructed labor due to breech presentation, notapplicable or unspecified */
"O641XX1" = '1' /*Obstructed labor due to breech presentation, fetus 1 */
"O641XX2" = '1' /*Obstructed labor due to breech presentation, fetus 2 */
"O641XX3" = '1' /*Obstructed labor due to breech presentation, fetus 3 */
"O641XX4" = '1' /*Obstructed labor due to breech presentation, fetus 4 */
"O641XX5" = '1' /*Obstructed labor due to breech presentation, fetus 5 */
"O641XX9" = '1' /*Obstructed labor due to breech presentation, otherfetus */
"O642XX0" = '1' /*Obstructed labor due to face presentation, notapplicable or unspecified */
"O642XX1" = '1' /*Obstructed labor due to face presentation, fetus 1 */
"O642XX2" = '1' /*Obstructed labor due to face presentation, fetus 2 */
"O642XX3" = '1' /*Obstructed labor due to face presentation, fetus 3 */
"O642XX4" = '1' /*Obstructed labor due to face presentation, fetus 4 */
"O642XX5" = '1' /*Obstructed labor due to face presentation, fetus 5 */
"O642XX9" = '1' /*Obstructed labor due to face presentation, other fetus */
"O643XX0" = '1' /*Obstructed labor due to brow presentation, notapplicable or unspecified */
"O643XX1" = '1' /*Obstructed labor due to brow presentation, fetus 1 */
"O643XX2" = '1' /*Obstructed labor due to brow presentation, fetus 2 */
"O643XX3" = '1' /*Obstructed labor due to brow presentation, fetus 3 */
"O643XX4" = '1' /*Obstructed labor due to brow presentation, fetus 4 */
"O643XX5" = '1' /*Obstructed labor due to brow presentation, fetus 5 */
"O643XX9" = '1' /*Obstructed labor due to brow presentation, other fetus */
"O661" = '1' /*Obstructed labor due to locked twins */
"O666" = '1' /*Obstructed labor due to other multiple fetuses */
"Z371" = '1' /*Single stillbirth */
"Z372" = '1' /*Twins, both liveborn */
"Z373" = '1' /*Twins, one liveborn and one stillborn */
"Z374" = '1' /*Twins, both stillborn */
"Z3750" = '1' /*Multiple births, unspecified, all liveborn */
"Z3751" = '1' /*Triplets, all liveborn */
"Z3752" = '1' /*Quadruplets, all liveborn */
"Z3753" = '1' /*Quintuplets, all liveborn */
"Z3754" = '1' /*Sextuplets, all liveborn */
"Z3759" = '1' /*Other multiple births, all liveborn */
"Z3760" = '1' /*Multiple births, unspecified, some liveborn */
"Z3761" = '1' /*Triplets, some liveborn */
"Z3762" = '1' /*Quadruplets, some liveborn */
"Z3763" = '1' /*Quintuplets, some liveborn */
"Z3764" = '1' /*Sextuplets, some liveborn */
"Z3769" = '1' /*Other multiple births, some liveborn */
"Z377" = '1' /*Other multiple births, all stillborn */
OTHER = '0'
;

/* FORMAT FOR Cesarean delivery procedure codes */
Value $PRCSECP
"10D00Z0" = '1' /*Extraction of Products of Conception, Classical, Open Approach */
"10D00Z1" = '1' /*Extraction of Products of Conception, Low Cervical, OpenApproach */
"10D00Z2" = '1' /*Extraction of Products of Conception, Extraperitoneal, OpenApproach */
OTHER = '0'
;

/* FORMAT FOR Gastrointestinal-related cancer diagnosis codes */
Value $PRESO2D
"C160" = '1' /*Malignant neoplasm of cardia */
"C49A1" = '1' /*Gastrointestinal stromal tumor of esophagus */
"C7880" = '1' /*Secondary malignant neoplasm of unspecified digestive organ */
"C7889" = '1' /*Secondary malignant neoplasm of other digestive organs */
"D001" = '1' /*Carcinoma in situ of esophagus */
"D378" = '1' /*Neoplasm of uncertain behavior of other specified digestive organs */
"D379" = '1' /*Neoplasm of uncertain behavior of digestive organ, unspecified */
OTHER = '0'
;

/* FORMAT FOR Total gastrectomy procedure codes */
Value $PRESO2P
"0DT60ZZ" = '1' /*Resection of Stomach, Open Approach */
"0DT64ZZ" = '1' /*Resection of Stomach, Percutaneous Endoscopic Approach */
"0DT67ZZ" = '1' /*Resection of Stomach, Via Natural or Artificial Opening */
"0DT68ZZ" = '1' /*Resection of Stomach, Via Natural or Artificial Opening Endoscopic */
OTHER = '0'
;

/* FORMAT FOR Esophageal cancer diagnosis codes */
Value $PRESOPD
"C153" = '1' /*Malignant neoplasm of upper third of esophagus */
"C154" = '1' /*Malignant neoplasm of middle third of esophagus */
"C155" = '1' /*Malignant neoplasm of lower third of esophagus */
"C158" = '1' /*Malignant neoplasm of overlapping sites of esophagus */
"C159" = '1' /*Malignant neoplasm of esophagus, unspecified */
OTHER = '0'
;

/* FORMAT FOR Esophageal resection procedure codes */
Value $PRESOPP
"0D11074" = '1' /*Bypass Upper Esophagus to Cutaneous withAutologous Tissue Substitute, Open Approach */
"0D11076" = '1' /*Bypass Upper Esophagus to Stomach with AutologousTissue Substitute, Open Approach */
"0D11079" = '1' /*Bypass Upper Esophagus to Duodenum withAutologous Tissue Substitute, Open Approach */
"0D1107A" = '1' /*Bypass Upper Esophagus to Jejunum with AutologousTissue Substitute, Open Approach */
"0D1107B" = '1' /*Bypass Upper Esophagus to Ileum with AutologousTissue Substitute, Open Approach */
"0D110J4" = '1' /*Bypass Upper Esophagus to Cutaneous with SyntheticSubstitute, Open Approach */
"0D110J6" = '1' /*Bypass Upper Esophagus to Stomach with SyntheticSubstitute, Open Approach */
"0D110J9" = '1' /*Bypass Upper Esophagus to Duodenum with SyntheticSubstitute, Open Approach */
"0D110JA" = '1' /*Bypass Upper Esophagus to Jejunum with SyntheticSubstitute, Open Approach */
"0D110JB" = '1' /*Bypass Upper Esophagus to Ileum with SyntheticSubstitute, Open Approach */
"0D110K4" = '1' /*Bypass Upper Esophagus to Cutaneous withNonautologous Tissue Substitute, Open Approach */
"0D110K6" = '1' /*Bypass Upper Esophagus to Stomach withNonautologous Tissue Substitute, Open Approach */
"0D110K9" = '1' /*Bypass Upper Esophagus to Duodenum withNonautologous Tissue Substitute, Open Approach */
"0D110KA" = '1' /*Bypass Upper Esophagus to Jejunum withNonautologous Tissue Substitute, Open Approach */
"0D110KB" = '1' /*Bypass Upper Esophagus to Ileum with NonautologousTissue Substitute, Open Approach */
"0D110Z4" = '1' /*Bypass Upper Esophagus to Cutaneous, OpenApproach */
"0D110Z6" = '1' /*Bypass Upper Esophagus to Stomach, Open Approach */
"0D110Z9" = '1' /*Bypass Upper Esophagus to Duodenum, OpenApproach */
"0D110ZA" = '1' /*Bypass Upper Esophagus to Jejunum, Open Approach */
"0D110ZB" = '1' /*Bypass Upper Esophagus to Ileum, Open Approach */
"0D113J4" = '1' /*Bypass Upper Esophagus to Cutaneous with SyntheticSubstitute, Percutaneous Approach */
"0D11474" = '1' /*Bypass Upper Esophagus to Cutaneous withAutologous Tissue Substitute, PercutaneousEndoscopic Approach */
"0D11476" = '1' /*Bypass Upper Esophagus to Stomach with AutologousTissue Substitute, Percutaneous Endoscopic Approach */
"0D11479" = '1' /*Bypass Upper Esophagus to Duodenum withAutologous Tissue Substitute, PercutaneousEndoscopic Approach */
"0D1147A" = '1' /*Bypass Upper Esophagus to Jejunum with AutologousTissue Substitute, Percutaneous Endoscopic Approach */
"0D1147B" = '1' /*Bypass Upper Esophagus to Ileum with AutologousTissue Substitute, Percutaneous Endoscopic Approach */
"0D114J4" = '1' /*Bypass Upper Esophagus to Cutaneous with SyntheticSubstitute, Percutaneous Endoscopic Approach */
"0D114J6" = '1' /*Bypass Upper Esophagus to Stomach with SyntheticSubstitute, Percutaneous Endoscopic Approach */
"0D114J9" = '1' /*Bypass Upper Esophagus to Duodenum with SyntheticSubstitute, Percutaneous Endoscopic Approach */
"0D114JA" = '1' /*Bypass Upper Esophagus to Jejunum with SyntheticSubstitute, Percutaneous Endoscopic Approach */
"0D114JB" = '1' /*Bypass Upper Esophagus to Ileum with SyntheticSubstitute, Percutaneous Endoscopic Approach */
"0D114K4" = '1' /*Bypass Upper Esophagus to Cutaneous withNonautologous Tissue Substitute, PercutaneousEndoscopic Approach */
"0D114K6" = '1' /*Bypass Upper Esophagus to Stomach withNonautologous Tissue Substitute, PercutaneousEndoscopic Approach */
"0D114K9" = '1' /*Bypass Upper Esophagus to Duodenum withNonautologous Tissue Substitute, PercutaneousEndoscopic Approach */
"0D114KA" = '1' /*Bypass Upper Esophagus to Jejunum withNonautologous Tissue Substitute, PercutaneousEndoscopic Approach */
"0D114KB" = '1' /*Bypass Upper Esophagus to Ileum with NonautologousTissue Substitute, Percutaneous Endoscopic Approach */
"0D114Z4" = '1' /*Bypass Upper Esophagus to Cutaneous, PercutaneousEndoscopic Approach */
"0D114Z6" = '1' /*Bypass Upper Esophagus to Stomach, PercutaneousEndoscopic Approach */
"0D114Z9" = '1' /*Bypass Upper Esophagus to Duodenum, PercutaneousEndoscopic Approach */
"0D114ZA" = '1' /*Bypass Upper Esophagus to Jejunum, PercutaneousEndoscopic Approach */
"0D114ZB" = '1' /*Bypass Upper Esophagus to Ileum, PercutaneousEndoscopic Approach */
"0D11874" = '1' /*Bypass Upper Esophagus to Cutaneous withAutologous Tissue Substitute, Via Natural or ArtificialOpening Endoscopic */
"0D11876" = '1' /*Bypass Upper Esophagus to Stomach with AutologousTissue Substitute, Via Natural or Artificial OpeningEndoscopic */
"0D11879" = '1' /*Bypass Upper Esophagus to Duodenum withAutologous Tissue Substitute, Via Natural or ArtificialOpening Endoscopic */
"0D1187A" = '1' /*Bypass Upper Esophagus to Jejunum with AutologousTissue Substitute, Via Natural or Artificial OpeningEndoscopic */
"0D1187B" = '1' /*Bypass Upper Esophagus to Ileum with AutologousTissue Substitute, Via Natural or Artificial OpeningEndoscopic */
"0D118J4" = '1' /*Bypass Upper Esophagus to Cutaneous with SyntheticSubstitute, Via Natural or Artificial Opening Endoscopic */
"0D118J6" = '1' /*Bypass Upper Esophagus to Stomach with SyntheticSubstitute, Via Natural or Artificial Opening Endoscopic */
"0D118J9" = '1' /*Bypass Upper Esophagus to Duodenum with SyntheticSubstitute, Via Natural or Artificial Opening Endoscopic */
"0D118JA" = '1' /*Bypass Upper Esophagus to Jejunum with SyntheticSubstitute, Via Natural or Artificial Opening Endoscopic */
"0D118JB" = '1' /*Bypass Upper Esophagus to Ileum with SyntheticSubstitute, Via Natural or Artificial Opening Endoscopic */
"0D118K4" = '1' /*Bypass Upper Esophagus to Cutaneous withNonautologous Tissue Substitute, Via Natural orArtificial Opening Endoscopic */
"0D118K6" = '1' /*Bypass Upper Esophagus to Stomach withNonautologous Tissue Substitute, Via Natural orArtificial Opening Endoscopic */
"0D118K9" = '1' /*Bypass Upper Esophagus to Duodenum withNonautologous Tissue Substitute, Via Natural orArtificial Opening Endoscopic */
"0D118KA" = '1' /*Bypass Upper Esophagus to Jejunum withNonautologous Tissue Substitute, Via Natural orArtificial Opening Endoscopic */
"0D118KB" = '1' /*Bypass Upper Esophagus to Ileum with NonautologousTissue Substitute, Via Natural or Artificial OpeningEndoscopic */
"0D118Z4" = '1' /*Bypass Upper Esophagus to Cutaneous, Via Natural orArtificial Opening Endoscopic */
"0D118Z6" = '1' /*Bypass Upper Esophagus to Stomach, Via Natural orArtificial Opening Endoscopic */
"0D118Z9" = '1' /*Bypass Upper Esophagus to Duodenum, Via Natural orArtificial Opening Endoscopic */
"0D118ZA" = '1' /*Bypass Upper Esophagus to Jejunum, Via Natural orArtificial Opening Endoscopic */
"0D118ZB" = '1' /*Bypass Upper Esophagus to Ileum, Via Natural orArtificial Opening Endoscopic */
"0D12074" = '1' /*Bypass Middle Esophagus to Cutaneous withAutologous Tissue Substitute, Open Approach */
"0D12076" = '1' /*Bypass Middle Esophagus to Stomach with AutologousTissue Substitute, Open Approach */
"0D12079" = '1' /*Bypass Middle Esophagus to Duodenum withAutologous Tissue Substitute, Open Approach */
"0D1207A" = '1' /*Bypass Middle Esophagus to Jejunum with AutologousTissue Substitute, Open Approach */
"0D1207B" = '1' /*Bypass Middle Esophagus to Ileum with AutologousTissue Substitute, Open Approach */
"0D120J4" = '1' /*Bypass Middle Esophagus to Cutaneous with SyntheticSubstitute, Open Approach */
"0D120J6" = '1' /*Bypass Middle Esophagus to Stomach with SyntheticSubstitute, Open Approach */
"0D120J9" = '1' /*Bypass Middle Esophagus to Duodenum with SyntheticSubstitute, Open Approach */
"0D120JA" = '1' /*Bypass Middle Esophagus to Jejunum with SyntheticSubstitute, Open Approach */
"0D120JB" = '1' /*Bypass Middle Esophagus to Ileum with SyntheticSubstitute, Open Approach */
"0D120K4" = '1' /*Bypass Middle Esophagus to Cutaneous withNonautologous Tissue Substitute, Open Approach */
"0D120K6" = '1' /*Bypass Middle Esophagus to Stomach withNonautologous Tissue Substitute, Open Approach */
"0D120K9" = '1' /*Bypass Middle Esophagus to Duodenum withNonautologous Tissue Substitute, Open Approach */
"0D120KA" = '1' /*Bypass Middle Esophagus to Jejunum withNonautologous Tissue Substitute, Open Approach */
"0D120KB" = '1' /*Bypass Middle Esophagus to Ileum withNonautologous Tissue Substitute, Open Approach */
"0D120Z4" = '1' /*Bypass Middle Esophagus to Cutaneous, OpenApproach */
"0D120Z6" = '1' /*Bypass Middle Esophagus to Stomach, OpenApproach */
"0D120Z9" = '1' /*Bypass Middle Esophagus to Duodenum, OpenApproach */
"0D120ZA" = '1' /*Bypass Middle Esophagus to Jejunum, Open Approach */
"0D120ZB" = '1' /*Bypass Middle Esophagus to Ileum, Open Approach */
"0D123J4" = '1' /*Bypass Middle Esophagus to Cutaneous with SyntheticSubstitute, Percutaneous Approach */
"0D12474" = '1' /*Bypass Middle Esophagus to Cutaneous withAutologous Tissue Substitute, PercutaneousEndoscopic Approach */
"0D12476" = '1' /*Bypass Middle Esophagus to Stomach with AutologousTissue Substitute, Percutaneous Endoscopic Approach */
"0D12479" = '1' /*Bypass Middle Esophagus to Duodenum withAutologous Tissue Substitute, PercutaneousEndoscopic Approach */
"0D1247A" = '1' /*Bypass Middle Esophagus to Jejunum with AutologousTissue Substitute, Percutaneous Endoscopic Approach */
"0D1247B" = '1' /*Bypass Middle Esophagus to Ileum with AutologousTissue Substitute, Percutaneous Endoscopic Approach */
"0D124J4" = '1' /*Bypass Middle Esophagus to Cutaneous with SyntheticSubstitute, Percutaneous Endoscopic Approach */
"0D124J6" = '1' /*Bypass Middle Esophagus to Stomach with SyntheticSubstitute, Percutaneous Endoscopic Approach */
"0D124J9" = '1' /*Bypass Middle Esophagus to Duodenum with SyntheticSubstitute, Percutaneous Endoscopic Approach */
"0D124JA" = '1' /*Bypass Middle Esophagus to Jejunum with SyntheticSubstitute, Percutaneous Endoscopic Approach */
"0D124JB" = '1' /*Bypass Middle Esophagus to Ileum with SyntheticSubstitute, Percutaneous Endoscopic Approach */
"0D124K4" = '1' /*Bypass Middle Esophagus to Cutaneous withNonautologous Tissue Substitute, PercutaneousEndoscopic Approach */
"0D124K6" = '1' /*Bypass Middle Esophagus to Stomach withNonautologous Tissue Substitute, PercutaneousEndoscopic Approach */
"0D124K9" = '1' /*Bypass Middle Esophagus to Duodenum withNonautologous Tissue Substitute, PercutaneousEndoscopic Approach */
"0D124KA" = '1' /*Bypass Middle Esophagus to Jejunum withNonautologous Tissue Substitute, PercutaneousEndoscopic Approach */
"0D124KB" = '1' /*Bypass Middle Esophagus to Ileum withNonautologous Tissue Substitute, PercutaneousEndoscopic Approach */
"0D124Z4" = '1' /*Bypass Middle Esophagus to Cutaneous,Percutaneous Endoscopic Approach */
"0D124Z6" = '1' /*Bypass Middle Esophagus to Stomach, PercutaneousEndoscopic Approach */
"0D124Z9" = '1' /*Bypass Middle Esophagus to Duodenum,Percutaneous Endoscopic Approach */
"0D124ZA" = '1' /*Bypass Middle Esophagus to Jejunum, PercutaneousEndoscopic Approach */
"0D124ZB" = '1' /*Bypass Middle Esophagus to Ileum, PercutaneousEndoscopic Approach */
"0D12874" = '1' /*Bypass Middle Esophagus to Cutaneous withAutologous Tissue Substitute, Via Natural or ArtificialOpening Endoscopic */
"0D12876" = '1' /*Bypass Middle Esophagus to Stomach with AutologousTissue Substitute, Via Natural or Artificial OpeningEndoscopic */
"0D12879" = '1' /*Bypass Middle Esophagus to Duodenum withAutologous Tissue Substitute, Via Natural or ArtificialOpening Endoscopic */
"0D1287A" = '1' /*Bypass Middle Esophagus to Jejunum with AutologousTissue Substitute, Via Natural or Artificial OpeningEndoscopic */
"0D1287B" = '1' /*Bypass Middle Esophagus to Ileum with AutologousTissue Substitute, Via Natural or Artificial OpeningEndoscopic */
"0D128J4" = '1' /*Bypass Middle Esophagus to Cutaneous with SyntheticSubstitute, Via Natural or Artificial Opening Endoscopic */
"0D128J6" = '1' /*Bypass Middle Esophagus to Stomach with SyntheticSubstitute, Via Natural or Artificial Opening Endoscopic */
"0D128J9" = '1' /*Bypass Middle Esophagus to Duodenum with SyntheticSubstitute, Via Natural or Artificial Opening Endoscopic */
"0D128JA" = '1' /*Bypass Middle Esophagus to Jejunum with SyntheticSubstitute, Via Natural or Artificial Opening Endoscopic */
"0D128JB" = '1' /*Bypass Middle Esophagus to Ileum with SyntheticSubstitute, Via Natural or Artificial Opening Endoscopic */
"0D128K4" = '1' /*Bypass Middle Esophagus to Cutaneous withNonautologous Tissue Substitute, Via Natural orArtificial Opening Endoscopic */
"0D128K6" = '1' /*Bypass Middle Esophagus to Stomach withNonautologous Tissue Substitute, Via Natural orArtificial Opening Endoscopic */
"0D128K9" = '1' /*Bypass Middle Esophagus to Duodenum withNonautologous Tissue Substitute, Via Natural orArtificial Opening Endoscopic */
"0D128KA" = '1' /*Bypass Middle Esophagus to Jejunum withNonautologous Tissue Substitute, Via Natural orArtificial Opening Endoscopic */
"0D128KB" = '1' /*Bypass Middle Esophagus to Ileum withNonautologous Tissue Substitute, Via Natural orArtificial Opening Endoscopic */
"0D128Z4" = '1' /*Bypass Middle Esophagus to Cutaneous, Via Naturalor Artificial Opening Endoscopic */
"0D128Z6" = '1' /*Bypass Middle Esophagus to Stomach, Via Natural orArtificial Opening Endoscopic */
"0D128Z9" = '1' /*Bypass Middle Esophagus to Duodenum, Via Naturalor Artificial Opening Endoscopic */
"0D128ZA" = '1' /*Bypass Middle Esophagus to Jejunum, Via Natural orArtificial Opening Endoscopic */
"0D128ZB" = '1' /*Bypass Middle Esophagus to Ileum, Via Natural orArtificial Opening Endoscopic */
"0D13074" = '1' /*Bypass Lower Esophagus to Cutaneous withAutologous Tissue Substitute, Open Approach */
"0D13076" = '1' /*Bypass Lower Esophagus to Stomach with AutologousTissue Substitute, Open Approach */
"0D13079" = '1' /*Bypass Lower Esophagus to Duodenum withAutologous Tissue Substitute, Open Approach */
"0D1307A" = '1' /*Bypass Lower Esophagus to Jejunum with AutologousTissue Substitute, Open Approach */
"0D1307B" = '1' /*Bypass Lower Esophagus to Ileum with AutologousTissue Substitute, Open Approach */
"0D130J4" = '1' /*Bypass Lower Esophagus to Cutaneous with SyntheticSubstitute, Open Approach */
"0D130J6" = '1' /*Bypass Lower Esophagus to Stomach with SyntheticSubstitute, Open Approach */
"0D130J9" = '1' /*Bypass Lower Esophagus to Duodenum with SyntheticSubstitute, Open Approach */
"0D130JA" = '1' /*Bypass Lower Esophagus to Jejunum with SyntheticSubstitute, Open Approach */
"0D130JB" = '1' /*Bypass Lower Esophagus to Ileum with SyntheticSubstitute, Open Approach */
"0D130K4" = '1' /*Bypass Lower Esophagus to Cutaneous withNonautologous Tissue Substitute, Open Approach */
"0D130K6" = '1' /*Bypass Lower Esophagus to Stomach withNonautologous Tissue Substitute, Open Approach */
"0D130K9" = '1' /*Bypass Lower Esophagus to Duodenum withNonautologous Tissue Substitute, Open Approach */
"0D130KA" = '1' /*Bypass Lower Esophagus to Jejunum withNonautologous Tissue Substitute, Open Approach */
"0D130KB" = '1' /*Bypass Lower Esophagus to Ileum with NonautologousTissue Substitute, Open Approach */
"0D130Z4" = '1' /*Bypass Lower Esophagus to Cutaneous, OpenApproach */
"0D130Z6" = '1' /*Bypass Lower Esophagus to Stomach, Open Approach */
"0D130Z9" = '1' /*Bypass Lower Esophagus to Duodenum, OpenApproach */
"0D130ZA" = '1' /*Bypass Lower Esophagus to Jejunum, Open Approach */
"0D130ZB" = '1' /*Bypass Lower Esophagus to Ileum, Open Approach */
"0D133J4" = '1' /*Bypass Lower Esophagus to Cutaneous with SyntheticSubstitute, Percutaneous Approach */
"0D13474" = '1' /*Bypass Lower Esophagus to Cutaneous withAutologous Tissue Substitute, PercutaneousEndoscopic Approach */
"0D13476" = '1' /*Bypass Lower Esophagus to Stomach with AutologousTissue Substitute, Percutaneous Endoscopic Approach */
"0D13479" = '1' /*Bypass Lower Esophagus to Duodenum withAutologous Tissue Substitute, PercutaneousEndoscopic Approach */
"0D1347A" = '1' /*Bypass Lower Esophagus to Jejunum with AutologousTissue Substitute, Percutaneous Endoscopic Approach */
"0D1347B" = '1' /*Bypass Lower Esophagus to Ileum with AutologousTissue Substitute, Percutaneous Endoscopic Approach */
"0D134J4" = '1' /*Bypass Lower Esophagus to Cutaneous with SyntheticSubstitute, Percutaneous Endoscopic Approach */
"0D134J6" = '1' /*Bypass Lower Esophagus to Stomach with SyntheticSubstitute, Percutaneous Endoscopic Approach */
"0D134J9" = '1' /*Bypass Lower Esophagus to Duodenum with SyntheticSubstitute, Percutaneous Endoscopic Approach */
"0D134JA" = '1' /*Bypass Lower Esophagus to Jejunum with SyntheticSubstitute, Percutaneous Endoscopic Approach */
"0D134JB" = '1' /*Bypass Lower Esophagus to Ileum with SyntheticSubstitute, Percutaneous Endoscopic Approach */
"0D134K4" = '1' /*Bypass Lower Esophagus to Cutaneous withNonautologous Tissue Substitute, PercutaneousEndoscopic Approach */
"0D134K6" = '1' /*Bypass Lower Esophagus to Stomach withNonautologous Tissue Substitute, PercutaneousEndoscopic Approach */
"0D134K9" = '1' /*Bypass Lower Esophagus to Duodenum withNonautologous Tissue Substitute, PercutaneousEndoscopic Approach */
"0D134KA" = '1' /*Bypass Lower Esophagus to Jejunum withNonautologous Tissue Substitute, PercutaneousEndoscopic Approach */
"0D134KB" = '1' /*Bypass Lower Esophagus to Ileum with NonautologousTissue Substitute, Percutaneous Endoscopic Approach */
"0D134Z4" = '1' /*Bypass Lower Esophagus to Cutaneous, PercutaneousEndoscopic Approach */
"0D134Z6" = '1' /*Bypass Lower Esophagus to Stomach, PercutaneousEndoscopic Approach */
"0D134Z9" = '1' /*Bypass Lower Esophagus to Duodenum, PercutaneousEndoscopic Approach */
"0D134ZA" = '1' /*Bypass Lower Esophagus to Jejunum, PercutaneousEndoscopic Approach */
"0D134ZB" = '1' /*Bypass Lower Esophagus to Ileum, PercutaneousEndoscopic Approach */
"0D13874" = '1' /*Bypass Lower Esophagus to Cutaneous withAutologous Tissue Substitute, Via Natural or ArtificialOpening Endoscopic */
"0D13876" = '1' /*Bypass Lower Esophagus to Stomach with AutologousTissue Substitute, Via Natural or Artificial OpeningEndoscopic */
"0D13879" = '1' /*Bypass Lower Esophagus to Duodenum withAutologous Tissue Substitute, Via Natural or ArtificialOpening Endoscopic */
"0D1387A" = '1' /*Bypass Lower Esophagus to Jejunum with AutologousTissue Substitute, Via Natural or Artificial OpeningEndoscopic */
"0D1387B" = '1' /*Bypass Lower Esophagus to Ileum with AutologousTissue Substitute, Via Natural or Artificial OpeningEndoscopic */
"0D138J4" = '1' /*Bypass Lower Esophagus to Cutaneous with SyntheticSubstitute, Via Natural or Artificial Opening Endoscopic */
"0D138J6" = '1' /*Bypass Lower Esophagus to Stomach with SyntheticSubstitute, Via Natural or Artificial Opening Endoscopic */
"0D138J9" = '1' /*Bypass Lower Esophagus to Duodenum with SyntheticSubstitute, Via Natural or Artificial Opening Endoscopic */
"0D138JA" = '1' /*Bypass Lower Esophagus to Jejunum with SyntheticSubstitute, Via Natural or Artificial Opening Endoscopic */
"0D138JB" = '1' /*Bypass Lower Esophagus to Ileum with SyntheticSubstitute, Via Natural or Artificial Opening Endoscopic */
"0D138K4" = '1' /*Bypass Lower Esophagus to Cutaneous withNonautologous Tissue Substitute, Via Natural orArtificial Opening Endoscopic */
"0D138K6" = '1' /*Bypass Lower Esophagus to Stomach withNonautologous Tissue Substitute, Via Natural orArtificial Opening Endoscopic */
"0D138K9" = '1' /*Bypass Lower Esophagus to Duodenum withNonautologous Tissue Substitute, Via Natural orArtificial Opening Endoscopic */
"0D138KA" = '1' /*Bypass Lower Esophagus to Jejunum withNonautologous Tissue Substitute, Via Natural orArtificial Opening Endoscopic */
"0D138KB" = '1' /*Bypass Lower Esophagus to Ileum with NonautologousTissue Substitute, Via Natural or Artificial OpeningEndoscopic */
"0D138Z4" = '1' /*Bypass Lower Esophagus to Cutaneous, Via Natural orArtificial Opening Endoscopic */
"0D138Z6" = '1' /*Bypass Lower Esophagus to Stomach, Via Natural orArtificial Opening Endoscopic */
"0D138Z9" = '1' /*Bypass Lower Esophagus to Duodenum, Via Natural orArtificial Opening Endoscopic */
"0D138ZA" = '1' /*Bypass Lower Esophagus to Jejunum, Via Natural orArtificial Opening Endoscopic */
"0D138ZB" = '1' /*Bypass Lower Esophagus to Ileum, Via Natural orArtificial Opening Endoscopic */
"0D15074" = '1' /*Bypass Esophagus to Cutaneous with AutologousTissue Substitute, Open Approach */
"0D15076" = '1' /*Bypass Esophagus to Stomach with Autologous TissueSubstitute, Open Approach */
"0D15079" = '1' /*Bypass Esophagus to Duodenum with AutologousTissue Substitute, Open Approach */
"0D1507A" = '1' /*Bypass Esophagus to Jejunum with Autologous TissueSubstitute, Open Approach */
"0D1507B" = '1' /*Bypass Esophagus to Ileum with Autologous TissueSubstitute, Open Approach */
"0D150J4" = '1' /*Bypass Esophagus to Cutaneous with SyntheticSubstitute, Open Approach */
"0D150J6" = '1' /*Bypass Esophagus to Stomach with SyntheticSubstitute, Open Approach */
"0D150J9" = '1' /*Bypass Esophagus to Duodenum with SyntheticSubstitute, Open Approach */
"0D150JA" = '1' /*Bypass Esophagus to Jejunum with SyntheticSubstitute, Open Approach */
"0D150JB" = '1' /*Bypass Esophagus to Ileum with Synthetic Substitute,Open Approach */
"0D150K4" = '1' /*Bypass Esophagus to Cutaneous with NonautologousTissue Substitute, Open Approach */
"0D150K6" = '1' /*Bypass Esophagus to Stomach with NonautologousTissue Substitute, Open Approach */
"0D150K9" = '1' /*Bypass Esophagus to Duodenum with NonautologousTissue Substitute, Open Approach */
"0D150KA" = '1' /*Bypass Esophagus to Jejunum with NonautologousTissue Substitute, Open Approach */
"0D150KB" = '1' /*Bypass Esophagus to Ileum with NonautologousTissue Substitute, Open Approach */
"0D150Z4" = '1' /*Bypass Esophagus to Cutaneous, Open Approach */
"0D150Z6" = '1' /*Bypass Esophagus to Stomach, Open Approach */
"0D150Z9" = '1' /*Bypass Esophagus to Duodenum, Open Approach */
"0D150ZA" = '1' /*Bypass Esophagus to Jejunum, Open Approach */
"0D150ZB" = '1' /*Bypass Esophagus to Ileum, Open Approach */
"0D153J4" = '1' /*Bypass Esophagus to Cutaneous with SyntheticSubstitute, Percutaneous Approach */
"0D15474" = '1' /*Bypass Esophagus to Cutaneous with AutologousTissue Substitute, Percutaneous Endoscopic Approach */
"0D15476" = '1' /*Bypass Esophagus to Stomach with Autologous TissueSubstitute, Percutaneous Endoscopic Approach */
"0D15479" = '1' /*Bypass Esophagus to Duodenum with AutologousTissue Substitute, Percutaneous Endoscopic Approach */
"0D1547A" = '1' /*Bypass Esophagus to Jejunum with Autologous TissueSubstitute, Percutaneous Endoscopic Approach */
"0D1547B" = '1' /*Bypass Esophagus to Ileum with Autologous TissueSubstitute, Percutaneous Endoscopic Approach */
"0D154J4" = '1' /*Bypass Esophagus to Cutaneous with SyntheticSubstitute, Percutaneous Endoscopic Approach */
"0D154J6" = '1' /*Bypass Esophagus to Stomach with SyntheticSubstitute, Percutaneous Endoscopic Approach */
"0D154J9" = '1' /*Bypass Esophagus to Duodenum with SyntheticSubstitute, Percutaneous Endoscopic Approach */
"0D154JA" = '1' /*Bypass Esophagus to Jejunum with SyntheticSubstitute, Percutaneous Endoscopic Approach */
"0D154JB" = '1' /*Bypass Esophagus to Ileum with Synthetic Substitute,Percutaneous Endoscopic Approach */
"0D154K4" = '1' /*Bypass Esophagus to Cutaneous with NonautologousTissue Substitute, Percutaneous Endoscopic Approach */
"0D154K6" = '1' /*Bypass Esophagus to Stomach with NonautologousTissue Substitute, Percutaneous Endoscopic Approach */
"0D154K9" = '1' /*Bypass Esophagus to Duodenum with NonautologousTissue Substitute, Percutaneous Endoscopic Approach */
"0D154KA" = '1' /*Bypass Esophagus to Jejunum with NonautologousTissue Substitute, Percutaneous Endoscopic Approach */
"0D154KB" = '1' /*Bypass Esophagus to Ileum with NonautologousTissue Substitute, Percutaneous Endoscopic Approach */
"0D154Z4" = '1' /*Bypass Esophagus to Cutaneous, PercutaneousEndoscopic Approach */
"0D154Z6" = '1' /*Bypass Esophagus to Stomach, PercutaneousEndoscopic Approach */
"0D154Z9" = '1' /*Bypass Esophagus to Duodenum, PercutaneousEndoscopic Approach */
"0D154ZA" = '1' /*Bypass Esophagus to Jejunum, PercutaneousEndoscopic Approach */
"0D154ZB" = '1' /*Bypass Esophagus to Ileum, Percutaneous EndoscopicApproach */
"0D15874" = '1' /*Bypass Esophagus to Cutaneous with AutologousTissue Substitute, Via Natural or Artificial OpeningEndoscopic */
"0D15876" = '1' /*Bypass Esophagus to Stomach with Autologous TissueSubstitute, Via Natural or Artificial Opening Endoscopic */
"0D15879" = '1' /*Bypass Esophagus to Duodenum with AutologousTissue Substitute, Via Natural or Artificial OpeningEndoscopic */
"0D1587A" = '1' /*Bypass Esophagus to Jejunum with Autologous TissueSubstitute, Via Natural or Artificial Opening Endoscopic */
"0D1587B" = '1' /*Bypass Esophagus to Ileum with Autologous TissueSubstitute, Via Natural or Artificial Opening Endoscopic */
"0D158J4" = '1' /*Bypass Esophagus to Cutaneous with SyntheticSubstitute, Via Natural or Artificial Opening Endoscopic */
"0D158J6" = '1' /*Bypass Esophagus to Stomach with SyntheticSubstitute, Via Natural or Artificial Opening Endoscopic */
"0D158J9" = '1' /*Bypass Esophagus to Duodenum with SyntheticSubstitute, Via Natural or Artificial Opening Endoscopic */
"0D158JA" = '1' /*Bypass Esophagus to Jejunum with SyntheticSubstitute, Via Natural or Artificial Opening Endoscopic */
"0D158JB" = '1' /*Bypass Esophagus to Ileum with Synthetic Substitute,Via Natural or Artificial Opening Endoscopic */
"0D158K4" = '1' /*Bypass Esophagus to Cutaneous with NonautologousTissue Substitute, Via Natural or Artificial OpeningEndoscopic */
"0D158K6" = '1' /*Bypass Esophagus to Stomach with NonautologousTissue Substitute, Via Natural or Artificial OpeningEndoscopic */
"0D158K9" = '1' /*Bypass Esophagus to Duodenum with NonautologousTissue Substitute, Via Natural or Artificial OpeningEndoscopic */
"0D158KA" = '1' /*Bypass Esophagus to Jejunum with NonautologousTissue Substitute, Via Natural or Artificial OpeningEndoscopic */
"0D158KB" = '1' /*Bypass Esophagus to Ileum with NonautologousTissue Substitute, Via Natural or Artificial OpeningEndoscopic */
"0D158Z4" = '1' /*Bypass Esophagus to Cutaneous, Via Natural orArtificial Opening Endoscopic */
"0D158Z6" = '1' /*Bypass Esophagus to Stomach, Via Natural or ArtificialOpening Endoscopic */
"0D158Z9" = '1' /*Bypass Esophagus to Duodenum, Via Natural orArtificial Opening Endoscopic */
"0D158ZA" = '1' /*Bypass Esophagus to Jejunum, Via Natural or ArtificialOpening Endoscopic */
"0D158ZB" = '1' /*Bypass Esophagus to Ileum, Via Natural or ArtificialOpening Endoscopic */
"0DB10ZZ" = '1' /*Excision of Upper Esophagus, Open Approach */
"0DB13ZZ" = '1' /*Excision of Upper Esophagus, Percutaneous Approach */
"0DB17ZZ" = '1' /*Excision of Upper Esophagus, Via Natural or ArtificialOpening */
"0DB20ZZ" = '1' /*Excision of Middle Esophagus, Open Approach */
"0DB23ZZ" = '1' /*Excision of Middle Esophagus, Percutaneous Approach */
"0DB27ZZ" = '1' /*Excision of Middle Esophagus, Via Natural or ArtificialOpening */
"0DB30ZZ" = '1' /*Excision of Lower Esophagus, Open Approach */
"0DB33ZZ" = '1' /*Excision of Lower Esophagus, Percutaneous Approach */
"0DB37ZZ" = '1' /*Excision of Lower Esophagus, Via Natural or ArtificialOpening */
"0DB50ZZ" = '1' /*Excision of Esophagus, Open Approach */
"0DB53ZZ" = '1' /*Excision of Esophagus, Percutaneous Approach */
"0DB57ZZ" = '1' /*Excision of Esophagus, Via Natural or Artificial Opening */
"0DT10ZZ" = '1' /*Resection of Upper Esophagus, Open Approach */
"0DT14ZZ" = '1' /*Resection of Upper Esophagus, PercutaneousEndoscopic Approach */
"0DT17ZZ" = '1' /*Resection of Upper Esophagus, Via Natural or ArtificialOpening */
"0DT18ZZ" = '1' /*Resection of Upper Esophagus, Via Natural or ArtificialOpening Endoscopic */
"0DT20ZZ" = '1' /*Resection of Middle Esophagus, Open Approach */
"0DT24ZZ" = '1' /*Resection of Middle Esophagus, PercutaneousEndoscopic Approach */
"0DT27ZZ" = '1' /*Resection of Middle Esophagus, Via Natural or ArtificialOpening */
"0DT28ZZ" = '1' /*Resection of Middle Esophagus, Via Natural or ArtificialOpening Endoscopic */
"0DT30ZZ" = '1' /*Resection of Lower Esophagus, Open Approach */
"0DT34ZZ" = '1' /*Resection of Lower Esophagus, PercutaneousEndoscopic Approach */
"0DT37ZZ" = '1' /*Resection of Lower Esophagus, Via Natural or ArtificialOpening */
"0DT38ZZ" = '1' /*Resection of Lower Esophagus, Via Natural or ArtificialOpening Endoscopic */
"0DT50ZZ" = '1' /*Resection of Esophagus, Open Approach */
"0DT54ZZ" = '1' /*Resection of Esophagus, Percutaneous EndoscopicApproach */
"0DT57ZZ" = '1' /*Resection of Esophagus, Via Natural or ArtificialOpening */
"0DT58ZZ" = '1' /*Resection of Esophagus, Via Natural or ArtificialOpening Endoscopic */
"0DX60Z5" = '1' /*Transfer Stomach to Esophagus, Open Approach */
"0DX64Z5" = '1' /*Transfer Stomach to Esophagus, PercutaneousEndoscopic Approach */
"0DX80Z5" = '1' /*Transfer Small Intestine to Esophagus, Open Approach */
"0DX84Z5" = '1' /*Transfer Small Intestine to Esophagus, PercutaneousEndoscopic Approach */
"0DXE0Z5" = '1' /*Transfer Large Intestine to Esophagus, Open Approach */
"0DXE4Z5" = '1' /*Transfer Large Intestine to Esophagus, PercutaneousEndoscopic Approach */
OTHER = '0'
;

/* FORMAT FOR Acute pancreatitis diagnosis codes */
Value $PRPAN2D
"B252" = '1' /*Cytomegaloviral pancreatitis */
"B263" = '1' /*Mumps pancreatitis */
"K850" = '1' /*Idiopathic acute pancreatitis */
"K8501" = '1' /*Idiopathic acute pancreatitis with uninfected necrosis */
"K8502" = '1' /*Idiopathic acute pancreatitis with infected necrosis */
"K851" = '1' /*Biliary acute pancreatitis */
"K8511" = '1' /*Biliary acute pancreatitis with uninfected necrosis */
"K8512" = '1' /*Biliary acute pancreatitis with infected necrosis */
"K852" = '1' /*Alcohol induced acute pancreatitis */
"K8521" = '1' /*Alcohol induced acute pancreatitis with uninfected necrosis */
"K8522" = '1' /*Alcohol induced acute pancreatitis with infected necrosis */
"K853" = '1' /*Drug induced acute pancreatitis */
"K8531" = '1' /*Drug induced acute pancreatitis with uninfected necrosis */
"K8532" = '1' /*Drug induced acute pancreatitis with infected necrosis */
"K858" = '1' /*Other acute pancreatitis */
"K8581" = '1' /*Other acute pancreatitis with uninfected necrosis */
"K8582" = '1' /*Other acute pancreatitis with infected necrosis */
"K859" = '1' /*Acute pancreatitis, unspecified */
"K8591" = '1' /*Acute pancreatitis with uninfected necrosis, unspecified */
"K8592" = '1' /*Acute pancreatitis with infected necrosis, unspecified */
OTHER = '0'
;

/* FORMAT FOR Partial pancreatic resection procedure codes */
Value $PRPAN3P
"0FBG0ZZ" = '1' /*Excision of Pancreas, Open Approach */
"0FBG3ZZ" = '1' /*Excision of Pancreas, Percutaneous Approach */
"0FBG4ZZ" = '1' /*Excision of Pancreas, Percutaneous Endoscopic Approach */
"0FBG8ZZ" = '1' /*Excision of Pancreas, Via Natural or Artificial Opening Endoscopic */
OTHER = '0'
;

/* FORMAT FOR Pancreatic cancer diagnosis codes */
Value $PRPANCD
"C170" = '1' /*Malignant neoplasm of duodenum */
"C240" = '1' /*Malignant neoplasm of extrahepatic bile duct */
"C241" = '1' /*Malignant neoplasm of ampulla of Vater */
"C250" = '1' /*Malignant neoplasm of head of pancreas */
"C251" = '1' /*Malignant neoplasm of body of pancreas */
"C252" = '1' /*Malignant neoplasm of tail of pancreas */
"C253" = '1' /*Malignant neoplasm of pancreatic duct */
"C254" = '1' /*Malignant neoplasm of endocrine pancreas */
"C257" = '1' /*Malignant neoplasm of other parts of pancreas */
"C258" = '1' /*Malignant neoplasm of overlapping sites of pancreas */
"C259" = '1' /*Malignant neoplasm of pancreas, unspecified */
OTHER = '0'
;

/* FORMAT FOR Total pancreatic resection procedure codes */
Value $PRPANCP
"0FTG0ZZ" = '1' /*Resection of Pancreas, Open Approach */
"0FTG4ZZ" = '1' /*Resection of Pancreas, Percutaneous Endoscopic Approach */
OTHER = '0'
;

/* FORMAT FOR Percutaneous coronary intervention (PCI) procedure codes */
Value $PRPTCAP
"0270346" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"027034Z" = '1' /*Dilation of Coronary Artery, One Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"0270356" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"027035Z" = '1' /*Dilation of Coronary Artery, One Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0270366" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"027036Z" = '1' /*Dilation of Coronary Artery, One Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0270376" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"027037Z" = '1' /*Dilation of Coronary Artery, One Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"02703D6" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"02703DZ" = '1' /*Dilation of Coronary Artery, One Artery with Intraluminal Device, Percutaneous Approach */
"02703E6" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"02703EZ" = '1' /*Dilation of Coronary Artery, One Artery with Two Intraluminal Devices, Percutaneous Approach */
"02703F6" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"02703FZ" = '1' /*Dilation of Coronary Artery, One Artery with Three Intraluminal Devices, Percutaneous Approach */
"02703G6" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"02703GZ" = '1' /*Dilation of Coronary Artery, One Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"02703Z6" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, Percutaneous Approach */
"02703ZZ" = '1' /*Dilation of Coronary Artery, One Artery, Percutaneous Approach */
"0270446" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"027044Z" = '1' /*Dilation of Coronary Artery, One Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0270456" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"027045Z" = '1' /*Dilation of Coronary Artery, One Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0270466" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"027046Z" = '1' /*Dilation of Coronary Artery, One Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0270476" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Ap */
"027047Z" = '1' /*Dilation of Coronary Artery, One Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"02704D6" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"02704DZ" = '1' /*Dilation of Coronary Artery, One Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"02704E6" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"02704EZ" = '1' /*Dilation of Coronary Artery, One Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"02704F6" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"02704FZ" = '1' /*Dilation of Coronary Artery, One Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"02704G6" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"02704GZ" = '1' /*Dilation of Coronary Artery, One Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"02704Z6" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, Percutaneous Endoscopic Approach */
"02704ZZ" = '1' /*Dilation of Coronary Artery, One Artery, Percutaneous Endoscopic Approach */
"0271346" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"027134Z" = '1' /*Dilation of Coronary Artery, Two Arteries with Drug-eluting Intraluminal Device, Percutaneous Approach */
"0271356" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"027135Z" = '1' /*Dilation of Coronary Artery, Two Arteries with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0271366" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"027136Z" = '1' /*Dilation of Coronary Artery, Two Arteries with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0271376" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"027137Z" = '1' /*Dilation of Coronary Artery, Two Arteries with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"02713D6" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"02713DZ" = '1' /*Dilation of Coronary Artery, Two Arteries with Intraluminal Device, Percutaneous Approach */
"02713E6" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"02713EZ" = '1' /*Dilation of Coronary Artery, Two Arteries with Two Intraluminal Devices, Percutaneous Approach */
"02713F6" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"02713FZ" = '1' /*Dilation of Coronary Artery, Two Arteries with Three Intraluminal Devices, Percutaneous Approach */
"02713G6" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"02713GZ" = '1' /*Dilation of Coronary Artery, Two Arteries with Four or More Intraluminal Devices, Percutaneous Approach */
"02713Z6" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, Percutaneous Approach */
"02713ZZ" = '1' /*Dilation of Coronary Artery, Two Arteries, Percutaneous Approach */
"0271446" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"027144Z" = '1' /*Dilation of Coronary Artery, Two Arteries with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0271456" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"027145Z" = '1' /*Dilation of Coronary Artery, Two Arteries with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0271466" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approac */
"027146Z" = '1' /*Dilation of Coronary Artery, Two Arteries with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0271476" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic */
"027147Z" = '1' /*Dilation of Coronary Artery, Two Arteries with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"02714D6" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"02714DZ" = '1' /*Dilation of Coronary Artery, Two Arteries with Intraluminal Device, Percutaneous Endoscopic Approach */
"02714E6" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"02714EZ" = '1' /*Dilation of Coronary Artery, Two Arteries with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"02714F6" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"02714FZ" = '1' /*Dilation of Coronary Artery, Two Arteries with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"02714G6" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"02714GZ" = '1' /*Dilation of Coronary Artery, Two Arteries with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"02714Z6" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, Percutaneous Endoscopic Approach */
"02714ZZ" = '1' /*Dilation of Coronary Artery, Two Arteries, Percutaneous Endoscopic Approach */
"0272346" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"027234Z" = '1' /*Dilation of Coronary Artery, Three Arteries with Drug-eluting Intraluminal Device, Percutaneous Approach */
"0272356" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"027235Z" = '1' /*Dilation of Coronary Artery, Three Arteries with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0272366" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"027236Z" = '1' /*Dilation of Coronary Artery, Three Arteries with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0272376" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"027237Z" = '1' /*Dilation of Coronary Artery, Three Arteries with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"02723D6" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"02723DZ" = '1' /*Dilation of Coronary Artery, Three Arteries with Intraluminal Device, Percutaneous Approach */
"02723E6" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"02723EZ" = '1' /*Dilation of Coronary Artery, Three Arteries with Two Intraluminal Devices, Percutaneous Approach */
"02723F6" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"02723FZ" = '1' /*Dilation of Coronary Artery, Three Arteries with Three Intraluminal Devices, Percutaneous Approach */
"02723G6" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"02723GZ" = '1' /*Dilation of Coronary Artery, Three Arteries with Four or More Intraluminal Devices, Percutaneous Approach */
"02723Z6" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, Percutaneous Approach */
"02723ZZ" = '1' /*Dilation of Coronary Artery, Three Arteries, Percutaneous Approach */
"0272446" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"027244Z" = '1' /*Dilation of Coronary Artery, Three Arteries with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0272456" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approac */
"027245Z" = '1' /*Dilation of Coronary Artery, Three Arteries with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0272466" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Appro */
"027246Z" = '1' /*Dilation of Coronary Artery, Three Arteries with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0272476" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopi */
"027247Z" = '1' /*Dilation of Coronary Artery, Three Arteries with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"02724D6" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"02724DZ" = '1' /*Dilation of Coronary Artery, Three Arteries with Intraluminal Device, Percutaneous Endoscopic Approach */
"02724E6" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"02724EZ" = '1' /*Dilation of Coronary Artery, Three Arteries with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"02724F6" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"02724FZ" = '1' /*Dilation of Coronary Artery, Three Arteries with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"02724G6" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"02724GZ" = '1' /*Dilation of Coronary Artery, Three Arteries with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"02724Z6" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, Percutaneous Endoscopic Approach */
"02724ZZ" = '1' /*Dilation of Coronary Artery, Three Arteries, Percutaneous Endoscopic Approach */
"0273346" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"027334Z" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Drug-eluting Intraluminal Device, Percutaneous Approach */
"0273356" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"027335Z" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0273366" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"027336Z" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0273376" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Ap */
"027337Z" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"02733D6" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"02733DZ" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Intraluminal Device, Percutaneous Approach */
"02733E6" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"02733EZ" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Two Intraluminal Devices, Percutaneous Approach */
"02733F6" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"02733FZ" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Three Intraluminal Devices, Percutaneous Approach */
"02733G6" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"02733GZ" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Four or More Intraluminal Devices, Percutaneous Approach */
"02733Z6" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, Percutaneous Approach */
"02733ZZ" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Percutaneous Approach */
"0273446" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"027344Z" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0273456" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic */
"027345Z" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0273466" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopi */
"027346Z" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0273476" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous En */
"027347Z" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Appro */
"02734D6" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"02734DZ" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Intraluminal Device, Percutaneous Endoscopic Approach */
"02734E6" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"02734EZ" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"02734F6" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"02734FZ" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"02734G6" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Appr */
"02734GZ" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"02734Z6" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, Percutaneous Endoscopic Approach */
"02734ZZ" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Percutaneous Endoscopic Approach */
OTHER = '0'
;

/* FORMAT FOR Previous Cesarean delivery diagnosis codes */
Value $PRVBACD
"O3421" = '1' /*Maternal care for scar from previous cesarean delivery */
"O34211" = '1' /*Maternal care for low transverse scar from previous cesarean delivery */
"O34212" = '1' /*Maternal care for vertical scar from previous cesarean delivery */
"O34219" = '1' /*Maternal care for unspecified type scar from previous cesarean delivery */
"O6641" = '1' /*Failed attempted vaginal birth after previous cesarean delivery */
OTHER = '0'
;

/* FORMAT FOR Race/ethnicity categories */
Value RACECAT
1 = 'White' /*White */
2 = 'Black' /*Black */
3 = 'Hispanic' /*Hispanic */
4 = 'Asian and NH/PI' /*Asian and NH/PI */
5 = 'Amer Indian/AN' /*American Indian /AN */
6 = 'Other' /*Other */
;

/* FORMAT FOR Sex categories */
Value SEXCAT
1 = 'Male' /*Male */
2 = 'Female' /*Female */
;

/* FORMAT FOR Vaginal delivery procedure codes */
Value $VAGDELP
"10D07Z3" = '1' /*Extraction of Products of Conception, Low Forceps, Via Natural orArtificial Opening */
"10D07Z4" = '1' /*Extraction of Products of Conception, Mid Forceps, Via Natural orArtificial Opening */
"10D07Z5" = '1' /*Extraction of Products of Conception, High Forceps, Via Natural orArtificial Opening */
"10D07Z6" = '1' /*Extraction of Products of Conception, Vacuum, Via Natural orArtificial Opening */
"10D07Z7" = '1' /*Extraction of Products of Conception, Internal Version, Via Naturalor Artificial Opening */
"10D07Z8" = '1' /*Extraction of Products of Conception, Other, Via Natural or ArtificialOpening */
"10E0XZZ" = '1' /*Delivery of Products of Conception, External Approach */
OTHER = '0'
;

run;

*Restore source option to setting used prior to formats;
option &orgoptionValue;
