*======================PROGRAM: PQI_ALL_FORMATS.SAS =========================;
 *
 * DESCRIPTION: Creates format library for AHRQ Patient Quality Indicators; 
 *  VERSION: SAS QI v2018 (ICD-10 CM/PCS)
 * RELEASE DATE: JUNE 2018
 * 
 *============================================================================;
 *PATHNAME specifies the location of the PQI folder which includes the
     Programs, Macros, and SASdata subfolders; 
 %LET  PATHNAME=C:\PATHNAME\PQI;         *<===USER MUST modify; 

 filename CONTROL "&PATHNAME.\Programs\PQI_ALL_CONTROL.SAS";
 %INCLUDE CONTROL;

 *SAS option to print program text to log disabled to avoid filling log window;
 %let orgoptionValue = %sysfunc(getoption(source));  
 option nosource; 

 proc format LIBRARY=LIBRARY;

/* FORMAT FOR Chronic obstructive pulmonary disorder (excluding acute bronchitis) diagnosis codes */
Value $ACCOPDD
"J410" = '1' /*Simple chronic bronchitis */
"J411" = '1' /*Mucopurulent chronic bronchitis */
"J418" = '1' /*Mixed simple and mucopurulent chronic bronchitis */
"J42" = '1' /*Unspecified chronic bronchitis */
"J430" = '1' /*Unilateral pulmonary emphysema [MacLeod's syndrome] */
"J431" = '1' /*Panlobular emphysema */
"J432" = '1' /*Centrilobular emphysema */
"J438" = '1' /*Other emphysema */
"J439" = '1' /*Emphysema, unspecified */
"J440" = '1' /*Chronic obstructive pulmonary disease with acute lower respiratoryinfection */
"J441" = '1' /*Chronic obstructive pulmonary disease with (acute) exacerbation */
"J449" = '1' /*Chronic obstructive pulmonary disease, unspecified */
"J470" = '1' /*Bronchiectasis with acute lower respiratory infection */
"J471" = '1' /*Bronchiectasis with (acute) exacerbation */
"J479" = '1' /*Bronchiectasis, uncomplicated */
OTHER = '0'
;

/* FORMAT FOR Diabetes with long-term complications diagnosis codes */
Value $ACDIALD
"E1021" = '1' /*Type 1 diabetes mellitus with diabetic nephropathy */
"E1022" = '1' /*Type 1 diabetes mellitus with diabetic chronic kidneydisease */
"E1029" = '1' /*Type 1 diabetes mellitus with other diabetic kidneycomplication */
"E10311" = '1' /*Type 1 diabetes mellitus with unspecified diabeticretinopathy with macular edema */
"E10319" = '1' /*Type 1 diabetes mellitus with unspecified diabeticretinopathy without macular edema */
"E10321" = '1' /*Type 1 diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema */
"E103211" = '1' /*Type 1 diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema, right eye */
"E103212" = '1' /*Type 1 diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema, left eye */
"E103213" = '1' /*Type 1 diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema, bilateral */
"E103219" = '1' /*Type 1 diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema, unspecified eye */
"E10329" = '1' /*Type 1 diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema */
"E103291" = '1' /*Type 1 diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema, right eye */
"E103292" = '1' /*Type 1 diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema, left eye */
"E103293" = '1' /*Type 1 diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema, bilateral */
"E103299" = '1' /*Type 1 diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema, unspecified eye */
"E10331" = '1' /*Type 1 diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema */
"E103311" = '1' /*Type 1 diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema, right eye */
"E103312" = '1' /*Type 1 diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema, left eye */
"E103313" = '1' /*Type 1 diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema, bilateral */
"E103319" = '1' /*Type 1 diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema, unspecified eye */
"E10339" = '1' /*Type 1 diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema */
"E103391" = '1' /*Type 1 diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema, right eye */
"E103392" = '1' /*Type 1 diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema, left eye */
"E103393" = '1' /*Type 1 diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema, bilateral */
"E103399" = '1' /*Type 1 diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema, unspecified eye */
"E10341" = '1' /*Type 1 diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema */
"E103411" = '1' /*Type 1 diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema, right eye */
"E103412" = '1' /*Type 1 diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema, left eye */
"E103413" = '1' /*Type 1 diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema, bilateral */
"E103419" = '1' /*Type 1 diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema, unspecified eye */
"E10349" = '1' /*Type 1 diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema */
"E103491" = '1' /*Type 1 diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema, right eye */
"E103492" = '1' /*Type 1 diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema, left eye */
"E103493" = '1' /*Type 1 diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema, bilateral */
"E103499" = '1' /*Type 1 diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema, unspecified eye */
"E10351" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy with macular edema */
"E103511" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy with macular edema, right eye */
"E103512" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy with macular edema, left eye */
"E103513" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy with macular edema, bilateral */
"E103519" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy with macular edema, unspecified eye */
"E103521" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment involving the macula, right eye */
"E103522" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment involving the macula, left eye */
"E103523" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment involving the macula, bilateral */
"E103529" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment involving the macula, unspecified eye */
"E103531" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, right eye */
"E103532" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, left eye */
"E103533" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, bilateral */
"E103539" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, unspecified eye */
"E103541" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, right eye */
"E103542" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, left eye */
"E103543" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, bilateral */
"E103549" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, unspecified eye */
"E103551" = '1' /*Type 1 diabetes mellitus with stable proliferative diabetic retinopathy, right eye */
"E103552" = '1' /*Type 1 diabetes mellitus with stable proliferative diabetic retinopathy, left eye */
"E103553" = '1' /*Type 1 diabetes mellitus with stable proliferative diabetic retinopathy, bilateral */
"E103559" = '1' /*Type 1 diabetes mellitus with stable proliferative diabetic retinopathy, unspecified eye */
"E10359" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy without macular edema */
"E103591" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy without macular edema, right eye */
"E103592" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy without macular edema, left eye */
"E103593" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy without macular edema, bilateral */
"E103599" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy without macular edema, unspecified eye */
"E1036" = '1' /*Type 1 diabetes mellitus with diabetic cataract */
"E1037X1" = '1' /*Type 1 diabetes mellitus with diabetic macular edema, resolved following treatment, right eye */
"E1037X2" = '1' /*Type 1 diabetes mellitus with diabetic macular edema, resolved following treatment, left eye */
"E1037X3" = '1' /*Type 1 diabetes mellitus with diabetic macular edema, resolved following treatment, bilateral */
"E1037X9" = '1' /*Type 1 diabetes mellitus with diabetic macular edema, resolved following treatment, unspecified eye */
"E1039" = '1' /*Type 1 diabetes mellitus with other diabetic ophthalmiccomplication */
"E1040" = '1' /*Type 1 diabetes mellitus with diabetic neuropathy,unspecified */
"E1041" = '1' /*Type 1 diabetes mellitus with diabetic mononeuropathy */
"E1042" = '1' /*Type 1 diabetes mellitus with diabetic polyneuropathy */
"E1043" = '1' /*Type 1 diabetes mellitus with diabetic autonomic(poly)neuropathy */
"E1044" = '1' /*Type 1 diabetes mellitus with diabetic amyotrophy */
"E1049" = '1' /*Type 1 diabetes mellitus with other diabetic neurologicalcomplication */
"E1051" = '1' /*Type 1 diabetes mellitus with diabetic peripheralangiopathy without gangrene */
"E1052" = '1' /*Type 1 diabetes mellitus with diabetic peripheralangiopathy with gangrene */
"E1059" = '1' /*Type 1 diabetes mellitus with other circulatorycomplications */
"E10610" = '1' /*Type 1 diabetes mellitus with diabetic neuropathicarthropathy */
"E10618" = '1' /*Type 1 diabetes mellitus with other diabetic arthropathy */
"E10620" = '1' /*Type 1 diabetes mellitus with diabetic dermatitis */
"E10621" = '1' /*Type 1 diabetes mellitus with foot ulcer */
"E10622" = '1' /*Type 1 diabetes mellitus with other skin ulcer */
"E10628" = '1' /*Type 1 diabetes mellitus with other skin complications */
"E10630" = '1' /*Type 1 diabetes mellitus with periodontal disease */
"E10638" = '1' /*Type 1 diabetes mellitus with other oral complications */
"E1069" = '1' /*Type 1 diabetes mellitus with other specified complication */
"E108" = '1' /*Type 1 diabetes mellitus with unspecified complications */
"E1121" = '1' /*Type 2 diabetes mellitus with diabetic nephropathy */
"E1122" = '1' /*Type 2 diabetes mellitus with diabetic chronic kidneydisease */
"E1129" = '1' /*Type 2 diabetes mellitus with other diabetic kidneycomplication */
"E11311" = '1' /*Type 2 diabetes mellitus with unspecified diabeticretinopathy with macular edema */
"E11319" = '1' /*Type 2 diabetes mellitus with unspecified diabeticretinopathy without macular edema */
"E11321" = '1' /*Type 2 diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema */
"E113211" = '1' /*Type 2 diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema, right eye */
"E113212" = '1' /*Type 2 diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema, left eye */
"E113213" = '1' /*Type 2 diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema, bilateral */
"E113219" = '1' /*Type 2 diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema, unspecified eye */
"E11329" = '1' /*Type 2 diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema */
"E113291" = '1' /*Type 2 diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema, right eye */
"E113292" = '1' /*Type 2 diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema, left eye */
"E113293" = '1' /*Type 2 diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema, bilateral */
"E113299" = '1' /*Type 2 diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema, unspecified eye */
"E11331" = '1' /*Type 2 diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema */
"E113311" = '1' /*Type 2 diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema, right eye */
"E113312" = '1' /*Type 2 diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema, left eye */
"E113313" = '1' /*Type 2 diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema, bilateral */
"E113319" = '1' /*Type 2 diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema, unspecified eye */
"E11339" = '1' /*Type 2 diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema */
"E113391" = '1' /*Type 2 diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema, right eye */
"E113392" = '1' /*Type 2 diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema, left eye */
"E113393" = '1' /*Type 2 diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema, bilateral */
"E113399" = '1' /*Type 2 diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema, unspecified eye */
"E11341" = '1' /*Type 2 diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema */
"E113411" = '1' /*Type 2 diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema, right eye */
"E113412" = '1' /*Type 2 diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema, left eye */
"E113413" = '1' /*Type 2 diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema, bilateral */
"E113419" = '1' /*Type 2 diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema, unspecified eye */
"E11349" = '1' /*Type 2 diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema */
"E113491" = '1' /*Type 2 diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema, right eye */
"E113492" = '1' /*Type 2 diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema, left eye */
"E113493" = '1' /*Type 2 diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema, bilateral */
"E113499" = '1' /*Type 2 diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema, unspecified eye */
"E11351" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy with macular edema */
"E113511" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy with macular edema, right eye */
"E113512" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy with macular edema, left eye */
"E113513" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy with macular edema, bilateral */
"E113519" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy with macular edema, unspecified eye */
"E113521" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment involving the macula, right eye */
"E113522" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment involving the macula, left eye */
"E113523" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment involving the macula, bilateral */
"E113529" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment involving the macula, unspecified eye */
"E113531" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, right eye */
"E113532" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, left eye */
"E113533" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, bilateral */
"E113539" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, unspecified eye */
"E113541" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, right eye */
"E113542" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, left eye */
"E113543" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, bilateral */
"E113549" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, unspecified eye */
"E113551" = '1' /*Type 2 diabetes mellitus with stable proliferative diabetic retinopathy, right eye */
"E113552" = '1' /*Type 2 diabetes mellitus with stable proliferative diabetic retinopathy, left eye */
"E113553" = '1' /*Type 2 diabetes mellitus with stable proliferative diabetic retinopathy, bilateral */
"E113559" = '1' /*Type 2 diabetes mellitus with stable proliferative diabetic retinopathy, unspecified eye */
"E11359" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy without macular edema */
"E113591" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy without macular edema, right eye */
"E113592" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy without macular edema, left eye */
"E113593" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy without macular edema, bilateral */
"E113599" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy without macular edema, unspecified eye */
"E1136" = '1' /*Type 2 diabetes mellitus with diabetic cataract */
"E1137X1" = '1' /*Type 2 diabetes mellitus with diabetic macular edema, resolved following treatment, right eye */
"E1137X2" = '1' /*Type 2 diabetes mellitus with diabetic macular edema, resolved following treatment, left eye */
"E1137X3" = '1' /*Type 2 diabetes mellitus with diabetic macular edema, resolved following treatment, bilateral */
"E1137X9" = '1' /*Type 2 diabetes mellitus with diabetic macular edema, resolved following treatment, unspecified eye */
"E1139" = '1' /*Type 2 diabetes mellitus with other diabetic ophthalmiccomplication */
"E1140" = '1' /*Type 2 diabetes mellitus with diabetic neuropathy,unspecified */
"E1141" = '1' /*Type 2 diabetes mellitus with diabetic mononeuropathy */
"E1142" = '1' /*Type 2 diabetes mellitus with diabetic polyneuropathy */
"E1143" = '1' /*Type 2 diabetes mellitus with diabetic autonomic(poly)neuropathy */
"E1144" = '1' /*Type 2 diabetes mellitus with diabetic amyotrophy */
"E1149" = '1' /*Type 2 diabetes mellitus with other diabetic neurologicalcomplication */
"E1151" = '1' /*Type 2 diabetes mellitus with diabetic peripheralangiopathy without gangrene */
"E1152" = '1' /*Type 2 diabetes mellitus with diabetic peripheralangiopathy with gangrene */
"E1159" = '1' /*Type 2 diabetes mellitus with other circulatorycomplications */
"E11610" = '1' /*Type 2 diabetes mellitus with diabetic neuropathicarthropathy */
"E11618" = '1' /*Type 2 diabetes mellitus with other diabetic arthropathy */
"E11620" = '1' /*Type 2 diabetes mellitus with diabetic dermatitis */
"E11621" = '1' /*Type 2 diabetes mellitus with foot ulcer */
"E11622" = '1' /*Type 2 diabetes mellitus with other skin ulcer */
"E11628" = '1' /*Type 2 diabetes mellitus with other skin complications */
"E11630" = '1' /*Type 2 diabetes mellitus with periodontal disease */
"E11638" = '1' /*Type 2 diabetes mellitus with other oral complications */
"E1169" = '1' /*Type 2 diabetes mellitus with other specified complication */
"E118" = '1' /*Type 2 diabetes mellitus with unspecified complications */
OTHER = '0'
;

/* FORMAT FOR Diabetes with short-term complications diagnosis codes */
Value $ACDIASD
"E1010" = '1' /*Type 1 diabetes mellitus with ketoacidosis without coma */
"E1011" = '1' /*Type 1 diabetes mellitus with ketoacidosis with coma */
"E10641" = '1' /*Type 1 diabetes mellitus with hypoglycemia with coma */
"E1100" = '1' /*Type 2 diabetes mellitus with hyperosmolarity withoutnonketotic hyperglycemic-hyperosmolar coma (NKHHC) */
"E1101" = '1' /*Type 2 diabetes mellitus with hyperosmolarity with coma */
"E1110" = '1' /*Type 2 diabetes mellitus with ketoacidosis without coma */
"E1111" = '1' /*Type 2 diabetes mellitus with ketoacidosis with coma */
"E11641" = '1' /*Type 2 diabetes mellitus with hypoglycemia with coma */
OTHER = '0'
;

/* FORMAT FOR Uncontrolled diabetes without mention of a short-term or long-term complication diagnosis codes */
Value $ACDIAUD
"E10649" = '1' /*Type 1 diabetes mellitus with hypoglycemia without coma */
"E1065" = '1' /*Type 1 diabetes mellitus with hyperglycemia */
"E1110" = '1' /*Type 2 diabetes mellitus with ketoacidosis without coma */
"E1111" = '1' /*Type 2 diabetes mellitus with ketoacidosis with coma */
"E11649" = '1' /*Type 2 diabetes mellitus with hypoglycemia without coma */
"E1165" = '1' /*Type 2 diabetes mellitus with hyperglycemia */
OTHER = '0'
;

/* FORMAT FOR ICD10 Diagnosis */
Value $ACLEA2D
"S78011A" = '1' /*Complete traumatic amputation at right hip joint, initialencounter */
"S78012A" = '1' /*Complete traumatic amputation at left hip joint, initialencounter */
"S78019A" = '1' /*Complete traumatic amputation at unspecified hip joint,initial encounter */
"S78021A" = '1' /*Partial traumatic amputation at right hip joint, initialencounter */
"S78022A" = '1' /*Partial traumatic amputation at left hip joint, initialencounter */
"S78029A" = '1' /*Partial traumatic amputation at unspecified hip joint,initial encounter */
"S78111A" = '1' /*Complete traumatic amputation at level between righthip and knee, initial encounter */
"S78112A" = '1' /*Complete traumatic amputation at level between left hipand knee, initial encounter */
"S78119A" = '1' /*Complete traumatic amputation at level betweenunspecified hip and knee, initial encounter */
"S78121A" = '1' /*Partial traumatic amputation at level between right hipand knee, initial encounter */
"S78122A" = '1' /*Partial traumatic amputation at level between left hip andknee, initial encounter */
"S78129A" = '1' /*Partial traumatic amputation at level betweenunspecified hip and knee, initial encounter */
"S78911A" = '1' /*Complete traumatic amputation of right hip and thigh,level unspecified, initial encounter */
"S78912A" = '1' /*Complete traumatic amputation of left hip and thigh,level unspecified, initial encounter */
"S78919A" = '1' /*Complete traumatic amputation of unspecified hip andthigh, level unspecified, initial encounter */
"S78921A" = '1' /*Partial traumatic amputation of right hip and thigh, levelunspecified, initial encounter */
"S78922A" = '1' /*Partial traumatic amputation of left hip and thigh, levelunspecified, initial encounter */
"S78929A" = '1' /*Partial traumatic amputation of unspecified hip andthigh, level unspecified, initial encounter */
"S88011A" = '1' /*Complete traumatic amputation at knee level, right lowerleg, initial encounter */
"S88012A" = '1' /*Complete traumatic amputation at knee level, left lowerleg, initial encounter */
"S88019A" = '1' /*Complete traumatic amputation at knee level,unspecified lower leg, initial encounter */
"S88021A" = '1' /*Partial traumatic amputation at knee level, right lowerleg, initial encounter */
"S88022A" = '1' /*Partial traumatic amputation at knee level, left lower leg,initial encounter */
"S88029A" = '1' /*Partial traumatic amputation at knee level, unspecifiedlower leg, initial encounter */
"S88111A" = '1' /*Complete traumatic amputation at level between kneeand ankle, right lower leg, initial encounter */
"S88112A" = '1' /*Complete traumatic amputation at level between kneeand ankle, left lower leg, initial encounter */
"S88119A" = '1' /*Complete traumatic amputation at level between kneeand ankle, unspecified lower leg, initial encounter */
"S88121A" = '1' /*Partial traumatic amputation at level between knee andankle, right lower leg, initial encounter */
"S88122A" = '1' /*Partial traumatic amputation at level between knee andankle, left lower leg, initial encounter */
"S88129A" = '1' /*Partial traumatic amputation at level between knee andankle, unspecified lower leg, initial encounter */
"S88911A" = '1' /*Complete traumatic amputation of right lower leg, levelunspecified, initial encounter */
"S88912A" = '1' /*Complete traumatic amputation of left lower leg, levelunspecified, initial encounter */
"S88919A" = '1' /*Complete traumatic amputation of unspecified lower leg,level unspecified, initial encounter */
"S88921A" = '1' /*Partial traumatic amputation of right lower leg, levelunspecified, initial encounter */
"S88922A" = '1' /*Partial traumatic amputation of left lower leg, levelunspecified, initial encounter */
"S88929A" = '1' /*Partial traumatic amputation of unspecified lower leg,level unspecified, initial encounter */
"S98011A" = '1' /*Complete traumatic amputation of right foot at anklelevel, initial encounter */
"S98012A" = '1' /*Complete traumatic amputation of left foot at ankle level,initial encounter */
"S98019A" = '1' /*Complete traumatic amputation of unspecified foot atankle level, initial encounter */
"S98021A" = '1' /*Partial traumatic amputation of right foot at ankle level,initial encounter */
"S98022A" = '1' /*Partial traumatic amputation of left foot at ankle level,initial encounter */
"S98029A" = '1' /*Partial traumatic amputation of unspecified foot at anklelevel, initial encounter */
"S98111A" = '1' /*Complete traumatic amputation of right great toe, initialencounter */
"S98112A" = '1' /*Complete traumatic amputation of left great toe, initialencounter */
"S98119A" = '1' /*Complete traumatic amputation of unspecified great toe,initial encounter */
"S98121A" = '1' /*Partial traumatic amputation of right great toe, initialencounter */
"S98122A" = '1' /*Partial traumatic amputation of left great toe, initialencounter */
"S98129A" = '1' /*Partial traumatic amputation of unspecified great toe,initial encounter */
"S98131A" = '1' /*Complete traumatic amputation of one right lesser toe,initial encounter */
"S98132A" = '1' /*Complete traumatic amputation of one left lesser toe,initial encounter */
"S98139A" = '1' /*Complete traumatic amputation of one unspecifiedlesser toe, initial encounter */
"S98141A" = '1' /*Partial traumatic amputation of one right lesser toe, initialencounter */
"S98142A" = '1' /*Partial traumatic amputation of one left lesser toe, initialencounter */
"S98149A" = '1' /*Partial traumatic amputation of one unspecified lessertoe, initial encounter */
"S98211A" = '1' /*Complete traumatic amputation of two or more rightlesser toes, initial encounter */
"S98212A" = '1' /*Complete traumatic amputation of two or more left lessertoes, initial encounter */
"S98219A" = '1' /*Complete traumatic amputation of two or moreunspecified lesser toes, initial encounter */
"S98221A" = '1' /*Partial traumatic amputation of two or more right lessertoes, initial encounter */
"S98222A" = '1' /*Partial traumatic amputation of two or more left lessertoes, initial encounter */
"S98229A" = '1' /*Partial traumatic amputation of two or more unspecifiedlesser toes, initial encounter */
"S98311A" = '1' /*Complete traumatic amputation of right midfoot, initialencounter */
"S98312A" = '1' /*Complete traumatic amputation of left midfoot, initialencounter */
"S98319A" = '1' /*Complete traumatic amputation of unspecified midfoot,initial encounter */
"S98321A" = '1' /*Partial traumatic amputation of right midfoot, initialencounter */
"S98322A" = '1' /*Partial traumatic amputation of left midfoot, initialencounter */
"S98329A" = '1' /*Partial traumatic amputation of unspecified midfoot,initial encounter */
"S98911A" = '1' /*Complete traumatic amputation of right foot, levelunspecified, initial encounter */
"S98912A" = '1' /*Complete traumatic amputation of left foot, levelunspecified, initial encounter */
"S98919A" = '1' /*Complete traumatic amputation of unspecified foot, levelunspecified, initial encounter */
"S98921A" = '1' /*Partial traumatic amputation of right foot, levelunspecified, initial encounter */
"S98922A" = '1' /*Partial traumatic amputation of left foot, levelunspecified, initial encounter */
"S98929A" = '1' /*Partial traumatic amputation of unspecified foot, levelunspecified, initial encounter */
OTHER = '0'
;

/* FORMAT FOR Gastroenteritis diagnosis codes */
Value $ACPGASD
"A080" = '1' /*Rotaviral enteritis */
"A0811" = '1' /*Acute gastroenteropathy due to Norwalk agent */
"A0819" = '1' /*Acute gastroenteropathy due to other small round viruses */
"A082" = '1' /*Adenoviral enteritis */
"A0831" = '1' /*Calicivirus enteritis */
"A0832" = '1' /*Astrovirus enteritis */
"A0839" = '1' /*Other viral enteritis */
"A084" = '1' /*Viral intestinal infection, unspecified */
"A088" = '1' /*Other specified intestinal infections */
"A09" = '1' /*Infectious gastroenteritis and colitis, unspecified */
"K523" = '1' /*Indeterminate colitis */
"K5289" = '1' /*Other specified noninfective gastroenteritis and colitis */
"K529" = '1' /*Noninfective gastroenteritis and colitis, unspecified */
OTHER = '0'
;

/* FORMAT FOR Appendicitis diagnosis codes */
Value $ACSAP2D
"K352" = '1' /*Acute appendicitis with generalized peritonitis */
"K353" = '1' /*Acute appendicitis with localized peritonitis */
"K3580" = '1' /*Unspecified acute appendicitis */
"K3589" = '1' /*Other acute appendicitis */
"K37" = '1' /*Unspecified appendicitis */
OTHER = '0'
;

/* FORMAT FOR Perforations or abscesses of appendix diagnosis codes */
Value $ACSAPPD
"K352" = '1' /*Acuteappendicitiswith generalized peritonitis */
"K353" = '1' /*Acuteappendicitis with localizedperitonitis */
OTHER = '0'
;

/* FORMAT FOR Asthma diagnosis codes */
Value $ACSASTD
"J4521" = '1' /*Mild intermittent asthma with (acute) exacerbation */
"J4522" = '1' /*Mild intermittent asthma with status asthmaticus */
"J4531" = '1' /*Mild persistent asthma with (acute) exacerbation */
"J4532" = '1' /*Mild persistent asthma with status asthmaticus */
"J4541" = '1' /*Moderate persistent asthma with (acute) exacerbation */
"J4542" = '1' /*Moderate persistent asthma with status asthmaticus */
"J4551" = '1' /*Severe persistent asthma with (acute) exacerbation */
"J4552" = '1' /*Severe persistent asthma with status asthmaticus */
"J45901" = '1' /*Unspecified asthma with (acute) exacerbation */
"J45902" = '1' /*Unspecified asthma with status asthmaticus */
"J45990" = '1' /*Exercise induced bronchospasm */
"J45991" = '1' /*Cough variant asthma */
"J45998" = '1' /*Other asthma */
OTHER = '0'
;

/* FORMAT FOR Sickle cell anemia or HB-S disease diagnosis codes */
Value $ACSBA2D
"D5700" = '1' /*Hb-SS disease with crisis, unspecified */
"D5701" = '1' /*Hb-SS disease with acute chest syndrome */
"D5702" = '1' /*Hb-SS disease with splenic sequestration */
"D571" = '1' /*Sickle-cell disease without crisis */
"D5720" = '1' /*Sickle-cell/Hb-C disease without crisis */
"D57211" = '1' /*Sickle-cell/Hb-C disease with acute chest syndrome */
"D57212" = '1' /*Sickle-cell/Hb-C disease with splenic sequestration */
"D57219" = '1' /*Sickle-cell/Hb-C disease with crisis, unspecified */
"D5740" = '1' /*Sickle-cell thalassemia without crisis */
"D57411" = '1' /*Sickle-cell thalassemia with acute chest syndrome */
"D57412" = '1' /*Sickle-cell thalassemia with splenic sequestration */
"D57419" = '1' /*Sickle-cell thalassemia with crisis, unspecified */
"D5780" = '1' /*Other sickle-cell disorders without crisis */
"D57811" = '1' /*Other sickle-cell disorders with acute chest syndrome */
"D57812" = '1' /*Other sickle-cell disorders with splenic sequestration */
"D57819" = '1' /*Other sickle-cell disorders with crisis, unspecified */
OTHER = '0'
;

/* FORMAT FOR Community acquired pneumonia diagnosis codes */
Value $ACSBACD
"J13" = '1' /*Pneumonia due to Streptococcus pneumoniae */
"J14" = '1' /*Pneumonia due to Hemophilus influenzae */
"J15211" = '1' /*Pneumonia due to Methicillin susceptible Staphylococcus aureus */
"J15212" = '1' /*Pneumonia due to Methicillin resistant Staphylococcus aureus */
"J153" = '1' /*Pneumonia due to streptococcus, group B */
"J154" = '1' /*Pneumonia due to other streptococci */
"J157" = '1' /*Pneumonia due to Mycoplasma pneumoniae */
"J159" = '1' /*Unspecified bacterial pneumonia */
"J160" = '1' /*Chlamydial pneumonia */
"J168" = '1' /*Pneumonia due to other specified infectious organisms */
"J180" = '1' /*Bronchopneumonia, unspecified organism */
"J181" = '1' /*Lobar pneumonia, unspecified organism */
"J188" = '1' /*Other pneumonia, unspecified organism */
"J189" = '1' /*Pneumonia, unspecified organism */
OTHER = '0'
;

/* FORMAT FOR Cardiac procedure codes */
Value $ACSCARP
"0210083" = '1' /*Bypass Coronary Artery, One Artery from Coronary Artery with Zooplastic Tissue, Open Approach */
"0210088" = '1' /*Bypass Coronary Artery, One Artery from Right Internal Mammary with Zooplastic Tissue, Open Approach */
"0210089" = '1' /*Bypass Coronary Artery, One Artery from Left Internal Mammary with Zooplastic Tissue, Open Approach */
"021008C" = '1' /*Bypass Coronary Artery, One Artery from Thoracic Artery with Zooplastic Tissue, Open Approach */
"021008F" = '1' /*Bypass Coronary Artery, One Artery from Abdominal Artery with Zooplastic Tissue, Open Approach */
"021008W" = '1' /*Bypass Coronary Artery, One Artery from Aorta with Zooplastic Tissue, Open Approach */
"0210093" = '1' /*Bypass Coronary Artery, One Artery from Coronary Artery with Autologous Venous Tissue, Open Approach */
"0210098" = '1' /*Bypass Coronary Artery, One Artery from Right Internal Mammary with Autologous Venous Tissue, Open Approach */
"0210099" = '1' /*Bypass Coronary Artery, One Artery from Left Internal Mammary with Autologous Venous Tissue, Open Approach */
"021009C" = '1' /*Bypass Coronary Artery, One Artery from Thoracic Artery with Autologous Venous Tissue, Open Approach */
"021009F" = '1' /*Bypass Coronary Artery, One Artery from Abdominal Artery with Autologous Venous Tissue, Open Approach */
"021009W" = '1' /*Bypass Coronary Artery, One Artery from Aorta with Autologous Venous Tissue, Open Approach */
"02100A3" = '1' /*Bypass Coronary Artery, One Artery from Coronary Artery with Autologous Arterial Tissue, Open Approach */
"02100A8" = '1' /*Bypass Coronary Artery, One Artery from Right Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02100A9" = '1' /*Bypass Coronary Artery, One Artery from Left Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02100AC" = '1' /*Bypass Coronary Artery, One Artery from Thoracic Artery with Autologous Arterial Tissue, Open Approach */
"02100AF" = '1' /*Bypass Coronary Artery, One Artery from Abdominal Artery with Autologous Arterial Tissue, Open Approach */
"02100AW" = '1' /*Bypass Coronary Artery, One Artery from Aorta with Autologous Arterial Tissue, Open Approach */
"02100J3" = '1' /*Bypass Coronary Artery, One Artery from Coronary Artery with Synthetic Substitute, Open Approach */
"02100J8" = '1' /*Bypass Coronary Artery, One Artery from Right Internal Mammary with Synthetic Substitute, Open Approach */
"02100J9" = '1' /*Bypass Coronary Artery, One Artery from Left Internal Mammary with Synthetic Substitute, Open Approach */
"02100JC" = '1' /*Bypass Coronary Artery, One Artery from Thoracic Artery with Synthetic Substitute, Open Approach */
"02100JF" = '1' /*Bypass Coronary Artery, One Artery from Abdominal Artery with Synthetic Substitute, Open Approach */
"02100JW" = '1' /*Bypass Coronary Artery, One Artery from Aorta with Synthetic Substitute, Open Approach */
"02100K3" = '1' /*Bypass Coronary Artery, One Artery from Coronary Artery with Nonautologous Tissue Substitute, Open Approach */
"02100K8" = '1' /*Bypass Coronary Artery, One Artery from Right Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02100K9" = '1' /*Bypass Coronary Artery, One Artery from Left Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02100KC" = '1' /*Bypass Coronary Artery, One Artery from Thoracic Artery with Nonautologous Tissue Substitute, Open Approach */
"02100KF" = '1' /*Bypass Coronary Artery, One Artery from Abdominal Artery with Nonautologous Tissue Substitute, Open Approach */
"02100KW" = '1' /*Bypass Coronary Artery, One Artery from Aorta with Nonautologous Tissue Substitute, Open Approach */
"02100Z3" = '1' /*Bypass Coronary Artery, One Artery from Coronary Artery, Open Approach */
"02100Z8" = '1' /*Bypass Coronary Artery, One Artery from Right Internal Mammary, Open Approach */
"02100Z9" = '1' /*Bypass Coronary Artery, One Artery from Left Internal Mammary, Open Approach */
"02100ZC" = '1' /*Bypass Coronary Artery, One Artery from Thoracic Artery, Open Approach */
"02100ZF" = '1' /*Bypass Coronary Artery, One Artery from Abdominal Artery, Open Approach */
"0210344" = '1' /*Bypass Coronary Artery, One Artery from Coronary Vein with Drug-eluting Intraluminal Device, Percutaneous Approach */
"02103D4" = '1' /*Bypass Coronary Artery, One Artery from Coronary Vein with Intraluminal Device, Percutaneous Approach */
"0210444" = '1' /*Bypass Coronary Artery, One Artery from Coronary Vein with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0210483" = '1' /*Bypass Coronary Artery, One Artery from Coronary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"0210488" = '1' /*Bypass Coronary Artery, One Artery from Right Internal Mammary with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"0210489" = '1' /*Bypass Coronary Artery, One Artery from Left Internal Mammary with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021048C" = '1' /*Bypass Coronary Artery, One Artery from Thoracic Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021048F" = '1' /*Bypass Coronary Artery, One Artery from Abdominal Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021048W" = '1' /*Bypass Coronary Artery, One Artery from Aorta with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"0210493" = '1' /*Bypass Coronary Artery, One Artery from Coronary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0210498" = '1' /*Bypass Coronary Artery, One Artery from Right Internal Mammary with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0210499" = '1' /*Bypass Coronary Artery, One Artery from Left Internal Mammary with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021049C" = '1' /*Bypass Coronary Artery, One Artery from Thoracic Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021049F" = '1' /*Bypass Coronary Artery, One Artery from Abdominal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021049W" = '1' /*Bypass Coronary Artery, One Artery from Aorta with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"02104A3" = '1' /*Bypass Coronary Artery, One Artery from Coronary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02104A8" = '1' /*Bypass Coronary Artery, One Artery from Right Internal Mammary with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02104A9" = '1' /*Bypass Coronary Artery, One Artery from Left Internal Mammary with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02104AC" = '1' /*Bypass Coronary Artery, One Artery from Thoracic Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02104AF" = '1' /*Bypass Coronary Artery, One Artery from Abdominal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02104AW" = '1' /*Bypass Coronary Artery, One Artery from Aorta with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02104D4" = '1' /*Bypass Coronary Artery, One Artery from Coronary Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"02104J3" = '1' /*Bypass Coronary Artery, One Artery from Coronary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02104J8" = '1' /*Bypass Coronary Artery, One Artery from Right Internal Mammary with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02104J9" = '1' /*Bypass Coronary Artery, One Artery from Left Internal Mammary with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02104JC" = '1' /*Bypass Coronary Artery, One Artery from Thoracic Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02104JF" = '1' /*Bypass Coronary Artery, One Artery from Abdominal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02104JW" = '1' /*Bypass Coronary Artery, One Artery from Aorta with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02104K3" = '1' /*Bypass Coronary Artery, One Artery from Coronary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02104K8" = '1' /*Bypass Coronary Artery, One Artery from Right Internal Mammary with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02104K9" = '1' /*Bypass Coronary Artery, One Artery from Left Internal Mammary with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02104KC" = '1' /*Bypass Coronary Artery, One Artery from Thoracic Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02104KF" = '1' /*Bypass Coronary Artery, One Artery from Abdominal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02104KW" = '1' /*Bypass Coronary Artery, One Artery from Aorta with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02104Z3" = '1' /*Bypass Coronary Artery, One Artery from Coronary Artery, Percutaneous Endoscopic Approach */
"02104Z8" = '1' /*Bypass Coronary Artery, One Artery from Right Internal Mammary, Percutaneous Endoscopic Approach */
"02104Z9" = '1' /*Bypass Coronary Artery, One Artery from Left Internal Mammary, Percutaneous Endoscopic Approach */
"02104ZC" = '1' /*Bypass Coronary Artery, One Artery from Thoracic Artery, Percutaneous Endoscopic Approach */
"02104ZF" = '1' /*Bypass Coronary Artery, One Artery from Abdominal Artery, Percutaneous Endoscopic Approach */
"0211083" = '1' /*Bypass Coronary Artery, Two Arteries from Coronary Artery with Zooplastic Tissue, Open Approach */
"0211088" = '1' /*Bypass Coronary Artery, Two Arteries from Right Internal Mammary with Zooplastic Tissue, Open Approach */
"0211089" = '1' /*Bypass Coronary Artery, Two Arteries from Left Internal Mammary with Zooplastic Tissue, Open Approach */
"021108C" = '1' /*Bypass Coronary Artery, Two Arteries from Thoracic Artery with Zooplastic Tissue, Open Approach */
"021108F" = '1' /*Bypass Coronary Artery, Two Arteries from Abdominal Artery with Zooplastic Tissue, Open Approach */
"021108W" = '1' /*Bypass Coronary Artery, Two Arteries from Aorta with Zooplastic Tissue, Open Approach */
"0211093" = '1' /*Bypass Coronary Artery, Three Sites from Coronary Artery with Autologous Venous Tissue, Open Approach */
"0211098" = '1' /*Bypass Coronary Artery, Three Sites from Right Internal Mammary with Autologous Venous Tissue, Open Approach */
"0211099" = '1' /*Bypass Coronary Artery, Three Sites from Left Internal Mammary with Autologous Venous Tissue, Open Approach */
"021109C" = '1' /*Bypass Coronary Artery, Three Sites from Thoracic Artery with Autologous Venous Tissue, Open Approach */
"021109F" = '1' /*Bypass Coronary Artery, Three Sites from Abdominal Artery with Autologous Venous Tissue, Open Approach */
"021109W" = '1' /*Bypass Coronary Artery, Three Sites from Aorta with Autologous Venous Tissue, Open Approach */
"02110A3" = '1' /*Bypass Coronary Artery, Three Sites from Coronary Artery with Autologous Arterial Tissue, Open Approach */
"02110A8" = '1' /*Bypass Coronary Artery, Three Sites from Right Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02110A9" = '1' /*Bypass Coronary Artery, Three Sites from Left Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02110AC" = '1' /*Bypass Coronary Artery, Three Sites from Thoracic Artery with Autologous Arterial Tissue, Open Approach */
"02110AF" = '1' /*Bypass Coronary Artery, Three Sites from Abdominal Artery with Autologous Arterial Tissue, Open Approach */
"02110AW" = '1' /*Bypass Coronary Artery, Three Sites from Aorta with Autologous Arterial Tissue, Open Approach */
"02110J3" = '1' /*Bypass Coronary Artery, Three Sites from Coronary Artery with Synthetic Substitute, Open Approach */
"02110J8" = '1' /*Bypass Coronary Artery, Three Sites from Right Internal Mammary with Synthetic Substitute, Open Approach */
"02110J9" = '1' /*Bypass Coronary Artery, Three Sites from Left Internal Mammary with Synthetic Substitute, Open Approach */
"02110JC" = '1' /*Bypass Coronary Artery, Three Sites from Thoracic Artery with Synthetic Substitute, Open Approach */
"02110JF" = '1' /*Bypass Coronary Artery, Three Sites from Abdominal Artery with Synthetic Substitute, Open Approach */
"02110JW" = '1' /*Bypass Coronary Artery, Three Sites from Aorta with Synthetic Substitute, Open Approach */
"02110K3" = '1' /*Bypass Coronary Artery, Three Sites from Coronary Artery with Nonautologous Tissue Substitute, Open Approach */
"02110K8" = '1' /*Bypass Coronary Artery, Three Sites from Right Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02110K9" = '1' /*Bypass Coronary Artery, Three Sites from Left Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02110KC" = '1' /*Bypass Coronary Artery, Three Sites from Thoracic Artery with Nonautologous Tissue Substitute, Open Approach */
"02110KF" = '1' /*Bypass Coronary Artery, Three Sites from Abdominal Artery with Nonautologous Tissue Substitute, Open Approach */
"02110KW" = '1' /*Bypass Coronary Artery, Three Sites from Aorta with Nonautologous Tissue Substitute, Open Approach */
"02110Z3" = '1' /*Bypass Coronary Artery, Three Sites from Coronary Artery, Open Approach */
"02110Z8" = '1' /*Bypass Coronary Artery, Three Sites from Right Internal Mammary, Open Approach */
"02110Z9" = '1' /*Bypass Coronary Artery, Three Sites from Left Internal Mammary, Open Approach */
"02110ZC" = '1' /*Bypass Coronary Artery, Three Sites from Thoracic Artery, Open Approach */
"02110ZF" = '1' /*Bypass Coronary Artery, Three Sites from Abdominal Artery, Open Approach */
"0211344" = '1' /*Bypass Coronary Artery, Three Sites from Coronary Vein with Drug-eluting Intraluminal Device, Percutaneous Approach */
"02113D4" = '1' /*Bypass Coronary Artery, Three Sites from Coronary Vein with Intraluminal Device, Percutaneous Approach */
"0211444" = '1' /*Bypass Coronary Artery, Three Sites from Coronary Vein with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0211483" = '1' /*Bypass Coronary Artery, Two Arteries from Coronary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"0211488" = '1' /*Bypass Coronary Artery, Two Arteries from Right Internal Mammary with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"0211489" = '1' /*Bypass Coronary Artery, Two Arteries from Left Internal Mammary with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021148C" = '1' /*Bypass Coronary Artery, Two Arteries from Thoracic Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021148F" = '1' /*Bypass Coronary Artery, Two Arteries from Abdominal Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021148W" = '1' /*Bypass Coronary Artery, Two Arteries from Aorta with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"0211493" = '1' /*Bypass Coronary Artery, Two Arteries from Coronary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0211498" = '1' /*Bypass Coronary Artery, Two Arteries from Right Internal Mammary with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0211499" = '1' /*Bypass Coronary Artery, Two Arteries from Left Internal Mammary with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021149C" = '1' /*Bypass Coronary Artery, Two Arteries from Thoracic Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021149F" = '1' /*Bypass Coronary Artery, Two Arteries from Abdominal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021149W" = '1' /*Bypass Coronary Artery, Two Arteries from Aorta with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"02114A3" = '1' /*Bypass Coronary Artery, Two Arteries from Coronary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02114A8" = '1' /*Bypass Coronary Artery, Two Arteries from Right Internal Mammary with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02114A9" = '1' /*Bypass Coronary Artery, Two Arteries from Left Internal Mammary with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02114AC" = '1' /*Bypass Coronary Artery, Two Arteries from Thoracic Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02114AF" = '1' /*Bypass Coronary Artery, Two Arteries from Abdominal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02114AW" = '1' /*Bypass Coronary Artery, Two Arteries from Aorta with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02114D4" = '1' /*Bypass Coronary Artery, Two Arteries from Coronary Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"02114J3" = '1' /*Bypass Coronary Artery, Two Arteries from Coronary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02114J8" = '1' /*Bypass Coronary Artery, Two Arteries from Right Internal Mammary with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02114J9" = '1' /*Bypass Coronary Artery, Two Arteries from Left Internal Mammary with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02114JC" = '1' /*Bypass Coronary Artery, Two Arteries from Thoracic Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02114JF" = '1' /*Bypass Coronary Artery, Two Arteries from Abdominal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02114JW" = '1' /*Bypass Coronary Artery, Two Arteries from Aorta with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02114K3" = '1' /*Bypass Coronary Artery, Two Arteries from Coronary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02114K8" = '1' /*Bypass Coronary Artery, Two Arteries from Right Internal Mammary with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02114K9" = '1' /*Bypass Coronary Artery, Two Arteries from Left Internal Mammary with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02114KC" = '1' /*Bypass Coronary Artery, Two Arteries from Thoracic Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02114KF" = '1' /*Bypass Coronary Artery, Two Arteries from Abdominal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02114KW" = '1' /*Bypass Coronary Artery, Two Arteries from Aorta with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02114Z3" = '1' /*Bypass Coronary Artery, Two Arteries from Coronary Artery, Percutaneous Endoscopic Approach */
"02114Z8" = '1' /*Bypass Coronary Artery, Two Arteries from Right Internal Mammary, Percutaneous Endoscopic Approach */
"02114Z9" = '1' /*Bypass Coronary Artery, Two Arteries from Left Internal Mammary, Percutaneous Endoscopic Approach */
"02114ZC" = '1' /*Bypass Coronary Artery, Two Arteries from Thoracic Artery, Percutaneous Endoscopic Approach */
"02114ZF" = '1' /*Bypass Coronary Artery, Two Arteries from Abdominal Artery, Percutaneous Endoscopic Approach */
"0212083" = '1' /*Bypass Coronary Artery, Three Arteries from Coronary Artery with Zooplastic Tissue, Open Approach */
"0212088" = '1' /*Bypass Coronary Artery, Three Arteries from Right Internal Mammary with Zooplastic Tissue, Open Approach */
"0212089" = '1' /*Bypass Coronary Artery, Three Arteries from Left Internal Mammary with Zooplastic Tissue, Open Approach */
"021208C" = '1' /*Bypass Coronary Artery, Three Arteries from Thoracic Artery with Zooplastic Tissue, Open Approach */
"021208F" = '1' /*Bypass Coronary Artery, Three Arteries from Abdominal Artery with Zooplastic Tissue, Open Approach */
"021208W" = '1' /*Bypass Coronary Artery, Three Arteries from Aorta with Zooplastic Tissue, Open Approach */
"0212093" = '1' /*Bypass Coronary Artery, Three Arteries from Coronary Artery with Autologous Venous Tissue, Open Approach */
"0212098" = '1' /*Bypass Coronary Artery, Three Arteries from Right Internal Mammary with Autologous Venous Tissue, Open Approach */
"0212099" = '1' /*Bypass Coronary Artery, Three Arteries from Left Internal Mammary with Autologous Venous Tissue, Open Approach */
"021209C" = '1' /*Bypass Coronary Artery, Three Arteries from Thoracic Artery with Autologous Venous Tissue, Open Approach */
"021209F" = '1' /*Bypass Coronary Artery, Three Arteries from Abdominal Artery with Autologous Venous Tissue, Open Approach */
"021209W" = '1' /*Bypass Coronary Artery, Three Arteries from Aorta with Autologous Venous Tissue, Open Approach */
"02120A3" = '1' /*Bypass Coronary Artery, Three Arteries from Coronary Artery with Autologous Arterial Tissue, Open Approach */
"02120A8" = '1' /*Bypass Coronary Artery, Three Arteries from Right Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02120A9" = '1' /*Bypass Coronary Artery, Three Arteries from Left Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02120AC" = '1' /*Bypass Coronary Artery, Three Arteries from Thoracic Artery with Autologous Arterial Tissue, Open Approach */
"02120AF" = '1' /*Bypass Coronary Artery, Three Arteries from Abdominal Artery with Autologous Arterial Tissue, Open Approach */
"02120AW" = '1' /*Bypass Coronary Artery, Three Arteries from Aorta with Autologous Arterial Tissue, Open Approach */
"02120J3" = '1' /*Bypass Coronary Artery, Three Arteries from Coronary Artery with Synthetic Substitute, Open Approach */
"02120J8" = '1' /*Bypass Coronary Artery, Three Arteries from Right Internal Mammary with Synthetic Substitute, Open Approach */
"02120J9" = '1' /*Bypass Coronary Artery, Three Arteries from Left Internal Mammary with Synthetic Substitute, Open Approach */
"02120JC" = '1' /*Bypass Coronary Artery, Three Arteries from Thoracic Artery with Synthetic Substitute, Open Approach */
"02120JF" = '1' /*Bypass Coronary Artery, Three Arteries from Abdominal Artery with Synthetic Substitute, Open Approach */
"02120JW" = '1' /*Bypass Coronary Artery, Three Arteries from Aorta with Synthetic Substitute, Open Approach */
"02120K3" = '1' /*Bypass Coronary Artery, Three Arteries from Coronary Artery with Nonautologous Tissue Substitute, Open Approach */
"02120K8" = '1' /*Bypass Coronary Artery, Three Arteries from Right Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02120K9" = '1' /*Bypass Coronary Artery, Three Arteries from Left Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02120KC" = '1' /*Bypass Coronary Artery, Three Arteries from Thoracic Artery with Nonautologous Tissue Substitute, Open Approach */
"02120KF" = '1' /*Bypass Coronary Artery, Three Arteries from Abdominal Artery with Nonautologous Tissue Substitute, Open Approach */
"02120KW" = '1' /*Bypass Coronary Artery, Three Arteries from Aorta with Nonautologous Tissue Substitute, Open Approach */
"02120Z3" = '1' /*Bypass Coronary Artery, Three Arteries from Coronary Artery, Open Approach */
"02120Z8" = '1' /*Bypass Coronary Artery, Three Arteries from Right Internal Mammary, Open Approach */
"02120Z9" = '1' /*Bypass Coronary Artery, Three Arteries from Left Internal Mammary, Open Approach */
"02120ZC" = '1' /*Bypass Coronary Artery, Three Arteries from Thoracic Artery, Open Approach */
"02120ZF" = '1' /*Bypass Coronary Artery, Three Arteries from Abdominal Artery, Open Approach */
"0212344" = '1' /*Bypass Coronary Artery, Three Arteries from Coronary Vein with Drug-eluting Intraluminal Device, Percutaneous Approach */
"02123D4" = '1' /*Bypass Coronary Artery, Three Arteries from Coronary Vein with Intraluminal Device, Percutaneous Approach */
"0212444" = '1' /*Bypass Coronary Artery, Three Arteries from Coronary Vein with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0212483" = '1' /*Bypass Coronary Artery, Three Arteries from Coronary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"0212488" = '1' /*Bypass Coronary Artery, Three Arteries from Right Internal Mammary with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"0212489" = '1' /*Bypass Coronary Artery, Three Arteries from Left Internal Mammary with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021248C" = '1' /*Bypass Coronary Artery, Three Arteries from Thoracic Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021248F" = '1' /*Bypass Coronary Artery, Three Arteries from Abdominal Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021248W" = '1' /*Bypass Coronary Artery, Three Arteries from Aorta with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"0212493" = '1' /*Bypass Coronary Artery, Three Arteries from Coronary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0212498" = '1' /*Bypass Coronary Artery, Three Arteries from Right Internal Mammary with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0212499" = '1' /*Bypass Coronary Artery, Three Arteries from Left Internal Mammary with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021249C" = '1' /*Bypass Coronary Artery, Three Arteries from Thoracic Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021249F" = '1' /*Bypass Coronary Artery, Three Arteries from Abdominal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021249W" = '1' /*Bypass Coronary Artery, Three Arteries from Aorta with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"02124A3" = '1' /*Bypass Coronary Artery, Three Arteries from Coronary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02124A8" = '1' /*Bypass Coronary Artery, Three Arteries from Right Internal Mammary with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02124A9" = '1' /*Bypass Coronary Artery, Three Arteries from Left Internal Mammary with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02124AC" = '1' /*Bypass Coronary Artery, Three Arteries from Thoracic Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02124AF" = '1' /*Bypass Coronary Artery, Three Arteries from Abdominal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02124AW" = '1' /*Bypass Coronary Artery, Three Arteries from Aorta with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02124D4" = '1' /*Bypass Coronary Artery, Three Arteries from Coronary Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"02124J3" = '1' /*Bypass Coronary Artery, Three Arteries from Coronary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02124J8" = '1' /*Bypass Coronary Artery, Three Arteries from Right Internal Mammary with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02124J9" = '1' /*Bypass Coronary Artery, Three Arteries from Left Internal Mammary with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02124JC" = '1' /*Bypass Coronary Artery, Three Arteries from Thoracic Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02124JF" = '1' /*Bypass Coronary Artery, Three Arteries from Abdominal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02124JW" = '1' /*Bypass Coronary Artery, Three Arteries from Aorta with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02124K3" = '1' /*Bypass Coronary Artery, Three Arteries from Coronary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02124K8" = '1' /*Bypass Coronary Artery, Three Arteries from Right Internal Mammary with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02124K9" = '1' /*Bypass Coronary Artery, Three Arteries from Left Internal Mammary with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02124KC" = '1' /*Bypass Coronary Artery, Three Arteries from Thoracic Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02124KF" = '1' /*Bypass Coronary Artery, Three Arteries from Abdominal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02124KW" = '1' /*Bypass Coronary Artery, Three Arteries from Aorta with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02124Z3" = '1' /*Bypass Coronary Artery, Three Arteries from Coronary Artery, Percutaneous Endoscopic Approach */
"02124Z8" = '1' /*Bypass Coronary Artery, Three Arteries from Right Internal Mammary, Percutaneous Endoscopic Approach */
"02124Z9" = '1' /*Bypass Coronary Artery, Three Arteries from Left Internal Mammary, Percutaneous Endoscopic Approach */
"02124ZC" = '1' /*Bypass Coronary Artery, Three Arteries from Thoracic Artery, Percutaneous Endoscopic Approach */
"02124ZF" = '1' /*Bypass Coronary Artery, Three Arteries from Abdominal Artery, Percutaneous Endoscopic Approach */
"0213083" = '1' /*Bypass Coronary Artery, Four or More Arteries from Coronary Artery with Zooplastic Tissue, Open Approach */
"0213088" = '1' /*Bypass Coronary Artery, Four or More Arteries from Right Internal Mammary with Zooplastic Tissue, Open Approach */
"0213089" = '1' /*Bypass Coronary Artery, Four or More Arteries from Left Internal Mammary with Zooplastic Tissue, Open Approach */
"021308C" = '1' /*Bypass Coronary Artery, Four or More Arteries from Thoracic Artery with Zooplastic Tissue, Open Approach */
"021308F" = '1' /*Bypass Coronary Artery, Four or More Arteries from Abdominal Artery with Zooplastic Tissue, Open Approach */
"021308W" = '1' /*Bypass Coronary Artery, Four or More Arteries from Aorta with Zooplastic Tissue, Open Approach */
"0213093" = '1' /*Bypass Coronary Artery, Four or More Arteries from Coronary Artery with Autologous Venous Tissue, Open Approach */
"0213098" = '1' /*Bypass Coronary Artery, Four or More Arteries from Right Internal Mammary with Autologous Venous Tissue, Open Approach */
"0213099" = '1' /*Bypass Coronary Artery, Four or More Arteries from Left Internal Mammary with Autologous Venous Tissue, Open Approach */
"021309C" = '1' /*Bypass Coronary Artery, Four or More Arteries from Thoracic Artery with Autologous Venous Tissue, Open Approach */
"021309F" = '1' /*Bypass Coronary Artery, Four or More Arteries from Abdominal Artery with Autologous Venous Tissue, Open Approach */
"021309W" = '1' /*Bypass Coronary Artery, Four or More Arteries from Aorta with Autologous Venous Tissue, Open Approach */
"02130A3" = '1' /*Bypass Coronary Artery, Four or More Arteries from Coronary Artery with Autologous Arterial Tissue, Open Approach */
"02130A8" = '1' /*Bypass Coronary Artery, Four or More Arteries from Right Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02130A9" = '1' /*Bypass Coronary Artery, Four or More Arteries from Left Internal Mammary with Autologous Arterial Tissue, Open Approach */
"02130AC" = '1' /*Bypass Coronary Artery, Four or More Arteries from Thoracic Artery with Autologous Arterial Tissue, Open Approach */
"02130AF" = '1' /*Bypass Coronary Artery, Four or More Arteries from Abdominal Artery with Autologous Arterial Tissue, Open Approach */
"02130AW" = '1' /*Bypass Coronary Artery, Four or More Arteries from Aorta with Autologous Arterial Tissue, Open Approach */
"02130J3" = '1' /*Bypass Coronary Artery, Four or More Arteries from Coronary Artery with Synthetic Substitute, Open Approach */
"02130J8" = '1' /*Bypass Coronary Artery, Four or More Arteries from Right Internal Mammary with Synthetic Substitute, Open Approach */
"02130J9" = '1' /*Bypass Coronary Artery, Four or More Arteries from Left Internal Mammary with Synthetic Substitute, Open Approach */
"02130JC" = '1' /*Bypass Coronary Artery, Four or More Arteries from Thoracic Artery with Synthetic Substitute, Open Approach */
"02130JF" = '1' /*Bypass Coronary Artery, Four or More Arteries from Abdominal Artery with Synthetic Substitute, Open Approach */
"02130JW" = '1' /*Bypass Coronary Artery, Four or More Arteries from Aorta with Synthetic Substitute, Open Approach */
"02130K3" = '1' /*Bypass Coronary Artery, Four or More Arteries from Coronary Artery with Nonautologous Tissue Substitute, Open Approach */
"02130K8" = '1' /*Bypass Coronary Artery, Four or More Arteries from Right Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02130K9" = '1' /*Bypass Coronary Artery, Four or More Arteries from Left Internal Mammary with Nonautologous Tissue Substitute, Open Approach */
"02130KC" = '1' /*Bypass Coronary Artery, Four or More Arteries from Thoracic Artery with Nonautologous Tissue Substitute, Open Approach */
"02130KF" = '1' /*Bypass Coronary Artery, Four or More Arteries from Abdominal Artery with Nonautologous Tissue Substitute, Open Approach */
"02130KW" = '1' /*Bypass Coronary Artery, Four or More Arteries from Aorta with Nonautologous Tissue Substitute, Open Approach */
"02130Z3" = '1' /*Bypass Coronary Artery, Four or More Arteries from Coronary Artery, Open Approach */
"02130Z8" = '1' /*Bypass Coronary Artery, Four or More Arteries from Right Internal Mammary, Open Approach */
"02130Z9" = '1' /*Bypass Coronary Artery, Four or More Arteries from Left Internal Mammary, Open Approach */
"02130ZC" = '1' /*Bypass Coronary Artery, Four or More Arteries from Thoracic Artery, Open Approach */
"02130ZF" = '1' /*Bypass Coronary Artery, Four or More Arteries from Abdominal Artery, Open Approach */
"0213344" = '1' /*Bypass Coronary Artery, Four or More Arteries from Coronary Vein with Drug-eluting Intraluminal Device, Percutaneous Approach */
"02133D4" = '1' /*Bypass Coronary Artery, Four or More Arteries from Coronary Vein with Intraluminal Device, Percutaneous Approach */
"0213444" = '1' /*Bypass Coronary Artery, Four or More Arteries from Coronary Vein with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0213483" = '1' /*Bypass Coronary Artery, Four or More Arteries from Coronary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"0213488" = '1' /*Bypass Coronary Artery, Four or More Arteries from Right Internal Mammary with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"0213489" = '1' /*Bypass Coronary Artery, Four or More Arteries from Left Internal Mammary with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021348C" = '1' /*Bypass Coronary Artery, Four or More Arteries from Thoracic Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021348F" = '1' /*Bypass Coronary Artery, Four or More Arteries from Abdominal Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021348W" = '1' /*Bypass Coronary Artery, Four or More Arteries from Aorta with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"0213493" = '1' /*Bypass Coronary Artery, Four or More Arteries from Coronary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0213498" = '1' /*Bypass Coronary Artery, Four or More Arteries from Right Internal Mammary with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"0213499" = '1' /*Bypass Coronary Artery, Four or More Arteries from Left Internal Mammary with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021349C" = '1' /*Bypass Coronary Artery, Four or More Arteries from Thoracic Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021349F" = '1' /*Bypass Coronary Artery, Four or More Arteries from Abdominal Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021349W" = '1' /*Bypass Coronary Artery, Four or More Arteries from Aorta with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"02134A3" = '1' /*Bypass Coronary Artery, Four or More Arteries from Coronary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02134A8" = '1' /*Bypass Coronary Artery, Four or More Arteries from Right Internal Mammary with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02134A9" = '1' /*Bypass Coronary Artery, Four or More Arteries from Left Internal Mammary with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02134AC" = '1' /*Bypass Coronary Artery, Four or More Arteries from Thoracic Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02134AF" = '1' /*Bypass Coronary Artery, Four or More Arteries from Abdominal Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02134AW" = '1' /*Bypass Coronary Artery, Four or More Arteries from Aorta with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02134D4" = '1' /*Bypass Coronary Artery, Four or More Arteries from Coronary Vein with Intraluminal Device, Percutaneous Endoscopic Approach */
"02134J3" = '1' /*Bypass Coronary Artery, Four or More Arteries from Coronary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02134J8" = '1' /*Bypass Coronary Artery, Four or More Arteries from Right Internal Mammary with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02134J9" = '1' /*Bypass Coronary Artery, Four or More Arteries from Left Internal Mammary with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02134JC" = '1' /*Bypass Coronary Artery, Four or More Arteries from Thoracic Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02134JF" = '1' /*Bypass Coronary Artery, Four or More Arteries from Abdominal Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02134JW" = '1' /*Bypass Coronary Artery, Four or More Arteries from Aorta with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02134K3" = '1' /*Bypass Coronary Artery, Four or More Arteries from Coronary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02134K8" = '1' /*Bypass Coronary Artery, Four or More Arteries from Right Internal Mammary with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02134K9" = '1' /*Bypass Coronary Artery, Four or More Arteries from Left Internal Mammary with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02134KC" = '1' /*Bypass Coronary Artery, Four or More Arteries from Thoracic Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02134KF" = '1' /*Bypass Coronary Artery, Four or More Arteries from Abdominal Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02134KW" = '1' /*Bypass Coronary Artery, Four or More Arteries from Aorta with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02134Z3" = '1' /*Bypass Coronary Artery, Four or More Arteries from Coronary Artery, Percutaneous Endoscopic Approach */
"02134Z8" = '1' /*Bypass Coronary Artery, Four or More Arteries from Right Internal Mammary, Percutaneous Endoscopic Approach */
"02134Z9" = '1' /*Bypass Coronary Artery, Four or More Arteries from Left Internal Mammary, Percutaneous Endoscopic Approach */
"02134ZC" = '1' /*Bypass Coronary Artery, Four or More Arteries from Thoracic Artery, Percutaneous Endoscopic Approach */
"02134ZF" = '1' /*Bypass Coronary Artery, Four or More Arteries from Abdominal Artery, Percutaneous Endoscopic Approach */
"021608P" = '1' /*Bypass Right Atrium to Pulmonary Trunk with Zooplastic Tissue, Open Approach */
"021608Q" = '1' /*Bypass Right Atrium to Right Pulmonary Artery with Zooplastic Tissue, Open Approach */
"021608R" = '1' /*Bypass Right Atrium to Left Pulmonary Artery with Zooplastic Tissue, Open Approach */
"021609P" = '1' /*Bypass Right Atrium to Pulmonary Trunk withAutologous Venous Tissue, Open Approach */
"021609Q" = '1' /*Bypass Right Atrium to Right Pulmonary Artery withAutologous Venous Tissue, Open Approach */
"021609R" = '1' /*Bypass Right Atrium to Left Pulmonary Artery withAutologous Venous Tissue, Open Approach */
"02160AP" = '1' /*Bypass Right Atrium to Pulmonary Trunk withAutologous Arterial Tissue, Open Approach */
"02160AQ" = '1' /*Bypass Right Atrium to Right Pulmonary Artery withAutologous Arterial Tissue, Open Approach */
"02160AR" = '1' /*Bypass Right Atrium to Left Pulmonary Artery withAutologous Arterial Tissue, Open Approach */
"02160JP" = '1' /*Bypass Right Atrium to Pulmonary Trunk withSynthetic Substitute, Open Approach */
"02160JQ" = '1' /*Bypass Right Atrium to Right Pulmonary Artery withSynthetic Substitute, Open Approach */
"02160JR" = '1' /*Bypass Right Atrium to Left Pulmonary Artery withSynthetic Substitute, Open Approach */
"02160KP" = '1' /*Bypass Right Atrium to Pulmonary Trunk withNonautologous Tissue Substitute, Open Approach */
"02160KQ" = '1' /*Bypass Right Atrium to Right Pulmonary Artery withNonautologous Tissue Substitute, Open Approach */
"02160KR" = '1' /*Bypass Right Atrium to Left Pulmonary Artery withNonautologous Tissue Substitute, Open Approach */
"02160Z7" = '1' /*Bypass Right Atrium to Left Atrium, OpenApproach */
"02160ZP" = '1' /*Bypass Right Atrium to Pulmonary Trunk, OpenApproach */
"02160ZQ" = '1' /*Bypass Right Atrium to Right Pulmonary Artery, OpenApproach */
"02160ZR" = '1' /*Bypass Right Atrium to Left Pulmonary Artery, OpenApproach */
"02163Z7" = '1' /*Bypass Right Atrium to Left Atrium, Percutaneous Approach */
"021648P" = '1' /*Bypass Right Atrium to Pulmonary Trunk with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021648Q" = '1' /*Bypass Right Atrium to Right Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021648R" = '1' /*Bypass Right Atrium to Left Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021649P" = '1' /*Bypass Right Atrium to Pulmonary Trunk withAutologous Venous Tissue, Percutaneous EndoscopicApproach */
"021649Q" = '1' /*Bypass Right Atrium to Right Pulmonary Artery withAutologous Venous Tissue, Percutaneous EndoscopicApproach */
"021649R" = '1' /*Bypass Right Atrium to Left Pulmonary Artery withAutologous Venous Tissue, Percutaneous EndoscopicApproach */
"02164AP" = '1' /*Bypass Right Atrium to Pulmonary Trunk withAutologous Arterial Tissue, Percutaneous EndoscopicApproach */
"02164AQ" = '1' /*Bypass Right Atrium to Right Pulmonary Artery withAutologous Arterial Tissue, Percutaneous EndoscopicApproach */
"02164AR" = '1' /*Bypass Right Atrium to Left Pulmonary Artery withAutologous Arterial Tissue, Percutaneous EndoscopicApproach */
"02164JP" = '1' /*Bypass Right Atrium to Pulmonary Trunk withSynthetic Substitute, Percutaneous EndoscopicApproach */
"02164JQ" = '1' /*Bypass Right Atrium to Right Pulmonary Artery withSynthetic Substitute, Percutaneous EndoscopicApproach */
"02164JR" = '1' /*Bypass Right Atrium to Left Pulmonary Artery withSynthetic Substitute, Percutaneous EndoscopicApproach */
"02164KP" = '1' /*Bypass Right Atrium to Pulmonary Trunk withNonautologous Tissue Substitute, PercutaneousEndoscopic Approach */
"02164KQ" = '1' /*Bypass Right Atrium to Right Pulmonary Artery withNonautologous Tissue Substitute, PercutaneousEndoscopic Approach */
"02164KR" = '1' /*Bypass Right Atrium to Left Pulmonary Artery withNonautologous Tissue Substitute, PercutaneousEndoscopic Approach */
"02164Z7" = '1' /*Bypass Right Atrium to Left Atrium,Percutaneous Endoscopic Approach */
"02164ZP" = '1' /*Bypass Right Atrium to Pulmonary Trunk,Percutaneous Endoscopic Approach */
"02164ZQ" = '1' /*Bypass Right Atrium to Right Pulmonary Artery,Percutaneous Endoscopic Approach */
"02164ZR" = '1' /*Bypass Right Atrium to Left Pulmonary Artery,Percutaneous Endoscopic Approach */
"021708P" = '1' /*Bypass Left Atrium to Pulmonary Trunk with Zooplastic Tissue, Open Approach */
"021708Q" = '1' /*Bypass Left Atrium to Right Pulmonary Artery with Zooplastic Tissue, Open Approach */
"021708R" = '1' /*Bypass Left Atrium to Left Pulmonary Artery with Zooplastic Tissue, Open Approach */
"021709P" = '1' /*Bypass Left Atrium to Pulmonary Trunk withAutologous Venous Tissue, Open Approach */
"021709Q" = '1' /*Bypass Left Atrium to Right Pulmonary Artery withAutologous Venous Tissue, Open Approach */
"021709R" = '1' /*Bypass Left Atrium to Left Pulmonary Artery withAutologous Venous Tissue, Open Approach */
"021709S" = '1' /*Bypass Left Atrium to Right Pulmonary Vein with Autologous Venous Tissue, Open Approach */
"021709T" = '1' /*Bypass Left Atrium to Left Pulmonary Vein with Autologous Venous Tissue, Open Approach */
"021709U" = '1' /*Bypass Left Atrium to Pulmonary Vein Confluence with Autologous Venous Tissue, Open Approach */
"02170AP" = '1' /*Bypass Left Atrium to Pulmonary Trunk withAutologous Arterial Tissue, Open Approach */
"02170AQ" = '1' /*Bypass Left Atrium to Right Pulmonary Artery withAutologous Arterial Tissue, Open Approach */
"02170AR" = '1' /*Bypass Left Atrium to Left Pulmonary Artery withAutologous Arterial Tissue, Open Approach */
"02170AS" = '1' /*Bypass Left Atrium to Right Pulmonary Vein with Autologous Arterial Tissue, Open Approach */
"02170AT" = '1' /*Bypass Left Atrium to Left Pulmonary Vein with Autologous Arterial Tissue, Open Approach */
"02170AU" = '1' /*Bypass Left Atrium to Pulmonary Vein Confluence with Autologous Arterial Tissue, Open Approach */
"02170JP" = '1' /*Bypass Left Atrium to Pulmonary Trunk with SyntheticSubstitute, Open Approach */
"02170JQ" = '1' /*Bypass Left Atrium to Right Pulmonary Artery withSynthetic Substitute, Open Approach */
"02170JR" = '1' /*Bypass Left Atrium to Left Pulmonary Artery withSynthetic Substitute, Open Approach */
"02170JS" = '1' /*Bypass Left Atrium to Right Pulmonary Vein with Synthetic Substitute, Open Approach */
"02170JT" = '1' /*Bypass Left Atrium to Left Pulmonary Vein with Synthetic Substitute, Open Approach */
"02170JU" = '1' /*Bypass Left Atrium to Pulmonary Vein Confluence with Synthetic Substitute, Open Approach */
"02170KP" = '1' /*Bypass Left Atrium to Pulmonary Trunk withNonautologous Tissue Substitute, Open Approach */
"02170KQ" = '1' /*Bypass Left Atrium to Right Pulmonary Artery withNonautologous Tissue Substitute, Open Approach */
"02170KR" = '1' /*Bypass Left Atrium to Left Pulmonary Artery withNonautologous Tissue Substitute, Open Approach */
"02170KS" = '1' /*Bypass Left Atrium to Right Pulmonary Vein with Nonautologous Tissue Substitute, Open Approach */
"02170KT" = '1' /*Bypass Left Atrium to Left Pulmonary Vein with Nonautologous Tissue Substitute, Open Approach */
"02170KU" = '1' /*Bypass Left Atrium to Pulmonary Vein Confluence with Nonautologous Tissue Substitute, Open Approach */
"02170ZP" = '1' /*Bypass Left Atrium to Pulmonary Trunk, OpenApproach */
"02170ZQ" = '1' /*Bypass Left Atrium to Right Pulmonary Artery, OpenApproach */
"02170ZR" = '1' /*Bypass Left Atrium to Left Pulmonary Artery, OpenApproach */
"02170ZS" = '1' /*Bypass Left Atrium to Right Pulmonary Vein, Open Approach */
"02170ZT" = '1' /*Bypass Left Atrium to Left Pulmonary Vein, Open Approach */
"02170ZU" = '1' /*Bypass Left Atrium to Pulmonary Vein Confluence, Open Approach */
"021748P" = '1' /*Bypass Left Atrium to Pulmonary Trunk with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021748Q" = '1' /*Bypass Left Atrium to Right Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021748R" = '1' /*Bypass Left Atrium to Left Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021749P" = '1' /*Bypass Left Atrium to Pulmonary Trunk withAutologous Venous Tissue, Percutaneous EndoscopicApproach */
"021749Q" = '1' /*Bypass Left Atrium to Right Pulmonary Artery withAutologous Venous Tissue, Percutaneous EndoscopicApproach */
"021749R" = '1' /*Bypass Left Atrium to Left Pulmonary Artery withAutologous Venous Tissue, Percutaneous EndoscopicApproach */
"021749S" = '1' /*Bypass Left Atrium to Right Pulmonary Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021749T" = '1' /*Bypass Left Atrium to Left Pulmonary Vein with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"021749U" = '1' /*Bypass Left Atrium to Pulmonary Vein Confluence with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"02174AP" = '1' /*Bypass Left Atrium to Pulmonary Trunk withAutologous Arterial Tissue, Percutaneous EndoscopicApproach */
"02174AQ" = '1' /*Bypass Left Atrium to Right Pulmonary Artery withAutologous Arterial Tissue, Percutaneous EndoscopicApproach */
"02174AR" = '1' /*Bypass Left Atrium to Left Pulmonary Artery withAutologous Arterial Tissue, Percutaneous EndoscopicApproach */
"02174AS" = '1' /*Bypass Left Atrium to Right Pulmonary Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02174AT" = '1' /*Bypass Left Atrium to Left Pulmonary Vein with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02174AU" = '1' /*Bypass Left Atrium to Pulmonary Vein Confluence with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"02174JP" = '1' /*Bypass Left Atrium to Pulmonary Trunk with SyntheticSubstitute, Percutaneous Endoscopic Approach */
"02174JQ" = '1' /*Bypass Left Atrium to Right Pulmonary Artery withSynthetic Substitute, Percutaneous EndoscopicApproach */
"02174JR" = '1' /*Bypass Left Atrium to Left Pulmonary Artery withSynthetic Substitute, Percutaneous EndoscopicApproach */
"02174JS" = '1' /*Bypass Left Atrium to Right Pulmonary Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02174JT" = '1' /*Bypass Left Atrium to Left Pulmonary Vein with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02174JU" = '1' /*Bypass Left Atrium to Pulmonary Vein Confluence with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02174KP" = '1' /*Bypass Left Atrium to Pulmonary Trunk withNonautologous Tissue Substitute, PercutaneousEndoscopic Approach */
"02174KQ" = '1' /*Bypass Left Atrium to Right Pulmonary Artery withNonautologous Tissue Substitute, PercutaneousEndoscopic Approach */
"02174KR" = '1' /*Bypass Left Atrium to Left Pulmonary Artery withNonautologous Tissue Substitute, PercutaneousEndoscopic Approach */
"02174KS" = '1' /*Bypass Left Atrium to Right Pulmonary Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02174KT" = '1' /*Bypass Left Atrium to Left Pulmonary Vein with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02174KU" = '1' /*Bypass Left Atrium to Pulmonary Vein Confluence with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02174ZP" = '1' /*Bypass Left Atrium to Pulmonary Trunk,Percutaneous Endoscopic Approach */
"02174ZQ" = '1' /*Bypass Left Atrium to Right Pulmonary Artery,Percutaneous Endoscopic Approach */
"02174ZR" = '1' /*Bypass Left Atrium to Left Pulmonary Artery,Percutaneous Endoscopic Approach */
"02174ZS" = '1' /*Bypass Left Atrium to Right Pulmonary Vein, Percutaneous Endoscopic Approach */
"02174ZT" = '1' /*Bypass Left Atrium to Left Pulmonary Vein, Percutaneous Endoscopic Approach */
"02174ZU" = '1' /*Bypass Left Atrium to Pulmonary Vein Confluence, Percutaneous Endoscopic Approach */
"021K08P" = '1' /*Bypass Right Ventricle to Pulmonary Trunk with Zooplastic Tissue, Open Approach */
"021K08Q" = '1' /*Bypass Right Ventricle to Right Pulmonary Artery with Zooplastic Tissue, Open Approach */
"021K08R" = '1' /*Bypass Right Ventricle to Left Pulmonary Artery with Zooplastic Tissue, Open Approach */
"021K09P" = '1' /*Bypass Right Ventricle to Pulmonary Trunk withAutologous Venous Tissue, Open Approach */
"021K09Q" = '1' /*Bypass Right Ventricle to Right Pulmonary Artery withAutologous Venous Tissue, Open Approach */
"021K09R" = '1' /*Bypass Right Ventricle to Left Pulmonary Artery withAutologous Venous Tissue, Open Approach */
"021K0AP" = '1' /*Bypass Right Ventricle to Pulmonary Trunk withAutologous Arterial Tissue, Open Approach */
"021K0AQ" = '1' /*Bypass Right Ventricle to Right Pulmonary Artery withAutologous Arterial Tissue, Open Approach */
"021K0AR" = '1' /*Bypass Right Ventricle to Left Pulmonary Artery withAutologous Arterial Tissue, Open Approach */
"021K0JP" = '1' /*Bypass Right Ventricle to Pulmonary Trunk withSynthetic Substitute, Open Approach */
"021K0JQ" = '1' /*Bypass Right Ventricle to Right Pulmonary Artery withSynthetic Substitute, Open Approach */
"021K0JR" = '1' /*Bypass Right Ventricle to Left Pulmonary Artery withSynthetic Substitute, Open Approach */
"021K0KP" = '1' /*Bypass Right Ventricle to Pulmonary Trunk withNonautologous Tissue Substitute, Open Approach */
"021K0KQ" = '1' /*Bypass Right Ventricle to Right Pulmonary Artery withNonautologous Tissue Substitute, Open Approach */
"021K0KR" = '1' /*Bypass Right Ventricle to Left Pulmonary Artery withNonautologous Tissue Substitute, Open Approach */
"021K0Z5" = '1' /*Bypass Right Ventricle to Coronary Circulation, OpenApproach */
"021K0Z8" = '1' /*Bypass Right Ventricle to Right Internal Mammary,Open Approach */
"021K0Z9" = '1' /*Bypass Right Ventricle to Left Internal Mammary,Open Approach */
"021K0ZC" = '1' /*Bypass Right Ventricle to Thoracic Artery, OpenApproach */
"021K0ZF" = '1' /*Bypass Right Ventricle to Abdominal Artery, OpenApproach */
"021K0ZP" = '1' /*Bypass Right Ventricle to Pulmonary Trunk, OpenApproach */
"021K0ZQ" = '1' /*Bypass Right Ventricle to Right Pulmonary Artery,Open Approach */
"021K0ZR" = '1' /*Bypass Right Ventricle to Left Pulmonary Artery,Open Approach */
"021K0ZW" = '1' /*Bypass Right Ventricle to Aorta, Open Approach */
"021K48P" = '1' /*Bypass Right Ventricle to Pulmonary Trunk with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021K48Q" = '1' /*Bypass Right Ventricle to Right Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021K48R" = '1' /*Bypass Right Ventricle to Left Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021K49P" = '1' /*Bypass Right Ventricle to Pulmonary Trunk withAutologous Venous Tissue, Percutaneous EndoscopicApproach */
"021K49Q" = '1' /*Bypass Right Ventricle to Right Pulmonary Artery withAutologous Venous Tissue, Percutaneous EndoscopicApproach */
"021K49R" = '1' /*Bypass Right Ventricle to Left Pulmonary Artery withAutologous Venous Tissue, Percutaneous EndoscopicApproach */
"021K4AP" = '1' /*Bypass Right Ventricle to Pulmonary Trunk withAutologous Arterial Tissue, Percutaneous EndoscopicApproach */
"021K4AQ" = '1' /*Bypass Right Ventricle to Right Pulmonary Artery withAutologous Arterial Tissue, Percutaneous EndoscopicApproach */
"021K4AR" = '1' /*Bypass Right Ventricle to Left Pulmonary Artery withAutologous Arterial Tissue, Percutaneous EndoscopicApproach */
"021K4JP" = '1' /*Bypass Right Ventricle to Pulmonary Trunk withSynthetic Substitute, Percutaneous EndoscopicApproach */
"021K4JQ" = '1' /*Bypass Right Ventricle to Right Pulmonary Artery withSynthetic Substitute, Percutaneous EndoscopicApproach */
"021K4JR" = '1' /*Bypass Right Ventricle to Left Pulmonary Artery withSynthetic Substitute, Percutaneous EndoscopicApproach */
"021K4KP" = '1' /*Bypass Right Ventricle to Pulmonary Trunk withNonautologous Tissue Substitute, PercutaneousEndoscopic Approach */
"021K4KQ" = '1' /*Bypass Right Ventricle to Right Pulmonary Artery withNonautologous Tissue Substitute, PercutaneousEndoscopic Approach */
"021K4KR" = '1' /*Bypass Right Ventricle to Left Pulmonary Artery withNonautologous Tissue Substitute, PercutaneousEndoscopic Approach */
"021K4Z5" = '1' /*Bypass Right Ventricle to Coronary Circulation,Percutaneous Endoscopic Approach */
"021K4Z8" = '1' /*Bypass Right Ventricle to Right Internal Mammary,Percutaneous Endoscopic Approach */
"021K4Z9" = '1' /*Bypass Right Ventricle to Left Internal Mammary,Percutaneous Endoscopic Approach */
"021K4ZC" = '1' /*Bypass Right Ventricle to Thoracic Artery,Percutaneous Endoscopic Approach */
"021K4ZF" = '1' /*Bypass Right Ventricle to Abdominal Artery,Percutaneous Endoscopic Approach */
"021K4ZP" = '1' /*Bypass Right Ventricle to Pulmonary Trunk,Percutaneous Endoscopic Approach */
"021K4ZQ" = '1' /*Bypass Right Ventricle to Right Pulmonary Artery,Percutaneous Endoscopic Approach */
"021K4ZR" = '1' /*Bypass Right Ventricle to Left Pulmonary Artery,Percutaneous Endoscopic Approach */
"021K4ZW" = '1' /*Bypass Right Ventricle to Aorta, PercutaneousEndoscopic Approach */
"021L08P" = '1' /*Bypass Left Ventricle to Pulmonary Trunk with Zooplastic Tissue, Open Approach */
"021L08Q" = '1' /*Bypass Left Ventricle to Right Pulmonary Artery with Zooplastic Tissue, Open Approach */
"021L08R" = '1' /*Bypass Left Ventricle to Left Pulmonary Artery with Zooplastic Tissue, Open Approach */
"021L09P" = '1' /*Bypass Left Ventricle to Pulmonary Trunk withAutologous Venous Tissue, Open Approach */
"021L09Q" = '1' /*Bypass Left Ventricle to Right Pulmonary Artery withAutologous Venous Tissue, Open Approach */
"021L09R" = '1' /*Bypass Left Ventricle to Left Pulmonary Artery withAutologous Venous Tissue, Open Approach */
"021L0AP" = '1' /*Bypass Left Ventricle to Pulmonary Trunk withAutologous Arterial Tissue, Open Approach */
"021L0AQ" = '1' /*Bypass Left Ventricle to Right Pulmonary Artery withAutologous Arterial Tissue, Open Approach */
"021L0AR" = '1' /*Bypass Left Ventricle to Left Pulmonary Artery withAutologous Arterial Tissue, Open Approach */
"021L0JP" = '1' /*Bypass Left Ventricle to Pulmonary Trunk withSynthetic Substitute, Open Approach */
"021L0JQ" = '1' /*Bypass Left Ventricle to Right Pulmonary Artery withSynthetic Substitute, Open Approach */
"021L0JR" = '1' /*Bypass Left Ventricle to Left Pulmonary Artery withSynthetic Substitute, Open Approach */
"021L0KP" = '1' /*Bypass Left Ventricle to Pulmonary Trunk withNonautologous Tissue Substitute, Open Approach */
"021L0KQ" = '1' /*Bypass Left Ventricle to Right Pulmonary Artery withNonautologous Tissue Substitute, Open Approach */
"021L0KR" = '1' /*Bypass Left Ventricle to Left Pulmonary Artery withNonautologous Tissue Substitute, Open Approach */
"021L0Z5" = '1' /*Bypass Left Ventricle to Coronary Circulation, OpenApproach */
"021L0Z8" = '1' /*Bypass Left Ventricle to Right Internal Mammary,Open Approach */
"021L0Z9" = '1' /*Bypass Left Ventricle to Left Internal Mammary, OpenApproach */
"021L0ZC" = '1' /*Bypass Left Ventricle to Thoracic Artery, OpenApproach */
"021L0ZF" = '1' /*Bypass Left Ventricle to Abdominal Artery, OpenApproach */
"021L0ZP" = '1' /*Bypass Left Ventricle to Pulmonary Trunk, OpenApproach */
"021L0ZQ" = '1' /*Bypass Left Ventricle to Right Pulmonary Artery,Open Approach */
"021L0ZR" = '1' /*Bypass Left Ventricle to Left Pulmonary Artery, OpenApproach */
"021L0ZW" = '1' /*Bypass Left Ventricle to Aorta, Open Approach */
"021L48P" = '1' /*Bypass Left Ventricle to Pulmonary Trunk with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021L48Q" = '1' /*Bypass Left Ventricle to Right Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021L48R" = '1' /*Bypass Left Ventricle to Left Pulmonary Artery with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"021L49P" = '1' /*Bypass Left Ventricle to Pulmonary Trunk withAutologous Venous Tissue, Percutaneous EndoscopicApproach */
"021L49Q" = '1' /*Bypass Left Ventricle to Right Pulmonary Artery withAutologous Venous Tissue, Percutaneous EndoscopicApproach */
"021L49R" = '1' /*Bypass Left Ventricle to Left Pulmonary Artery withAutologous Venous Tissue, Percutaneous EndoscopicApproach */
"021L4AP" = '1' /*Bypass Left Ventricle to Pulmonary Trunk withAutologous Arterial Tissue, Percutaneous EndoscopicApproach */
"021L4AQ" = '1' /*Bypass Left Ventricle to Right Pulmonary Artery withAutologous Arterial Tissue, Percutaneous EndoscopicApproach */
"021L4AR" = '1' /*Bypass Left Ventricle to Left Pulmonary Artery withAutologous Arterial Tissue, Percutaneous EndoscopicApproach */
"021L4JP" = '1' /*Bypass Left Ventricle to Pulmonary Trunk withSynthetic Substitute, Percutaneous EndoscopicApproach */
"021L4JQ" = '1' /*Bypass Left Ventricle to Right Pulmonary Artery withSynthetic Substitute, Percutaneous EndoscopicApproach */
"021L4JR" = '1' /*Bypass Left Ventricle to Left Pulmonary Artery withSynthetic Substitute, Percutaneous EndoscopicApproach */
"021L4KP" = '1' /*Bypass Left Ventricle to Pulmonary Trunk withNonautologous Tissue Substitute, PercutaneousEndoscopic Approach */
"021L4KQ" = '1' /*Bypass Left Ventricle to Right Pulmonary Artery withNonautologous Tissue Substitute, PercutaneousEndoscopic Approach */
"021L4KR" = '1' /*Bypass Left Ventricle to Left Pulmonary Artery withNonautologous Tissue Substitute, PercutaneousEndoscopic Approach */
"021L4Z5" = '1' /*Bypass Left Ventricle to Coronary Circulation,Percutaneous Endoscopic Approach */
"021L4Z8" = '1' /*Bypass Left Ventricle to Right Internal Mammary,Percutaneous Endoscopic Approach */
"021L4Z9" = '1' /*Bypass Left Ventricle to Left Internal Mammary,Percutaneous Endoscopic Approach */
"021L4ZC" = '1' /*Bypass Left Ventricle to Thoracic Artery,Percutaneous Endoscopic Approach */
"021L4ZF" = '1' /*Bypass Left Ventricle to Abdominal Artery,Percutaneous Endoscopic Approach */
"021L4ZP" = '1' /*Bypass Left Ventricle to Pulmonary Trunk,Percutaneous Endoscopic Approach */
"021L4ZQ" = '1' /*Bypass Left Ventricle to Right Pulmonary Artery,Percutaneous Endoscopic Approach */
"021L4ZR" = '1' /*Bypass Left Ventricle to Left Pulmonary Artery,Percutaneous Endoscopic Approach */
"021L4ZW" = '1' /*Bypass Left Ventricle to Aorta, PercutaneousEndoscopic Approach */
"024F07J" = '1' /*Creation of Aortic Valve from Truncal Valve using Autologous Tissue Substitute, Open Approach */
"024F08J" = '1' /*Creation of Aortic Valve from Truncal Valve using Zooplastic Tissue, Open Approach */
"024F0JJ" = '1' /*Creation of Aortic Valve from Truncal Valve using Synthetic Substitute, Open Approach */
"024F0KJ" = '1' /*Creation of Aortic Valve from Truncal Valve using Nonautologous Tissue Substitute, Open Approach */
"024G072" = '1' /*Creation of Mitral Valve from Common Atrioventricular Valve using Autologous Tissue Substitute, Open Approach */
"024G082" = '1' /*Creation of Mitral Valve from Common Atrioventricular Valve using Zooplastic Tissue, Open Approach */
"024G0J2" = '1' /*Creation of Mitral Valve from Common Atrioventricular Valve using Synthetic Substitute, Open Approach */
"024G0K2" = '1' /*Creation of Mitral Valve from Common Atrioventricular Valve using Nonautologous Tissue Substitute, Open Approach */
"024J072" = '1' /*Creation of Tricuspid Valve from Common Atrioventricular Valve using Autologous Tissue Substitute, Open Approach */
"024J082" = '1' /*Creation of Tricuspid Valve from Common Atrioventricular Valve using Zooplastic Tissue, Open Approach */
"024J0J2" = '1' /*Creation of Tricuspid Valve from Common Atrioventricular Valve using Synthetic Substitute, Open Approach */
"024J0K2" = '1' /*Creation of Tricuspid Valve from Common Atrioventricular Valve using Nonautologous Tissue Substitute, Open Approach */
"02540ZZ" = '1' /*Destruction of Coronary Vein, Open Approach */
"02543ZZ" = '1' /*Destruction of Coronary Vein, PercutaneousApproach */
"02544ZZ" = '1' /*Destruction of Coronary Vein, PercutaneousEndoscopic Approach */
"02550ZZ" = '1' /*Destruction of Atrial Septum, Open Approach */
"02553ZZ" = '1' /*Destruction of Atrial Septum, Percutaneous Approach */
"02554ZZ" = '1' /*Destruction of Atrial Septum, PercutaneousEndoscopic Approach */
"02560ZZ" = '1' /*Destruction of Right Atrium, Open Approach */
"02563ZZ" = '1' /*Destruction of Right Atrium, Percutaneous Approach */
"02564ZZ" = '1' /*Destruction of Right Atrium, PercutaneousEndoscopic Approach */
"02570ZK" = '1' /*Destruction of Left Atrial Appendage, Open Approach */
"02570ZZ" = '1' /*Destruction of Left Atrium, Open Approach */
"02573ZK" = '1' /*Destruction of Left Atrial Appendage, PercutaneousApproach */
"02573ZZ" = '1' /*Destruction of Left Atrium, Percutaneous Approach */
"02574ZK" = '1' /*Destruction of Left Atrial Appendage, PercutaneousEndoscopic Approach */
"02574ZZ" = '1' /*Destruction of Left Atrium, Percutaneous EndoscopicApproach */
"02580ZZ" = '1' /*Destruction of Conduction Mechanism, OpenApproach */
"02583ZZ" = '1' /*Destruction of Conduction Mechanism, PercutaneousApproach */
"02584ZZ" = '1' /*Destruction of Conduction Mechanism, PercutaneousEndoscopic Approach */
"02590ZZ" = '1' /*Destruction of Chordae Tendineae, Open Approach */
"02593ZZ" = '1' /*Destruction of Chordae Tendineae, PercutaneousApproach */
"02594ZZ" = '1' /*Destruction of Chordae Tendineae, PercutaneousEndoscopic Approach */
"025D0ZZ" = '1' /*Destruction of Papillary Muscle, Open Approach */
"025D3ZZ" = '1' /*Destruction of Papillary Muscle, PercutaneousApproach */
"025D4ZZ" = '1' /*Destruction of Papillary Muscle, PercutaneousEndoscopic Approach */
"025F0ZZ" = '1' /*Destruction of Aortic Valve, Open Approach */
"025F3ZZ" = '1' /*Destruction of Aortic Valve, Percutaneous Approach */
"025F4ZZ" = '1' /*Destruction of Aortic Valve, Percutaneous EndoscopicApproach */
"025G0ZZ" = '1' /*Destruction of Mitral Valve, Open Approach */
"025G3ZZ" = '1' /*Destruction of Mitral Valve, Percutaneous Approach */
"025G4ZZ" = '1' /*Destruction of Mitral Valve, Percutaneous EndoscopicApproach */
"025H0ZZ" = '1' /*Destruction of Pulmonary Valve, Open Approach */
"025H3ZZ" = '1' /*Destruction of Pulmonary Valve, PercutaneousApproach */
"025H4ZZ" = '1' /*Destruction of Pulmonary Valve, PercutaneousEndoscopic Approach */
"025J0ZZ" = '1' /*Destruction of Tricuspid Valve, Open Approach */
"025J3ZZ" = '1' /*Destruction of Tricuspid Valve, PercutaneousApproach */
"025J4ZZ" = '1' /*Destruction of Tricuspid Valve, PercutaneousEndoscopic Approach */
"025K0ZZ" = '1' /*Destruction of Right Ventricle, Open Approach */
"025K3ZZ" = '1' /*Destruction of Right Ventricle, PercutaneousApproach */
"025K4ZZ" = '1' /*Destruction of Right Ventricle, PercutaneousEndoscopic Approach */
"025L0ZZ" = '1' /*Destruction of Left Ventricle, Open Approach */
"025L3ZZ" = '1' /*Destruction of Left Ventricle, Percutaneous Approach */
"025L4ZZ" = '1' /*Destruction of Left Ventricle, PercutaneousEndoscopic Approach */
"025M0ZZ" = '1' /*Destruction of Ventricular Septum, Open Approach */
"025M3ZZ" = '1' /*Destruction of Ventricular Septum, PercutaneousApproach */
"025M4ZZ" = '1' /*Destruction of Ventricular Septum, PercutaneousEndoscopic Approach */
"025N0ZZ" = '1' /*Destruction of Pericardium, Open Approach */
"025N3ZZ" = '1' /*Destruction of Pericardium, Percutaneous Approach */
"025N4ZZ" = '1' /*Destruction of Pericardium, Percutaneous EndoscopicApproach */
"0270046" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"027004Z" = '1' /*Dilation of Coronary Artery, One Artery with Drug-eluting Intraluminal Device, Percutaneous Approach */
"0270056" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"027005Z" = '1' /*Dilation of Coronary Artery, One Artery with Two Drug-eluting Intraluminal Devices, Open Approach */
"0270066" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"027006Z" = '1' /*Dilation of Coronary Artery, One Artery with Three Drug-eluting Intraluminal Devices, Open Approach */
"0270076" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"027007Z" = '1' /*Dilation of Coronary Artery, One Artery with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"02700D6" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"02700DZ" = '1' /*Dilation of Coronary Artery, One Artery with Intraluminal Device, Percutaneous Approach */
"02700E6" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Two Intraluminal Devices, Open Approach */
"02700EZ" = '1' /*Dilation of Coronary Artery, One Artery with Two Intraluminal Devices, Open Approach */
"02700F6" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Three Intraluminal Devices, Open Approach */
"02700FZ" = '1' /*Dilation of Coronary Artery, One Artery with Three Intraluminal Devices, Open Approach */
"02700G6" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"02700GZ" = '1' /*Dilation of Coronary Artery, One Artery with Four or More Intraluminal Devices, Open Approach */
"02700T6" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Radioactive Intraluminal Device, Percutaneous Approach */
"02700TZ" = '1' /*Dilation of Coronary Artery, One Artery with Radioactive Intraluminal Device, Percutaneous Approach */
"02700Z6" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, Percutaneous Approach */
"02700ZZ" = '1' /*Dilation of Coronary Artery, One Artery, Percutaneous Approach */
"0270346" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"027034Z" = '1' /*Dilation of Coronary Artery, One Artery with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0270356" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"027035Z" = '1' /*Dilation of Coronary Artery, One Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0270366" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"027036Z" = '1' /*Dilation of Coronary Artery, One Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0270376" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"027037Z" = '1' /*Dilation of Coronary Artery, One Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"02703D6" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"02703DZ" = '1' /*Dilation of Coronary Artery, One Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"02703E6" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"02703EZ" = '1' /*Dilation of Coronary Artery, One Artery with Two Intraluminal Devices, Percutaneous Approach */
"02703F6" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"02703FZ" = '1' /*Dilation of Coronary Artery, One Artery with Three Intraluminal Devices, Percutaneous Approach */
"02703G6" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"02703GZ" = '1' /*Dilation of Coronary Artery, One Artery with Four or More Intraluminal Devices, Percutaneous Approach */
"02703T6" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Radioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"02703TZ" = '1' /*Dilation of Coronary Artery, One Artery with Radioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"02703Z6" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, Percutaneous Endoscopic Approach */
"02703ZZ" = '1' /*Dilation of Coronary Artery, One Artery, Percutaneous Endoscopic Approach */
"0270446" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"027044Z" = '1' /*Dilation of Coronary Artery, Two Arteries with Drug-eluting Intraluminal Device, Open Approach */
"0270456" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"027045Z" = '1' /*Dilation of Coronary Artery, One Artery with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0270466" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"027046Z" = '1' /*Dilation of Coronary Artery, One Artery with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0270476" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"027047Z" = '1' /*Dilation of Coronary Artery, One Artery with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"02704D6" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Intraluminal Device, Open Approach */
"02704DZ" = '1' /*Dilation of Coronary Artery, Two Arteries with Intraluminal Device, Open Approach */
"02704E6" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"02704EZ" = '1' /*Dilation of Coronary Artery, One Artery with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"02704F6" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"02704FZ" = '1' /*Dilation of Coronary Artery, One Artery with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"02704G6" = '1' /*Dilation of Coronary Artery, One Artery, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"02704GZ" = '1' /*Dilation of Coronary Artery, One Artery with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"02704T6" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Radioactive Intraluminal Device, Open Approach */
"02704TZ" = '1' /*Dilation of Coronary Artery, Two Arteries with Radioactive Intraluminal Device, Open Approach */
"02704Z6" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, Open Approach */
"02704ZZ" = '1' /*Dilation of Coronary Artery, Two Arteries, Open Approach */
"0271046" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"027104Z" = '1' /*Dilation of Coronary Artery, Two Arteries with Drug-eluting Intraluminal Device, Percutaneous Approach */
"0271056" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"027105Z" = '1' /*Dilation of Coronary Artery, Two Arteries with Two Drug-eluting Intraluminal Devices, Open Approach */
"0271066" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"027106Z" = '1' /*Dilation of Coronary Artery, Two Arteries with Three Drug-eluting Intraluminal Devices, Open Approach */
"0271076" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"027107Z" = '1' /*Dilation of Coronary Artery, Two Arteries with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"02710D6" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"02710DZ" = '1' /*Dilation of Coronary Artery, Two Arteries with Intraluminal Device, Percutaneous Approach */
"02710E6" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Two Intraluminal Devices, Open Approach */
"02710EZ" = '1' /*Dilation of Coronary Artery, Two Arteries with Two Intraluminal Devices, Open Approach */
"02710F6" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Three Intraluminal Devices, Open Approach */
"02710FZ" = '1' /*Dilation of Coronary Artery, Two Arteries with Three Intraluminal Devices, Open Approach */
"02710G6" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"02710GZ" = '1' /*Dilation of Coronary Artery, Two Arteries with Four or More Intraluminal Devices, Open Approach */
"02710T6" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Radioactive Intraluminal Device, Percutaneous Approach */
"02710TZ" = '1' /*Dilation of Coronary Artery, Two Arteries with Radioactive Intraluminal Device, Percutaneous Approach */
"02710Z6" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, Percutaneous Approach */
"02710ZZ" = '1' /*Dilation of Coronary Artery, Two Arteries, Percutaneous Approach */
"0271346" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"027134Z" = '1' /*Dilation of Coronary Artery, Two Arteries with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0271356" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"027135Z" = '1' /*Dilation of Coronary Artery, Two Arteries with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0271366" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"027136Z" = '1' /*Dilation of Coronary Artery, Two Arteries with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0271376" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"027137Z" = '1' /*Dilation of Coronary Artery, Two Arteries with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"02713D6" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"02713DZ" = '1' /*Dilation of Coronary Artery, Two Arteries with Intraluminal Device, Percutaneous Endoscopic Approach */
"02713E6" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"02713EZ" = '1' /*Dilation of Coronary Artery, Two Arteries with Two Intraluminal Devices, Percutaneous Approach */
"02713F6" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"02713FZ" = '1' /*Dilation of Coronary Artery, Two Arteries with Three Intraluminal Devices, Percutaneous Approach */
"02713G6" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"02713GZ" = '1' /*Dilation of Coronary Artery, Two Arteries with Four or More Intraluminal Devices, Percutaneous Approach */
"02713T6" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Radioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"02713TZ" = '1' /*Dilation of Coronary Artery, Two Arteries with Radioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"02713Z6" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, Percutaneous Endoscopic Approach */
"02713ZZ" = '1' /*Dilation of Coronary Artery, Two Arteries, Percutaneous Endoscopic Approach */
"0271446" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"027144Z" = '1' /*Dilation of Coronary Artery, Three Arteries with Drug-eluting Intraluminal Device, Open Approach */
"0271456" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"027145Z" = '1' /*Dilation of Coronary Artery, Two Arteries with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0271466" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"027146Z" = '1' /*Dilation of Coronary Artery, Two Arteries with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0271476" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"027147Z" = '1' /*Dilation of Coronary Artery, Two Arteries with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"02714D6" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Intraluminal Device, Open Approach */
"02714DZ" = '1' /*Dilation of Coronary Artery, Three Arteries with Intraluminal Device, Open Approach */
"02714E6" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"02714EZ" = '1' /*Dilation of Coronary Artery, Two Arteries with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"02714F6" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"02714FZ" = '1' /*Dilation of Coronary Artery, Two Arteries with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"02714G6" = '1' /*Dilation of Coronary Artery, Two Arteries, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"02714GZ" = '1' /*Dilation of Coronary Artery, Two Arteries with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"02714T6" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Radioactive Intraluminal Device, Open Approach */
"02714TZ" = '1' /*Dilation of Coronary Artery, Three Arteries with Radioactive Intraluminal Device, Open Approach */
"02714Z6" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, Open Approach */
"02714ZZ" = '1' /*Dilation of Coronary Artery, Three Arteries, Open Approach */
"0272046" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"027204Z" = '1' /*Dilation of Coronary Artery, Three Arteries with Drug-eluting Intraluminal Device, Percutaneous Approach */
"0272056" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"027205Z" = '1' /*Dilation of Coronary Artery, Three Arteries with Two Drug-eluting Intraluminal Devices, Open Approach */
"0272066" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"027206Z" = '1' /*Dilation of Coronary Artery, Three Arteries with Three Drug-eluting Intraluminal Devices, Open Approach */
"0272076" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"027207Z" = '1' /*Dilation of Coronary Artery, Three Arteries with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"02720D6" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"02720DZ" = '1' /*Dilation of Coronary Artery, Three Arteries with Intraluminal Device, Percutaneous Approach */
"02720E6" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Two Intraluminal Devices, Open Approach */
"02720EZ" = '1' /*Dilation of Coronary Artery, Three Arteries with Two Intraluminal Devices, Open Approach */
"02720F6" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Three Intraluminal Devices, Open Approach */
"02720FZ" = '1' /*Dilation of Coronary Artery, Three Arteries with Three Intraluminal Devices, Open Approach */
"02720G6" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"02720GZ" = '1' /*Dilation of Coronary Artery, Three Arteries with Four or More Intraluminal Devices, Open Approach */
"02720T6" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Radioactive Intraluminal Device, Percutaneous Approach */
"02720TZ" = '1' /*Dilation of Coronary Artery, Three Arteries with Radioactive Intraluminal Device, Percutaneous Approach */
"02720Z6" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, Percutaneous Approach */
"02720ZZ" = '1' /*Dilation of Coronary Artery, Three Arteries, Percutaneous Approach */
"0272346" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"027234Z" = '1' /*Dilation of Coronary Artery, Three Arteries with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0272356" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"027235Z" = '1' /*Dilation of Coronary Artery, Three Arteries with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0272366" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"027236Z" = '1' /*Dilation of Coronary Artery, Three Arteries with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0272376" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"027237Z" = '1' /*Dilation of Coronary Artery, Three Arteries with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"02723D6" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"02723DZ" = '1' /*Dilation of Coronary Artery, Three Arteries with Intraluminal Device, Percutaneous Endoscopic Approach */
"02723E6" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"02723EZ" = '1' /*Dilation of Coronary Artery, Three Arteries with Two Intraluminal Devices, Percutaneous Approach */
"02723F6" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"02723FZ" = '1' /*Dilation of Coronary Artery, Three Arteries with Three Intraluminal Devices, Percutaneous Approach */
"02723G6" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"02723GZ" = '1' /*Dilation of Coronary Artery, Three Arteries with Four or More Intraluminal Devices, Percutaneous Approach */
"02723T6" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Radioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"02723TZ" = '1' /*Dilation of Coronary Artery, Three Arteries with Radioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"02723Z6" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, Percutaneous Endoscopic Approach */
"02723ZZ" = '1' /*Dilation of Coronary Artery, Three Arteries, Percutaneous Endoscopic Approach */
"0272446" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Drug-eluting Intraluminal Device, Open Approach */
"027244Z" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Drug-eluting Intraluminal Device, Open Approach */
"0272456" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"027245Z" = '1' /*Dilation of Coronary Artery, Three Arteries with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0272466" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"027246Z" = '1' /*Dilation of Coronary Artery, Three Arteries with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0272476" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"027247Z" = '1' /*Dilation of Coronary Artery, Three Arteries with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"02724D6" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Intraluminal Device, Open Approach */
"02724DZ" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Intraluminal Device, Open Approach */
"02724E6" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"02724EZ" = '1' /*Dilation of Coronary Artery, Three Arteries with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"02724F6" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"02724FZ" = '1' /*Dilation of Coronary Artery, Three Arteries with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"02724G6" = '1' /*Dilation of Coronary Artery, Three Arteries, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"02724GZ" = '1' /*Dilation of Coronary Artery, Three Arteries with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"02724T6" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Radioactive Intraluminal Device, Open Approach */
"02724TZ" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Radioactive Intraluminal Device, Open Approach */
"02724Z6" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, Open Approach */
"02724ZZ" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Open Approach */
"0273046" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"027304Z" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Drug-eluting Intraluminal Device, Percutaneous Approach */
"0273056" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Two Drug-eluting Intraluminal Devices, Open Approach */
"027305Z" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Two Drug-eluting Intraluminal Devices, Open Approach */
"0273066" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Three Drug-eluting Intraluminal Devices, Open Approach */
"027306Z" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Three Drug-eluting Intraluminal Devices, Open Approach */
"0273076" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"027307Z" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Four or More Drug-eluting Intraluminal Devices, Open Approach */
"02730D6" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"02730DZ" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Intraluminal Device, Percutaneous Approach */
"02730E6" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Two Intraluminal Devices, Open Approach */
"02730EZ" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Two Intraluminal Devices, Open Approach */
"02730F6" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Three Intraluminal Devices, Open Approach */
"02730FZ" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Three Intraluminal Devices, Open Approach */
"02730G6" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Four or More Intraluminal Devices, Open Approach */
"02730GZ" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Four or More Intraluminal Devices, Open Approach */
"02730T6" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Radioactive Intraluminal Device, Open Approach */
"02730TZ" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Radioactive Intraluminal Device, Open Approach */
"02730Z6" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, Open Approach */
"02730ZZ" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Open Approach */
"0273346" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Approach */
"027334Z" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Drug-eluting Intraluminal Device, Percutaneous Approach */
"0273356" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"027335Z" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Two Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0273366" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"027336Z" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Three Drug-eluting Intraluminal Devices, Percutaneous Approach */
"0273376" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"027337Z" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Four or More Drug-eluting Intraluminal Devices, Percutaneous Approach */
"02733D6" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Intraluminal Device, Percutaneous Approach */
"02733DZ" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Intraluminal Device, Percutaneous Approach */
"02733E6" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Two Intraluminal Devices, Percutaneous Approach */
"02733EZ" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Two Intraluminal Devices, Percutaneous Approach */
"02733F6" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Three Intraluminal Devices, Percutaneous Approach */
"02733FZ" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Three Intraluminal Devices, Percutaneous Approach */
"02733G6" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Approach */
"02733GZ" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Four or More Intraluminal Devices, Percutaneous Approach */
"02733T6" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Radioactive Intraluminal Device, Percutaneous Approach */
"02733TZ" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Radioactive Intraluminal Device, Percutaneous Approach */
"02733Z6" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, Percutaneous Approach */
"02733ZZ" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Percutaneous Approach */
"0273446" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"027344Z" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Drug-eluting Intraluminal Device, Percutaneous Endoscopic Approach */
"0273456" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"027345Z" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Two Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0273466" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"027346Z" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Three Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"0273476" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"027347Z" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Four or More Drug-eluting Intraluminal Devices, Percutaneous Endoscopic Approach */
"02734D6" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Intraluminal Device, Percutaneous Endoscopic Approach */
"02734DZ" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Intraluminal Device, Percutaneous Endoscopic Approach */
"02734E6" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"02734EZ" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Two Intraluminal Devices, Percutaneous Endoscopic Approach */
"02734F6" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"02734FZ" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Three Intraluminal Devices, Percutaneous Endoscopic Approach */
"02734G6" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"02734GZ" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Four or More Intraluminal Devices, Percutaneous Endoscopic Approach */
"02734T6" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, with Radioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"02734TZ" = '1' /*Dilation of Coronary Artery, Four or More Arteries with Radioactive Intraluminal Device, Percutaneous Endoscopic Approach */
"02734Z6" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Bifurcation, Percutaneous Endoscopic Approach */
"02734ZZ" = '1' /*Dilation of Coronary Artery, Four or More Arteries, Percutaneous Endoscopic Approach */
"027F04Z" = '1' /*Dilation of Aortic Valve with Drug-eluting IntraluminalDevice, Open Approach */
"027F0DZ" = '1' /*Dilation of Aortic Valve with Intraluminal Device, OpenApproach */
"027F0ZZ" = '1' /*Dilation of Aortic Valve, Open Approach */
"027F34Z" = '1' /*Dilation of Aortic Valve with Drug-eluting IntraluminalDevice, Percutaneous Approach */
"027F3DZ" = '1' /*Dilation of Aortic Valve with Intraluminal Device,Percutaneous Approach */
"027F3ZZ" = '1' /*Dilation of Aortic Valve, Percutaneous Approach */
"027F44Z" = '1' /*Dilation of Aortic Valve with Drug-eluting IntraluminalDevice, Percutaneous Endoscopic Approach */
"027F4DZ" = '1' /*Dilation of Aortic Valve with Intraluminal Device,Percutaneous Endoscopic Approach */
"027F4ZZ" = '1' /*Dilation of Aortic Valve, Percutaneous EndoscopicApproach */
"027G04Z" = '1' /*Dilation of Mitral Valve with Drug-eluting IntraluminalDevice, Open Approach */
"027G0DZ" = '1' /*Dilation of Mitral Valve with Intraluminal Device, OpenApproach */
"027G0ZZ" = '1' /*Dilation of Mitral Valve, Open Approach */
"027G34Z" = '1' /*Dilation of Mitral Valve with Drug-eluting IntraluminalDevice, Percutaneous Approach */
"027G3DZ" = '1' /*Dilation of Mitral Valve with Intraluminal Device,Percutaneous Approach */
"027G3ZZ" = '1' /*Dilation of Mitral Valve, Percutaneous Approach */
"027G44Z" = '1' /*Dilation of Mitral Valve with Drug-eluting IntraluminalDevice, Percutaneous Endoscopic Approach */
"027G4DZ" = '1' /*Dilation of Mitral Valve with Intraluminal Device,Percutaneous Endoscopic Approach */
"027G4ZZ" = '1' /*Dilation of Mitral Valve, Percutaneous EndoscopicApproach */
"027H04Z" = '1' /*Dilation of Pulmonary Valve with Drug-elutingIntraluminal Device, Open Approach */
"027H0DZ" = '1' /*Dilation of Pulmonary Valve with Intraluminal Device,Open Approach */
"027H0ZZ" = '1' /*Dilation of Pulmonary Valve, Open Approach */
"027H34Z" = '1' /*Dilation of Pulmonary Valve with Drug-elutingIntraluminal Device, Percutaneous Approach */
"027H3DZ" = '1' /*Dilation of Pulmonary Valve with Intraluminal Device,Percutaneous Approach */
"027H3ZZ" = '1' /*Dilation of Pulmonary Valve, Percutaneous Approach */
"027H44Z" = '1' /*Dilation of Pulmonary Valve with Drug-elutingIntraluminal Device, Percutaneous EndoscopicApproach */
"027H4DZ" = '1' /*Dilation of Pulmonary Valve with Intraluminal Device,Percutaneous Endoscopic Approach */
"027H4ZZ" = '1' /*Dilation of Pulmonary Valve, PercutaneousEndoscopic Approach */
"027J04Z" = '1' /*Dilation of Tricuspid Valve with Drug-elutingIntraluminal Device, Open Approach */
"027J0DZ" = '1' /*Dilation of Tricuspid Valve with Intraluminal Device,Open Approach */
"027J0ZZ" = '1' /*Dilation of Tricuspid Valve, Open Approach */
"027J34Z" = '1' /*Dilation of Tricuspid Valve with Drug-elutingIntraluminal Device, Percutaneous Approach */
"027J3DZ" = '1' /*Dilation of Tricuspid Valve with Intraluminal Device,Percutaneous Approach */
"027J3ZZ" = '1' /*Dilation of Tricuspid Valve, Percutaneous Approach */
"027J44Z" = '1' /*Dilation of Tricuspid Valve with Drug-elutingIntraluminal Device, Percutaneous EndoscopicApproach */
"027J4DZ" = '1' /*Dilation of Tricuspid Valve with Intraluminal Device,Percutaneous Endoscopic Approach */
"027J4ZZ" = '1' /*Dilation of Tricuspid Valve, Percutaneous EndoscopicApproach */
"027K04Z" = '1' /*Dilation of Right Ventricle with Drug-elutingIntraluminal Device, Open Approach */
"027K0DZ" = '1' /*Dilation of Right Ventricle with IntraluminalDevice, Open Approach */
"027K0ZZ" = '1' /*Dilation of Right Ventricle, Open Approach */
"027K44Z" = '1' /*Dilation of Right Ventricle with Drug-elutingIntraluminal Device, PercutaneousEndoscopic Approach */
"027K4DZ" = '1' /*Dilation of Right Ventricle with IntraluminalDevice, Percutaneous Endoscopic Approach */
"027K4ZZ" = '1' /*Dilation of Right Ventricle, PercutaneousEndoscopic Approach */
"027R04T" = '1' /*Dilation of Ductus Arteriosus withDrug-eluting Intraluminal Device, OpenApproach */
"027R0DT" = '1' /*Dilation of Ductus Arteriosus withIntraluminal Device, Open Approach */
"027R0ZT" = '1' /*Dilation of Ductus Arteriosus, OpenApproach */
"027R44T" = '1' /*Dilation of Ductus Arteriosus withDrug-eluting Intraluminal Device,Percutaneous Endoscopic Approach */
"027R4DT" = '1' /*Dilation of Ductus Arteriosus withIntraluminal Device, PercutaneousEndoscopic Approach */
"027R4ZT" = '1' /*Dilation of Ductus Arteriosus, PercutaneousEndoscopic Approach */
"02890ZZ" = '1' /*Division of Chordae Tendineae, Open Approach */
"02893ZZ" = '1' /*Division of Chordae Tendineae, PercutaneousApproach */
"02894ZZ" = '1' /*Division of Chordae Tendineae, PercutaneousEndoscopic Approach */
"028D0ZZ" = '1' /*Division of Papillary Muscle, Open Approach */
"028D3ZZ" = '1' /*Division of Papillary Muscle, Percutaneous Approach */
"028D4ZZ" = '1' /*Division of Papillary Muscle, PercutaneousEndoscopic Approach */
"02B40ZZ" = '1' /*Excision of Coronary Vein, Open Approach */
"02B43ZZ" = '1' /*Excision of Coronary Vein, Percutaneous Approach */
"02B44ZZ" = '1' /*Excision of Coronary Vein, Percutaneous EndoscopicApproach */
"02B50ZZ" = '1' /*Excision of Atrial Septum, Open Approach */
"02B53ZZ" = '1' /*Excision of Atrial Septum, Percutaneous Approach */
"02B54ZZ" = '1' /*Excision of Atrial Septum, Percutaneous EndoscopicApproach */
"02B60ZZ" = '1' /*Excision of Right Atrium, Open Approach */
"02B63ZZ" = '1' /*Excision of Right Atrium, Percutaneous Approach */
"02B64ZZ" = '1' /*Excision of Right Atrium, Percutaneous EndoscopicApproach */
"02B70ZK" = '1' /*Excision of Left Atrial Appendage, Open Approach */
"02B70ZZ" = '1' /*Excision of Left Atrium, Open Approach */
"02B73ZK" = '1' /*Excision of Left Atrial Appendage, PercutaneousApproach */
"02B73ZZ" = '1' /*Excision of Left Atrium, Percutaneous Approach */
"02B74ZK" = '1' /*Excision of Left Atrial Appendage, PercutaneousEndoscopic Approach */
"02B74ZZ" = '1' /*Excision of Left Atrium, Percutaneous EndoscopicApproach */
"02B80ZZ" = '1' /*Excision of Conduction Mechanism, Open Approach */
"02B83ZZ" = '1' /*Excision of Conduction Mechanism, PercutaneousApproach */
"02B84ZZ" = '1' /*Excision of Conduction Mechanism, PercutaneousEndoscopic Approach */
"02B90ZZ" = '1' /*Excision of Chordae Tendineae, Open Approach */
"02B93ZZ" = '1' /*Excision of Chordae Tendineae, PercutaneousApproach */
"02B94ZZ" = '1' /*Excision of Chordae Tendineae, PercutaneousEndoscopic Approach */
"02BD0ZZ" = '1' /*Excision of Papillary Muscle, Open Approach */
"02BD3ZZ" = '1' /*Excision of Papillary Muscle, Percutaneous Approach */
"02BD4ZZ" = '1' /*Excision of Papillary Muscle, PercutaneousEndoscopic Approach */
"02BF0ZZ" = '1' /*Excision of Aortic Valve, Open Approach */
"02BF3ZZ" = '1' /*Excision of Aortic Valve, Percutaneous Approach */
"02BF4ZZ" = '1' /*Excision of Aortic Valve, Percutaneous EndoscopicApproach */
"02BG0ZZ" = '1' /*Excision of Mitral Valve, Open Approach */
"02BG3ZZ" = '1' /*Excision of Mitral Valve, Percutaneous Approach */
"02BG4ZZ" = '1' /*Excision of Mitral Valve, Percutaneous EndoscopicApproach */
"02BH0ZZ" = '1' /*Excision of Pulmonary Valve, Open Approach */
"02BH3ZZ" = '1' /*Excision of Pulmonary Valve, Percutaneous Approach */
"02BH4ZZ" = '1' /*Excision of Pulmonary Valve, PercutaneousEndoscopic Approach */
"02BJ0ZZ" = '1' /*Excision of Tricuspid Valve, Open Approach */
"02BJ3ZZ" = '1' /*Excision of Tricuspid Valve, Percutaneous Approach */
"02BJ4ZZ" = '1' /*Excision of Tricuspid Valve, Percutaneous EndoscopicApproach */
"02BK0ZZ" = '1' /*Excision of Right Ventricle, Open Approach */
"02BK3ZZ" = '1' /*Excision of Right Ventricle, Percutaneous Approach */
"02BK4ZZ" = '1' /*Excision of Right Ventricle, Percutaneous EndoscopicApproach */
"02BL0ZZ" = '1' /*Excision of Left Ventricle, Open Approach */
"02BL3ZZ" = '1' /*Excision of Left Ventricle, Percutaneous Approach */
"02BL4ZZ" = '1' /*Excision of Left Ventricle, Percutaneous EndoscopicApproach */
"02BM0ZZ" = '1' /*Excision of Ventricular Septum, Open Approach */
"02BM3ZZ" = '1' /*Excision of Ventricular Septum, PercutaneousApproach */
"02BM4ZZ" = '1' /*Excision of Ventricular Septum, PercutaneousEndoscopic Approach */
"02BN0ZZ" = '1' /*Excision of Pericardium, Open Approach */
"02BN3ZZ" = '1' /*Excision of Pericardium, Percutaneous Approach */
"02BN4ZZ" = '1' /*Excision of Pericardium, Percutaneous EndoscopicApproach */
"02C00Z6" = '1' /*Extirpation of Matter from Coronary Artery, One Artery, Bifurcation, Open Approach */
"02C00ZZ" = '1' /*Extirpation of Matter from Coronary Artery, One Artery, Open Approach */
"02C03Z6" = '1' /*Extirpation of Matter from Coronary Artery, One Artery, Bifurcation, Percutaneous Approach */
"02C03ZZ" = '1' /*Extirpation of Matter from Coronary Artery, One Artery, Percutaneous Approach */
"02C04Z6" = '1' /*Extirpation of Matter from Coronary Artery, One Artery, Bifurcation, Percutaneous Endoscopic Approach */
"02C04ZZ" = '1' /*Extirpation of Matter from Coronary Artery, One Artery, Percutaneous Endoscopic Approach */
"02C10Z6" = '1' /*Extirpation of Matter from Coronary Artery, Two Arteries, Bifurcation, Open Approach */
"02C10ZZ" = '1' /*Extirpation of Matter from Coronary Artery, Two Arteries, Open Approach */
"02C13Z6" = '1' /*Extirpation of Matter from Coronary Artery, Two Arteries, Bifurcation, Percutaneous Approach */
"02C13ZZ" = '1' /*Extirpation of Matter from Coronary Artery, Two Arteries, Percutaneous Approach */
"02C14Z6" = '1' /*Extirpation of Matter from Coronary Artery, Two Arteries, Bifurcation, Percutaneous Endoscopic Approach */
"02C14ZZ" = '1' /*Extirpation of Matter from Coronary Artery, Two Arteries, Percutaneous Endoscopic Approach */
"02C20Z6" = '1' /*Extirpation of Matter from Coronary Artery, Three Arteries, Bifurcation, Open Approach */
"02C20ZZ" = '1' /*Extirpation of Matter from Coronary Artery, Three Arteries, Open Approach */
"02C23Z6" = '1' /*Extirpation of Matter from Coronary Artery, Three Arteries, Bifurcation, Percutaneous Approach */
"02C23ZZ" = '1' /*Extirpation of Matter from Coronary Artery, Three Arteries, Percutaneous Approach */
"02C24Z6" = '1' /*Extirpation of Matter from Coronary Artery, Three Arteries, Bifurcation, Percutaneous Endoscopic Approach */
"02C24ZZ" = '1' /*Extirpation of Matter from Coronary Artery, Three Arteries, Percutaneous Endoscopic Approach */
"02C30Z6" = '1' /*Extirpation of Matter from Coronary Artery, Four or More Arteries, Bifurcation, Open Approach */
"02C30ZZ" = '1' /*Extirpation of Matter from Coronary Artery, Four or More Arteries, Open Approach */
"02C33Z6" = '1' /*Extirpation of Matter from Coronary Artery, Four or More Arteries, Bifurcation, Percutaneous Approach */
"02C33ZZ" = '1' /*Extirpation of Matter from Coronary Artery, Four or More Arteries, Percutaneous Approach */
"02C34Z6" = '1' /*Extirpation of Matter from Coronary Artery, Four or More Arteries, Bifurcation, Percutaneous Endoscopic Approach */
"02C34ZZ" = '1' /*Extirpation of Matter from Coronary Artery, Four or More Arteries, Percutaneous Endoscopic Approach */
"02C40ZZ" = '1' /*Extirpation of Matter from Coronary Vein, OpenApproach */
"02C43ZZ" = '1' /*Extirpation of Matter from Coronary Vein, Percutaneous Approach */
"02C44ZZ" = '1' /*Extirpation of Matter from Coronary Vein,Percutaneous Endoscopic Approach */
"02C50ZZ" = '1' /*Extirpation of Matter from Atrial Septum, OpenApproach */
"02C53ZZ" = '1' /*Extirpation of Matter from Atrial Septum,Percutaneous Approach */
"02C54ZZ" = '1' /*Extirpation of Matter from Atrial Septum,Percutaneous Endoscopic Approach */
"02C60ZZ" = '1' /*Extirpation of Matter from Right Atrium,Open Approach */
"02C64ZZ" = '1' /*Extirpation of Matter from Right Atrium,Percutaneous Endoscopic Approach */
"02C70ZZ" = '1' /*Extirpation of Matter from Left Atrium, OpenApproach */
"02C74ZZ" = '1' /*Extirpation of Matter from Left Atrium,Percutaneous Endoscopic Approach */
"02C80ZZ" = '1' /*Extirpation of Matter from ConductionMechanism, Open Approach */
"02C84ZZ" = '1' /*Extirpation of Matter from ConductionMechanism, Percutaneous EndoscopicApproach */
"02C90ZZ" = '1' /*Extirpation of Matter from ChordaeTendineae, Open Approach */
"02C94ZZ" = '1' /*Extirpation of Matter from ChordaeTendineae, Percutaneous EndoscopicApproach */
"02CD0ZZ" = '1' /*Extirpation of Matter from Papillary Muscle, OpenApproach */
"02CD3ZZ" = '1' /*Extirpation of Matter from Papillary Muscle,Percutaneous Approach */
"02CD4ZZ" = '1' /*Extirpation of Matter from Papillary Muscle,Percutaneous Endoscopic Approach */
"02CF0ZZ" = '1' /*Extirpation of Matter from Aortic Valve, OpenApproach */
"02CF3ZZ" = '1' /*Extirpation of Matter from Aortic Valve, PercutaneousApproach */
"02CF4ZZ" = '1' /*Extirpation of Matter from Aortic Valve, PercutaneousEndoscopic Approach */
"02CG0ZZ" = '1' /*Extirpation of Matter from Mitral Valve, OpenApproach */
"02CG3ZZ" = '1' /*Extirpation of Matter from Mitral Valve, PercutaneousApproach */
"02CG4ZZ" = '1' /*Extirpation of Matter from Mitral Valve, PercutaneousEndoscopic Approach */
"02CH0ZZ" = '1' /*Extirpation of Matter from Pulmonary Valve, OpenApproach */
"02CH3ZZ" = '1' /*Extirpation of Matter from Pulmonary Valve,Percutaneous Approach */
"02CH4ZZ" = '1' /*Extirpation of Matter from Pulmonary Valve,Percutaneous Endoscopic Approach */
"02CJ0ZZ" = '1' /*Extirpation of Matter from Tricuspid Valve, OpenApproach */
"02CJ3ZZ" = '1' /*Extirpation of Matter from Tricuspid Valve,Percutaneous Approach */
"02CJ4ZZ" = '1' /*Extirpation of Matter from Tricuspid Valve,Percutaneous Endoscopic Approach */
"02CK0ZZ" = '1' /*Extirpation of Matter from Right Ventricle,Open Approach */
"02CK4ZZ" = '1' /*Extirpation of Matter from Right Ventricle,Percutaneous Endoscopic Approach */
"02CL0ZZ" = '1' /*Extirpation of Matter from Left Ventricle,Open Approach */
"02CL4ZZ" = '1' /*Extirpation of Matter from Left Ventricle,Percutaneous Endoscopic Approach */
"02CM0ZZ" = '1' /*Extirpation of Matter from Ventricular Septum, OpenApproach */
"02CM3ZZ" = '1' /*Extirpation of Matter from Ventricular Septum,Percutaneous Approach */
"02CM4ZZ" = '1' /*Extirpation of Matter from Ventricular Septum,Percutaneous Endoscopic Approach */
"02CN0ZZ" = '1' /*Extirpation of Matter from Pericardium, OpenApproach */
"02H400Z" = '1' /*Insertion of Pressure Sensor Monitoring Device intoCoronary Vein, Open Approach */
"02H402Z" = '1' /*Insertion of Monitoring Device into Coronary Vein,Open Approach */
"02H403Z" = '1' /*Insertion of Infusion Device into Coronary Vein, OpenApproach */
"02H40DZ" = '1' /*Insertion of Intraluminal Device into Coronary Vein,Open Approach */
"02H40JZ" = '1' /*Insertion of Pacemaker Lead into Coronary Vein,Open Approach */
"02H40KZ" = '1' /*Insertion of Defibrillator Lead into Coronary Vein,Open Approach */
"02H40MZ" = '1' /*Insertion of Cardiac Lead into Coronary Vein, OpenApproach */
"02H40NZ" = '1' /*Insertion of Intracardiac Pacemaker into Coronary Vein, Open Approach */
"02H430Z" = '1' /*Insertion of Pressure Sensor Monitoring Device intoCoronary Vein, Percutaneous Approach */
"02H432Z" = '1' /*Insertion of Monitoring Device into Coronary Vein,Percutaneous Approach */
"02H433Z" = '1' /*Insertion of Infusion Device into Coronary Vein,Percutaneous Approach */
"02H43DZ" = '1' /*Insertion of Intraluminal Device into Coronary Vein,Percutaneous Approach */
"02H43JZ" = '1' /*Insertion of Pacemaker Lead into Coronary Vein,Percutaneous Approach */
"02H43KZ" = '1' /*Insertion of Defibrillator Lead into Coronary Vein,Percutaneous Approach */
"02H43MZ" = '1' /*Insertion of Cardiac Lead into Coronary Vein,Percutaneous Approach */
"02H43NZ" = '1' /*Insertion of Intracardiac Pacemaker into Coronary Vein, Percutaneous Approach */
"02H440Z" = '1' /*Insertion of Pressure Sensor Monitoring Device intoCoronary Vein, Percutaneous Endoscopic Approach */
"02H442Z" = '1' /*Insertion of Monitoring Device into Coronary Vein,Percutaneous Endoscopic Approach */
"02H443Z" = '1' /*Insertion of Infusion Device into Coronary Vein,Percutaneous Endoscopic Approach */
"02H44DZ" = '1' /*Insertion of Intraluminal Device into Coronary Vein,Percutaneous Endoscopic Approach */
"02H44JZ" = '1' /*Insertion of Pacemaker Lead into Coronary Vein,Percutaneous Endoscopic Approach */
"02H44KZ" = '1' /*Insertion of Defibrillator Lead into Coronary Vein,Percutaneous Endoscopic Approach */
"02H44MZ" = '1' /*Insertion of Cardiac Lead into Coronary Vein,Percutaneous Endoscopic Approach */
"02H44NZ" = '1' /*Insertion of Intracardiac Pacemaker into Coronary Vein, Percutaneous Endoscopic Approach */
"02H600Z" = '1' /*Insertion of Pressure Sensor Monitoring Device intoRight Atrium, Open Approach */
"02H60JZ" = '1' /*Insertion of Pacemaker Lead into Right Atrium, OpenApproach */
"02H60KZ" = '1' /*Insertion of Defibrillator Lead into Right Atrium, OpenApproach */
"02H60MZ" = '1' /*Insertion of Cardiac Lead into Right Atrium, OpenApproach */
"02H60NZ" = '1' /*Insertion of Intracardiac Pacemaker into Right Atrium, Open Approach */
"02H630Z" = '1' /*Insertion of Pressure Sensor Monitoring Device intoRight Atrium, Percutaneous Approach */
"02H63JZ" = '1' /*Insertion of Pacemaker Lead into Right Atrium,Percutaneous Approach */
"02H63KZ" = '1' /*Insertion of Defibrillator Lead into Right Atrium,Percutaneous Approach */
"02H63MZ" = '1' /*Insertion of Cardiac Lead into Right Atrium,Percutaneous Approach */
"02H640Z" = '1' /*Insertion of Pressure Sensor Monitoring Device intoRight Atrium, Percutaneous Endoscopic Approach */
"02H64JZ" = '1' /*Insertion of Pacemaker Lead into Right Atrium,Percutaneous Endoscopic Approach */
"02H64KZ" = '1' /*Insertion of Defibrillator Lead into Right Atrium,Percutaneous Endoscopic Approach */
"02H64MZ" = '1' /*Insertion of Cardiac Lead into Right Atrium,Percutaneous Endoscopic Approach */
"02H64NZ" = '1' /*Insertion of Intracardiac Pacemaker into Right Atrium, Percutaneous Endoscopic Approach */
"02H700Z" = '1' /*Insertion of Pressure Sensor Monitoring Device intoLeft Atrium, Open Approach */
"02H70JZ" = '1' /*Insertion of Pacemaker Lead into Left Atrium, OpenApproach */
"02H70KZ" = '1' /*Insertion of Defibrillator Lead into Left Atrium, OpenApproach */
"02H70MZ" = '1' /*Insertion of Cardiac Lead into Left Atrium, OpenApproach */
"02H70NZ" = '1' /*Insertion of Intracardiac Pacemaker into Left Atrium, Open Approach */
"02H730Z" = '1' /*Insertion of Pressure Sensor Monitoring Device intoLeft Atrium, Percutaneous Approach */
"02H73JZ" = '1' /*Insertion of Pacemaker Lead into Left Atrium,Percutaneous Approach */
"02H73KZ" = '1' /*Insertion of Defibrillator Lead into Left Atrium,Percutaneous Approach */
"02H73MZ" = '1' /*Insertion of Cardiac Lead into Left Atrium,Percutaneous Approach */
"02H740Z" = '1' /*Insertion of Pressure Sensor Monitoring Device intoLeft Atrium, Percutaneous Endoscopic Approach */
"02H74JZ" = '1' /*Insertion of Pacemaker Lead into Left Atrium,Percutaneous Endoscopic Approach */
"02H74KZ" = '1' /*Insertion of Defibrillator Lead into Left Atrium,Percutaneous Endoscopic Approach */
"02H74MZ" = '1' /*Insertion of Cardiac Lead into Left Atrium,Percutaneous Endoscopic Approach */
"02H74NZ" = '1' /*Insertion of Intracardiac Pacemaker into Left Atrium, Percutaneous Endoscopic Approach */
"02HA0QZ" = '1' /*Insertion of Implantable Heart Assist System intoHeart, Open Approach */
"02HA0RJ" = '1' /*Insertion of Short-term External Heart Assist System into Heart, Intraoperative, Open Approach */
"02HA0RS" = '1' /*Insertion of Biventricular Short-term External Heart Assist System into Heart, Open Approach */
"02HA0RZ" = '1' /*Insertion of Short-term External Heart Assist System into Heart, Open Approach */
"02HA3QZ" = '1' /*Insertion of Implantable Heart Assist System intoHeart, Percutaneous Approach */
"02HA3RJ" = '1' /*Insertion of Short-term External Heart Assist System into Heart, Intraoperative, Percutaneous Approach */
"02HA3RS" = '1' /*Insertion of Biventricular Short-term External Heart Assist System into Heart, Percutaneous Approach */
"02HA3RZ" = '1' /*Insertion of Short-term External Heart Assist System into Heart, Percutaneous Approach */
"02HA4QZ" = '1' /*Insertion of Implantable Heart Assist System intoHeart, Percutaneous Endoscopic Approach */
"02HA4RJ" = '1' /*Insertion of Short-term External Heart Assist System into Heart, Intraoperative, Percutaneous Endoscopic Approach */
"02HA4RS" = '1' /*Insertion of Biventricular Short-term External Heart Assist System into Heart, Percutaneous Endoscopic Approach */
"02HA4RZ" = '1' /*Insertion of Short-term External Heart Assist System into Heart, Percutaneous Endoscopic Approach */
"02HK00Z" = '1' /*Insertion of Pressure Sensor Monitoring Device intoRight Ventricle, Open Approach */
"02HK02Z" = '1' /*Insertion of Monitoring Device into Right Ventricle,Open Approach */
"02HK0JZ" = '1' /*Insertion of Pacemaker Lead into Right Ventricle,Open Approach */
"02HK0KZ" = '1' /*Insertion of Defibrillator Lead into Right Ventricle,Open Approach */
"02HK0MZ" = '1' /*Insertion of Cardiac Lead into Right Ventricle, OpenApproach */
"02HK0NZ" = '1' /*Insertion of Intracardiac Pacemaker into Right Ventricle, Open Approach */
"02HK30Z" = '1' /*Insertion of Pressure Sensor Monitoring Device intoRight Ventricle, Percutaneous Approach */
"02HK32Z" = '1' /*Insertion of Monitoring Device into Right Ventricle,Percutaneous Approach */
"02HK3JZ" = '1' /*Insertion of Pacemaker Lead into Right Ventricle,Percutaneous Approach */
"02HK3KZ" = '1' /*Insertion of Defibrillator Lead into Right Ventricle,Percutaneous Approach */
"02HK3MZ" = '1' /*Insertion of Cardiac Lead into Right Ventricle,Percutaneous Approach */
"02HK40Z" = '1' /*Insertion of Pressure Sensor Monitoring Device intoRight Ventricle, Percutaneous Endoscopic Approach */
"02HK42Z" = '1' /*Insertion of Monitoring Device into Right Ventricle,Percutaneous Endoscopic Approach */
"02HK4JZ" = '1' /*Insertion of Pacemaker Lead into Right Ventricle,Percutaneous Endoscopic Approach */
"02HK4KZ" = '1' /*Insertion of Defibrillator Lead into Right Ventricle,Percutaneous Endoscopic Approach */
"02HK4MZ" = '1' /*Insertion of Cardiac Lead into Right Ventricle,Percutaneous Endoscopic Approach */
"02HK4NZ" = '1' /*Insertion of Intracardiac Pacemaker into Right Ventricle, Percutaneous Endoscopic Approach */
"02HL00Z" = '1' /*Insertion of Pressure Sensor Monitoring Device intoLeft Ventricle, Open Approach */
"02HL0JZ" = '1' /*Insertion of Pacemaker Lead into Left Ventricle, OpenApproach */
"02HL0KZ" = '1' /*Insertion of Defibrillator Lead into Left Ventricle, OpenApproach */
"02HL0MZ" = '1' /*Insertion of Cardiac Lead into Left Ventricle, OpenApproach */
"02HL0NZ" = '1' /*Insertion of Intracardiac Pacemaker into Left Ventricle, Open Approach */
"02HL30Z" = '1' /*Insertion of Pressure Sensor Monitoring Device intoLeft Ventricle, Percutaneous Approach */
"02HL3JZ" = '1' /*Insertion of Pacemaker Lead into Left Ventricle,Percutaneous Approach */
"02HL3KZ" = '1' /*Insertion of Defibrillator Lead into Left Ventricle,Percutaneous Approach */
"02HL3MZ" = '1' /*Insertion of Cardiac Lead into Left Ventricle,Percutaneous Approach */
"02HL40Z" = '1' /*Insertion of Pressure Sensor Monitoring Device intoLeft Ventricle, Percutaneous Endoscopic Approach */
"02HL4JZ" = '1' /*Insertion of Pacemaker Lead into Left Ventricle,Percutaneous Endoscopic Approach */
"02HL4KZ" = '1' /*Insertion of Defibrillator Lead into Left Ventricle,Percutaneous Endoscopic Approach */
"02HL4MZ" = '1' /*Insertion of Cardiac Lead into Left Ventricle,Percutaneous Endoscopic Approach */
"02HL4NZ" = '1' /*Insertion of Intracardiac Pacemaker into Left Ventricle, Percutaneous Endoscopic Approach */
"02HN0JZ" = '1' /*Insertion of Pacemaker Lead into Pericardium, OpenApproach */
"02HN0KZ" = '1' /*Insertion of Defibrillator Lead into Pericardium, OpenApproach */
"02HN0MZ" = '1' /*Insertion of Cardiac Lead into Pericardium, OpenApproach */
"02HN3JZ" = '1' /*Insertion of Pacemaker Lead into Pericardium,Percutaneous Approach */
"02HN3KZ" = '1' /*Insertion of Defibrillator Lead into Pericardium,Percutaneous Approach */
"02HN3MZ" = '1' /*Insertion of Cardiac Lead into Pericardium,Percutaneous Approach */
"02HN4JZ" = '1' /*Insertion of Pacemaker Lead into Pericardium,Percutaneous Endoscopic Approach */
"02HN4KZ" = '1' /*Insertion of Defibrillator Lead into Pericardium,Percutaneous Endoscopic Approach */
"02HN4MZ" = '1' /*Insertion of Cardiac Lead into Pericardium,Percutaneous Endoscopic Approach */
"02HS00Z" = '1' /*Insertion of Pressure Sensor Monitoring Device intoRight Pulmonary Vein, Open Approach */
"02HS30Z" = '1' /*Insertion of Pressure Sensor Monitoring Device intoRight Pulmonary Vein, Percutaneous Approach */
"02HS40Z" = '1' /*Insertion of Pressure Sensor Monitoring Device intoRight Pulmonary Vein, Percutaneous EndoscopicApproach */
"02HT00Z" = '1' /*Insertion of Pressure Sensor Monitoring Device intoLeft Pulmonary Vein, Open Approach */
"02HT30Z" = '1' /*Insertion of Pressure Sensor Monitoring Device intoLeft Pulmonary Vein, Percutaneous Approach */
"02HT40Z" = '1' /*Insertion of Pressure Sensor Monitoring Device intoLeft Pulmonary Vein, Percutaneous EndoscopicApproach */
"02HV00Z" = '1' /*Insertion of Pressure Sensor Monitoring Device intoSuperior Vena Cava, Open Approach */
"02HV30Z" = '1' /*Insertion of Pressure Sensor Monitoring Device intoSuperior Vena Cava, Percutaneous Approach */
"02HV40Z" = '1' /*Insertion of Pressure Sensor Monitoring Device intoSuperior Vena Cava, Percutaneous EndoscopicApproach */
"02HX02Z" = '1' /*Insertion of Monitoring Device into Thoracic Aorta, Ascending/Arch, Open Approach */
"02HX0DZ" = '1' /*Insertion of Intraluminal Device into Thoracic Aorta, Ascending/Arch, Open Approach */
"02HX42Z" = '1' /*Insertion of Monitoring Device into Thoracic Aorta, Ascending/Arch, Percutaneous Endoscopic Approach */
"02HX4DZ" = '1' /*Insertion of Intraluminal Device into Thoracic Aorta, Ascending/Arch, Percutaneous Endoscopic Approach */
"02L70CK" = '1' /*Occlusion of Left Atrial Appendage with ExtraluminalDevice, Open Approach */
"02L70DK" = '1' /*Occlusion of Left Atrial Appendage with IntraluminalDevice, Open Approach */
"02L70ZK" = '1' /*Occlusion of Left Atrial Appendage, Open Approach */
"02L73CK" = '1' /*Occlusion of Left Atrial Appendage with ExtraluminalDevice, Percutaneous Approach */
"02L73DK" = '1' /*Occlusion of Left Atrial Appendage with IntraluminalDevice, Percutaneous Approach */
"02L73ZK" = '1' /*Occlusion of Left Atrial Appendage, PercutaneousApproach */
"02L74CK" = '1' /*Occlusion of Left Atrial Appendage with ExtraluminalDevice, Percutaneous Endoscopic Approach */
"02L74DK" = '1' /*Occlusion of Left Atrial Appendage with IntraluminalDevice, Percutaneous Endoscopic Approach */
"02L74ZK" = '1' /*Occlusion of Left Atrial Appendage, PercutaneousEndoscopic Approach */
"02LQ0CZ" = '1' /*Occlusion of Right Pulmonary Artery with Extraluminal Device, Open Approach */
"02LQ0DZ" = '1' /*Occlusion of Right Pulmonary Artery with Intraluminal Device, Open Approach */
"02LQ0ZZ" = '1' /*Occlusion of Right Pulmonary Artery, Open Approach */
"02LQ3CZ" = '1' /*Occlusion of Right Pulmonary Artery with Extraluminal Device, Percutaneous Approach */
"02LQ3DZ" = '1' /*Occlusion of Right Pulmonary Artery with Intraluminal Device, Percutaneous Approach */
"02LQ3ZZ" = '1' /*Occlusion of Right Pulmonary Artery, Percutaneous Approach */
"02LQ4CZ" = '1' /*Occlusion of Right Pulmonary Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"02LQ4DZ" = '1' /*Occlusion of Right Pulmonary Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"02LQ4ZZ" = '1' /*Occlusion of Right Pulmonary Artery, Percutaneous Endoscopic Approach */
"02LR0CZ" = '1' /*Occlusion of Left Pulmonary Artery with Extraluminal Device, Open Approach */
"02LR0DZ" = '1' /*Occlusion of Left Pulmonary Artery with Intraluminal Device, Open Approach */
"02LR0ZT" = '1' /*Occlusion of Ductus Arteriosus, Open Approach */
"02LR0ZZ" = '1' /*Occlusion of Left Pulmonary Artery, Open Approach */
"02LR3CZ" = '1' /*Occlusion of Left Pulmonary Artery with Extraluminal Device, Percutaneous Approach */
"02LR3DZ" = '1' /*Occlusion of Left Pulmonary Artery with Intraluminal Device, Percutaneous Approach */
"02LR3ZZ" = '1' /*Occlusion of Left Pulmonary Artery, Percutaneous Approach */
"02LR4CZ" = '1' /*Occlusion of Left Pulmonary Artery with Extraluminal Device, Percutaneous Endoscopic Approach */
"02LR4DZ" = '1' /*Occlusion of Left Pulmonary Artery with Intraluminal Device, Percutaneous Endoscopic Approach */
"02LR4ZZ" = '1' /*Occlusion of Left Pulmonary Artery, Percutaneous Endoscopic Approach */
"02LS0ZZ" = '1' /*Occlusion of Right Pulmonary Vein, Open Approach */
"02LT0ZZ" = '1' /*Occlusion of Left Pulmonary Vein, Open Approach */
"02N00ZZ" = '1' /*Release Coronary Artery, One Artery, Open Approach */
"02N03ZZ" = '1' /*Release Coronary Artery, One Artery, Percutaneous Approach */
"02N04ZZ" = '1' /*Release Coronary Artery, One Artery, Percutaneous Endoscopic Approach */
"02N10ZZ" = '1' /*Release Coronary Artery, Two Arteries, Open Approach */
"02N13ZZ" = '1' /*Release Coronary Artery, Two Arteries, Percutaneous Approach */
"02N14ZZ" = '1' /*Release Coronary Artery, Two Arteries, Percutaneous Endoscopic Approach */
"02N20ZZ" = '1' /*Release Coronary Artery, Three Arteries, Open Approach */
"02N23ZZ" = '1' /*Release Coronary Artery, Three Arteries, Percutaneous Approach */
"02N24ZZ" = '1' /*Release Coronary Artery, Three Arteries, Percutaneous Endoscopic Approach */
"02N30ZZ" = '1' /*Release Coronary Artery, Four or More Arteries, Open Approach */
"02N33ZZ" = '1' /*Release Coronary Artery, Four or More Arteries, Percutaneous Approach */
"02N34ZZ" = '1' /*Release Coronary Artery, Four or More Arteries, Percutaneous Endoscopic Approach */
"02N50ZZ" = '1' /*Release Atrial Septum, Open Approach */
"02N53ZZ" = '1' /*Release Atrial Septum, Percutaneous Approach */
"02N54ZZ" = '1' /*Release Atrial Septum, Percutaneous EndoscopicApproach */
"02N90ZZ" = '1' /*Release Chordae Tendineae, Open Approach */
"02N93ZZ" = '1' /*Release Chordae Tendineae, Percutaneous Approach */
"02N94ZZ" = '1' /*Release Chordae Tendineae, PercutaneousEndoscopic Approach */
"02ND0ZZ" = '1' /*Release Papillary Muscle, Open Approach */
"02ND3ZZ" = '1' /*Release Papillary Muscle, Percutaneous Approach */
"02ND4ZZ" = '1' /*Release Papillary Muscle, Percutaneous EndoscopicApproach */
"02NF0ZZ" = '1' /*Release Aortic Valve, Open Approach */
"02NF3ZZ" = '1' /*Release Aortic Valve, Percutaneous Approach */
"02NF4ZZ" = '1' /*Release Aortic Valve, Percutaneous EndoscopicApproach */
"02NG0ZZ" = '1' /*Release Mitral Valve, Open Approach */
"02NG3ZZ" = '1' /*Release Mitral Valve, Percutaneous Approach */
"02NG4ZZ" = '1' /*Release Mitral Valve, Percutaneous EndoscopicApproach */
"02NH0ZZ" = '1' /*Release Pulmonary Valve, Open Approach */
"02NH3ZZ" = '1' /*Release Pulmonary Valve, Percutaneous Approach */
"02NH4ZZ" = '1' /*Release Pulmonary Valve, Percutaneous EndoscopicApproach */
"02NJ0ZZ" = '1' /*Release Tricuspid Valve, Open Approach */
"02NJ3ZZ" = '1' /*Release Tricuspid Valve, Percutaneous Approach */
"02NJ4ZZ" = '1' /*Release Tricuspid Valve, Percutaneous EndoscopicApproach */
"02NK0ZZ" = '1' /*Release Right Ventricle, Open Approach */
"02NK3ZZ" = '1' /*Release Right Ventricle, Percutaneous Approach */
"02NK4ZZ" = '1' /*Release Right Ventricle, Percutaneous EndoscopicApproach */
"02NL0ZZ" = '1' /*Release Left Ventricle, Open Approach */
"02NL3ZZ" = '1' /*Release Left Ventricle, Percutaneous Approach */
"02NL4ZZ" = '1' /*Release Left Ventricle, Percutaneous EndoscopicApproach */
"02NM0ZZ" = '1' /*Release Ventricular Septum, Open Approach */
"02NM3ZZ" = '1' /*Release Ventricular Septum, Percutaneous Approach */
"02NM4ZZ" = '1' /*Release Ventricular Septum, PercutaneousEndoscopic Approach */
"02PA0MZ" = '1' /*Removal of Cardiac Lead from Heart, Open Approach */
"02PA0NZ" = '1' /*Removal of Intracardiac Pacemaker from Heart, Open Approach */
"02PA0QZ" = '1' /*Removal of Implantable Heart Assist System fromHeart, Open Approach */
"02PA0RS" = '1' /*Removal of Biventricular Short-term External Heart Assist System from Heart, Open Approach */
"02PA0RZ" = '1' /*Removal of Short-term External Heart Assist System from Heart, Open Approach */
"02PA3MZ" = '1' /*Removal of Cardiac Lead from Heart, PercutaneousApproach */
"02PA3QZ" = '1' /*Removal of Implantable Heart Assist System fromHeart, Percutaneous Approach */
"02PA3RS" = '1' /*Removal of Biventricular Short-term External Heart Assist System from Heart, Percutaneous Approach */
"02PA3RZ" = '1' /*Removal of Short-term External Heart Assist System from Heart, Percutaneous Approach */
"02PA4MZ" = '1' /*Removal of Cardiac Lead from Heart, PercutaneousEndoscopic Approach */
"02PA4NZ" = '1' /*Removal of Intracardiac Pacemaker from Heart, Percutaneous Endoscopic Approach */
"02PA4QZ" = '1' /*Removal of Implantable Heart Assist System fromHeart, Percutaneous Endoscopic Approach */
"02PA4RS" = '1' /*Removal of Biventricular Short-term External Heart Assist System from Heart, Percutaneous Endoscopic Approach */
"02PA4RZ" = '1' /*Removal of Short-term External Heart Assist System from Heart, Percutaneous Endoscopic Approach */
"02PAXMZ" = '1' /*Removal of Cardiac Lead from Heart, ExternalApproach */
"02Q00ZZ" = '1' /*Repair Coronary Artery, One Artery, Open Approach */
"02Q03ZZ" = '1' /*Repair Coronary Artery, One Artery, Percutaneous Approach */
"02Q04ZZ" = '1' /*Repair Coronary Artery, One Artery, Percutaneous Endoscopic Approach */
"02Q10ZZ" = '1' /*Repair Coronary Artery, Two Arteries, Open Approach */
"02Q13ZZ" = '1' /*Repair Coronary Artery, Two Arteries, Percutaneous Approach */
"02Q14ZZ" = '1' /*Repair Coronary Artery, Two Arteries, Percutaneous Endoscopic Approach */
"02Q20ZZ" = '1' /*Repair Coronary Artery, Three Arteries, Open Approach */
"02Q23ZZ" = '1' /*Repair Coronary Artery, Three Arteries, Percutaneous Approach */
"02Q24ZZ" = '1' /*Repair Coronary Artery, Three Arteries, Percutaneous Endoscopic Approach */
"02Q30ZZ" = '1' /*Repair Coronary Artery, Four or More Arteries, Open Approach */
"02Q33ZZ" = '1' /*Repair Coronary Artery, Four or More Arteries, Percutaneous Approach */
"02Q34ZZ" = '1' /*Repair Coronary Artery, Four or More Arteries, Percutaneous Endoscopic Approach */
"02Q40ZZ" = '1' /*Repair Coronary Vein, Open Approach */
"02Q43ZZ" = '1' /*Repair Coronary Vein, Percutaneous Approach */
"02Q44ZZ" = '1' /*Repair Coronary Vein, Percutaneous EndoscopicApproach */
"02Q50ZZ" = '1' /*Repair Atrial Septum, Open Approach */
"02Q53ZZ" = '1' /*Repair Atrial Septum, Percutaneous Approach */
"02Q54ZZ" = '1' /*Repair Atrial Septum, Percutaneous EndoscopicApproach */
"02Q70ZZ" = '1' /*Repair Left Atrium, Open Approach */
"02Q73ZZ" = '1' /*Repair Left Atrium, Percutaneous Approach */
"02Q74ZZ" = '1' /*Repair Left Atrium, Percutaneous EndoscopicApproach */
"02Q90ZZ" = '1' /*Repair Chordae Tendineae, Open Approach */
"02Q93ZZ" = '1' /*Repair Chordae Tendineae, Percutaneous Approach */
"02Q94ZZ" = '1' /*Repair Chordae Tendineae, PercutaneousEndoscopic Approach */
"02QA0ZZ" = '1' /*Repair Heart, Open Approach */
"02QA3ZZ" = '1' /*Repair Heart, Percutaneous Approach */
"02QA4ZZ" = '1' /*Repair Heart, Percutaneous Endoscopic Approach */
"02QB0ZZ" = '1' /*Repair Right Heart, Open Approach */
"02QB3ZZ" = '1' /*Repair Right Heart, Percutaneous Approach */
"02QB4ZZ" = '1' /*Repair Right Heart, Percutaneous EndoscopicApproach */
"02QC0ZZ" = '1' /*Repair Left Heart, Open Approach */
"02QC3ZZ" = '1' /*Repair Left Heart, Percutaneous Approach */
"02QC4ZZ" = '1' /*Repair Left Heart, Percutaneous EndoscopicApproach */
"02QD0ZZ" = '1' /*Repair Papillary Muscle, Open Approach */
"02QD3ZZ" = '1' /*Repair Papillary Muscle, Percutaneous Approach */
"02QD4ZZ" = '1' /*Repair Papillary Muscle, Percutaneous EndoscopicApproach */
"02QF0ZJ" = '1' /*Repair Aortic Valve created from Truncal Valve, Open Approach */
"02QF0ZZ" = '1' /*Repair Aortic Valve, Open Approach */
"02QF3ZJ" = '1' /*Repair Aortic Valve created from Truncal Valve, Percutaneous Approach */
"02QF3ZZ" = '1' /*Repair Aortic Valve, Percutaneous Approach */
"02QF4ZJ" = '1' /*Repair Aortic Valve created from Truncal Valve, Percutaneous Endoscopic Approach */
"02QF4ZZ" = '1' /*Repair Aortic Valve, Percutaneous EndoscopicApproach */
"02QG0ZE" = '1' /*Repair Mitral Valve created from Left Atrioventricular Valve, Open Approach */
"02QG0ZZ" = '1' /*Repair Mitral Valve, Open Approach */
"02QG3ZE" = '1' /*Repair Mitral Valve created from Left Atrioventricular Valve, Percutaneous Approach */
"02QG3ZZ" = '1' /*Repair Mitral Valve, Percutaneous Approach */
"02QG4ZE" = '1' /*Repair Mitral Valve created from Left Atrioventricular Valve, Percutaneous Endoscopic Approach */
"02QG4ZZ" = '1' /*Repair Mitral Valve, Percutaneous EndoscopicApproach */
"02QH0ZZ" = '1' /*Repair Pulmonary Valve, Open Approach */
"02QH3ZZ" = '1' /*Repair Pulmonary Valve, Percutaneous Approach */
"02QH4ZZ" = '1' /*Repair Pulmonary Valve, Percutaneous EndoscopicApproach */
"02QJ0ZG" = '1' /*Repair Tricuspid Valve created from Right Atrioventricular Valve, Open Approach */
"02QJ0ZZ" = '1' /*Repair Tricuspid Valve, Open Approach */
"02QJ3ZG" = '1' /*Repair Tricuspid Valve created from Right Atrioventricular Valve, Percutaneous Approach */
"02QJ3ZZ" = '1' /*Repair Tricuspid Valve, Percutaneous Approach */
"02QJ4ZG" = '1' /*Repair Tricuspid Valve created from Right Atrioventricular Valve, Percutaneous Endoscopic Approach */
"02QJ4ZZ" = '1' /*Repair Tricuspid Valve, Percutaneous EndoscopicApproach */
"02QM0ZZ" = '1' /*Repair Ventricular Septum, Open Approach */
"02QM3ZZ" = '1' /*Repair Ventricular Septum, Percutaneous Approach */
"02QM4ZZ" = '1' /*Repair Ventricular Septum, Percutaneous EndoscopicApproach */
"02R907Z" = '1' /*Replacement of Chordae Tendineae with AutologousTissue Substitute, Open Approach */
"02R908Z" = '1' /*Replacement of Chordae Tendineae with ZooplasticTissue, Open Approach */
"02R90JZ" = '1' /*Replacement of Chordae Tendineae with SyntheticSubstitute, Open Approach */
"02R90KZ" = '1' /*Replacement of Chordae Tendineae withNonautologous Tissue Substitute, Open Approach */
"02R947Z" = '1' /*Replacement of Chordae Tendineae with AutologousTissue Substitute, Percutaneous EndoscopicApproach */
"02R948Z" = '1' /*Replacement of Chordae Tendineae with ZooplasticTissue, Percutaneous Endoscopic Approach */
"02R94JZ" = '1' /*Replacement of Chordae Tendineae with SyntheticSubstitute, Percutaneous Endoscopic Approach */
"02R94KZ" = '1' /*Replacement of Chordae Tendineae withNonautologous Tissue Substitute, PercutaneousEndoscopic Approach */
"02RD07Z" = '1' /*Replacement of Papillary Muscle with AutologousTissue Substitute, Open Approach */
"02RD08Z" = '1' /*Replacement of Papillary Muscle with ZooplasticTissue, Open Approach */
"02RD0JZ" = '1' /*Replacement of Papillary Muscle with SyntheticSubstitute, Open Approach */
"02RD0KZ" = '1' /*Replacement of Papillary Muscle with NonautologousTissue Substitute, Open Approach */
"02RD47Z" = '1' /*Replacement of Papillary Muscle with AutologousTissue Substitute, Percutaneous EndoscopicApproach */
"02RD48Z" = '1' /*Replacement of Papillary Muscle with ZooplasticTissue, Percutaneous Endoscopic Approach */
"02RD4JZ" = '1' /*Replacement of Papillary Muscle with SyntheticSubstitute, Percutaneous Endoscopic Approach */
"02RD4KZ" = '1' /*Replacement of Papillary Muscle with NonautologousTissue Substitute, Percutaneous EndoscopicApproach */
"02RF07Z" = '1' /*Replacement of Aortic Valve with Autologous TissueSubstitute, Open Approach */
"02RF08Z" = '1' /*Replacement of Aortic Valve with Zooplastic Tissue,Open Approach */
"02RF0JZ" = '1' /*Replacement of Aortic Valve with Synthetic Substitute,Open Approach */
"02RF0KZ" = '1' /*Replacement of Aortic Valve with NonautologousTissue Substitute, Open Approach */
"02RF37H" = '1' /*Replacement of Aortic Valve with Autologous TissueSubstitute, Transapical, Percutaneous Approach */
"02RF37Z" = '1' /*Replacement of Aortic Valve with Autologous TissueSubstitute, Percutaneous Approach */
"02RF38H" = '1' /*Replacement of Aortic Valve with Zooplastic Tissue,Transapical, Percutaneous Approach */
"02RF38Z" = '1' /*Replacement of Aortic Valve with Zooplastic Tissue,Percutaneous Approach */
"02RF3JH" = '1' /*Replacement of Aortic Valve with Synthetic Substitute,Transapical, Percutaneous Approach */
"02RF3JZ" = '1' /*Replacement of Aortic Valve with Synthetic Substitute,Percutaneous Approach */
"02RF3KH" = '1' /*Replacement of Aortic Valve with NonautologousTissue Substitute, Transapical, PercutaneousApproach */
"02RF3KZ" = '1' /*Replacement of Aortic Valve with NonautologousTissue Substitute, Percutaneous Approach */
"02RF47Z" = '1' /*Replacement of Aortic Valve with Autologous TissueSubstitute, Percutaneous Endoscopic Approach */
"02RF48Z" = '1' /*Replacement of Aortic Valve with Zooplastic Tissue,Percutaneous Endoscopic Approach */
"02RF4JZ" = '1' /*Replacement of Aortic Valve with Synthetic Substitute,Percutaneous Endoscopic Approach */
"02RF4KZ" = '1' /*Replacement of Aortic Valve with NonautologousTissue Substitute, Percutaneous EndoscopicApproach */
"02RG07Z" = '1' /*Replacement of Mitral Valve with Autologous TissueSubstitute, Open Approach */
"02RG08Z" = '1' /*Replacement of Mitral Valve with Zooplastic Tissue,Open Approach */
"02RG0JZ" = '1' /*Replacement of Mitral Valve with Synthetic Substitute,Open Approach */
"02RG0KZ" = '1' /*Replacement of Mitral Valve with NonautologousTissue Substitute, Open Approach */
"02RG37H" = '1' /*Replacement of Mitral Valve with Autologous TissueSubstitute, Transapical, Percutaneous Approach */
"02RG37Z" = '1' /*Replacement of Mitral Valve with Autologous TissueSubstitute, Percutaneous Approach */
"02RG38H" = '1' /*Replacement of Mitral Valve with Zooplastic Tissue,Transapical, Percutaneous Approach */
"02RG38Z" = '1' /*Replacement of Mitral Valve with Zooplastic Tissue,Percutaneous Approach */
"02RG3JH" = '1' /*Replacement of Mitral Valve with Synthetic Substitute,Transapical, Percutaneous Approach */
"02RG3JZ" = '1' /*Replacement of Mitral Valve with Synthetic Substitute,Percutaneous Approach */
"02RG3KH" = '1' /*Replacement of Mitral Valve with NonautologousTissue Substitute, Transapical, PercutaneousApproach */
"02RG3KZ" = '1' /*Replacement of Mitral Valve with NonautologousTissue Substitute, Percutaneous Approach */
"02RG47Z" = '1' /*Replacement of Mitral Valve with Autologous TissueSubstitute, Percutaneous Endoscopic Approach */
"02RG48Z" = '1' /*Replacement of Mitral Valve with Zooplastic Tissue,Percutaneous Endoscopic Approach */
"02RG4JZ" = '1' /*Replacement of Mitral Valve with Synthetic Substitute,Percutaneous Endoscopic Approach */
"02RG4KZ" = '1' /*Replacement of Mitral Valve with NonautologousTissue Substitute, Percutaneous EndoscopicApproach */
"02RH07Z" = '1' /*Replacement of Pulmonary Valve with AutologousTissue Substitute, Open Approach */
"02RH08Z" = '1' /*Replacement of Pulmonary Valve with ZooplasticTissue, Open Approach */
"02RH0JZ" = '1' /*Replacement of Pulmonary Valve with SyntheticSubstitute, Open Approach */
"02RH0KZ" = '1' /*Replacement of Pulmonary Valve with NonautologousTissue Substitute, Open Approach */
"02RH37H" = '1' /*Replacement of Pulmonary Valve with AutologousTissue Substitute, Transapical, PercutaneousApproach */
"02RH37Z" = '1' /*Replacement of Pulmonary Valve with AutologousTissue Substitute, Percutaneous Approach */
"02RH38H" = '1' /*Replacement of Pulmonary Valve with ZooplasticTissue, Transapical, Percutaneous Approach */
"02RH38Z" = '1' /*Replacement of Pulmonary Valve with ZooplasticTissue, Percutaneous Approach */
"02RH3JH" = '1' /*Replacement of Pulmonary Valve with SyntheticSubstitute, Transapical, Percutaneous Approach */
"02RH3JZ" = '1' /*Replacement of Pulmonary Valve with SyntheticSubstitute, Percutaneous Approach */
"02RH3KH" = '1' /*Replacement of Pulmonary Valve with NonautologousTissue Substitute, Transapical, PercutaneousApproach */
"02RH3KZ" = '1' /*Replacement of Pulmonary Valve with NonautologousTissue Substitute, Percutaneous Approach */
"02RH47Z" = '1' /*Replacement of Pulmonary Valve with AutologousTissue Substitute, Percutaneous EndoscopicApproach */
"02RH48Z" = '1' /*Replacement of Pulmonary Valve with ZooplasticTissue, Percutaneous Endoscopic Approach */
"02RH4JZ" = '1' /*Replacement of Pulmonary Valve with SyntheticSubstitute, Percutaneous Endoscopic Approach */
"02RH4KZ" = '1' /*Replacement of Pulmonary Valve with NonautologousTissue Substitute, Percutaneous EndoscopicApproach */
"02RJ07Z" = '1' /*Replacement of Tricuspid Valve with AutologousTissue Substitute, Open Approach */
"02RJ08Z" = '1' /*Replacement of Tricuspid Valve with ZooplasticTissue, Open Approach */
"02RJ0JZ" = '1' /*Replacement of Tricuspid Valve with SyntheticSubstitute, Open Approach */
"02RJ0KZ" = '1' /*Replacement of Tricuspid Valve with NonautologousTissue Substitute, Open Approach */
"02RJ37H" = '1' /*Replacement of Tricuspid Valve with Autologous Tissue Substitute, Transapical, Percutaneous Approach */
"02RJ37Z" = '1' /*Replacement of Tricuspid Valve with Autologous Tissue Substitute, Percutaneous Approach */
"02RJ38H" = '1' /*Replacement of Tricuspid Valve with Zooplastic Tissue, Transapical, Percutaneous Approach */
"02RJ38Z" = '1' /*Replacement of Tricuspid Valve with Zooplastic Tissue, Percutaneous Approach */
"02RJ3JH" = '1' /*Replacement of Tricuspid Valve with Synthetic Substitute, Transapical, Percutaneous Approach */
"02RJ3JZ" = '1' /*Replacement of Tricuspid Valve with Synthetic Substitute, Percutaneous Approach */
"02RJ3KH" = '1' /*Replacement of Tricuspid Valve with Nonautologous Tissue Substitute, Transapical, Percutaneous Approach */
"02RJ3KZ" = '1' /*Replacement of Tricuspid Valve with Nonautologous Tissue Substitute, Percutaneous Approach */
"02RJ47Z" = '1' /*Replacement of Tricuspid Valve with AutologousTissue Substitute, Percutaneous EndoscopicApproach */
"02RJ48Z" = '1' /*Replacement of Tricuspid Valve with ZooplasticTissue, Percutaneous Endoscopic Approach */
"02RJ4JZ" = '1' /*Replacement of Tricuspid Valve with SyntheticSubstitute, Percutaneous Endoscopic Approach */
"02RJ4KZ" = '1' /*Replacement of Tricuspid Valve with NonautologousTissue Substitute, Percutaneous EndoscopicApproach */
"02RK07Z" = '1' /*Replacement of Right Ventricle with AutologousTissue Substitute, Open Approach */
"02RK0JZ" = '1' /*Replacement of Right Ventricle with SyntheticSubstitute, Open Approach */
"02RK0KZ" = '1' /*Replacement of Right Ventricle with NonautologousTissue Substitute, Open Approach */
"02RK47Z" = '1' /*Replacement of Right Ventricle with AutologousTissue Substitute, Percutaneous EndoscopicApproach */
"02RK4KZ" = '1' /*Replacement of Right Ventricle with NonautologousTissue Substitute, Percutaneous EndoscopicApproach */
"02RL07Z" = '1' /*Replacement of Left Ventricle with Autologous TissueSubstitute, Open Approach */
"02RL0JZ" = '1' /*Replacement of Left Ventricle with SyntheticSubstitute, Open Approach */
"02RL0KZ" = '1' /*Replacement of Left Ventricle with NonautologousTissue Substitute, Open Approach */
"02RL47Z" = '1' /*Replacement of Left Ventricle with Autologous TissueSubstitute, Percutaneous Endoscopic Approach */
"02RL4KZ" = '1' /*Replacement of Left Ventricle with NonautologousTissue Substitute, Percutaneous EndoscopicApproach */
"02RM07Z" = '1' /*Replacement of Ventricular Septum with AutologousTissue Substitute, Open Approach */
"02RM0JZ" = '1' /*Replacement of Ventricular Septum with SyntheticSubstitute, Open Approach */
"02RM0KZ" = '1' /*Replacement of Ventricular Septum withNonautologous Tissue Substitute, Open Approach */
"02RM47Z" = '1' /*Replacement of Ventricular Septum with AutologousTissue Substitute, Percutaneous EndoscopicApproach */
"02RM4JZ" = '1' /*Replacement of Ventricular Septum with SyntheticSubstitute, Percutaneous Endoscopic Approach */
"02RM4KZ" = '1' /*Replacement of Ventricular Septum withNonautologous Tissue Substitute, PercutaneousEndoscopic Approach */
"02RP0JZ" = '1' /*Replacement of Pulmonary Trunk with SyntheticSubstitute, Open Approach */
"02RQ07Z" = '1' /*Replacement of Right Pulmonary Artery withAutologous Tissue Substitute, Open Approach */
"02RQ0JZ" = '1' /*Replacement of Right Pulmonary Artery with SyntheticSubstitute, Open Approach */
"02RR07Z" = '1' /*Replacement of Left Pulmonary Artery withAutologous Tissue Substitute, Open Approach */
"02RR0JZ" = '1' /*Replacement of Left Pulmonary Artery with SyntheticSubstitute, Open Approach */
"02SP0ZZ" = '1' /*Reposition Pulmonary Trunk, Open Approach */
"02SW0ZZ" = '1' /*Reposition Thoracic Aorta, Open Approach */
"02SX0ZZ" = '1' /*Reposition Thoracic Aorta, Ascending/Arch, Open Approach */
"02T50ZZ" = '1' /*Resection of Atrial Septum, Open Approach */
"02T53ZZ" = '1' /*Resection of Atrial Septum, Percutaneous Approach */
"02T54ZZ" = '1' /*Resection of Atrial Septum, Percutaneous EndoscopicApproach */
"02T80ZZ" = '1' /*Resection of Conduction Mechanism, Open Approach */
"02T83ZZ" = '1' /*Resection of Conduction Mechanism, PercutaneousApproach */
"02T84ZZ" = '1' /*Resection of Conduction Mechanism, PercutaneousEndoscopic Approach */
"02T90ZZ" = '1' /*Resection of Chordae Tendineae, Open Approach */
"02T93ZZ" = '1' /*Resection of Chordae Tendineae, PercutaneousApproach */
"02T94ZZ" = '1' /*Resection of Chordae Tendineae, PercutaneousEndoscopic Approach */
"02TD0ZZ" = '1' /*Resection of Papillary Muscle, Open Approach */
"02TD3ZZ" = '1' /*Resection of Papillary Muscle, PercutaneousApproach */
"02TD4ZZ" = '1' /*Resection of Papillary Muscle, PercutaneousEndoscopic Approach */
"02TH0ZZ" = '1' /*Resection of Pulmonary Valve, Open Approach */
"02TH3ZZ" = '1' /*Resection of Pulmonary Valve, PercutaneousApproach */
"02TH4ZZ" = '1' /*Resection of Pulmonary Valve, PercutaneousEndoscopic Approach */
"02TM0ZZ" = '1' /*Resection of Ventricular Septum, Open Approach */
"02TM3ZZ" = '1' /*Resection of Ventricular Septum, PercutaneousApproach */
"02TM4ZZ" = '1' /*Resection of Ventricular Septum, PercutaneousEndoscopic Approach */
"02TN0ZZ" = '1' /*Resection of Pericardium, Open Approach */
"02TN3ZZ" = '1' /*Resection of Pericardium, Percutaneous Approach */
"02TN4ZZ" = '1' /*Resection of Pericardium, Percutaneous EndoscopicApproach */
"02U507Z" = '1' /*Supplement Atrial Septum with Autologous TissueSubstitute, Open Approach */
"02U508Z" = '1' /*Supplement Atrial Septum with Zooplastic Tissue,Open Approach */
"02U50JZ" = '1' /*Supplement Atrial Septum with Synthetic Substitute,Open Approach */
"02U50KZ" = '1' /*Supplement Atrial Septum with Nonautologous TissueSubstitute, Open Approach */
"02U537Z" = '1' /*Supplement Atrial Septum with Autologous TissueSubstitute, Percutaneous Approach */
"02U538Z" = '1' /*Supplement Atrial Septum with Zooplastic Tissue,Percutaneous Approach */
"02U53JZ" = '1' /*Supplement Atrial Septum with Synthetic Substitute,Percutaneous Approach */
"02U53KZ" = '1' /*Supplement Atrial Septum with Nonautologous TissueSubstitute, Percutaneous Approach */
"02U547Z" = '1' /*Supplement Atrial Septum with Autologous TissueSubstitute, Percutaneous Endoscopic Approach */
"02U548Z" = '1' /*Supplement Atrial Septum with Zooplastic Tissue,Percutaneous Endoscopic Approach */
"02U54JZ" = '1' /*Supplement Atrial Septum with Synthetic Substitute,Percutaneous Endoscopic Approach */
"02U54KZ" = '1' /*Supplement Atrial Septum with Nonautologous TissueSubstitute, Percutaneous Endoscopic Approach */
"02U607Z" = '1' /*Supplement Right Atrium with Autologous TissueSubstitute, Open Approach */
"02U608Z" = '1' /*Supplement Right Atrium with Zooplastic Tissue,Open Approach */
"02U60KZ" = '1' /*Supplement Right Atrium with Nonautologous TissueSubstitute, Open Approach */
"02U707Z" = '1' /*Supplement Left Atrium with Autologous TissueSubstitute, Open Approach */
"02U708Z" = '1' /*Supplement Left Atrium with Zooplastic Tissue, OpenApproach */
"02U70JZ" = '1' /*Supplement Left Atrium with Synthetic Substitute,Open Approach */
"02U70KZ" = '1' /*Supplement Left Atrium with Nonautologous TissueSubstitute, Open Approach */
"02U737Z" = '1' /*Supplement Left Atrium with Autologous TissueSubstitute, Percutaneous Approach */
"02U738Z" = '1' /*Supplement Left Atrium with Zooplastic Tissue,Percutaneous Approach */
"02U73KZ" = '1' /*Supplement Left Atrium with Nonautologous TissueSubstitute, Percutaneous Approach */
"02U747Z" = '1' /*Supplement Left Atrium with Autologous TissueSubstitute, Percutaneous Endoscopic Approach */
"02U748Z" = '1' /*Supplement Left Atrium with Zooplastic Tissue,Percutaneous Endoscopic Approach */
"02U74KZ" = '1' /*Supplement Left Atrium with Nonautologous TissueSubstitute, Percutaneous Endoscopic Approach */
"02U907Z" = '1' /*Supplement Chordae Tendineae with AutologousTissue Substitute, Open Approach */
"02U908Z" = '1' /*Supplement Chordae Tendineae with ZooplasticTissue, Open Approach */
"02U90JZ" = '1' /*Supplement Chordae Tendineae with SyntheticSubstitute, Open Approach */
"02U90KZ" = '1' /*Supplement Chordae Tendineae with NonautologousTissue Substitute, Open Approach */
"02U937Z" = '1' /*Supplement Chordae Tendineae with AutologousTissue Substitute, Percutaneous Approach */
"02U938Z" = '1' /*Supplement Chordae Tendineae with ZooplasticTissue, Percutaneous Approach */
"02U93JZ" = '1' /*Supplement Chordae Tendineae with SyntheticSubstitute, Percutaneous Approach */
"02U93KZ" = '1' /*Supplement Chordae Tendineae with NonautologousTissue Substitute, Percutaneous Approach */
"02U947Z" = '1' /*Supplement Chordae Tendineae with AutologousTissue Substitute, Percutaneous EndoscopicApproach */
"02U948Z" = '1' /*Supplement Chordae Tendineae with ZooplasticTissue, Percutaneous Endoscopic Approach */
"02U94JZ" = '1' /*Supplement Chordae Tendineae with SyntheticSubstitute, Percutaneous Endoscopic Approach */
"02U94KZ" = '1' /*Supplement Chordae Tendineae with NonautologousTissue Substitute, Percutaneous EndoscopicApproach */
"02UA0JZ" = '1' /*Supplement Heart with Synthetic Substitute, OpenApproach */
"02UA3JZ" = '1' /*Supplement Heart with Synthetic Substitute,Percutaneous Approach */
"02UA4JZ" = '1' /*Supplement Heart with Synthetic Substitute,Percutaneous Endoscopic Approach */
"02UD07Z" = '1' /*Supplement Papillary Muscle with Autologous TissueSubstitute, Open Approach */
"02UD08Z" = '1' /*Supplement Papillary Muscle with Zooplastic Tissue,Open Approach */
"02UD0JZ" = '1' /*Supplement Papillary Muscle with SyntheticSubstitute, Open Approach */
"02UD0KZ" = '1' /*Supplement Papillary Muscle with NonautologousTissue Substitute, Open Approach */
"02UD37Z" = '1' /*Supplement Papillary Muscle with Autologous TissueSubstitute, Percutaneous Approach */
"02UD38Z" = '1' /*Supplement Papillary Muscle with Zooplastic Tissue,Percutaneous Approach */
"02UD3JZ" = '1' /*Supplement Papillary Muscle with SyntheticSubstitute, Percutaneous Approach */
"02UD3KZ" = '1' /*Supplement Papillary Muscle with NonautologousTissue Substitute, Percutaneous Approach */
"02UD47Z" = '1' /*Supplement Papillary Muscle with Autologous TissueSubstitute, Percutaneous Endoscopic Approach */
"02UD48Z" = '1' /*Supplement Papillary Muscle with Zooplastic Tissue,Percutaneous Endoscopic Approach */
"02UD4JZ" = '1' /*Supplement Papillary Muscle with SyntheticSubstitute, Percutaneous Endoscopic Approach */
"02UD4KZ" = '1' /*Supplement Papillary Muscle with NonautologousTissue Substitute, Percutaneous EndoscopicApproach */
"02UF07J" = '1' /*Supplement Aortic Valve created from Truncal Valve with Autologous Tissue Substitute, Open Approach */
"02UF07Z" = '1' /*Supplement Aortic Valve with Autologous TissueSubstitute, Open Approach */
"02UF08J" = '1' /*Supplement Aortic Valve created from Truncal Valve with Zooplastic Tissue, Open Approach */
"02UF08Z" = '1' /*Supplement Aortic Valve with Zooplastic Tissue, OpenApproach */
"02UF0JJ" = '1' /*Supplement Aortic Valve created from Truncal Valve with Synthetic Substitute, Open Approach */
"02UF0JZ" = '1' /*Supplement Aortic Valve with Synthetic Substitute,Open Approach */
"02UF0KJ" = '1' /*Supplement Aortic Valve created from Truncal Valve with Nonautologous Tissue Substitute, Open Approach */
"02UF0KZ" = '1' /*Supplement Aortic Valve with Nonautologous TissueSubstitute, Open Approach */
"02UF37J" = '1' /*Supplement Aortic Valve created from Truncal Valve with Autologous Tissue Substitute, Percutaneous Approach */
"02UF37Z" = '1' /*Supplement Aortic Valve with Autologous TissueSubstitute, Percutaneous Approach */
"02UF38J" = '1' /*Supplement Aortic Valve created from Truncal Valve with Zooplastic Tissue, Percutaneous Approach */
"02UF38Z" = '1' /*Supplement Aortic Valve with Zooplastic Tissue,Percutaneous Approach */
"02UF3JJ" = '1' /*Supplement Aortic Valve created from Truncal Valve with Synthetic Substitute, Percutaneous Approach */
"02UF3JZ" = '1' /*Supplement Aortic Valve with Synthetic Substitute,Percutaneous Approach */
"02UF3KJ" = '1' /*Supplement Aortic Valve created from Truncal Valve with Nonautologous Tissue Substitute, Percutaneous Approach */
"02UF3KZ" = '1' /*Supplement Aortic Valve with Nonautologous TissueSubstitute, Percutaneous Approach */
"02UF47J" = '1' /*Supplement Aortic Valve created from Truncal Valve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UF47Z" = '1' /*Supplement Aortic Valve with Autologous TissueSubstitute, Percutaneous Endoscopic Approach */
"02UF48J" = '1' /*Supplement Aortic Valve created from Truncal Valve with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UF48Z" = '1' /*Supplement Aortic Valve with Zooplastic Tissue,Percutaneous Endoscopic Approach */
"02UF4JJ" = '1' /*Supplement Aortic Valve created from Truncal Valve with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UF4JZ" = '1' /*Supplement Aortic Valve with Synthetic Substitute,Percutaneous Endoscopic Approach */
"02UF4KJ" = '1' /*Supplement Aortic Valve created from Truncal Valve with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UF4KZ" = '1' /*Supplement Aortic Valve with Nonautologous TissueSubstitute, Percutaneous Endoscopic Approach */
"02UG07E" = '1' /*Supplement Mitral Valve created from Left Atrioventricular Valve with Autologous Tissue Substitute, Open Approach */
"02UG07Z" = '1' /*Supplement Mitral Valve with Autologous TissueSubstitute, Open Approach */
"02UG08E" = '1' /*Supplement Mitral Valve created from Left Atrioventricular Valve with Zooplastic Tissue, Open Approach */
"02UG08Z" = '1' /*Supplement Mitral Valve with Zooplastic Tissue, OpenApproach */
"02UG0JE" = '1' /*Supplement Mitral Valve created from Left Atrioventricular Valve with Synthetic Substitute, Open Approach */
"02UG0JZ" = '1' /*Supplement Mitral Valve with Synthetic Substitute,Open Approach */
"02UG0KE" = '1' /*Supplement Mitral Valve created from Left Atrioventricular Valve with Nonautologous Tissue Substitute, Open Approach */
"02UG0KZ" = '1' /*Supplement Mitral Valve with Nonautologous TissueSubstitute, Open Approach */
"02UG37E" = '1' /*Supplement Mitral Valve created from Left Atrioventricular Valve with Autologous Tissue Substitute, Percutaneous Approach */
"02UG37Z" = '1' /*Supplement Mitral Valve with Autologous TissueSubstitute, Percutaneous Approach */
"02UG38E" = '1' /*Supplement Mitral Valve created from Left Atrioventricular Valve with Zooplastic Tissue, Percutaneous Approach */
"02UG38Z" = '1' /*Supplement Mitral Valve with Zooplastic Tissue,Percutaneous Approach */
"02UG3JE" = '1' /*Supplement Mitral Valve created from Left Atrioventricular Valve with Synthetic Substitute, Percutaneous Approach */
"02UG3JZ" = '1' /*Supplement Mitral Valve with Synthetic Substitute,Percutaneous Approach */
"02UG3KE" = '1' /*Supplement Mitral Valve created from Left Atrioventricular Valve with Nonautologous Tissue Substitute, Percutaneous Approach */
"02UG3KZ" = '1' /*Supplement Mitral Valve with Nonautologous TissueSubstitute, Percutaneous Approach */
"02UG47E" = '1' /*Supplement Mitral Valve created from Left Atrioventricular Valve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UG47Z" = '1' /*Supplement Mitral Valve with Autologous TissueSubstitute, Percutaneous Endoscopic Approach */
"02UG48E" = '1' /*Supplement Mitral Valve created from Left Atrioventricular Valve with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UG48Z" = '1' /*Supplement Mitral Valve with Zooplastic Tissue,Percutaneous Endoscopic Approach */
"02UG4JE" = '1' /*Supplement Mitral Valve created from Left Atrioventricular Valve with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UG4JZ" = '1' /*Supplement Mitral Valve with Synthetic Substitute,Percutaneous Endoscopic Approach */
"02UG4KE" = '1' /*Supplement Mitral Valve created from Left Atrioventricular Valve with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UG4KZ" = '1' /*Supplement Mitral Valve with Nonautologous TissueSubstitute, Percutaneous Endoscopic Approach */
"02UH07Z" = '1' /*Supplement Pulmonary Valve with Autologous TissueSubstitute, Open Approach */
"02UH08Z" = '1' /*Supplement Pulmonary Valve with Zooplastic Tissue,Open Approach */
"02UH0JZ" = '1' /*Supplement Pulmonary Valve with SyntheticSubstitute, Open Approach */
"02UH0KZ" = '1' /*Supplement Pulmonary Valve with NonautologousTissue Substitute, Open Approach */
"02UH37Z" = '1' /*Supplement Pulmonary Valve with Autologous TissueSubstitute, Percutaneous Approach */
"02UH38Z" = '1' /*Supplement Pulmonary Valve with Zooplastic Tissue,Percutaneous Approach */
"02UH3JZ" = '1' /*Supplement Pulmonary Valve with SyntheticSubstitute, Percutaneous Approach */
"02UH3KZ" = '1' /*Supplement Pulmonary Valve with NonautologousTissue Substitute, Percutaneous Approach */
"02UH47Z" = '1' /*Supplement Pulmonary Valve with Autologous TissueSubstitute, Percutaneous Endoscopic Approach */
"02UH48Z" = '1' /*Supplement Pulmonary Valve with Zooplastic Tissue,Percutaneous Endoscopic Approach */
"02UH4JZ" = '1' /*Supplement Pulmonary Valve with SyntheticSubstitute, Percutaneous Endoscopic Approach */
"02UH4KZ" = '1' /*Supplement Pulmonary Valve with NonautologousTissue Substitute, Percutaneous EndoscopicApproach */
"02UJ07G" = '1' /*Supplement Tricuspid Valve created from Right Atrioventricular Valve with Autologous Tissue Substitute, Open Approach */
"02UJ07Z" = '1' /*Supplement Tricuspid Valve with Autologous TissueSubstitute, Open Approach */
"02UJ08G" = '1' /*Supplement Tricuspid Valve created from Right Atrioventricular Valve with Zooplastic Tissue, Open Approach */
"02UJ08Z" = '1' /*Supplement Tricuspid Valve with Zooplastic Tissue,Open Approach */
"02UJ0JG" = '1' /*Supplement Tricuspid Valve created from Right Atrioventricular Valve with Synthetic Substitute, Open Approach */
"02UJ0JZ" = '1' /*Supplement Tricuspid Valve with Synthetic Substitute,Open Approach */
"02UJ0KG" = '1' /*Supplement Tricuspid Valve created from Right Atrioventricular Valve with Nonautologous Tissue Substitute, Open Approach */
"02UJ0KZ" = '1' /*Supplement Tricuspid Valve with NonautologousTissue Substitute, Open Approach */
"02UJ37G" = '1' /*Supplement Tricuspid Valve created from Right Atrioventricular Valve with Autologous Tissue Substitute, Percutaneous Approach */
"02UJ37Z" = '1' /*Supplement Tricuspid Valve with Autologous TissueSubstitute, Percutaneous Approach */
"02UJ38G" = '1' /*Supplement Tricuspid Valve created from Right Atrioventricular Valve with Zooplastic Tissue, Percutaneous Approach */
"02UJ38Z" = '1' /*Supplement Tricuspid Valve with Zooplastic Tissue,Percutaneous Approach */
"02UJ3JG" = '1' /*Supplement Tricuspid Valve created from Right Atrioventricular Valve with Synthetic Substitute, Percutaneous Approach */
"02UJ3JZ" = '1' /*Supplement Tricuspid Valve with Synthetic Substitute,Percutaneous Approach */
"02UJ3KG" = '1' /*Supplement Tricuspid Valve created from Right Atrioventricular Valve with Nonautologous Tissue Substitute, Percutaneous Approach */
"02UJ3KZ" = '1' /*Supplement Tricuspid Valve with NonautologousTissue Substitute, Percutaneous Approach */
"02UJ47G" = '1' /*Supplement Tricuspid Valve created from Right Atrioventricular Valve with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UJ47Z" = '1' /*Supplement Tricuspid Valve with Autologous TissueSubstitute, Percutaneous Endoscopic Approach */
"02UJ48G" = '1' /*Supplement Tricuspid Valve created from Right Atrioventricular Valve with Zooplastic Tissue, Percutaneous Endoscopic Approach */
"02UJ48Z" = '1' /*Supplement Tricuspid Valve with Zooplastic Tissue,Percutaneous Endoscopic Approach */
"02UJ4JG" = '1' /*Supplement Tricuspid Valve created from Right Atrioventricular Valve with Synthetic Substitute, Percutaneous Endoscopic Approach */
"02UJ4JZ" = '1' /*Supplement Tricuspid Valve with Synthetic Substitute,Percutaneous Endoscopic Approach */
"02UJ4KG" = '1' /*Supplement Tricuspid Valve created from Right Atrioventricular Valve with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"02UJ4KZ" = '1' /*Supplement Tricuspid Valve with NonautologousTissue Substitute, Percutaneous EndoscopicApproach */
"02UK0KZ" = '1' /*Supplement Right Ventricle with NonautologousTissue Substitute, Open Approach */
"02UK3KZ" = '1' /*Supplement Right Ventricle with NonautologousTissue Substitute, Percutaneous Approach */
"02UK4KZ" = '1' /*Supplement Right Ventricle with NonautologousTissue Substitute, Percutaneous EndoscopicApproach */
"02UL0KZ" = '1' /*Supplement Left Ventricle with Nonautologous TissueSubstitute, Open Approach */
"02UL3KZ" = '1' /*Supplement Left Ventricle with Nonautologous TissueSubstitute, Percutaneous Approach */
"02UL4KZ" = '1' /*Supplement Left Ventricle with Nonautologous TissueSubstitute, Percutaneous Endoscopic Approach */
"02UM07Z" = '1' /*Supplement Ventricular Septum with AutologousTissue Substitute, Open Approach */
"02UM0JZ" = '1' /*Supplement Ventricular Septum with SyntheticSubstitute, Open Approach */
"02UM0KZ" = '1' /*Supplement Ventricular Septum with NonautologousTissue Substitute, Open Approach */
"02UM37Z" = '1' /*Supplement Ventricular Septum with AutologousTissue Substitute, Percutaneous Approach */
"02UM38Z" = '1' /*Supplement Ventricular Septum with ZooplasticTissue, Percutaneous Approach */
"02UM3JZ" = '1' /*Supplement Ventricular Septum with SyntheticSubstitute, Percutaneous Approach */
"02UM3KZ" = '1' /*Supplement Ventricular Septum with NonautologousTissue Substitute, Percutaneous Approach */
"02UM47Z" = '1' /*Supplement Ventricular Septum with AutologousTissue Substitute, Percutaneous EndoscopicApproach */
"02UM48Z" = '1' /*Supplement Ventricular Septum with ZooplasticTissue, Percutaneous Endoscopic Approach */
"02UM4JZ" = '1' /*Supplement Ventricular Septum with SyntheticSubstitute, Percutaneous Endoscopic Approach */
"02UM4KZ" = '1' /*Supplement Ventricular Septum with NonautologousTissue Substitute, Percutaneous EndoscopicApproach */
"02VG0ZZ" = '1' /*Restriction of Mitral Valve, Open Approach */
"02VG3ZZ" = '1' /*Restriction of Mitral Valve, Percutaneous Approach */
"02VG4ZZ" = '1' /*Restriction of Mitral Valve, Percutaneous Endoscopic Approach */
"02VR0ZT" = '1' /*Restriction of Ductus Arteriosus, Open Approach */
"02W50JZ" = '1' /*Revision of Synthetic Substitute in Atrial Septum,Open Approach */
"02W54JZ" = '1' /*Revision of Synthetic Substitute in Atrial Septum,Percutaneous Endoscopic Approach */
"02WA0JZ" = '1' /*Revision of Synthetic Substitute in Heart, OpenApproach */
"02WA0MZ" = '1' /*Revision of Cardiac Lead in Heart, Open Approach */
"02WA0NZ" = '1' /*Revision of Intracardiac Pacemaker in Heart, Open Approach */
"02WA0QZ" = '1' /*Revision of Implantable Heart Assist System in Heart,Open Approach */
"02WA0RS" = '1' /*Revision of Biventricular Short-term External Heart Assist System in Heart, Open Approach */
"02WA0RZ" = '1' /*Revision of Short-term External Heart Assist System in Heart, Open Approach */
"02WA3MZ" = '1' /*Revision of Cardiac Lead in Heart, PercutaneousApproach */
"02WA3QZ" = '1' /*Revision of Implantable Heart Assist System in Heart,Percutaneous Approach */
"02WA3RS" = '1' /*Revision of Biventricular Short-term External Heart Assist System in Heart, Percutaneous Approach */
"02WA3RZ" = '1' /*Revision of Short-term External Heart Assist System in Heart, Percutaneous Approach */
"02WA4MZ" = '1' /*Revision of Cardiac Lead in Heart, PercutaneousEndoscopic Approach */
"02WA4NZ" = '1' /*Revision of Intracardiac Pacemaker in Heart, Percutaneous Endoscopic Approach */
"02WA4QZ" = '1' /*Revision of Implantable Heart Assist System in Heart,Percutaneous Endoscopic Approach */
"02WA4RS" = '1' /*Revision of Biventricular Short-term External Heart Assist System in Heart, Percutaneous Endoscopic Approach */
"02WA4RZ" = '1' /*Revision of Short-term External Heart Assist System in Heart, Percutaneous Endoscopic Approach */
"02WAXRS" = '1' /*Revision of Biventricular Short-term External Heart Assist System in Heart, External Approach */
"02WF07Z" = '1' /*Revision of Autologous Tissue Substitute in AorticValve, Open Approach */
"02WF08Z" = '1' /*Revision of Zooplastic Tissue in Aortic Valve, OpenApproach */
"02WF0JZ" = '1' /*Revision of Synthetic Substitute in Aortic Valve, OpenApproach */
"02WF0KZ" = '1' /*Revision of Nonautologous Tissue Substitute in AorticValve, Open Approach */
"02WF37Z" = '1' /*Revision of Autologous Tissue Substitute in Aortic Valve, Percutaneous Approach */
"02WF38Z" = '1' /*Revision of Zooplastic Tissue in Aortic Valve, Percutaneous Approach */
"02WF3JZ" = '1' /*Revision of Synthetic Substitute in Aortic Valve, Percutaneous Approach */
"02WF3KZ" = '1' /*Revision of Nonautologous Tissue Substitute in Aortic Valve, Percutaneous Approach */
"02WF47Z" = '1' /*Revision of Autologous Tissue Substitute in AorticValve, Percutaneous Endoscopic Approach */
"02WF48Z" = '1' /*Revision of Zooplastic Tissue in Aortic Valve,Percutaneous Endoscopic Approach */
"02WF4JZ" = '1' /*Revision of Synthetic Substitute in Aortic Valve,Percutaneous Endoscopic Approach */
"02WF4KZ" = '1' /*Revision of Nonautologous Tissue Substitute in AorticValve, Percutaneous Endoscopic Approach */
"02WG07Z" = '1' /*Revision of Autologous Tissue Substitute in MitralValve, Open Approach */
"02WG08Z" = '1' /*Revision of Zooplastic Tissue in Mitral Valve, OpenApproach */
"02WG0JZ" = '1' /*Revision of Synthetic Substitute in Mitral Valve, OpenApproach */
"02WG0KZ" = '1' /*Revision of Nonautologous Tissue Substitute in MitralValve, Open Approach */
"02WG37Z" = '1' /*Revision of Autologous Tissue Substitute in Mitral Valve, Percutaneous Approach */
"02WG38Z" = '1' /*Revision of Zooplastic Tissue in Mitral Valve, Percutaneous Approach */
"02WG3JZ" = '1' /*Revision of Synthetic Substitute in Mitral Valve, Percutaneous Approach */
"02WG3KZ" = '1' /*Revision of Nonautologous Tissue Substitute in Mitral Valve, Percutaneous Approach */
"02WG47Z" = '1' /*Revision of Autologous Tissue Substitute in MitralValve, Percutaneous Endoscopic Approach */
"02WG48Z" = '1' /*Revision of Zooplastic Tissue in Mitral Valve,Percutaneous Endoscopic Approach */
"02WG4JZ" = '1' /*Revision of Synthetic Substitute in Mitral Valve,Percutaneous Endoscopic Approach */
"02WG4KZ" = '1' /*Revision of Nonautologous Tissue Substitute in MitralValve, Percutaneous Endoscopic Approach */
"02WH07Z" = '1' /*Revision of Autologous Tissue Substitute inPulmonary Valve, Open Approach */
"02WH08Z" = '1' /*Revision of Zooplastic Tissue in Pulmonary Valve,Open Approach */
"02WH0JZ" = '1' /*Revision of Synthetic Substitute in Pulmonary Valve,Open Approach */
"02WH0KZ" = '1' /*Revision of Nonautologous Tissue Substitute inPulmonary Valve, Open Approach */
"02WH37Z" = '1' /*Revision of Autologous Tissue Substitute in Pulmonary Valve, Percutaneous Approach */
"02WH38Z" = '1' /*Revision of Zooplastic Tissue in Pulmonary Valve, Percutaneous Approach */
"02WH3JZ" = '1' /*Revision of Synthetic Substitute in Pulmonary Valve, Percutaneous Approach */
"02WH3KZ" = '1' /*Revision of Nonautologous Tissue Substitute in Pulmonary Valve, Percutaneous Approach */
"02WH47Z" = '1' /*Revision of Autologous Tissue Substitute inPulmonary Valve, Percutaneous EndoscopicApproach */
"02WH48Z" = '1' /*Revision of Zooplastic Tissue in Pulmonary Valve,Percutaneous Endoscopic Approach */
"02WH4JZ" = '1' /*Revision of Synthetic Substitute in Pulmonary Valve,Percutaneous Endoscopic Approach */
"02WH4KZ" = '1' /*Revision of Nonautologous Tissue Substitute inPulmonary Valve, Percutaneous EndoscopicApproach */
"02WJ07Z" = '1' /*Revision of Autologous Tissue Substitute in TricuspidValve, Open Approach */
"02WJ08Z" = '1' /*Revision of Zooplastic Tissue in Tricuspid Valve,Open Approach */
"02WJ0JZ" = '1' /*Revision of Synthetic Substitute in Tricuspid Valve,Open Approach */
"02WJ0KZ" = '1' /*Revision of Nonautologous Tissue Substitute inTricuspid Valve, Open Approach */
"02WJ37Z" = '1' /*Revision of Autologous Tissue Substitute in Tricuspid Valve, Percutaneous Approach */
"02WJ38Z" = '1' /*Revision of Zooplastic Tissue in Tricuspid Valve, Percutaneous Approach */
"02WJ3JZ" = '1' /*Revision of Synthetic Substitute in Tricuspid Valve, Percutaneous Approach */
"02WJ3KZ" = '1' /*Revision of Nonautologous Tissue Substitute in Tricuspid Valve, Percutaneous Approach */
"02WJ47Z" = '1' /*Revision of Autologous Tissue Substitute in TricuspidValve, Percutaneous Endoscopic Approach */
"02WJ48Z" = '1' /*Revision of Zooplastic Tissue in Tricuspid Valve,Percutaneous Endoscopic Approach */
"02WJ4JZ" = '1' /*Revision of Synthetic Substitute in Tricuspid Valve,Percutaneous Endoscopic Approach */
"02WJ4KZ" = '1' /*Revision of Nonautologous Tissue Substitute inTricuspid Valve, Percutaneous Endoscopic Approach */
"02WM0JZ" = '1' /*Revision of Synthetic Substitute in VentricularSeptum, Open Approach */
"02WM4JZ" = '1' /*Revision of Synthetic Substitute in VentricularSeptum, Percutaneous Endoscopic Approach */
"02YA0Z0" = '1' /*Transplantation of Heart, Allogeneic, Open Approach */
"02YA0Z1" = '1' /*Transplantation of Heart, Syngeneic, Open Approach */
"02YA0Z2" = '1' /*Transplantation of Heart, Zooplastic, Open Approach */
"061007P" = '1' /*Bypass Inferior Vena Cava to Pulmonary Trunk with Autologous Tissue Substitute, Open Approach */
"061007Q" = '1' /*Bypass Inferior Vena Cava to Right Pulmonary Artery with Autologous Tissue Substitute, Open Approach */
"061007R" = '1' /*Bypass Inferior Vena Cava to Left Pulmonary Artery with Autologous Tissue Substitute, Open Approach */
"061009P" = '1' /*Bypass Inferior Vena Cava to Pulmonary Trunk with Autologous Venous Tissue, Open Approach */
"061009Q" = '1' /*Bypass Inferior Vena Cava to Right Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"061009R" = '1' /*Bypass Inferior Vena Cava to Left Pulmonary Artery with Autologous Venous Tissue, Open Approach */
"06100AP" = '1' /*Bypass Inferior Vena Cava to Pulmonary Trunk with Autologous Arterial Tissue, Open Approach */
"06100AQ" = '1' /*Bypass Inferior Vena Cava to Right Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"06100AR" = '1' /*Bypass Inferior Vena Cava to Left Pulmonary Artery with Autologous Arterial Tissue, Open Approach */
"06100JP" = '1' /*Bypass Inferior Vena Cava to Pulmonary Trunk with Synthetic Substitute, Open Approach */
"06100JQ" = '1' /*Bypass Inferior Vena Cava to Right Pulmonary Artery with Synthetic Substitute, Open Approach */
"06100JR" = '1' /*Bypass Inferior Vena Cava to Left Pulmonary Artery with Synthetic Substitute, Open Approach */
"06100KP" = '1' /*Bypass Inferior Vena Cava to Pulmonary Trunk with Nonautologous Tissue Substitute, Open Approach */
"06100KQ" = '1' /*Bypass Inferior Vena Cava to Right Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"06100KR" = '1' /*Bypass Inferior Vena Cava to Left Pulmonary Artery with Nonautologous Tissue Substitute, Open Approach */
"06100ZP" = '1' /*Bypass Inferior Vena Cava to Pulmonary Trunk, Open Approach */
"06100ZQ" = '1' /*Bypass Inferior Vena Cava to Right Pulmonary Artery, Open Approach */
"06100ZR" = '1' /*Bypass Inferior Vena Cava to Left Pulmonary Artery, Open Approach */
"061047P" = '1' /*Bypass Inferior Vena Cava to Pulmonary Trunk with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061047Q" = '1' /*Bypass Inferior Vena Cava to Right Pulmonary Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061047R" = '1' /*Bypass Inferior Vena Cava to Left Pulmonary Artery with Autologous Tissue Substitute, Percutaneous Endoscopic Approach */
"061049P" = '1' /*Bypass Inferior Vena Cava to Pulmonary Trunk with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"061049Q" = '1' /*Bypass Inferior Vena Cava to Right Pulmonary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"061049R" = '1' /*Bypass Inferior Vena Cava to Left Pulmonary Artery with Autologous Venous Tissue, Percutaneous Endoscopic Approach */
"06104AP" = '1' /*Bypass Inferior Vena Cava to Pulmonary Trunk with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"06104AQ" = '1' /*Bypass Inferior Vena Cava to Right Pulmonary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"06104AR" = '1' /*Bypass Inferior Vena Cava to Left Pulmonary Artery with Autologous Arterial Tissue, Percutaneous Endoscopic Approach */
"06104JP" = '1' /*Bypass Inferior Vena Cava to Pulmonary Trunk with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06104JQ" = '1' /*Bypass Inferior Vena Cava to Right Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06104JR" = '1' /*Bypass Inferior Vena Cava to Left Pulmonary Artery with Synthetic Substitute, Percutaneous Endoscopic Approach */
"06104KP" = '1' /*Bypass Inferior Vena Cava to Pulmonary Trunk with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06104KQ" = '1' /*Bypass Inferior Vena Cava to Right Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06104KR" = '1' /*Bypass Inferior Vena Cava to Left Pulmonary Artery with Nonautologous Tissue Substitute, Percutaneous Endoscopic Approach */
"06104ZP" = '1' /*Bypass Inferior Vena Cava to Pulmonary Trunk, Percutaneous Endoscopic Approach */
"06104ZQ" = '1' /*Bypass Inferior Vena Cava to Right Pulmonary Artery, Percutaneous Endoscopic Approach */
"06104ZR" = '1' /*Bypass Inferior Vena Cava to Left Pulmonary Artery, Percutaneous Endoscopic Approach */
"0JH600Z" = '1' /*Insertion of Hemodynamic Monitoring Device intoChest Subcutaneous Tissue and Fascia, OpenApproach */
"0JH604Z" = '1' /*Insertion of Pacemaker, Single Chamber into ChestSubcutaneous Tissue and Fascia, Open Approach */
"0JH605Z" = '1' /*Insertion of Pacemaker, Single Chamber RateResponsive into Chest Subcutaneous Tissue andFascia, Open Approach */
"0JH606Z" = '1' /*Insertion of Pacemaker, Dual Chamber into ChestSubcutaneous Tissue and Fascia, Open Approach */
"0JH607Z" = '1' /*Insertion of Cardiac Resynchronization PacemakerPulse Generator into Chest Subcutaneous Tissue andFascia, Open Approach */
"0JH608Z" = '1' /*Insertion of Defibrillator Generator into ChestSubcutaneous Tissue and Fascia, Open Approach */
"0JH609Z" = '1' /*Insertion of Cardiac Resynchronization DefibrillatorPulse Generator into Chest Subcutaneous Tissue andFascia, Open Approach */
"0JH60AZ" = '1' /*Insertion of Contractility Modulation Device into ChestSubcutaneous Tissue and Fascia, Open Approach */
"0JH60PZ" = '1' /*Insertion of Cardiac Rhythm Related Device intoChest Subcutaneous Tissue and Fascia, OpenApproach */
"0JH630Z" = '1' /*Insertion of Hemodynamic Monitoring Device intoChest Subcutaneous Tissue and Fascia,Percutaneous Approach */
"0JH634Z" = '1' /*Insertion of Pacemaker, Single Chamber into ChestSubcutaneous Tissue and Fascia, PercutaneousApproach */
"0JH635Z" = '1' /*Insertion of Pacemaker, Single Chamber RateResponsive into Chest Subcutaneous Tissue andFascia, Percutaneous Approach */
"0JH636Z" = '1' /*Insertion of Pacemaker, Dual Chamber into ChestSubcutaneous Tissue and Fascia, PercutaneousApproach */
"0JH637Z" = '1' /*Insertion of Cardiac Resynchronization PacemakerPulse Generator into Chest Subcutaneous Tissue andFascia, Percutaneous Approach */
"0JH638Z" = '1' /*Insertion of Defibrillator Generator into ChestSubcutaneous Tissue and Fascia, PercutaneousApproach */
"0JH639Z" = '1' /*Insertion of Cardiac Resynchronization DefibrillatorPulse Generator into Chest Subcutaneous Tissue andFascia, Percutaneous Approach */
"0JH63AZ" = '1' /*Insertion of Contractility Modulation Device into ChestSubcutaneous Tissue and Fascia, PercutaneousApproach */
"0JH63PZ" = '1' /*Insertion of Cardiac Rhythm Related Device intoChest Subcutaneous Tissue and Fascia,Percutaneous Approach */
"0JH800Z" = '1' /*Insertion of Hemodynamic Monitoring Device intoAbdomen Subcutaneous Tissue and Fascia, OpenApproach */
"0JH804Z" = '1' /*Insertion of Pacemaker, Single Chamber intoAbdomen Subcutaneous Tissue and Fascia, OpenApproach */
"0JH805Z" = '1' /*Insertion of Pacemaker, Single Chamber RateResponsive into Abdomen Subcutaneous Tissue andFascia, Open Approach */
"0JH806Z" = '1' /*Insertion of Pacemaker, Dual Chamber into AbdomenSubcutaneous Tissue and Fascia, Open Approach */
"0JH807Z" = '1' /*Insertion of Cardiac Resynchronization PacemakerPulse Generator into Abdomen Subcutaneous Tissueand Fascia, Open Approach */
"0JH808Z" = '1' /*Insertion of Defibrillator Generator into AbdomenSubcutaneous Tissue and Fascia, Open Approach */
"0JH809Z" = '1' /*Insertion of Cardiac Resynchronization DefibrillatorPulse Generator into Abdomen Subcutaneous Tissueand Fascia, Open Approach */
"0JH80AZ" = '1' /*Insertion of Contractility Modulation Device intoAbdomen Subcutaneous Tissue and Fascia, OpenApproach */
"0JH80PZ" = '1' /*Insertion of Cardiac Rhythm Related Device intoAbdomen Subcutaneous Tissue and Fascia, OpenApproach */
"0JH830Z" = '1' /*Insertion of Hemodynamic Monitoring Device intoAbdomen Subcutaneous Tissue and Fascia,Percutaneous Approach */
"0JH834Z" = '1' /*Insertion of Pacemaker, Single Chamber intoAbdomen Subcutaneous Tissue and Fascia,Percutaneous Approach */
"0JH835Z" = '1' /*Insertion of Pacemaker, Single Chamber RateResponsive into Abdomen Subcutaneous Tissue andFascia, Percutaneous Approach */
"0JH836Z" = '1' /*Insertion of Pacemaker, Dual Chamber into AbdomenSubcutaneous Tissue and Fascia, PercutaneousApproach */
"0JH837Z" = '1' /*Insertion of Cardiac Resynchronization PacemakerPulse Generator into Abdomen Subcutaneous Tissueand Fascia, Percutaneous Approach */
"0JH838Z" = '1' /*Insertion of Defibrillator Generator into AbdomenSubcutaneous Tissue and Fascia, PercutaneousApproach */
"0JH839Z" = '1' /*Insertion of Cardiac Resynchronization DefibrillatorPulse Generator into Abdomen Subcutaneous Tissueand Fascia, Percutaneous Approach */
"0JH83AZ" = '1' /*Insertion of Contractility Modulation Device intoAbdomen Subcutaneous Tissue and Fascia,Percutaneous Approach */
"0JH83PZ" = '1' /*Insertion of Cardiac Rhythm Related Device intoAbdomen Subcutaneous Tissue and Fascia,Percutaneous Approach */
"0JPT0PZ" = '1' /*Removal of Cardiac Rhythm Related Device fromTrunk Subcutaneous Tissue and Fascia, OpenApproach */
"0JPT3PZ" = '1' /*Removal of Cardiac Rhythm Related Device fromTrunk Subcutaneous Tissue and Fascia,Percutaneous Approach */
"0JWT0PZ" = '1' /*Revision of Cardiac Rhythm Related Device in TrunkSubcutaneous Tissue and Fascia, Open Approach */
"0JWT3PZ" = '1' /*Revision of Cardiac Rhythm Related Device in TrunkSubcutaneous Tissue and Fascia, PercutaneousApproach */
"0W9D00Z" = '1' /*Drainage of Pericardial Cavity with DrainageDevice, Open Approach */
"0W9D0ZX" = '1' /*Drainage of Pericardial Cavity, OpenApproach, Diagnostic */
"0W9D0ZZ" = '1' /*Drainage of Pericardial Cavity, OpenApproach */
"0W9D30Z" = '1' /*Drainage of Pericardial Cavity with DrainageDevice, Percutaneous Approach */
"0W9D3ZX" = '1' /*Drainage of Pericardial Cavity,Percutaneous Approach, Diagnostic */
"0W9D3ZZ" = '1' /*Drainage of Pericardial Cavity,Percutaneous Approach */
"0W9D40Z" = '1' /*Drainage of Pericardial Cavity with DrainageDevice, Percutaneous Endoscopic Approach */
"0W9D4ZX" = '1' /*Drainage of Pericardial Cavity,Percutaneous Endoscopic Approach,Diagnostic */
"0W9D4ZZ" = '1' /*Drainage of Pericardial Cavity,Percutaneous Endoscopic Approach */
"0WCD0ZZ" = '1' /*Extirpation of Matter from Pericardial Cavity,Open Approach */
"0WCD3ZZ" = '1' /*Extirpation of Matter from Pericardial Cavity,Percutaneous Approach */
"0WCD4ZZ" = '1' /*Extirpation of Matter from Pericardial Cavity,Percutaneous Endoscopic Approach */
"0WFD0ZZ" = '1' /*Fragmentation in Pericardial Cavity, OpenApproach */
"0WFD3ZZ" = '1' /*Fragmentation in Pericardial Cavity,Percutaneous Approach */
"0WFD4ZZ" = '1' /*Fragmentation in Pericardial Cavity,Percutaneous Endoscopic Approach */
"0WFDXZZ" = '1' /*Fragmentation in Pericardial Cavity, ExternalApproach */
"0WHD03Z" = '1' /*Insertion of Infusion Device into PericardialCavity, Open Approach */
"0WHD0YZ" = '1' /*Insertion of Other Device into PericardialCavity, Open Approach */
"0WHD33Z" = '1' /*Insertion of Infusion Device into PericardialCavity, Percutaneous Approach */
"0WHD3YZ" = '1' /*Insertion of Other Device into PericardialCavity, Percutaneous Approach */
"0WHD43Z" = '1' /*Insertion of Infusion Device into PericardialCavity, Percutaneous Endoscopic Approach */
"0WHD4YZ" = '1' /*Insertion of Other Device into PericardialCavity, Percutaneous Endoscopic Approach */
"0WPD00Z" = '1' /*Removal of Drainage Device fromPericardial Cavity, Open Approach */
"0WPD01Z" = '1' /*Removal of Radioactive Element fromPericardial Cavity, Open Approach */
"0WPD03Z" = '1' /*Removal of Infusion Device from PericardialCavity, Open Approach */
"0WPD0YZ" = '1' /*Removal of Other Device from PericardialCavity, Open Approach */
"0WPD30Z" = '1' /*Removal of Drainage Device fromPericardial Cavity, Percutaneous Approach */
"0WPD31Z" = '1' /*Removal of Radioactive Element fromPericardial Cavity, Percutaneous Approach */
"0WPD33Z" = '1' /*Removal of Infusion Device from PericardialCavity, Percutaneous Approach */
"0WPD3YZ" = '1' /*Removal of Other Device from PericardialCavity, Percutaneous Approach */
"0WPD40Z" = '1' /*Removal of Drainage Device fromPericardial Cavity, PercutaneousEndoscopic Approach */
"0WPD41Z" = '1' /*Removal of Radioactive Element fromPericardial Cavity, PercutaneousEndoscopic Approach */
"0WPD43Z" = '1' /*Removal of Infusion Device from PericardialCavity, Percutaneous Endoscopic Approach */
"0WPD4YZ" = '1' /*Removal of Other Device from PericardialCavity, Percutaneous Endoscopic Approach */
"0WWD00Z" = '1' /*Revision of Drainage Device in PericardialCavity, Open Approach */
"0WWD01Z" = '1' /*Revision of Radioactive Element inPericardial Cavity, Open Approach */
"0WWD03Z" = '1' /*Revision of Infusion Device in PericardialCavity, Open Approach */
"0WWD0YZ" = '1' /*Revision of Other Device in PericardialCavity, Open Approach */
"0WWD30Z" = '1' /*Revision of Drainage Device in PericardialCavity, Percutaneous Approach */
"0WWD31Z" = '1' /*Revision of Radioactive Element inPericardial Cavity, Percutaneous Approach */
"0WWD33Z" = '1' /*Revision of Infusion Device in PericardialCavity, Percutaneous Approach */
"0WWD3YZ" = '1' /*Revision of Other Device in PericardialCavity, Percutaneous Approach */
"0WWD40Z" = '1' /*Revision of Drainage Device in PericardialCavity, Percutaneous Endoscopic Approach */
"0WWD41Z" = '1' /*Revision of Radioactive Element inPericardial Cavity, PercutaneousEndoscopic Approach */
"0WWD43Z" = '1' /*Revision of Infusion Device in PericardialCavity, Percutaneous Endoscopic Approach */
"0WWD4YZ" = '1' /*Revision of Other Device in PericardialCavity, Percutaneous Endoscopic Approach */
"30230G2" = '1' /*Transfusion of Allogeneic Related Bone Marrow into Peripheral Vein, Open Approach */
"30230G3" = '1' /*Transfusion of Allogeneic Unrelated Bone Marrow into Peripheral Vein, Open Approach */
"30230G4" = '1' /*Transfusion of Allogeneic Unspecified Bone Marrow into Peripheral Vein, Open Approach */
"30230X2" = '1' /*Transfusion of Allogeneic Related Cord Blood Stem Cells into Peripheral Vein, Open Approach */
"30230X3" = '1' /*Transfusion of Allogeneic Unrelated Cord Blood Stem Cells into Peripheral Vein, Open Approach */
"30230X4" = '1' /*Transfusion of Allogeneic Unspecified Cord Blood Stem Cells into Peripheral Vein, Open Approach */
"30230Y2" = '1' /*Transfusion of Allogeneic Related Hematopoietic Stem Cells into Peripheral Vein, Open Approach */
"30230Y3" = '1' /*Transfusion of Allogeneic Unrelated Hematopoietic Stem Cells into Peripheral Vein, Open Approach */
"30230Y4" = '1' /*Transfusion of Allogeneic Unspecified Hematopoietic Stem Cells into Peripheral Vein, Open Approach */
"30233G2" = '1' /*Transfusion of Allogeneic Related Bone Marrow into Peripheral Vein, Percutaneous Approach */
"30233G3" = '1' /*Transfusion of Allogeneic Unrelated Bone Marrow into Peripheral Vein, Percutaneous Approach */
"30233G4" = '1' /*Transfusion of Allogeneic Unspecified Bone Marrow into Peripheral Vein, Percutaneous Approach */
"30233X2" = '1' /*Transfusion of Allogeneic Related Cord Blood Stem Cells into Peripheral Vein, Percutaneous Approach */
"30233X3" = '1' /*Transfusion of Allogeneic Unrelated Cord Blood Stem Cells into Peripheral Vein, Percutaneous Approach */
"30233X4" = '1' /*Transfusion of Allogeneic Unspecified Cord Blood Stem Cells into Peripheral Vein, Percutaneous Approach */
"30233Y2" = '1' /*Transfusion of Allogeneic Related Hematopoietic Stem Cells into Peripheral Vein, Percutaneous Approach */
"30233Y3" = '1' /*Transfusion of Allogeneic Unrelated Hematopoietic Stem Cells into Peripheral Vein, Percutaneous Approach */
"30233Y4" = '1' /*Transfusion of Allogeneic Unspecified Hematopoietic Stem Cells into Peripheral Vein, Percutaneous Approach */
"30240G2" = '1' /*Transfusion of Allogeneic Related Bone Marrow into Central Vein, Open Approach */
"30240G3" = '1' /*Transfusion of Allogeneic Unrelated Bone Marrow into Central Vein, Open Approach */
"30240G4" = '1' /*Transfusion of Allogeneic Unspecified Bone Marrow into Central Vein, Open Approach */
"30240X2" = '1' /*Transfusion of Allogeneic Related Cord Blood Stem Cells into Central Vein, Open Approach */
"30240X3" = '1' /*Transfusion of Allogeneic Unrelated Cord Blood Stem Cells into Central Vein, Open Approach */
"30240X4" = '1' /*Transfusion of Allogeneic Unspecified Cord Blood Stem Cells into Central Vein, Open Approach */
"30240Y2" = '1' /*Transfusion of Allogeneic Related Hematopoietic Stem Cells into Central Vein, Open Approach */
"30240Y3" = '1' /*Transfusion of Allogeneic Unrelated Hematopoietic Stem Cells into Central Vein, Open Approach */
"30240Y4" = '1' /*Transfusion of Allogeneic Unspecified Hematopoietic Stem Cells into Central Vein, Open Approach */
"30243G2" = '1' /*Transfusion of Allogeneic Related Bone Marrow into Central Vein, Percutaneous Approach */
"30243G3" = '1' /*Transfusion of Allogeneic Unrelated Bone Marrow into Central Vein, Percutaneous Approach */
"30243G4" = '1' /*Transfusion of Allogeneic Unspecified Bone Marrow into Central Vein, Percutaneous Approach */
"30243X2" = '1' /*Transfusion of Allogeneic Related Cord Blood Stem Cells into Central Vein, Percutaneous Approach */
"30243X3" = '1' /*Transfusion of Allogeneic Unrelated Cord Blood Stem Cells into Central Vein, Percutaneous Approach */
"30243X4" = '1' /*Transfusion of Allogeneic Unspecified Cord Blood Stem Cells into Central Vein, Percutaneous Approach */
"30243Y2" = '1' /*Transfusion of Allogeneic Related Hematopoietic Stem Cells into Central Vein, Percutaneous Approach */
"30243Y3" = '1' /*Transfusion of Allogeneic Unrelated Hematopoietic Stem Cells into Central Vein, Percutaneous Approach */
"30243Y4" = '1' /*Transfusion of Allogeneic Unspecified Hematopoietic Stem Cells into Central Vein, Percutaneous Approach */
"3E07017" = '1' /*Introduction of Other Thrombolytic into CoronaryArtery, Open Approach */
"3E070PZ" = '1' /*Introduction of Platelet Inhibitor into Coronary Artery,Open Approach */
"3E07317" = '1' /*Introduction of Other Thrombolytic into CoronaryArtery, Percutaneous Approach */
"3E073PZ" = '1' /*Introduction of Platelet Inhibitor into Coronary Artery,Percutaneous Approach */
"3E074GC" = '1' /*Introduction of Other Therapeutic Substance into Coronary Artery, Percutaneous Endoscopic Approach */
"3E084GC" = '1' /*Introduction of Other Therapeutic Substance into Heart, Percutaneous Endoscopic Approach */
"5A02110" = '1' /*Assistance with Cardiac Output using Balloon Pump,Intermittent */
"5A02116" = '1' /*Assistance with Cardiac Output using Other Pump,Intermittent */
"5A02210" = '1' /*Assistance with Cardiac Output using Balloon Pump,Continuous */
"5A02216" = '1' /*Assistance with Cardiac Output using Other Pump,Continuous */
"5A1213Z" = '1' /*Performance of Cardiac Pacing, Intermittent */
"5A1223Z" = '1' /*Performance of Cardiac Pacing, Continuous */
"X2RF032" = '1' /*Replacement of Aortic Valve using Zooplastic Tissue, Rapid Deployment Technique, Open Approach, New Technology Group 2 */
"X2RF332" = '1' /*Replacement of Aortic Valve using Zooplastic Tissue, Rapid Deployment Technique, Percutaneous Approach, New Technology Group 2 */
"X2RF432" = '1' /*Replacement of Aortic Valve using Zooplastic Tissue, Rapid Deployment Technique, Percutaneous Endoscopic Approach, New Technology Group 2 */
OTHER = '0'
;

/* FORMAT FOR Dehydration diagnosis codes */
Value $ACSDEHD
"E860" = '1' /*Dehydration */
"E861" = '1' /*Hypovolemia */
"E869" = '1' /*Volumedepletion,unspecified */
OTHER = '0'
;

/* FORMAT FOR Stage I-IV kidney disease diagnosis codes */
Value $ACSHY2D
"I129" = '1' /*Hypertensive chronic kidney disease with stage1 through stage 4 chronic kidney disease, orunspecified chronic kidney disease */
"I1310" = '1' /*Hypertensive heart and chronic kidney diseasewithout heart failure, with stage 1 through stage4 chronic kidney disease, or unspecified chronickidney disease */
OTHER = '0'
;

/* FORMAT FOR Hypertension diagnosis codes */
Value $ACSHYPD
"I10" = '1' /*Essential (primary) hypertension */
"I119" = '1' /*Hypertensive heart disease without heart failure */
"I129" = '1' /*Hypertensive chronic kidney disease with stage1 through stage 4 chronic kidney disease, orunspecified chronic kidney disease */
"I1310" = '1' /*Hypertensive heart and chronic kidney diseasewithout heart failure, with stage 1 through stage4 chronic kidney disease, or unspecifiedchronic kidney disease */
"I160" = '1' /*Hypertensive urgency */
"I161" = '1' /*Hypertensive emergency */
"I169" = '1' /*Hypertensive crisis, unspecified */
OTHER = '0'
;

/* FORMAT FOR Diabetes diagnosis codes */
Value $ACSLEAD
"E1010" = '1' /*Type 1 diabetes mellitus with ketoacidosis without coma */
"E1011" = '1' /*Type 1 diabetes mellitus with ketoacidosis with coma */
"E1021" = '1' /*Type 1 diabetes mellitus with diabetic nephropathy */
"E1022" = '1' /*Type 1 diabetes mellitus with diabetic chronic kidney disease */
"E1029" = '1' /*Type 1 diabetes mellitus with other diabetic kidney complication */
"E10311" = '1' /*Type 1 diabetes mellitus with unspecified diabetic retinopathy with macular edema */
"E10319" = '1' /*Type 1 diabetes mellitus with unspecified diabetic retinopathy without macular edema */
"E10321" = '1' /*Type 1 diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema */
"E103211" = '1' /*Type 1 diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema, right eye */
"E103212" = '1' /*Type 1 diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema, left eye */
"E103213" = '1' /*Type 1 diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema, bilateral */
"E103219" = '1' /*Type 1 diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema, unspecified eye */
"E10329" = '1' /*Type 1 diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema */
"E103291" = '1' /*Type 1 diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema, right eye */
"E103292" = '1' /*Type 1 diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema, left eye */
"E103293" = '1' /*Type 1 diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema, bilateral */
"E103299" = '1' /*Type 1 diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema, unspecified eye */
"E10331" = '1' /*Type 1 diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema */
"E103311" = '1' /*Type 1 diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema, right eye */
"E103312" = '1' /*Type 1 diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema, left eye */
"E103313" = '1' /*Type 1 diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema, bilateral */
"E103319" = '1' /*Type 1 diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema, unspecified eye */
"E10339" = '1' /*Type 1 diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema */
"E103391" = '1' /*Type 1 diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema, right eye */
"E103392" = '1' /*Type 1 diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema, left eye */
"E103393" = '1' /*Type 1 diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema, bilateral */
"E103399" = '1' /*Type 1 diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema, unspecified eye */
"E10341" = '1' /*Type 1 diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema */
"E103411" = '1' /*Type 1 diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema, right eye */
"E103412" = '1' /*Type 1 diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema, left eye */
"E103413" = '1' /*Type 1 diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema, bilateral */
"E103419" = '1' /*Type 1 diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema, unspecified eye */
"E10349" = '1' /*Type 1 diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema */
"E103491" = '1' /*Type 1 diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema, right eye */
"E103492" = '1' /*Type 1 diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema, left eye */
"E103493" = '1' /*Type 1 diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema, bilateral */
"E103499" = '1' /*Type 1 diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema, unspecified eye */
"E10351" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy with macular edema */
"E103511" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy with macular edema, right eye */
"E103512" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy with macular edema, left eye */
"E103513" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy with macular edema, bilateral */
"E103519" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy with macular edema, unspecified eye */
"E103521" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment involving the macula, right eye */
"E103522" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment involving the macula, left eye */
"E103523" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment involving the macula, bilateral */
"E103529" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment involving the macula, unspecified eye */
"E103531" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, right eye */
"E103532" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, left eye */
"E103533" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, bilateral */
"E103539" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, unspecified eye */
"E103541" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, right eye */
"E103542" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, left eye */
"E103543" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, bilateral */
"E103549" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, unspecified eye */
"E103551" = '1' /*Type 1 diabetes mellitus with stable proliferative diabetic retinopathy, right eye */
"E103552" = '1' /*Type 1 diabetes mellitus with stable proliferative diabetic retinopathy, left eye */
"E103553" = '1' /*Type 1 diabetes mellitus with stable proliferative diabetic retinopathy, bilateral */
"E103559" = '1' /*Type 1 diabetes mellitus with stable proliferative diabetic retinopathy, unspecified eye */
"E10359" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy without macular edema */
"E103591" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy without macular edema, right eye */
"E103592" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy without macular edema, left eye */
"E103593" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy without macular edema, bilateral */
"E103599" = '1' /*Type 1 diabetes mellitus with proliferative diabetic retinopathy without macular edema, unspecified eye */
"E1036" = '1' /*Type 1 diabetes mellitus with diabetic cataract */
"E1037X1" = '1' /*Type 1 diabetes mellitus with diabetic macular edema, resolved following treatment, right eye */
"E1037X2" = '1' /*Type 1 diabetes mellitus with diabetic macular edema, resolved following treatment, left eye */
"E1037X3" = '1' /*Type 1 diabetes mellitus with diabetic macular edema, resolved following treatment, bilateral */
"E1037X9" = '1' /*Type 1 diabetes mellitus with diabetic macular edema, resolved following treatment, unspecified eye */
"E1039" = '1' /*Type 1 diabetes mellitus with other diabetic ophthalmic complication */
"E1040" = '1' /*Type 1 diabetes mellitus with diabetic neuropathy, unspecified */
"E1041" = '1' /*Type 1 diabetes mellitus with diabetic mononeuropathy */
"E1042" = '1' /*Type 1 diabetes mellitus with diabetic polyneuropathy */
"E1043" = '1' /*Type 1 diabetes mellitus with diabetic autonomic (poly)neuropathy */
"E1044" = '1' /*Type 1 diabetes mellitus with diabetic amyotrophy */
"E1049" = '1' /*Type 1 diabetes mellitus with other diabetic neurological complication */
"E1051" = '1' /*Type 1 diabetes mellitus with diabetic peripheral angiopathy without gangrene */
"E1052" = '1' /*Type 1 diabetes mellitus with diabetic peripheral angiopathy with gangrene */
"E1059" = '1' /*Type 1 diabetes mellitus with other circulatory complications */
"E10610" = '1' /*Type 1 diabetes mellitus with diabetic neuropathic arthropathy */
"E10618" = '1' /*Type 1 diabetes mellitus with other diabetic arthropathy */
"E10620" = '1' /*Type 1 diabetes mellitus with diabetic dermatitis */
"E10621" = '1' /*Type 1 diabetes mellitus with foot ulcer */
"E10622" = '1' /*Type 1 diabetes mellitus with other skin ulcer */
"E10628" = '1' /*Type 1 diabetes mellitus with other skin complications */
"E10630" = '1' /*Type 1 diabetes mellitus with periodontal disease */
"E10638" = '1' /*Type 1 diabetes mellitus with other oral complications */
"E10641" = '1' /*Type 1 diabetes mellitus with hypoglycemia with coma */
"E10649" = '1' /*Type 1 diabetes mellitus with hypoglycemia without coma */
"E1065" = '1' /*Type 1 diabetes mellitus with hyperglycemia */
"E1069" = '1' /*Type 1 diabetes mellitus with other specified complication */
"E108" = '1' /*Type 1 diabetes mellitus with unspecified complications */
"E109" = '1' /*Type 1 diabetes mellitus without complications */
"E1100" = '1' /*Type 2 diabetes mellitus with hyperosmolarity without nonketotic hyperglycemic-hyperosmolar coma (NKHHC) */
"E1101" = '1' /*Type 2 diabetes mellitus with hyperosmolarity with coma */
"E1121" = '1' /*Type 2 diabetes mellitus with diabetic nephropathy */
"E1122" = '1' /*Type 2 diabetes mellitus with diabetic chronic kidney disease */
"E1129" = '1' /*Type 2 diabetes mellitus with other diabetic kidney complication */
"E11311" = '1' /*Type 2 diabetes mellitus with unspecified diabetic retinopathy with macular edema */
"E11319" = '1' /*Type 2 diabetes mellitus with unspecified diabetic retinopathy without macular edema */
"E11321" = '1' /*Type 2 diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema */
"E113211" = '1' /*Type 2 diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema, right eye */
"E113212" = '1' /*Type 2 diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema, left eye */
"E113213" = '1' /*Type 2 diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema, bilateral */
"E113219" = '1' /*Type 2 diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema, unspecified eye */
"E11329" = '1' /*Type 2 diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema */
"E113291" = '1' /*Type 2 diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema, right eye */
"E113292" = '1' /*Type 2 diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema, left eye */
"E113293" = '1' /*Type 2 diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema, bilateral */
"E113299" = '1' /*Type 2 diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema, unspecified eye */
"E11331" = '1' /*Type 2 diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema */
"E113311" = '1' /*Type 2 diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema, right eye */
"E113312" = '1' /*Type 2 diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema, left eye */
"E113313" = '1' /*Type 2 diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema, bilateral */
"E113319" = '1' /*Type 2 diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema, unspecified eye */
"E11339" = '1' /*Type 2 diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema */
"E113391" = '1' /*Type 2 diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema, right eye */
"E113392" = '1' /*Type 2 diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema, left eye */
"E113393" = '1' /*Type 2 diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema, bilateral */
"E113399" = '1' /*Type 2 diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema, unspecified eye */
"E11341" = '1' /*Type 2 diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema */
"E113411" = '1' /*Type 2 diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema, right eye */
"E113412" = '1' /*Type 2 diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema, left eye */
"E113413" = '1' /*Type 2 diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema, bilateral */
"E113419" = '1' /*Type 2 diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema, unspecified eye */
"E11349" = '1' /*Type 2 diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema */
"E113491" = '1' /*Type 2 diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema, right eye */
"E113492" = '1' /*Type 2 diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema, left eye */
"E113493" = '1' /*Type 2 diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema, bilateral */
"E113499" = '1' /*Type 2 diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema, unspecified eye */
"E11351" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy with macular edema */
"E113511" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy with macular edema, right eye */
"E113512" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy with macular edema, left eye */
"E113513" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy with macular edema, bilateral */
"E113519" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy with macular edema, unspecified eye */
"E113521" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment involving the macula, right eye */
"E113522" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment involving the macula, left eye */
"E113523" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment involving the macula, bilateral */
"E113529" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment involving the macula, unspecified eye */
"E113531" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, right eye */
"E113532" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, left eye */
"E113533" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, bilateral */
"E113539" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, unspecified eye */
"E113541" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, right eye */
"E113542" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, left eye */
"E113543" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, bilateral */
"E113549" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, unspecified eye */
"E113551" = '1' /*Type 2 diabetes mellitus with stable proliferative diabetic retinopathy, right eye */
"E113552" = '1' /*Type 2 diabetes mellitus with stable proliferative diabetic retinopathy, left eye */
"E113553" = '1' /*Type 2 diabetes mellitus with stable proliferative diabetic retinopathy, bilateral */
"E113559" = '1' /*Type 2 diabetes mellitus with stable proliferative diabetic retinopathy, unspecified eye */
"E11359" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy without macular edema */
"E113591" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy without macular edema, right eye */
"E113592" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy without macular edema, left eye */
"E113593" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy without macular edema, bilateral */
"E113599" = '1' /*Type 2 diabetes mellitus with proliferative diabetic retinopathy without macular edema, unspecified eye */
"E1136" = '1' /*Type 2 diabetes mellitus with diabetic cataract */
"E1137X1" = '1' /*Type 2 diabetes mellitus with diabetic macular edema, resolved following treatment, right eye */
"E1137X2" = '1' /*Type 2 diabetes mellitus with diabetic macular edema, resolved following treatment, left eye */
"E1137X3" = '1' /*Type 2 diabetes mellitus with diabetic macular edema, resolved following treatment, bilateral */
"E1137X9" = '1' /*Type 2 diabetes mellitus with diabetic macular edema, resolved following treatment, unspecified eye */
"E1139" = '1' /*Type 2 diabetes mellitus with other diabetic ophthalmic complication */
"E1140" = '1' /*Type 2 diabetes mellitus with diabetic neuropathy, unspecified */
"E1141" = '1' /*Type 2 diabetes mellitus with diabetic mononeuropathy */
"E1142" = '1' /*Type 2 diabetes mellitus with diabetic polyneuropathy */
"E1143" = '1' /*Type 2 diabetes mellitus with diabetic autonomic (poly)neuropathy */
"E1144" = '1' /*Type 2 diabetes mellitus with diabetic amyotrophy */
"E1149" = '1' /*Type 2 diabetes mellitus with other diabetic neurological complication */
"E1151" = '1' /*Type 2 diabetes mellitus with diabetic peripheral angiopathy without gangrene */
"E1152" = '1' /*Type 2 diabetes mellitus with diabetic peripheral angiopathy with gangrene */
"E1159" = '1' /*Type 2 diabetes mellitus with other circulatory complications */
"E11610" = '1' /*Type 2 diabetes mellitus with diabetic neuropathic arthropathy */
"E11618" = '1' /*Type 2 diabetes mellitus with other diabetic arthropathy */
"E11620" = '1' /*Type 2 diabetes mellitus with diabetic dermatitis */
"E11621" = '1' /*Type 2 diabetes mellitus with foot ulcer */
"E11622" = '1' /*Type 2 diabetes mellitus with other skin ulcer */
"E11628" = '1' /*Type 2 diabetes mellitus with other skin complications */
"E11630" = '1' /*Type 2 diabetes mellitus with periodontal disease */
"E11638" = '1' /*Type 2 diabetes mellitus with other oral complications */
"E11641" = '1' /*Type 2 diabetes mellitus with hypoglycemia with coma */
"E11649" = '1' /*Type 2 diabetes mellitus with hypoglycemia without coma */
"E1165" = '1' /*Type 2 diabetes mellitus with hyperglycemia */
"E1169" = '1' /*Type 2 diabetes mellitus with other specified complication */
"E118" = '1' /*Type 2 diabetes mellitus with unspecified complications */
"E119" = '1' /*Type 2 diabetes mellitus without complications */
"E1300" = '1' /*Other specified diabetes mellitus with hyperosmolarity without nonketotic hyperglycemic-hyperosmolar coma (NKHHC) */
"E1301" = '1' /*Other specified diabetes mellitus with hyperosmolarity with coma */
"E1310" = '1' /*Other specified diabetes mellitus with ketoacidosis without coma */
"E1311" = '1' /*Other specified diabetes mellitus with ketoacidosis with coma */
"E1321" = '1' /*Other specified diabetes mellitus with diabetic nephropathy */
"E1322" = '1' /*Other specified diabetes mellitus with diabetic chronic kidney disease */
"E1329" = '1' /*Other specified diabetes mellitus with other diabetic kidney complication */
"E13311" = '1' /*Other specified diabetes mellitus with unspecified diabetic retinopathy with macular edema */
"E13319" = '1' /*Other specified diabetes mellitus with unspecified diabetic retinopathy without macular edema */
"E13321" = '1' /*Other specified diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema */
"E133211" = '1' /*Other specified diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema, right eye */
"E133212" = '1' /*Other specified diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema, left eye */
"E133213" = '1' /*Other specified diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema, bilateral */
"E133219" = '1' /*Other specified diabetes mellitus with mild nonproliferative diabetic retinopathy with macular edema, unspecified eye */
"E13329" = '1' /*Other specified diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema */
"E133291" = '1' /*Other specified diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema, right eye */
"E133292" = '1' /*Other specified diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema, left eye */
"E133293" = '1' /*Other specified diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema, bilateral */
"E133299" = '1' /*Other specified diabetes mellitus with mild nonproliferative diabetic retinopathy without macular edema, unspecified eye */
"E13331" = '1' /*Other specified diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema */
"E133311" = '1' /*Other specified diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema, right eye */
"E133312" = '1' /*Other specified diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema, left eye */
"E133313" = '1' /*Other specified diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema, bilateral */
"E133319" = '1' /*Other specified diabetes mellitus with moderate nonproliferative diabetic retinopathy with macular edema, unspecified eye */
"E13339" = '1' /*Other specified diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema */
"E133391" = '1' /*Other specified diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema, right eye */
"E133392" = '1' /*Other specified diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema, left eye */
"E133393" = '1' /*Other specified diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema, bilateral */
"E133399" = '1' /*Other specified diabetes mellitus with moderate nonproliferative diabetic retinopathy without macular edema, unspecified eye */
"E13341" = '1' /*Other specified diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema */
"E133411" = '1' /*Other specified diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema, right eye */
"E133412" = '1' /*Other specified diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema, left eye */
"E133413" = '1' /*Other specified diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema, bilateral */
"E133419" = '1' /*Other specified diabetes mellitus with severe nonproliferative diabetic retinopathy with macular edema, unspecified eye */
"E13349" = '1' /*Other specified diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema */
"E133491" = '1' /*Other specified diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema, right eye */
"E133492" = '1' /*Other specified diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema, left eye */
"E133493" = '1' /*Other specified diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema, bilateral */
"E133499" = '1' /*Other specified diabetes mellitus with severe nonproliferative diabetic retinopathy without macular edema, unspecified eye */
"E13351" = '1' /*Other specified diabetes mellitus with proliferative diabetic retinopathy with macular edema */
"E133511" = '1' /*Other specified diabetes mellitus with proliferative diabetic retinopathy with macular edema, right eye */
"E133512" = '1' /*Other specified diabetes mellitus with proliferative diabetic retinopathy with macular edema, left eye */
"E133513" = '1' /*Other specified diabetes mellitus with proliferative diabetic retinopathy with macular edema, bilateral */
"E133519" = '1' /*Other specified diabetes mellitus with proliferative diabetic retinopathy with macular edema, unspecified eye */
"E133521" = '1' /*Other specified diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment involving the macula, right eye */
"E133522" = '1' /*Other specified diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment involving the macula, left eye */
"E133523" = '1' /*Other specified diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment involving the macula, bilateral */
"E133529" = '1' /*Other specified diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment involving the macula, unspecified eye */
"E133531" = '1' /*Other specified diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, right eye */
"E133532" = '1' /*Other specified diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, left eye */
"E133533" = '1' /*Other specified diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, bilateral */
"E133539" = '1' /*Other specified diabetes mellitus with proliferative diabetic retinopathy with traction retinal detachment not involving the macula, unspecified eye */
"E133541" = '1' /*Other specified diabetes mellitus with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, right eye */
"E133542" = '1' /*Other specified diabetes mellitus with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, left eye */
"E133543" = '1' /*Other specified diabetes mellitus with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, bilateral */
"E133549" = '1' /*Other specified diabetes mellitus with proliferative diabetic retinopathy with combined traction retinal detachment and rhegmatogenous retinal detachment, unspecified eye */
"E133551" = '1' /*Other specified diabetes mellitus with stable proliferative diabetic retinopathy, right eye */
"E133552" = '1' /*Other specified diabetes mellitus with stable proliferative diabetic retinopathy, left eye */
"E133553" = '1' /*Other specified diabetes mellitus with stable proliferative diabetic retinopathy, bilateral */
"E133559" = '1' /*Other specified diabetes mellitus with stable proliferative diabetic retinopathy, unspecified eye */
"E13359" = '1' /*Other specified diabetes mellitus with proliferative diabetic retinopathy without macular edema */
"E133591" = '1' /*Other specified diabetes mellitus with proliferative diabetic retinopathy without macular edema, right eye */
"E133592" = '1' /*Other specified diabetes mellitus with proliferative diabetic retinopathy without macular edema, left eye */
"E133593" = '1' /*Other specified diabetes mellitus with proliferative diabetic retinopathy without macular edema, bilateral */
"E133599" = '1' /*Other specified diabetes mellitus with proliferative diabetic retinopathy without macular edema, unspecified eye */
"E1336" = '1' /*Other specified diabetes mellitus with diabetic cataract */
"E1337X1" = '1' /*Other specified diabetes mellitus with diabetic macular edema, resolved following treatment, right eye */
"E1337X2" = '1' /*Other specified diabetes mellitus with diabetic macular edema, resolved following treatment, left eye */
"E1337X3" = '1' /*Other specified diabetes mellitus with diabetic macular edema, resolved following treatment, bilateral */
"E1337X9" = '1' /*Other specified diabetes mellitus with diabetic macular edema, resolved following treatment, unspecified eye */
"E1339" = '1' /*Other specified diabetes mellitus with other diabetic ophthalmic complication */
"E1340" = '1' /*Other specified diabetes mellitus with diabetic neuropathy, unspecified */
"E1341" = '1' /*Other specified diabetes mellitus with diabetic mononeuropathy */
"E1342" = '1' /*Other specified diabetes mellitus with diabetic polyneuropathy */
"E1343" = '1' /*Other specified diabetes mellitus with diabetic autonomic (poly)neuropathy */
"E1344" = '1' /*Other specified diabetes mellitus with diabetic amyotrophy */
"E1349" = '1' /*Other specified diabetes mellitus with other diabetic neurological complication */
"E1351" = '1' /*Other specified diabetes mellitus with diabetic peripheral angiopathy without gangrene */
"E1352" = '1' /*Other specified diabetes mellitus with diabetic peripheral angiopathy with gangrene */
"E1359" = '1' /*Other specified diabetes mellitus with other circulatory complications */
"E13610" = '1' /*Other specified diabetes mellitus with diabetic neuropathic arthropathy */
"E13618" = '1' /*Other specified diabetes mellitus with other diabetic arthropathy */
"E13620" = '1' /*Other specified diabetes mellitus with diabetic dermatitis */
"E13621" = '1' /*Other specified diabetes mellitus with foot ulcer */
"E13622" = '1' /*Other specified diabetes mellitus with other skin ulcer */
"E13628" = '1' /*Other specified diabetes mellitus with other skin complications */
"E13630" = '1' /*Other specified diabetes mellitus with periodontal disease */
"E13638" = '1' /*Other specified diabetes mellitus with other oral complications */
"E13641" = '1' /*Other specified diabetes mellitus with hypoglycemia with coma */
"E13649" = '1' /*Other specified diabetes mellitus with hypoglycemia without coma */
"E1365" = '1' /*Other specified diabetes mellitus with hyperglycemia */
"E1369" = '1' /*Other specified diabetes mellitus with other specified complication */
"E138" = '1' /*Other specified diabetes mellitus with unspecified complications */
"E139" = '1' /*Other specified diabetes mellitus without complications */
OTHER = '0'
;

/* FORMAT FOR Lower extremity amputation procedure codes */
Value $ACSLEAP
"0Y620ZZ" = '1' /*Detachment at Right Hindquarter, Open Approach */
"0Y630ZZ" = '1' /*Detachment at Left Hindquarter, Open Approach */
"0Y640ZZ" = '1' /*Detachment at Bilateral Hindquarter, Open Approach */
"0Y670ZZ" = '1' /*Detachment at Right Femoral Region, Open Approach */
"0Y680ZZ" = '1' /*Detachment at Left Femoral Region, Open Approach */
"0Y6C0Z1" = '1' /*Detachment at Right Upper Leg, High, Open Approach */
"0Y6C0Z2" = '1' /*Detachment at Right Upper Leg, Mid, Open Approach */
"0Y6C0Z3" = '1' /*Detachment at Right Upper Leg, Low, Open Approach */
"0Y6D0Z1" = '1' /*Detachment at Left Upper Leg, High, Open Approach */
"0Y6D0Z2" = '1' /*Detachment at Left Upper Leg, Mid, Open Approach */
"0Y6D0Z3" = '1' /*Detachment at Left Upper Leg, Low, Open Approach */
"0Y6F0ZZ" = '1' /*Detachment at Right Knee Region, Open Approach */
"0Y6G0ZZ" = '1' /*Detachment at Left Knee Region, Open Approach */
"0Y6H0Z1" = '1' /*Detachment at Right Lower Leg, High, Open Approach */
"0Y6H0Z2" = '1' /*Detachment at Right Lower Leg, Mid, Open Approach */
"0Y6H0Z3" = '1' /*Detachment at Right Lower Leg, Low, Open Approach */
"0Y6J0Z1" = '1' /*Detachment at Left Lower Leg, High, Open Approach */
"0Y6J0Z2" = '1' /*Detachment at Left Lower Leg, Mid, Open Approach */
"0Y6J0Z3" = '1' /*Detachment at Left Lower Leg, Low, Open Approach */
"0Y6M0Z0" = '1' /*Detachment at Right Foot, Complete, Open Approach */
"0Y6M0Z4" = '1' /*Detachment at Right Foot, Complete 1st Ray, Open Approach */
"0Y6M0Z5" = '1' /*Detachment at Right Foot, Complete 2nd Ray, Open Approach */
"0Y6M0Z6" = '1' /*Detachment at Right Foot, Complete 3rd Ray, Open Approach */
"0Y6M0Z7" = '1' /*Detachment at Right Foot, Complete 4th Ray, Open Approach */
"0Y6M0Z8" = '1' /*Detachment at Right Foot, Complete 5th Ray, Open Approach */
"0Y6M0Z9" = '1' /*Detachment at Right Foot, Partial 1st Ray, Open Approach */
"0Y6M0ZB" = '1' /*Detachment at Right Foot, Partial 2nd Ray, Open Approach */
"0Y6M0ZC" = '1' /*Detachment at Right Foot, Partial 3rd Ray, Open Approach */
"0Y6M0ZD" = '1' /*Detachment at Right Foot, Partial 4th Ray, Open Approach */
"0Y6M0ZF" = '1' /*Detachment at Right Foot, Partial 5th Ray, Open Approach */
"0Y6N0Z0" = '1' /*Detachment at Left Foot, Complete, Open Approach */
"0Y6N0Z4" = '1' /*Detachment at Left Foot, Complete 1st Ray, Open Approach */
"0Y6N0Z5" = '1' /*Detachment at Left Foot, Complete 2nd Ray, Open Approach */
"0Y6N0Z6" = '1' /*Detachment at Left Foot, Complete 3rd Ray, Open Approach */
"0Y6N0Z7" = '1' /*Detachment at Left Foot, Complete 4th Ray, Open Approach */
"0Y6N0Z8" = '1' /*Detachment at Left Foot, Complete 5th Ray, Open Approach */
"0Y6N0Z9" = '1' /*Detachment at Left Foot, Partial 1st Ray, Open Approach */
"0Y6N0ZB" = '1' /*Detachment at Left Foot, Partial 2nd Ray, Open Approach */
"0Y6N0ZC" = '1' /*Detachment at Left Foot, Partial 3rd Ray, Open Approach */
"0Y6N0ZD" = '1' /*Detachment at Left Foot, Partial 4th Ray, Open Approach */
"0Y6N0ZF" = '1' /*Detachment at Left Foot, Partial 5th Ray, Open Approach */
OTHER = '0'
;

/* FORMAT FOR Urinary tract infection diagnosis codes */
Value $ACSUTID
"N10" = '1' /*Acute pyelonephritis */
"N12" = '1' /*Tubulo-interstitial nephritis, not specified as acute or chronic */
"N151" = '1' /*Renal and perinephric abscess */
"N159" = '1' /*Renal tubulo-interstitial disease, unspecified */
"N16" = '1' /*Renal tubulo-interstitial disorders in diseases classified elsewhere */
"N2884" = '1' /*Pyelitis cystica */
"N2885" = '1' /*Pyeloureteritis cystica */
"N2886" = '1' /*Ureteritis cystica */
"N3000" = '1' /*Acute cystitis without hematuria */
"N3001" = '1' /*Acute cystitis with hematuria */
"N3090" = '1' /*Cystitis, unspecified without hematuria */
"N3091" = '1' /*Cystitis, unspecified with hematuria */
"N390" = '1' /*Urinary tract infection, site not specified */
OTHER = '0'
;

/* FORMAT FOR Age Category */
Value AGECAT
0 = '00 to 17' /*Newborns to Age 17 */
1 = '18 to 39' /*Age 18 to 39 */
2 = '40 to 64' /*Age 40 to 64 */
3 = '65 to 74' /*Age 65 to 74 */
4 = '75+' /*Age 75+ */
;

/* FORMAT FOR AGE STRATIFIERS */
Value AGEFMT
LOW  - 4  = 1
5  - 9  = 2
10  - 14  = 3
15  - 17  = 4
18  - 24  = 5
25  - 29  = 6
30  - 34  = 7
35  - 39  = 8
40  - 44  = 9
45  - 49  = 10
50  - 54  = 11
55  - 59  = 12
60  - 64  = 13
65  - 69  = 14
70  - 74  = 15
75  - 79  = 16
80  - 84  = 17
85  - HIGH  = 18
;

/* FORMAT FOR Chronic renal failure diagnosis codes */
Value $CRENLFD
"I120" = '1' /*Hypertensive chronic kidney disease with stage 5 chronickidney disease or end stage renal disease */
"I1311" = '1' /*Hypertensive heart and chronic kidney disease withoutheart failure, with stage 5 chronic kidney disease, or endstage renal disease */
"I132" = '1' /*Hypertensive heart and chronic kidney disease with heartfailure and with stage 5 chronic kidney disease, or endstage renal disease */
"N185" = '1' /*Chronic kidney disease, stage 5 */
"N186" = '1' /*End stage renal disease */
OTHER = '0'
;

/* FORMAT FOR ICD10 Procedure */
Value $DIALY2P
"031509D" = '1' /*Bypass Right Axillary Artery to Upper Arm Vein withAutologous Venous Tissue, Open Approach */
"031509F" = '1' /*Bypass Right Axillary Artery to Lower Arm Vein withAutologous Venous Tissue, Open Approach */
"031509V" = '1' /*Bypass Right Axillary Artery to Superior Vena Cava with Autologous Venous Tissue, Open Approach */
"03150AD" = '1' /*Bypass Right Axillary Artery to Upper Arm Vein withAutologous Arterial Tissue, Open Approach */
"03150AF" = '1' /*Bypass Right Axillary Artery to Lower Arm Vein withAutologous Arterial Tissue, Open Approach */
"03150AV" = '1' /*Bypass Right Axillary Artery to Superior Vena Cava with Autologous Arterial Tissue, Open Approach */
"03150JD" = '1' /*Bypass Right Axillary Artery to Upper Arm Vein withSynthetic Substitute, Open Approach */
"03150JF" = '1' /*Bypass Right Axillary Artery to Lower Arm Vein withSynthetic Substitute, Open Approach */
"03150JV" = '1' /*Bypass Right Axillary Artery to Superior Vena Cava with Synthetic Substitute, Open Approach */
"03150KD" = '1' /*Bypass Right Axillary Artery to Upper Arm Vein withNonautologous Tissue Substitute, Open Approach */
"03150KF" = '1' /*Bypass Right Axillary Artery to Lower Arm Vein withNonautologous Tissue Substitute, Open Approach */
"03150KV" = '1' /*Bypass Right Axillary Artery to Superior Vena Cava with Nonautologous Tissue Substitute, Open Approach */
"03150ZD" = '1' /*Bypass Right Axillary Artery to Upper Arm Vein, OpenApproach */
"03150ZF" = '1' /*Bypass Right Axillary Artery to Lower Arm Vein, OpenApproach */
"03150ZV" = '1' /*Bypass Right Axillary Artery to Superior Vena Cava, Open Approach */
"031609D" = '1' /*Bypass Left Axillary Artery to Upper Arm Vein withAutologous Venous Tissue, Open Approach */
"031609F" = '1' /*Bypass Left Axillary Artery to Lower Arm Vein withAutologous Venous Tissue, Open Approach */
"031609V" = '1' /*Bypass Left Axillary Artery to Superior Vena Cava with Autologous Venous Tissue, Open Approach */
"03160AD" = '1' /*Bypass Left Axillary Artery to Upper Arm Vein withAutologous Arterial Tissue, Open Approach */
"03160AF" = '1' /*Bypass Left Axillary Artery to Lower Arm Vein withAutologous Arterial Tissue, Open Approach */
"03160AV" = '1' /*Bypass Left Axillary Artery to Superior Vena Cava with Autologous Arterial Tissue, Open Approach */
"03160JD" = '1' /*Bypass Left Axillary Artery to Upper Arm Vein withSynthetic Substitute, Open Approach */
"03160JF" = '1' /*Bypass Left Axillary Artery to Lower Arm Vein withSynthetic Substitute, Open Approach */
"03160JV" = '1' /*Bypass Left Axillary Artery to Superior Vena Cava with Synthetic Substitute, Open Approach */
"03160KD" = '1' /*Bypass Left Axillary Artery to Upper Arm Vein withNonautologous Tissue Substitute, Open Approach */
"03160KF" = '1' /*Bypass Left Axillary Artery to Lower Arm Vein withNonautologous Tissue Substitute, Open Approach */
"03160KV" = '1' /*Bypass Left Axillary Artery to Superior Vena Cava with Nonautologous Tissue Substitute, Open Approach */
"03160ZD" = '1' /*Bypass Left Axillary Artery to Upper Arm Vein, OpenApproach */
"03160ZF" = '1' /*Bypass Left Axillary Artery to Lower Arm Vein, OpenApproach */
"03160ZV" = '1' /*Bypass Left Axillary Artery to Superior Vena Cava, Open Approach */
"031709D" = '1' /*Bypass Right Brachial Artery to Upper Arm Vein withAutologous Venous Tissue, Open Approach */
"031709F" = '1' /*Bypass Right Brachial Artery to Lower Arm Vein withAutologous Venous Tissue, Open Approach */
"031709V" = '1' /*Bypass Right Brachial Artery to Superior Vena Cava with Autologous Venous Tissue, Open Approach */
"03170AD" = '1' /*Bypass Right Brachial Artery to Upper Arm Vein withAutologous Arterial Tissue, Open Approach */
"03170AF" = '1' /*Bypass Right Brachial Artery to Lower Arm Vein withAutologous Arterial Tissue, Open Approach */
"03170AV" = '1' /*Bypass Right Brachial Artery to Superior Vena Cava with Autologous Arterial Tissue, Open Approach */
"03170JD" = '1' /*Bypass Right Brachial Artery to Upper Arm Vein withSynthetic Substitute, Open Approach */
"03170JF" = '1' /*Bypass Right Brachial Artery to Lower Arm Vein withSynthetic Substitute, Open Approach */
"03170JV" = '1' /*Bypass Right Brachial Artery to Superior Vena Cava with Synthetic Substitute, Open Approach */
"03170KD" = '1' /*Bypass Right Brachial Artery to Upper Arm Vein withNonautologous Tissue Substitute, Open Approach */
"03170KF" = '1' /*Bypass Right Brachial Artery to Lower Arm Vein withNonautologous Tissue Substitute, Open Approach */
"03170KV" = '1' /*Bypass Right Brachial Artery to Superior Vena Cava with Nonautologous Tissue Substitute, Open Approach */
"03170ZD" = '1' /*Bypass Right Brachial Artery to Upper Arm Vein, OpenApproach */
"03170ZF" = '1' /*Bypass Right Brachial Artery to Lower Arm Vein, OpenApproach */
"03170ZV" = '1' /*Bypass Right Brachial Artery to Superior Vena Cava, Open Approach */
"031809D" = '1' /*Bypass Left Brachial Artery to Upper Arm Vein withAutologous Venous Tissue, Open Approach */
"031809F" = '1' /*Bypass Left Brachial Artery to Lower Arm Vein withAutologous Venous Tissue, Open Approach */
"031809V" = '1' /*Bypass Left Brachial Artery to Superior Vena Cava with Autologous Venous Tissue, Open Approach */
"03180AD" = '1' /*Bypass Left Brachial Artery to Upper Arm Vein withAutologous Arterial Tissue, Open Approach */
"03180AF" = '1' /*Bypass Left Brachial Artery to Lower Arm Vein withAutologous Arterial Tissue, Open Approach */
"03180AV" = '1' /*Bypass Left Brachial Artery to Superior Vena Cava with Autologous Arterial Tissue, Open Approach */
"03180JD" = '1' /*Bypass Left Brachial Artery to Upper Arm Vein withSynthetic Substitute, Open Approach */
"03180JF" = '1' /*Bypass Left Brachial Artery to Lower Arm Vein withSynthetic Substitute, Open Approach */
"03180JV" = '1' /*Bypass Left Brachial Artery to Superior Vena Cava with Synthetic Substitute, Open Approach */
"03180KD" = '1' /*Bypass Left Brachial Artery to Upper Arm Vein withNonautologous Tissue Substitute, Open Approach */
"03180KF" = '1' /*Bypass Left Brachial Artery to Lower Arm Vein withNonautologous Tissue Substitute, Open Approach */
"03180KV" = '1' /*Bypass Left Brachial Artery to Superior Vena Cava with Nonautologous Tissue Substitute, Open Approach */
"03180ZD" = '1' /*Bypass Left Brachial Artery to Upper Arm Vein, OpenApproach */
"03180ZF" = '1' /*Bypass Left Brachial Artery to Lower Arm Vein, OpenApproach */
"03180ZV" = '1' /*Bypass Left Brachial Artery to Superior Vena Cava, Open Approach */
"031909F" = '1' /*Bypass Right Ulnar Artery to Lower Arm Vein withAutologous Venous Tissue, Open Approach */
"03190AF" = '1' /*Bypass Right Ulnar Artery to Lower Arm Vein withAutologous Arterial Tissue, Open Approach */
"03190JF" = '1' /*Bypass Right Ulnar Artery to Lower Arm Vein withSynthetic Substitute, Open Approach */
"03190KF" = '1' /*Bypass Right Ulnar Artery to Lower Arm Vein withNonautologous Tissue Substitute, Open Approach */
"03190ZF" = '1' /*Bypass Right Ulnar Artery to Lower Arm Vein, OpenApproach */
"031A09F" = '1' /*Bypass Left Ulnar Artery to Lower Arm Vein withAutologous Venous Tissue, Open Approach */
"031A0AF" = '1' /*Bypass Left Ulnar Artery to Lower Arm Vein withAutologous Arterial Tissue, Open Approach */
"031A0JF" = '1' /*Bypass Left Ulnar Artery to Lower Arm Vein withSynthetic Substitute, Open Approach */
"031A0KF" = '1' /*Bypass Left Ulnar Artery to Lower Arm Vein withNonautologous Tissue Substitute, Open Approach */
"031A0ZF" = '1' /*Bypass Left Ulnar Artery to Lower Arm Vein, OpenApproach */
"031B09F" = '1' /*Bypass Right Radial Artery to Lower Arm Vein withAutologous Venous Tissue, Open Approach */
"031B0AF" = '1' /*Bypass Right Radial Artery to Lower Arm Vein withAutologous Arterial Tissue, Open Approach */
"031B0JF" = '1' /*Bypass Right Radial Artery to Lower Arm Vein withSynthetic Substitute, Open Approach */
"031B0KF" = '1' /*Bypass Right Radial Artery to Lower Arm Vein withNonautologous Tissue Substitute, Open Approach */
"031B0ZF" = '1' /*Bypass Right Radial Artery to Lower Arm Vein, OpenApproach */
"031C09F" = '1' /*Bypass Left Radial Artery to Lower Arm Vein withAutologous Venous Tissue, Open Approach */
"031C0AF" = '1' /*Bypass Left Radial Artery to Lower Arm Vein withAutologous Arterial Tissue, Open Approach */
"031C0JF" = '1' /*Bypass Left Radial Artery to Lower Arm Vein withSynthetic Substitute, Open Approach */
"031C0KF" = '1' /*Bypass Left Radial Artery to Lower Arm Vein withNonautologous Tissue Substitute, Open Approach */
"031C0ZF" = '1' /*Bypass Left Radial Artery to Lower Arm Vein, OpenApproach */
"041K09S" = '1' /*Bypass Right Femoral Artery to Lower Extremity Veinwith Autologous Venous Tissue, Open Approach */
"041K0AS" = '1' /*Bypass Right Femoral Artery to Lower Extremity Veinwith Autologous Arterial Tissue, Open Approach */
"041K0JS" = '1' /*Bypass Right Femoral Artery to Lower Extremity Veinwith Synthetic Substitute, Open Approach */
"041K0KS" = '1' /*Bypass Right Femoral Artery to Lower Extremity Veinwith Nonautologous Tissue Substitute, Open Approach */
"041K0ZS" = '1' /*Bypass Right Femoral Artery to Lower Extremity Vein,Open Approach */
"041L09S" = '1' /*Bypass Left Femoral Artery to Lower Extremity Veinwith Autologous Venous Tissue, Open Approach */
"041L0AS" = '1' /*Bypass Left Femoral Artery to Lower Extremity Veinwith Autologous Arterial Tissue, Open Approach */
"041L0JS" = '1' /*Bypass Left Femoral Artery to Lower Extremity Veinwith Synthetic Substitute, Open Approach */
"041L0KS" = '1' /*Bypass Left Femoral Artery to Lower Extremity Veinwith Nonautologous Tissue Substitute, Open Approach */
"041L0ZS" = '1' /*Bypass Left Femoral Artery to Lower Extremity Vein,Open Approach */
OTHER = '0'
;

/* FORMAT FOR Hyperosmolality and/or hypernatremia diagnosis codes */
Value $HYPERID
"E870" = '1' /*Hyperosmolality and hypernatremia */
OTHER = '0'
;

/* FORMAT FOR Immunocompromised state diagnosis codes */
Value $IMMUNID
"B20" = '1' /*Human immunodeficiency virus [HIV] disease */
"B59" = '1' /*Pneumocystosis */
"C802" = '1' /*Malignant neoplasm associated with transplanted organ */
"C888" = '1' /*Other malignant immunoproliferative diseases */
"C9440" = '1' /*Acute panmyelosis with myelofibrosis not having achievedremission */
"C9441" = '1' /*Acute panmyelosis with myelofibrosis, in remission */
"C9442" = '1' /*Acute panmyelosis with myelofibrosis, in relapse */
"C946" = '1' /*Myelodysplastic disease, not classified */
"D4622" = '1' /*Refractory anemia with excess of blasts 2 */
"D4701" = '1' /*Cutaneous mastocytosis */
"D4702" = '1' /*Systemic mastocytosis */
"D4709" = '1' /*Other mast cell neoplasms of uncertain behavior */
"D471" = '1' /*Chronic myeloproliferative disease */
"D479" = '1' /*Neoplasm of uncertain behavior of lymphoid,hematopoietic and related tissue, unspecified */
"D47Z1" = '1' /*Post-transplant lymphoproliferative disorder (PTLD) */
"D47Z2" = '1' /*Castleman disease */
"D47Z9" = '1' /*Other specified neoplasms of uncertain behavior oflymphoid, hematopoietic and related tissue */
"D6109" = '1' /*Other constitutional aplastic anemia */
"D61810" = '1' /*Antineoplastic chemotherapy induced pancytopenia */
"D61811" = '1' /*Other drug-induced pancytopenia */
"D61818" = '1' /*Other pancytopenia */
"D700" = '1' /*Congenital agranulocytosis */
"D701" = '1' /*Agranulocytosis secondary to cancer chemotherapy */
"D702" = '1' /*Other drug-induced agranulocytosis */
"D704" = '1' /*Cyclic neutropenia */
"D708" = '1' /*Other neutropenia */
"D709" = '1' /*Neutropenia, unspecified */
"D71" = '1' /*Functional disorders of polymorphonuclear neutrophils */
"D720" = '1' /*Genetic anomalies of leukocytes */
"D72810" = '1' /*Lymphocytopenia */
"D72818" = '1' /*Other decreased white blood cell count */
"D72819" = '1' /*Decreased white blood cell count, unspecified */
"D7381" = '1' /*Neutropenic splenomegaly */
"D7581" = '1' /*Myelofibrosis */
"D761" = '1' /*Hemophagocytic lymphohistiocytosis */
"D762" = '1' /*Hemophagocytic syndrome, infection-associated */
"D763" = '1' /*Other histiocytosis syndromes */
"D800" = '1' /*Hereditary hypogammaglobulinemia */
"D801" = '1' /*Nonfamilial hypogammaglobulinemia */
"D802" = '1' /*Selective deficiency of immunoglobulin A [IgA] */
"D803" = '1' /*Selective deficiency of immunoglobulin G [IgG]subclasses */
"D804" = '1' /*Selective deficiency of immunoglobulin M [IgM] */
"D805" = '1' /*Immunodeficiency with increased immunoglobulin M [IgM] */
"D806" = '1' /*Antibody deficiency with near-normal immunoglobulins orwith hyperimmunoglobulinemia */
"D807" = '1' /*Transient hypogammaglobulinemia of infancy */
"D808" = '1' /*Other immunodeficiencies with predominantly antibodydefects */
"D809" = '1' /*Immunodeficiency with predominantly antibody defects,unspecified */
"D810" = '1' /*Severe combined immunodeficiency [SCID] with reticulardysgenesis */
"D811" = '1' /*Severe combined immunodeficiency [SCID] with low T-and B-cell numbers */
"D812" = '1' /*Severe combined immunodeficiency [SCID] with low ornormal B-cell numbers */
"D814" = '1' /*Nezelof's syndrome */
"D816" = '1' /*Major histocompatibility complex class I deficiency */
"D817" = '1' /*Major histocompatibility complex class II deficiency */
"D8189" = '1' /*Other combined immunodeficiencies */
"D819" = '1' /*Combined immunodeficiency, unspecified */
"D820" = '1' /*Wiskott-Aldrich syndrome */
"D821" = '1' /*Di George's syndrome */
"D822" = '1' /*Immunodeficiency with short-limbed stature */
"D823" = '1' /*Immunodeficiency following hereditary defective responseto Epstein-Barr virus */
"D824" = '1' /*Hyperimmunoglobulin E [IgE] syndrome */
"D828" = '1' /*Immunodeficiency associated with other specified majordefects */
"D829" = '1' /*Immunodeficiency associated with major defect,unspecified */
"D830" = '1' /*Common variable immunodeficiency with predominantabnormalities of B-cell numbers and function */
"D831" = '1' /*Common variable immunodeficiency with predominantimmunoregulatory T-cell disorders */
"D832" = '1' /*Common variable immunodeficiency with autoantibodiesto B- or T-cells */
"D838" = '1' /*Other common variable immunodeficiencies */
"D839" = '1' /*Common variable immunodeficiency, unspecified */
"D840" = '1' /*Lymphocyte function antigen-1 [LFA-1] defect */
"D841" = '1' /*Defects in the complement system */
"D848" = '1' /*Other specified immunodeficiencies */
"D849" = '1' /*Immunodeficiency, unspecified */
"D893" = '1' /*Immune reconstitution syndrome */
"D89810" = '1' /*Acute graft-versus-host disease */
"D89811" = '1' /*Chronic graft-versus-host disease */
"D89812" = '1' /*Acute on chronic graft-versus-host disease */
"D89813" = '1' /*Graft-versus-host disease, unspecified */
"D8982" = '1' /*Autoimmune lymphoproliferative syndrome [ALPS] */
"D8989" = '1' /*Other specified disorders involving the immunemechanism, not elsewhere classified */
"D899" = '1' /*Disorder involving the immune mechanism, unspecified */
"E40" = '1' /*Kwashiorkor */
"E41" = '1' /*Nutritional marasmus */
"E42" = '1' /*Marasmic kwashiorkor */
"E43" = '1' /*Unspecified severe protein-calorie malnutrition */
"I120" = '1' /*Hypertensive chronic kidney disease with stage 5 chronickidney disease or end stage renal disease */
"I1311" = '1' /*Hypertensive heart and chronic kidney disease withoutheart failure, with stage 5 chronic kidney disease, or endstage renal disease */
"I132" = '1' /*Hypertensive heart and chronic kidney disease with heartfailure and with stage 5 chronic kidney disease, or endstage renal disease */
"K912" = '1' /*Postsurgical malabsorption, not elsewhere classified */
"N185" = '1' /*Chronic kidney disease, stage 5 */
"N186" = '1' /*End stage renal disease */
"T8600" = '1' /*Unspecified complication of bone marrow transplant */
"T8601" = '1' /*Bone marrow transplant rejection */
"T8602" = '1' /*Bone marrow transplant failure */
"T8603" = '1' /*Bone marrow transplant infection */
"T8609" = '1' /*Other complications of bone marrow transplant */
"T8610" = '1' /*Unspecified complication of kidney transplant */
"T8611" = '1' /*Kidney transplant rejection */
"T8612" = '1' /*Kidney transplant failure */
"T8613" = '1' /*Kidney transplant infection */
"T8619" = '1' /*Other complication of kidney transplant */
"T8620" = '1' /*Unspecified complication of heart transplant */
"T8621" = '1' /*Heart transplant rejection */
"T8622" = '1' /*Heart transplant failure */
"T8623" = '1' /*Heart transplant infection */
"T86290" = '1' /*Cardiac allograft vasculopathy */
"T86298" = '1' /*Other complications of heart transplant */
"T8630" = '1' /*Unspecified complication of heart-lung transplant */
"T8631" = '1' /*Heart-lung transplant rejection */
"T8632" = '1' /*Heart-lung transplant failure */
"T8633" = '1' /*Heart-lung transplant infection */
"T8639" = '1' /*Other complications of heart-lung transplant */
"T8640" = '1' /*Unspecified complication of liver transplant */
"T8641" = '1' /*Liver transplant rejection */
"T8642" = '1' /*Liver transplant failure */
"T8643" = '1' /*Liver transplant infection */
"T8649" = '1' /*Other complications of liver transplant */
"T865" = '1' /*Complications of stem cell transplant */
"T86810" = '1' /*Lung transplant rejection */
"T86811" = '1' /*Lung transplant failure */
"T86812" = '1' /*Lung transplant infection */
"T86818" = '1' /*Other complications of lung transplant */
"T86819" = '1' /*Unspecified complication of lung transplant */
"T86830" = '1' /*Bone graft rejection */
"T86831" = '1' /*Bone graft failure */
"T86832" = '1' /*Bone graft infection */
"T86838" = '1' /*Other complications of bone graft */
"T86839" = '1' /*Unspecified complication of bone graft */
"T86850" = '1' /*Intestine transplant rejection */
"T86851" = '1' /*Intestine transplant failure */
"T86852" = '1' /*Intestine transplant infection */
"T86858" = '1' /*Other complications of intestine transplant */
"T86859" = '1' /*Unspecified complication of intestine transplant */
"T86890" = '1' /*Other transplanted tissue rejection */
"T86891" = '1' /*Other transplanted tissue failure */
"T86892" = '1' /*Other transplanted tissue infection */
"T86898" = '1' /*Other complications of other transplanted tissue */
"T86899" = '1' /*Unspecified complication of other transplanted tissue */
"T8690" = '1' /*Unspecified complication of unspecified transplantedorgan and tissue */
"T8691" = '1' /*Unspecified transplanted organ and tissue rejection */
"T8692" = '1' /*Unspecified transplanted organ and tissue failure */
"T8693" = '1' /*Unspecified transplanted organ and tissue infection */
"T8699" = '1' /*Other complications of unspecified transplanted organ andtissue */
"Z4821" = '1' /*Encounter for aftercare following heart transplant */
"Z4822" = '1' /*Encounter for aftercare following kidney transplant */
"Z4823" = '1' /*Encounter for aftercare following liver transplant */
"Z4824" = '1' /*Encounter for aftercare following lung transplant */
"Z48280" = '1' /*Encounter for aftercare following heart-lung transplant */
"Z48288" = '1' /*Encounter for aftercare following multiple organ transplant */
"Z48290" = '1' /*Encounter for aftercare following bone marrow transplant */
"Z48298" = '1' /*Encounter for aftercare following other organ transplant */
"Z4901" = '1' /*Encounter for fitting and adjustment of extracorporealdialysis catheter */
"Z4902" = '1' /*Encounter for fitting and adjustment of peritoneal dialysiscatheter */
"Z4931" = '1' /*Encounter for adequacy testing for hemodialysis */
"Z4932" = '1' /*Encounter for adequacy testing for peritoneal dialysis */
"Z940" = '1' /*Kidney transplant status */
"Z941" = '1' /*Heart transplant status */
"Z942" = '1' /*Lung transplant status */
"Z943" = '1' /*Heart and lungs transplant status */
"Z944" = '1' /*Liver transplant status */
"Z9481" = '1' /*Bone marrow transplant status */
"Z9482" = '1' /*Intestine transplant status */
"Z9483" = '1' /*Pancreas transplant status */
"Z9484" = '1' /*Stem cells transplant status */
"Z9489" = '1' /*Other transplanted organ and tissue status */
"Z992" = '1' /*Dependence on renal dialysis */
OTHER = '0'
;

/* FORMAT FOR Immunocompromised state procedure codes */
Value $IMMUNIP
"02YA0Z0" = '1' /*Transplantation of Heart, Allogeneic, Open Approach */
"02YA0Z2" = '1' /*Transplantation of Heart, Zooplastic, Open Approach */
"0BYC0Z0" = '1' /*Transplantation of Right Upper Lung Lobe, Allogeneic,Open Approach */
"0BYC0Z2" = '1' /*Transplantation of Right Upper Lung Lobe, Zooplastic,Open Approach */
"0BYD0Z0" = '1' /*Transplantation of Right Middle Lung Lobe, Allogeneic,Open Approach */
"0BYD0Z2" = '1' /*Transplantation of Right Middle Lung Lobe, Zooplastic,Open Approach */
"0BYF0Z0" = '1' /*Transplantation of Right Lower Lung Lobe, Allogeneic,Open Approach */
"0BYF0Z2" = '1' /*Transplantation of Right Lower Lung Lobe, Zooplastic,Open Approach */
"0BYG0Z0" = '1' /*Transplantation of Left Upper Lung Lobe, Allogeneic,Open Approach */
"0BYG0Z2" = '1' /*Transplantation of Left Upper Lung Lobe, Zooplastic,Open Approach */
"0BYH0Z0" = '1' /*Transplantation of Lung Lingula, Allogeneic, OpenApproach */
"0BYH0Z2" = '1' /*Transplantation of Lung Lingula, Zooplastic, OpenApproach */
"0BYJ0Z0" = '1' /*Transplantation of Left Lower Lung Lobe, Allogeneic,Open Approach */
"0BYJ0Z2" = '1' /*Transplantation of Left Lower Lung Lobe, Zooplastic,Open Approach */
"0BYK0Z0" = '1' /*Transplantation of Right Lung, Allogeneic, OpenApproach */
"0BYK0Z2" = '1' /*Transplantation of Right Lung, Zooplastic, OpenApproach */
"0BYL0Z0" = '1' /*Transplantation of Left Lung, Allogeneic, OpenApproach */
"0BYL0Z2" = '1' /*Transplantation of Left Lung, Zooplastic, OpenApproach */
"0BYM0Z0" = '1' /*Transplantation of Bilateral Lungs, Allogeneic, OpenApproach */
"0BYM0Z2" = '1' /*Transplantation of Bilateral Lungs, Zooplastic, OpenApproach */
"0FSG0ZZ" = '1' /*Reposition Pancreas, Open Approach */
"0FSG4ZZ" = '1' /*Reposition Pancreas, Percutaneous EndoscopicApproach */
"0FY00Z0" = '1' /*Transplantation of Liver, Allogeneic, Open Approach */
"0FY00Z2" = '1' /*Transplantation of Liver, Zooplastic, Open Approach */
"0FYG0Z0" = '1' /*Transplantation of Pancreas, Allogeneic, OpenApproach */
"0FYG0Z2" = '1' /*Transplantation of Pancreas, Zooplastic, OpenApproach */
"0TY00Z0" = '1' /*Transplantation of Right Kidney, Allogeneic, OpenApproach */
"0TY00Z2" = '1' /*Transplantation of Right Kidney, Zooplastic, OpenApproach */
"0TY10Z0" = '1' /*Transplantation of Left Kidney, Allogeneic, OpenApproach */
"0TY10Z2" = '1' /*Transplantation of Left Kidney, Zooplastic, OpenApproach */
"0WY20Z0" = '1' /*Transplantation of Face, Allogeneic, Open Approach */
"0XYJ0Z0" = '1' /*Transplantation of Right Hand, Allogeneic, Open Approach */
"0XYK0Z0" = '1' /*Transplantation of Left Hand, Allogeneic, Open Approach */
"30230AZ" = '1' /*Transfusion of Embryonic Stem Cells into PeripheralVein, Open Approach */
"30230G0" = '1' /*Transfusion of Autologous Bone Marrow into PeripheralVein, Open Approach */
"30230G1" = '1' /*Transfusion of Nonautologous Bone Marrow intoPeripheral Vein, Open Approach */
"30230G2" = '1' /*Transfusion of Allogeneic Related Bone Marrow into Peripheral Vein, Open Approach */
"30230G3" = '1' /*Transfusion of Allogeneic Unrelated Bone Marrow into Peripheral Vein, Open Approach */
"30230G4" = '1' /*Transfusion of Allogeneic Unspecified Bone Marrow into Peripheral Vein, Open Approach */
"30230X0" = '1' /*Transfusion of Autologous Cord Blood Stem Cells intoPeripheral Vein, Open Approach */
"30230X1" = '1' /*Transfusion of Nonautologous Cord Blood Stem Cellsinto Peripheral Vein, Open Approach */
"30230X2" = '1' /*Transfusion of Allogeneic Related Cord Blood Stem Cells into Peripheral Vein, Open Approach */
"30230X3" = '1' /*Transfusion of Allogeneic Unrelated Cord Blood Stem Cells into Peripheral Vein, Open Approach */
"30230X4" = '1' /*Transfusion of Allogeneic Unspecified Cord Blood Stem Cells into Peripheral Vein, Open Approach */
"30230Y0" = '1' /*Transfusion of Autologous Hematopoietic Stem Cellsinto Peripheral Vein, Open Approach */
"30230Y1" = '1' /*Transfusion of Nonautologous Hematopoietic StemCells into Peripheral Vein, Open Approach */
"30230Y2" = '1' /*Transfusion of Allogeneic Related Hematopoietic Stem Cells into Peripheral Vein, Open Approach */
"30230Y3" = '1' /*Transfusion of Allogeneic Unrelated Hematopoietic Stem Cells into Peripheral Vein, Open Approach */
"30230Y4" = '1' /*Transfusion of Allogeneic Unspecified Hematopoietic Stem Cells into Peripheral Vein, Open Approach */
"30233AZ" = '1' /*Transfusion of Embryonic Stem Cells into PeripheralVein, Percutaneous Approach */
"30233G0" = '1' /*Transfusion of Autologous Bone Marrow into PeripheralVein, Percutaneous Approach */
"30233G1" = '1' /*Transfusion of Nonautologous Bone Marrow intoPeripheral Vein, Percutaneous Approach */
"30233G2" = '1' /*Transfusion of Allogeneic Related Bone Marrow into Peripheral Vein, Percutaneous Approach */
"30233G3" = '1' /*Transfusion of Allogeneic Unrelated Bone Marrow into Peripheral Vein, Percutaneous Approach */
"30233G4" = '1' /*Transfusion of Allogeneic Unspecified Bone Marrow into Peripheral Vein, Percutaneous Approach */
"30233X0" = '1' /*Transfusion of Autologous Cord Blood Stem Cells intoPeripheral Vein, Percutaneous Approach */
"30233X1" = '1' /*Transfusion of Nonautologous Cord Blood Stem Cellsinto Peripheral Vein, Percutaneous Approach */
"30233X2" = '1' /*Transfusion of Allogeneic Related Cord Blood Stem Cells into Peripheral Vein, Percutaneous Approach */
"30233X3" = '1' /*Transfusion of Allogeneic Unrelated Cord Blood Stem Cells into Peripheral Vein, Percutaneous Approach */
"30233X4" = '1' /*Transfusion of Allogeneic Unspecified Cord Blood Stem Cells into Peripheral Vein, Percutaneous Approach */
"30233Y0" = '1' /*Transfusion of Autologous Hematopoietic Stem Cellsinto Peripheral Vein, Percutaneous Approach */
"30233Y1" = '1' /*Transfusion of Nonautologous Hematopoietic StemCells into Peripheral Vein, Percutaneous Approach */
"30233Y2" = '1' /*Transfusion of Allogeneic Related Hematopoietic Stem Cells into Peripheral Vein, Percutaneous Approach */
"30233Y3" = '1' /*Transfusion of Allogeneic Unrelated Hematopoietic Stem Cells into Peripheral Vein, Percutaneous Approach */
"30233Y4" = '1' /*Transfusion of Allogeneic Unspecified Hematopoietic Stem Cells into Peripheral Vein, Percutaneous Approach */
"30240AZ" = '1' /*Transfusion of Embryonic Stem Cells into Central Vein,Open Approach */
"30240G0" = '1' /*Transfusion of Autologous Bone Marrow into CentralVein, Open Approach */
"30240G1" = '1' /*Transfusion of Nonautologous Bone Marrow into CentralVein, Open Approach */
"30240G2" = '1' /*Transfusion of Allogeneic Related Bone Marrow into Central Vein, Open Approach */
"30240G3" = '1' /*Transfusion of Allogeneic Unrelated Bone Marrow into Central Vein, Open Approach */
"30240G4" = '1' /*Transfusion of Allogeneic Unspecified Bone Marrow into Central Vein, Open Approach */
"30240X0" = '1' /*Transfusion of Autologous Cord Blood Stem Cells intoCentral Vein, Open Approach */
"30240X1" = '1' /*Transfusion of Nonautologous Cord Blood Stem Cellsinto Central Vein, Open Approach */
"30240X2" = '1' /*Transfusion of Allogeneic Related Cord Blood Stem Cells into Central Vein, Open Approach */
"30240X3" = '1' /*Transfusion of Allogeneic Unrelated Cord Blood Stem Cells into Central Vein, Open Approach */
"30240X4" = '1' /*Transfusion of Allogeneic Unspecified Cord Blood Stem Cells into Central Vein, Open Approach */
"30240Y0" = '1' /*Transfusion of Autologous Hematopoietic Stem Cellsinto Central Vein, Open Approach */
"30240Y1" = '1' /*Transfusion of Nonautologous Hematopoietic StemCells into Central Vein, Open Approach */
"30240Y2" = '1' /*Transfusion of Allogeneic Related Hematopoietic Stem Cells into Central Vein, Open Approach */
"30240Y3" = '1' /*Transfusion of Allogeneic Unrelated Hematopoietic Stem Cells into Central Vein, Open Approach */
"30240Y4" = '1' /*Transfusion of Allogeneic Unspecified Hematopoietic Stem Cells into Central Vein, Open Approach */
"30243AZ" = '1' /*Transfusion of Embryonic Stem Cells into Central Vein,Percutaneous Approach */
"30243G0" = '1' /*Transfusion of Autologous Bone Marrow into CentralVein, Percutaneous Approach */
"30243G1" = '1' /*Transfusion of Nonautologous Bone Marrow into CentralVein, Percutaneous Approach */
"30243G2" = '1' /*Transfusion of Allogeneic Related Bone Marrow into Central Vein, Percutaneous Approach */
"30243G3" = '1' /*Transfusion of Allogeneic Unrelated Bone Marrow into Central Vein, Percutaneous Approach */
"30243G4" = '1' /*Transfusion of Allogeneic Unspecified Bone Marrow into Central Vein, Percutaneous Approach */
"30243X0" = '1' /*Transfusion of Autologous Cord Blood Stem Cells intoCentral Vein, Percutaneous Approach */
"30243X1" = '1' /*Transfusion of Nonautologous Cord Blood Stem Cellsinto Central Vein, Percutaneous Approach */
"30243X2" = '1' /*Transfusion of Allogeneic Related Cord Blood Stem Cells into Central Vein, Percutaneous Approach */
"30243X3" = '1' /*Transfusion of Allogeneic Unrelated Cord Blood Stem Cells into Central Vein, Percutaneous Approach */
"30243X4" = '1' /*Transfusion of Allogeneic Unspecified Cord Blood Stem Cells into Central Vein, Percutaneous Approach */
"30243Y0" = '1' /*Transfusion of Autologous Hematopoietic Stem Cellsinto Central Vein, Percutaneous Approach */
"30243Y1" = '1' /*Transfusion of Nonautologous Hematopoietic StemCells into Central Vein, Percutaneous Approach */
"30243Y2" = '1' /*Transfusion of Allogeneic Related Hematopoietic Stem Cells into Central Vein, Percutaneous Approach */
"30243Y3" = '1' /*Transfusion of Allogeneic Unrelated Hematopoietic Stem Cells into Central Vein, Percutaneous Approach */
"30243Y4" = '1' /*Transfusion of Allogeneic Unspecified Hematopoietic Stem Cells into Central Vein, Percutaneous Approach */
"30250G0" = '1' /*Transfusion of Autologous Bone Marrow into PeripheralArtery, Open Approach */
"30250G1" = '1' /*Transfusion of Nonautologous Bone Marrow intoPeripheral Artery, Open Approach */
"30250X0" = '1' /*Transfusion of Autologous Cord Blood Stem Cells intoPeripheral Artery, Open Approach */
"30250X1" = '1' /*Transfusion of Nonautologous Cord Blood Stem Cellsinto Peripheral Artery, Open Approach */
"30250Y0" = '1' /*Transfusion of Autologous Hematopoietic Stem Cellsinto Peripheral Artery, Open Approach */
"30250Y1" = '1' /*Transfusion of Nonautologous Hematopoietic StemCells into Peripheral Artery, Open Approach */
"30253G0" = '1' /*Transfusion of Autologous Bone Marrow into PeripheralArtery, Percutaneous Approach */
"30253G1" = '1' /*Transfusion of Nonautologous Bone Marrow intoPeripheral Artery, Percutaneous Approach */
"30253X0" = '1' /*Transfusion of Autologous Cord Blood Stem Cells intoPeripheral Artery, Percutaneous Approach */
"30253X1" = '1' /*Transfusion of Nonautologous Cord Blood Stem Cellsinto Peripheral Artery, Percutaneous Approach */
"30253Y0" = '1' /*Transfusion of Autologous Hematopoietic Stem Cellsinto Peripheral Artery, Percutaneous Approach */
"30253Y1" = '1' /*Transfusion of Nonautologous Hematopoietic StemCells into Peripheral Artery, Percutaneous Approach */
"30260G0" = '1' /*Transfusion of Autologous Bone Marrow into CentralArtery, Open Approach */
"30260G1" = '1' /*Transfusion of Nonautologous Bone Marrow into CentralArtery, Open Approach */
"30260X0" = '1' /*Transfusion of Autologous Cord Blood Stem Cells intoCentral Artery, Open Approach */
"30260X1" = '1' /*Transfusion of Nonautologous Cord Blood Stem Cellsinto Central Artery, Open Approach */
"30260Y0" = '1' /*Transfusion of Autologous Hematopoietic Stem Cellsinto Central Artery, Open Approach */
"30260Y1" = '1' /*Transfusion of Nonautologous Hematopoietic StemCells into Central Artery, Open Approach */
"30263G0" = '1' /*Transfusion of Autologous Bone Marrow into CentralArtery, Percutaneous Approach */
"30263G1" = '1' /*Transfusion of Nonautologous Bone Marrow into CentralArtery, Percutaneous Approach */
"30263X0" = '1' /*Transfusion of Autologous Cord Blood Stem Cells intoCentral Artery, Percutaneous Approach */
"30263X1" = '1' /*Transfusion of Nonautologous Cord Blood Stem Cellsinto Central Artery, Percutaneous Approach */
"30263Y0" = '1' /*Transfusion of Autologous Hematopoietic Stem Cellsinto Central Artery, Percutaneous Approach */
"30263Y1" = '1' /*Transfusion of Nonautologous Hematopoietic StemCells into Central Artery, Percutaneous Approach */
"3E03005" = '1' /*Introduction of Other Antineoplastic into Peripheral Vein,Open Approach */
"3E0300M" = '1' /*Introduction of Monoclonal Antibody into PeripheralVein, Open Approach */
"3E030U1" = '1' /*Introduction of Nonautologous Pancreatic Islet Cells intoPeripheral Vein, Open Approach */
"3E030WL" = '1' /*Introduction of Immunosuppressive into Peripheral Vein,Open */
"3E03305" = '1' /*Introduction of Other Antineoplastic into Peripheral Vein,Percutaneous Approach */
"3E0330M" = '1' /*Introduction of Monoclonal Antibody into PeripheralVein, Percutaneous Approach */
"3E033U1" = '1' /*Introduction of Nonautologous Pancreatic Islet Cells intoPeripheral Vein, Percutaneous Approach */
"3E033WL" = '1' /*Introduction of Immunosuppressive into Peripheral Vein,Percutaneous */
"3E04005" = '1' /*Introduction of Other Antineoplastic into Central Vein,Open Approach */
"3E0400M" = '1' /*Introduction of Monoclonal Antibody into Central Vein,Open Approach */
"3E040WL" = '1' /*Introduction of Immunosuppressive into Central Vein,Open */
"3E04305" = '1' /*Introduction of Other Antineoplastic into Central Vein,Percutaneous Approach */
"3E0430M" = '1' /*Introduction of Monoclonal Antibody into Central Vein,Percutaneous Approach */
"3E043WL" = '1' /*Introduction of Immunosuppressive into Central Vein,Percutaneous */
"3E05005" = '1' /*Introduction of Other Antineoplastic into PeripheralArtery, Open Approach */
"3E0500M" = '1' /*Introduction of Monoclonal Antibody into PeripheralArtery, Open Approach */
"3E050WL" = '1' /*Introduction of Immunosuppressive into PeripheralArtery, Open */
"3E05305" = '1' /*Introduction of Other Antineoplastic into PeripheralArtery, Percutaneous Approach */
"3E0530M" = '1' /*Introduction of Monoclonal Antibody into PeripheralArtery, Percutaneous Approach */
"3E053WL" = '1' /*Introduction of Immunosuppressive into PeripheralArtery, Percutaneous */
"3E06005" = '1' /*Introduction of Other Antineoplastic into Central Artery,Open Approach */
"3E0600M" = '1' /*Introduction of Monoclonal Antibody into Central Artery,Open Approach */
"3E060WL" = '1' /*Introduction of Immunosuppressive into Central Artery,Open */
"3E06305" = '1' /*Introduction of Other Antineoplastic into Central Artery,Percutaneous Approach */
"3E0630M" = '1' /*Introduction of Monoclonal Antibody into Central Artery,Percutaneous Approach */
"3E063WL" = '1' /*Introduction of Immunosuppressive into Central Artery,Percutaneous */
"3E0J3U1" = '1' /*Introduction of Nonautologous Pancreatic Islet Cells intoBiliary and Pancreatic Tract, Percutaneous Approach */
"3E0J7U1" = '1' /*Introduction of Nonautologous Pancreatic Islet Cells intoBiliary and Pancreatic Tract, Via Natural or ArtificialOpening */
"3E0J8U1" = '1' /*Introduction of Nonautologous Pancreatic Islet Cells intoBiliary and Pancreatic Tract, Via Natural or ArtificialOpening Endoscopic */
"XW033B3" = '1' /*Introduction of Cytarabine and Daunorubicin Liposome Antineoplastic into Peripheral Vein, Percutaneous Approach, New Technology Group 3 */
"XW033C3" = '1' /*Introduction of Engineered Autologous Chimeric Antigen Receptor T-cell Immunotherapy into Peripheral Vein, Percutaneous Approach, New Technology Group 3 */
"XW043B3" = '1' /*Introduction of Cytarabine and Daunorubicin Liposome Antineoplastic into Central Vein, Percutaneous Approach, New Technology Group 3 */
"XW043C3" = '1' /*Introduction of Engineered Autologous Chimeric Antigen Receptor T-cell Immunotherapy into Central Vein, Percutaneous Approach, New Technology Group 3 */
OTHER = '0'
;

/* FORMAT FOR Kidney or urinary tract disorder diagnosis codes */
Value $KIDNEY
"N110" = '1' /*Nonobstructive reflux-associated chronic pyelonephritis */
"N111" = '1' /*Chronic obstructive pyelonephritis */
"N118" = '1' /*Other chronic tubulo-interstitial nephritis */
"N119" = '1' /*Chronic tubulo-interstitial nephritis, unspecified */
"N130" = '1' /*Hydronephrosis with ureteropelvic junction obstruction */
"N136" = '1' /*Pyonephrosis */
"N1370" = '1' /*Vesicoureteral-reflux, unspecified */
"N1371" = '1' /*Vesicoureteral-reflux without reflux nephropathy */
"N13721" = '1' /*Vesicoureteral-reflux with reflux nephropathy without hydroureter,unilateral */
"N13722" = '1' /*Vesicoureteral-reflux with reflux nephropathy without hydroureter,bilateral */
"N13729" = '1' /*Vesicoureteral-reflux with reflux nephropathy without hydroureter,unspecified */
"N13731" = '1' /*Vesicoureteral-reflux with reflux nephropathy with hydroureter,unilateral */
"N13732" = '1' /*Vesicoureteral-reflux with reflux nephropathy with hydroureter,bilateral */
"N13739" = '1' /*Vesicoureteral-reflux with reflux nephropathy with hydroureter,unspecified */
"N139" = '1' /*Obstructive and reflux uropathy, unspecified */
"Q600" = '1' /*Renal agenesis, unilateral */
"Q601" = '1' /*Renal agenesis, bilateral */
"Q602" = '1' /*Renal agenesis, unspecified */
"Q603" = '1' /*Renal hypoplasia, unilateral */
"Q604" = '1' /*Renal hypoplasia, bilateral */
"Q605" = '1' /*Renal hypoplasia, unspecified */
"Q606" = '1' /*Potter's syndrome */
"Q6100" = '1' /*Congenital renal cyst, unspecified */
"Q6101" = '1' /*Congenital single renal cyst */
"Q6102" = '1' /*Congenital multiple renal cysts */
"Q6111" = '1' /*Cystic dilatation of collecting ducts */
"Q6119" = '1' /*Other polycystic kidney, infantile type */
"Q612" = '1' /*Polycystic kidney, adult type */
"Q613" = '1' /*Polycystic kidney, unspecified */
"Q614" = '1' /*Renal dysplasia */
"Q615" = '1' /*Medullary cystic kidney */
"Q618" = '1' /*Other cystic kidney diseases */
"Q619" = '1' /*Cystic kidney disease, unspecified */
"Q620" = '1' /*Congenital hydronephrosis */
"Q6210" = '1' /*Congenital occlusion of ureter, unspecified */
"Q6211" = '1' /*Congenital occlusion of ureteropelvic junction */
"Q6212" = '1' /*Congenital occlusion of ureterovesical orifice */
"Q622" = '1' /*Congenital megaureter */
"Q6231" = '1' /*Congenital ureterocele, orthotopic */
"Q6232" = '1' /*Cecoureterocele */
"Q6239" = '1' /*Other obstructive defects of renal pelvis and ureter */
"Q624" = '1' /*Agenesis of ureter */
"Q625" = '1' /*Duplication of ureter */
"Q6260" = '1' /*Malposition of ureter, unspecified */
"Q6261" = '1' /*Deviation of ureter */
"Q6262" = '1' /*Displacement of ureter */
"Q6263" = '1' /*Anomalous implantation of ureter */
"Q6269" = '1' /*Other malposition of ureter */
"Q627" = '1' /*Congenital vesico-uretero-renal reflux */
"Q628" = '1' /*Other congenital malformations of ureter */
"Q630" = '1' /*Accessory kidney */
"Q631" = '1' /*Lobulated, fused and horseshoe kidney */
"Q632" = '1' /*Ectopic kidney */
"Q633" = '1' /*Hyperplastic and giant kidney */
"Q638" = '1' /*Other specified congenital malformations of kidney */
"Q639" = '1' /*Congenital malformation of kidney, unspecified */
"Q6410" = '1' /*Exstrophy of urinary bladder, unspecified */
"Q6411" = '1' /*Supravesical fissure of urinary bladder */
"Q6412" = '1' /*Cloacal extrophy of urinary bladder */
"Q6419" = '1' /*Other exstrophy of urinary bladder */
"Q642" = '1' /*Congenital posterior urethral valves */
"Q6431" = '1' /*Congenital bladder neck obstruction */
"Q6432" = '1' /*Congenital stricture of urethra */
"Q6433" = '1' /*Congenital stricture of urinary meatus */
"Q6439" = '1' /*Other atresia and stenosis of urethra and bladder neck */
"Q645" = '1' /*Congenital absence of bladder and urethra */
"Q646" = '1' /*Congenital diverticulum of bladder */
"Q6470" = '1' /*Unspecified congenital malformation of bladder and urethra */
"Q6471" = '1' /*Congenital prolapse of urethra */
"Q6472" = '1' /*Congenital prolapse of urinary meatus */
"Q6473" = '1' /*Congenital urethrorectal fistula */
"Q6474" = '1' /*Double urethra */
"Q6475" = '1' /*Double urinary meatus */
"Q6479" = '1' /*Other congenital malformations of bladder and urethra */
"Q648" = '1' /*Other specified congenital malformations of urinary system */
"Q649" = '1' /*Congenital malformation of urinary system, unspecified */
OTHER = '0'
;

/* FORMAT FOR County Level with Modified FIPS */
Value $M1AREA
"02013" = '02001'
"02016" = '02001'
"02020" = '02001'
"02050" = '02001'
"02060" = '02001'
"02068" = '02001'
"02070" = '02001'
"02090" = '02001'
"02100" = '02001'
"02110" = '02001'
"02122" = '02001'
"02130" = '02001'
"02150" = '02001'
"02164" = '02001'
"02170" = '02001'
"02180" = '02001'
"02185" = '02001'
"02188" = '02001'
"02201" = '02001'
"02220" = '02001'
"02232" = '02001'
"02240" = '02001'
"02261" = '02001'
"02270" = '02001'
"02280" = '02001'
"02282" = '02001'
"02290" = '02001'
"15005" = '15009'
"24510" = '24007'
"29510" = '29191'
"32510" = '32025'
"51515" = '51019'
"51520" = '51119'
"51530" = '51163'
"51540" = '51003'
"51560" = '51005'
"51570" = '51041'
"51580" = '51005'
"51590" = '51143'
"51595" = '51081'
"51600" = '51059'
"51610" = '51059'
"51620" = '51175'
"51630" = '51177'
"51640" = '51077'
"51660" = '51165'
"51670" = '51149'
"51678" = '51163'
"51680" = '51031'
"51683" = '51153'
"51685" = '51153'
"51690" = '51089'
"51710" = '51129'
"51720" = '51195'
"51730" = '51053'
"51735" = '51199'
"51740" = '51129'
"51750" = '51121'
"51760" = '51087'
"51770" = '51161'
"51775" = '51161'
"51780" = '51083'
"51790" = '51015'
"51800" = '51123'
"51820" = '51015'
"51830" = '51095'
"51840" = '51069'
;

/* FORMAT FOR OMB 1999 METRO AREA */
value $M2AREA
'01001' = '5240 '
'01003' = '5160 '
'01009' = '1000 '
'01015' = '0450 '
'01033' = '2650 '
'01045' = '2180 '
'01051' = '5240 '
'01055' = '2880 '
'01069' = '2180 '
'01073' = '1000 '
'01077' = '2650 '
'01079' = '2030 '
'01081' = '0580 '
'01083' = '3440 '
'01089' = '3440 '
'01097' = '5160 '
'01101' = '5240 '
'01103' = '2030 '
'01113' = '1800 '
'01115' = '1000 '
'01117' = '1000 '
'01125' = '8600 '
'02020' = '0380 '
'04005' = '2620 '
'04013' = '6200 '
'04015' = '4120 '
'04019' = '8520 '
'04021' = '6200 '
'04027' = '9360 '
'05007' = '2580 '
'05031' = '3700 '
'05033' = '2720 '
'05035' = '4920 '
'05045' = '4400 '
'05069' = '6240 '
'05085' = '4400 '
'05091' = '8360 '
'05119' = '4400 '
'05125' = '4400 '
'05131' = '2720 '
'05143' = '2580 '
'06001' = '5775 '
'06007' = '1620 '
'06013' = '5775 '
'06017' = '6920 '
'06019' = '2840 '
'06029' = '0680 '
'06037' = '4480 '
'06039' = '2840 '
'06041' = '7360 '
'06047' = '4940 '
'06053' = '7120 '
'06055' = '8720 '
'06059' = '5945 '
'06061' = '6920 '
'06065' = '6780 '
'06067' = '6920 '
'06071' = '6780 '
'06073' = '7320 '
'06075' = '7360 '
'06077' = '8120 '
'06079' = '7460 '
'06081' = '7360 '
'06083' = '7480 '
'06085' = '7400 '
'06087' = '7485 '
'06089' = '6690 '
'06095' = '8720 '
'06097' = '7500 '
'06099' = '5170 '
'06101' = '9340 '
'06107' = '8780 '
'06111' = '8735 '
'06113' = '9270 '
'06115' = '9340 '
'08001' = '2080 '
'08005' = '2080 '
'08013' = '1125 '
'08031' = '2080 '
'08035' = '2080 '
'08041' = '1720 '
'08059' = '2080 '
'08069' = '2670 '
'08077' = '2995 '
'08101' = '6560 '
'08123' = '3060 '
'09001' = '5483 '
'09003' = '3283 '
'09007' = '3283 '
'09009' = '5483 '
'09011' = '5523 '
'09013' = '3283 '
'10001' = '2190 '
'10003' = '9160 '
'11001' = '8840 '
'12001' = '2900 '
'12005' = '6015 '
'12009' = '4900 '
'12011' = '2680 '
'12015' = '6580 '
'12019' = '3600 '
'12021' = '5345 '
'12031' = '3600 '
'12033' = '6080 '
'12035' = '2020 '
'12039' = '8240 '
'12053' = '8280 '
'12057' = '8280 '
'12069' = '5960 '
'12071' = '2700 '
'12073' = '8240 '
'12081' = '7510 '
'12083' = '5790 '
'12085' = '2710 '
'12086' = '5000 '
'12089' = '3600 '
'12091' = '2750 '
'12095' = '5960 '
'12097' = '5960 '
'12099' = '8960 '
'12101' = '8280 '
'12103' = '8280 '
'12105' = '3980 '
'12109' = '3600 '
'12111' = '2710 '
'12113' = '6080 '
'12115' = '7510 '
'12117' = '5960 '
'12127' = '2020 '
'13013' = '0520 '
'13015' = '0520 '
'13021' = '4680 '
'13029' = '7520 '
'13045' = '0520 '
'13047' = '1560 '
'13051' = '7520 '
'13053' = '1800 '
'13057' = '0520 '
'13059' = '0500 '
'13063' = '0520 '
'13067' = '0520 '
'13073' = '0600 '
'13077' = '0520 '
'13083' = '1560 '
'13089' = '0520 '
'13095' = '0120 '
'13097' = '0520 '
'13103' = '7520 '
'13113' = '0520 '
'13117' = '0520 '
'13121' = '0520 '
'13135' = '0520 '
'13145' = '1800 '
'13151' = '0520 '
'13153' = '4680 '
'13169' = '4680 '
'13177' = '0120 '
'13189' = '0600 '
'13195' = '0500 '
'13215' = '1800 '
'13217' = '0520 '
'13219' = '0500 '
'13223' = '0520 '
'13225' = '4680 '
'13227' = '0520 '
'13245' = '0600 '
'13247' = '0520 '
'13255' = '0520 '
'13289' = '4680 '
'13295' = '1560 '
'13297' = '0520 '
'15003' = '3320 '
'16001' = '1080 '
'16005' = '6340 '
'16027' = '1080 '
'17007' = '6880 '
'17019' = '1400 '
'17027' = '7040 '
'17031' = '1600 '
'17037' = '1600 '
'17043' = '1600 '
'17063' = '1600 '
'17073' = '1960 '
'17083' = '7040 '
'17089' = '1600 '
'17091' = '3740 '
'17093' = '1600 '
'17097' = '1600 '
'17111' = '1600 '
'17113' = '1040 '
'17115' = '2040 '
'17119' = '7040 '
'17129' = '7880 '
'17133' = '7040 '
'17141' = '6880 '
'17143' = '6120 '
'17161' = '1960 '
'17163' = '7040 '
'17167' = '7880 '
'17179' = '6120 '
'17197' = '1600 '
'17201' = '6880 '
'17203' = '6120 '
'18001' = '2760 '
'18003' = '2760 '
'18011' = '3480 '
'18019' = '4520 '
'18021' = '8320 '
'18023' = '3920 '
'18029' = '1640 '
'18033' = '2760 '
'18035' = '5280 '
'18039' = '2330 '
'18043' = '4520 '
'18057' = '3480 '
'18059' = '3480 '
'18061' = '4520 '
'18063' = '3480 '
'18067' = '3850 '
'18069' = '2760 '
'18081' = '3480 '
'18089' = '2960 '
'18095' = '3480 '
'18097' = '3480 '
'18105' = '1020 '
'18109' = '3480 '
'18115' = '1640 '
'18127' = '2960 '
'18129' = '2440 '
'18141' = '7800 '
'18143' = '4520 '
'18145' = '3480 '
'18157' = '3920 '
'18159' = '3850 '
'18163' = '2440 '
'18165' = '8320 '
'18167' = '8320 '
'18173' = '2440 '
'18179' = '2760 '
'18183' = '2760 '
'19013' = '8920 '
'19049' = '2120 '
'19061' = '2200 '
'19103' = '3500 '
'19113' = '1360 '
'19153' = '2120 '
'19155' = '5920 '
'19163' = '1960 '
'19181' = '2120 '
'19193' = '7720 '
'20015' = '9040 '
'20045' = '4150 '
'20079' = '9040 '
'20091' = '3760 '
'20103' = '3760 '
'20121' = '3760 '
'20173' = '9040 '
'20177' = '8440 '
'20209' = '3760 '
'21015' = '1640 '
'21017' = '4280 '
'21019' = '3400 '
'21029' = '4520 '
'21037' = '1640 '
'21043' = '3400 '
'21047' = '1660 '
'21049' = '4280 '
'21059' = '5990 '
'21067' = '4280 '
'21077' = '1640 '
'21081' = '1640 '
'21089' = '3400 '
'21101' = '2440 '
'21111' = '4520 '
'21113' = '4280 '
'21117' = '1640 '
'21151' = '4280 '
'21185' = '4520 '
'21191' = '1640 '
'21209' = '4280 '
'21239' = '4280 '
'22001' = '3880 '
'22005' = '0760 '
'22015' = '7680 '
'22017' = '7680 '
'22019' = '3960 '
'22033' = '0760 '
'22051' = '5560 '
'22055' = '3880 '
'22057' = '3350 '
'22063' = '0760 '
'22071' = '5560 '
'22073' = '5200 '
'22075' = '5560 '
'22079' = '0220 '
'22087' = '5560 '
'22089' = '5560 '
'22093' = '5560 '
'22095' = '5560 '
'22097' = '3880 '
'22099' = '3880 '
'22103' = '5560 '
'22109' = '3350 '
'22119' = '7680 '
'22121' = '0760 '
'23001' = '4243 '
'23005' = '6403 '
'23019' = '0733 '
'24001' = '1900 '
'24003' = '0720 '
'24005' = '0720 '
'24009' = '8840 '
'24013' = '0720 '
'24015' = '9160 '
'24017' = '8840 '
'24021' = '8840 '
'24025' = '0720 '
'24027' = '0720 '
'24031' = '8840 '
'24033' = '8840 '
'24035' = '0720 '
'24043' = '3180 '
'24510' = '0720 '
'25001' = '0743 '
'25003' = '6323 '
'25005' = '1123 '
'25009' = '1123 '
'25013' = '8003 '
'25015' = '8003 '
'25017' = '1123 '
'25021' = '1123 '
'25023' = '1123 '
'25025' = '1123 '
'25027' = '1123 '
'26005' = '3000 '
'26017' = '6960 '
'26021' = '0870 '
'26025' = '3720 '
'26037' = '4040 '
'26045' = '4040 '
'26049' = '2640 '
'26065' = '4040 '
'26075' = '3520 '
'26077' = '3720 '
'26081' = '3000 '
'26087' = '2160 '
'26091' = '0440 '
'26093' = '0440 '
'26099' = '2160 '
'26111' = '6960 '
'26115' = '2160 '
'26121' = '3000 '
'26125' = '2160 '
'26139' = '3000 '
'26145' = '6960 '
'26147' = '2160 '
'26159' = '3720 '
'26161' = '0440 '
'26163' = '2160 '
'27003' = '5120 '
'27009' = '6980 '
'27019' = '5120 '
'27025' = '5120 '
'27027' = '2520 '
'27037' = '5120 '
'27053' = '5120 '
'27055' = '3870 '
'27059' = '5120 '
'27109' = '6820 '
'27119' = '2985 '
'27123' = '5120 '
'27137' = '2240 '
'27139' = '5120 '
'27141' = '5120 '
'27145' = '6980 '
'27163' = '5120 '
'27171' = '5120 '
'28033' = '4920 '
'28035' = '3285 '
'28045' = '0920 '
'28047' = '0920 '
'28049' = '3560 '
'28059' = '0920 '
'28073' = '3285 '
'28089' = '3560 '
'28121' = '3560 '
'29003' = '7000 '
'29019' = '1740 '
'29021' = '7000 '
'29037' = '3760 '
'29043' = '7920 '
'29047' = '3760 '
'29049' = '3760 '
'29071' = '7040 '
'29077' = '7920 '
'29095' = '3760 '
'29097' = '3710 '
'29099' = '7040 '
'29107' = '3760 '
'29113' = '7040 '
'29145' = '3710 '
'29165' = '3760 '
'29177' = '3760 '
'29183' = '7040 '
'29189' = '7040 '
'29219' = '7040 '
'29225' = '7920 '
'29510' = '7040 '
'30013' = '3040 '
'30063' = '5140 '
'30111' = '0880 '
'31025' = '5920 '
'31043' = '7720 '
'31055' = '5920 '
'31109' = '4360 '
'31153' = '5920 '
'31177' = '5920 '
'32003' = '4120 '
'32023' = '4120 '
'32031' = '6720 '
'33011' = '1123 '
'33015' = '1123 '
'33017' = '1123 '
'34001' = '0560 '
'34003' = '0875 '
'34005' = '6160 '
'34007' = '6160 '
'34009' = '0560 '
'34011' = '8760 '
'34013' = '5640 '
'34015' = '6160 '
'34017' = '3640 '
'34019' = '5015 '
'34021' = '8480 '
'34023' = '5015 '
'34025' = '5190 '
'34027' = '5640 '
'34029' = '5190 '
'34031' = '0875 '
'34033' = '6160 '
'34035' = '5015 '
'34037' = '5640 '
'34039' = '5640 '
'34041' = '5640 '
'35001' = '0200 '
'35013' = '4100 '
'35028' = '7490 '
'35043' = '0200 '
'35049' = '7490 '
'35061' = '0200 '
'36001' = '0160 '
'36005' = '5600 '
'36007' = '0960 '
'36011' = '8160 '
'36013' = '3610 '
'36015' = '2335 '
'36027' = '2281 '
'36029' = '1280 '
'36037' = '6840 '
'36043' = '8680 '
'36047' = '5600 '
'36051' = '6840 '
'36053' = '8160 '
'36055' = '6840 '
'36057' = '0160 '
'36059' = '5380 '
'36061' = '5600 '
'36063' = '1280 '
'36065' = '8680 '
'36067' = '8160 '
'36069' = '6840 '
'36071' = '5660 '
'36073' = '6840 '
'36075' = '8160 '
'36079' = '5600 '
'36081' = '5600 '
'36083' = '0160 '
'36085' = '5600 '
'36087' = '5600 '
'36091' = '0160 '
'36093' = '0160 '
'36095' = '0160 '
'36103' = '5380 '
'36107' = '0960 '
'36113' = '2975 '
'36115' = '2975 '
'36117' = '6840 '
'36119' = '5600 '
'37001' = '3120 '
'37003' = '3290 '
'37019' = '9200 '
'37021' = '0480 '
'37023' = '3290 '
'37025' = '1520 '
'37027' = '3290 '
'37035' = '3290 '
'37037' = '6640 '
'37051' = '2560 '
'37053' = '5720 '
'37057' = '3120 '
'37059' = '3120 '
'37063' = '6640 '
'37065' = '6895 '
'37067' = '3120 '
'37069' = '6640 '
'37071' = '1520 '
'37081' = '3120 '
'37101' = '6640 '
'37109' = '1520 '
'37115' = '0480 '
'37119' = '1520 '
'37127' = '6895 '
'37129' = '9200 '
'37133' = '3605 '
'37135' = '6640 '
'37147' = '3150 '
'37151' = '3120 '
'37159' = '1520 '
'37169' = '3120 '
'37179' = '1520 '
'37183' = '6640 '
'37191' = '2980 '
'37197' = '3120 '
'38015' = '1010 '
'38017' = '2520 '
'38035' = '2985 '
'38059' = '1010 '
'39003' = '4320 '
'39007' = '1680 '
'39011' = '4320 '
'39013' = '9000 '
'39015' = '1640 '
'39017' = '3200 '
'39019' = '1320 '
'39023' = '2000 '
'39025' = '1640 '
'39029' = '9320 '
'39033' = '4800 '
'39035' = '1680 '
'39041' = '1840 '
'39045' = '1840 '
'39049' = '1840 '
'39051' = '8400 '
'39055' = '1680 '
'39057' = '2000 '
'39061' = '1640 '
'39081' = '8080 '
'39085' = '1680 '
'39087' = '3400 '
'39089' = '1840 '
'39093' = '1680 '
'39095' = '8400 '
'39097' = '1840 '
'39099' = '9320 '
'39103' = '1680 '
'39109' = '2000 '
'39113' = '2000 '
'39129' = '1840 '
'39133' = '0080 '
'39139' = '4800 '
'39151' = '1320 '
'39153' = '0080 '
'39155' = '9320 '
'39165' = '1640 '
'39167' = '6020 '
'39173' = '8400 '
'40017' = '5880 '
'40027' = '5880 '
'40031' = '4200 '
'40037' = '8560 '
'40047' = '2340 '
'40083' = '5880 '
'40087' = '5880 '
'40109' = '5880 '
'40113' = '8560 '
'40125' = '5880 '
'40131' = '8560 '
'40135' = '2720 '
'40143' = '8560 '
'40145' = '8560 '
'41003' = '1890 '
'41005' = '6440 '
'41009' = '6440 '
'41029' = '4890 '
'41039' = '2400 '
'41047' = '7080 '
'41051' = '6440 '
'41053' = '7080 '
'41067' = '6440 '
'41071' = '6440 '
'42003' = '6280 '
'42007' = '6280 '
'42011' = '6680 '
'42013' = '0280 '
'42017' = '6160 '
'42019' = '6280 '
'42021' = '3680 '
'42025' = '0240 '
'42027' = '8050 '
'42029' = '6160 '
'42037' = '7560 '
'42041' = '3240 '
'42043' = '3240 '
'42045' = '6160 '
'42049' = '2360 '
'42051' = '6280 '
'42069' = '7560 '
'42071' = '4000 '
'42075' = '3240 '
'42077' = '0240 '
'42079' = '7560 '
'42081' = '9140 '
'42085' = '7610 '
'42091' = '6160 '
'42095' = '0240 '
'42099' = '3240 '
'42101' = '6160 '
'42103' = '5660 '
'42111' = '3680 '
'42125' = '6280 '
'42129' = '6280 '
'42131' = '7560 '
'42133' = '9280 '
'44001' = '6483 '
'44003' = '6483 '
'44007' = '6483 '
'44009' = '6483 '
'45003' = '0600 '
'45007' = '3160 '
'45015' = '1440 '
'45019' = '1440 '
'45021' = '3160 '
'45035' = '1440 '
'45037' = '0600 '
'45041' = '2655 '
'45045' = '3160 '
'45051' = '5330 '
'45063' = '1760 '
'45077' = '3160 '
'45079' = '1760 '
'45083' = '3160 '
'45085' = '8140 '
'45091' = '1520 '
'46083' = '7760 '
'46099' = '7760 '
'46103' = '6660 '
'47001' = '3840 '
'47009' = '3840 '
'47019' = '3660 '
'47021' = '5360 '
'47023' = '3580 '
'47037' = '5360 '
'47043' = '5360 '
'47047' = '4920 '
'47065' = '1560 '
'47073' = '3660 '
'47093' = '3840 '
'47105' = '3840 '
'47113' = '3580 '
'47115' = '1560 '
'47125' = '1660 '
'47147' = '5360 '
'47149' = '5360 '
'47155' = '3840 '
'47157' = '4920 '
'47163' = '3660 '
'47165' = '5360 '
'47167' = '4920 '
'47171' = '3660 '
'47173' = '3840 '
'47179' = '3660 '
'47187' = '5360 '
'47189' = '5360 '
'48009' = '9080 '
'48021' = '0640 '
'48027' = '3810 '
'48029' = '7240 '
'48037' = '8360 '
'48039' = '1145 '
'48041' = '1260 '
'48055' = '0640 '
'48061' = '1240 '
'48071' = '3360 '
'48085' = '1920 '
'48091' = '7240 '
'48099' = '3810 '
'48113' = '1920 '
'48121' = '1920 '
'48135' = '5800 '
'48139' = '1920 '
'48141' = '2320 '
'48157' = '3360 '
'48167' = '2920 '
'48181' = '7640 '
'48183' = '4420 '
'48187' = '7240 '
'48199' = '0840 '
'48201' = '3360 '
'48203' = '4420 '
'48209' = '0640 '
'48213' = '1920 '
'48215' = '4880 '
'48221' = '2800 '
'48231' = '1920 '
'48245' = '0840 '
'48251' = '2800 '
'48257' = '1920 '
'48291' = '3360 '
'48303' = '4600 '
'48309' = '8800 '
'48329' = '5800 '
'48339' = '3360 '
'48355' = '1880 '
'48361' = '0840 '
'48367' = '2800 '
'48375' = '0320 '
'48381' = '0320 '
'48397' = '1920 '
'48409' = '1880 '
'48423' = '8640 '
'48439' = '2800 '
'48441' = '0040 '
'48451' = '7200 '
'48453' = '0640 '
'48459' = '4420 '
'48469' = '8750 '
'48473' = '3360 '
'48479' = '4080 '
'48485' = '9080 '
'48491' = '0640 '
'48493' = '7240 '
'49011' = '7160 '
'49025' = '2620 '
'49035' = '7160 '
'49049' = '6520 '
'49057' = '7160 '
'50007' = '1303 '
'50011' = '1303 '
'50013' = '1303 '
'51003' = '1540 '
'51009' = '4640 '
'51013' = '8840 '
'51019' = '4640 '
'51023' = '6800 '
'51031' = '4640 '
'51036' = '6760 '
'51041' = '6760 '
'51043' = '8840 '
'51047' = '8840 '
'51053' = '6760 '
'51059' = '8840 '
'51061' = '8840 '
'51065' = '1540 '
'51073' = '5720 '
'51075' = '6760 '
'51079' = '1540 '
'51085' = '6760 '
'51087' = '6760 '
'51093' = '5720 '
'51095' = '5720 '
'51099' = '8840 '
'51107' = '8840 '
'51115' = '5720 '
'51127' = '6760 '
'51143' = '1950 '
'51145' = '6760 '
'51149' = '6760 '
'51153' = '8840 '
'51161' = '6800 '
'51169' = '3660 '
'51177' = '8840 '
'51179' = '8840 '
'51187' = '8840 '
'51191' = '3660 '
'51199' = '5720 '
'51510' = '8840 '
'51515' = '4640 '
'51520' = '3660 '
'51540' = '1540 '
'51550' = '5720 '
'51570' = '6760 '
'51590' = '1950 '
'51600' = '8840 '
'51610' = '8840 '
'51630' = '8840 '
'51650' = '5720 '
'51670' = '6760 '
'51680' = '4640 '
'51683' = '8840 '
'51685' = '8840 '
'51700' = '5720 '
'51710' = '5720 '
'51730' = '6760 '
'51735' = '5720 '
'51740' = '5720 '
'51760' = '6760 '
'51770' = '6800 '
'51775' = '6800 '
'51800' = '5720 '
'51810' = '5720 '
'51830' = '5720 '
'53005' = '6740 '
'53011' = '6440 '
'53021' = '6740 '
'53029' = '7600 '
'53033' = '7600 '
'53035' = '1150 '
'53053' = '8200 '
'53061' = '7600 '
'53063' = '7840 '
'53067' = '5910 '
'53073' = '0860 '
'53077' = '9260 '
'54003' = '8840 '
'54009' = '8080 '
'54011' = '3400 '
'54029' = '8080 '
'54037' = '8840 '
'54039' = '1480 '
'54051' = '9000 '
'54057' = '1900 '
'54069' = '9000 '
'54079' = '1480 '
'54099' = '3400 '
'54107' = '6020 '
'55009' = '3080 '
'55015' = '0460 '
'55017' = '2290 '
'55025' = '4720 '
'55031' = '2240 '
'55035' = '2290 '
'55059' = '3800 '
'55063' = '3870 '
'55073' = '8940 '
'55079' = '5080 '
'55087' = '0460 '
'55089' = '5080 '
'55093' = '5120 '
'55101' = '6600 '
'55105' = '3620 '
'55109' = '5120 '
'55117' = '7620 '
'55131' = '5080 '
'55133' = '5080 '
'55139' = '0460 '
'56021' = '1580 '
'56025' = '1350 '
;

/* FORMAT FOR OMB 2003 METRO AREA */
Value $M3AREA
"01001" = '33860' /*Montgomery, AL Metropolitan Statistical Area */
"01003" = '19300' /*Daphne-Fairhope, AL Micropolitan Statistical Area */
"01005" = '21640' /*Eufaula, AL-GA Micropolitan Statistical Area */
"01007" = '13820' /*Birmingham-Hoover, AL Metropolitan Statistical Area */
"01009" = '13820' /*Birmingham-Hoover, AL Metropolitan Statistical Area */
"01015" = '11500' /*Anniston-Oxford, AL Metropolitan Statistical Area */
"01017" = '46740' /*Valley, AL Micropolitan Statistical Area */
"01021" = '13820' /*Birmingham-Hoover, AL Metropolitan Statistical Area */
"01031" = '21460' /*Enterprise-Ozark, AL Micropolitan Statistical Area */
"01033" = '22520' /*Florence-Muscle Shoals, AL Metropolitan Statistical Area */
"01037" = '10760' /*Alexander City, AL Micropolitan Statistical Area */
"01043" = '18980' /*Cullman, AL Micropolitan Statistical Area */
"01045" = '21460' /*Enterprise-Ozark, AL Micropolitan Statistical Area */
"01047" = '42820' /*Selma, AL Micropolitan Statistical Area */
"01049" = '22840' /*Fort Payne, AL Micropolitan Statistical Area */
"01051" = '33860' /*Montgomery, AL Metropolitan Statistical Area */
"01055" = '23460' /*Gadsden, AL Metropolitan Statistical Area */
"01061" = '20020' /*Dothan, AL Metropolitan Statistical Area */
"01063" = '46220' /*Tuscaloosa, AL Metropolitan Statistical Area */
"01065" = '46220' /*Tuscaloosa, AL Metropolitan Statistical Area */
"01067" = '20020' /*Dothan, AL Metropolitan Statistical Area */
"01069" = '20020' /*Dothan, AL Metropolitan Statistical Area */
"01071" = '42460' /*Scottsboro, AL Micropolitan Statistical Area */
"01073" = '13820' /*Birmingham-Hoover, AL Metropolitan Statistical Area */
"01077" = '22520' /*Florence-Muscle Shoals, AL Metropolitan Statistical Area */
"01079" = '19460' /*Decatur, AL Metropolitan Statistical Area */
"01081" = '12220' /*Auburn-Opelika, AL Metropolitan Statistical Area */
"01083" = '26620' /*Huntsville, AL Metropolitan Statistical Area */
"01085" = '33860' /*Montgomery, AL Metropolitan Statistical Area */
"01087" = '46260' /*Tuskegee, AL Micropolitan Statistical Area */
"01089" = '26620' /*Huntsville, AL Metropolitan Statistical Area */
"01095" = '10700' /*Albertville, AL Micropolitan Statistical Area */
"01097" = '33660' /*Mobile, AL Metropolitan Statistical Area */
"01101" = '33860' /*Montgomery, AL Metropolitan Statistical Area */
"01103" = '19460' /*Decatur, AL Metropolitan Statistical Area */
"01109" = '45980' /*Troy, AL Micropolitan Statistical Area */
"01113" = '17980' /*Columbus, GA-AL Metropolitan Statistical Area */
"01115" = '13820' /*Birmingham-Hoover, AL Metropolitan Statistical Area */
"01117" = '13820' /*Birmingham-Hoover, AL Metropolitan Statistical Area */
"01121" = '45180' /*Talladega-Sylacauga, AL Micropolitan Statistical Area */
"01123" = '10760' /*Alexander City, AL Micropolitan Statistical Area */
"01125" = '46220' /*Tuscaloosa, AL Metropolitan Statistical Area */
"01127" = '13820' /*Birmingham-Hoover, AL Metropolitan Statistical Area */
"02020" = '11260' /*Anchorage, AK Metropolitan Statistical Area */
"02090" = '21820' /*Fairbanks, AK Metropolitan Statistical Area */
"02110" = '27940' /*Juneau, AK Micropolitan Statistical Area */
"02130" = '28540' /*Ketchikan, AK Micropolitan Statistical Area */
"02150" = '28980' /*Kodiak, AK Micropolitan Statistical Area */
"02170" = '11260' /*Anchorage, AK Metropolitan Statistical Area */
"04003" = '43420' /*Sierra Vista-Douglas, AZ Micropolitan Statistical Area */
"04005" = '22380' /*Flagstaff, AZ Metropolitan Statistical Area */
"04007" = '37740' /*Payson, AZ Micropolitan Statistical Area */
"04009" = '40940' /*Safford, AZ Micropolitan Statistical Area */
"04011" = '40940' /*Safford, AZ Micropolitan Statistical Area */
"04013" = '38060' /*Phoenix-Mesa-Scottsdale, AZ Metropolitan Statistical Area */
"04015" = '29420' /*Lake Havasu City-Kingman, AZ Micropolitan Statistical Area */
"04019" = '46060' /*Tucson, AZ Metropolitan Statistical Area */
"04021" = '38060' /*Phoenix-Mesa-Scottsdale, AZ Metropolitan Statistical Area */
"04023" = '35700' /*Nogales, AZ Micropolitan Statistical Area */
"04025" = '39140' /*Prescott, AZ Metropolitan Statistical Area */
"04027" = '49740' /*Yuma, AZ Metropolitan Statistical Area */
"05005" = '34260' /*Mountain Home, AR Micropolitan Statistical Area */
"05007" = '22220' /*Fayetteville-Springdale-Rogers, AR-MO Metropolitan Statistical Area */
"05009" = '25460' /*Harrison, AR Micropolitan Statistical Area */
"05013" = '15780' /*Camden, AR Micropolitan Statistical Area */
"05019" = '11660' /*Arkadelphia, AR Micropolitan Statistical Area */
"05025" = '38220' /*Pine Bluff, AR Metropolitan Statistical Area */
"05027" = '31620' /*Magnolia, AR Micropolitan Statistical Area */
"05031" = '27860' /*Jonesboro, AR Metropolitan Statistical Area */
"05033" = '22900' /*Fort Smith, AR-OK Metropolitan Statistical Area */
"05035" = '32820' /*Memphis, TN -MS-AR Metropolitan Statistical Area */
"05045" = '30780' /*Little Rock-North Little Rock, AR Metropolitan Statistical Area */
"05047" = '22900' /*Fort Smith, AR-OK Metropolitan Statistical Area */
"05051" = '26300' /*Hot Springs, AR Metropolitan Statistical Area */
"05053" = '30780' /*Little Rock-North Little Rock, AR Metropolitan Statistical Area */
"05055" = '37500' /*Paragould, AR Micropolitan Statistical Area */
"05057" = '26260' /*Hope, AR Micropolitan Statistical Area */
"05063" = '12900' /*Batesville, AR Micropolitan Statistical Area */
"05069" = '38220' /*Pine Bluff, AR Metropolitan Statistical Area */
"05079" = '38220' /*Pine Bluff, AR Metropolitan Statistical Area */
"05085" = '30780' /*Little Rock-North Little Rock, AR Metropolitan Statistical Area */
"05087" = '22220' /*Fayetteville-Springdale-Rogers, AR-MO Metropolitan Statistical Area */
"05091" = '45500' /*Texarkana, TX-Texarkana, AR Metropolitan Statistical Area */
"05093" = '14180' /*Blytheville, AR Micropolitan Statistical Area */
"05099" = '26260' /*Hope, AR Micropolitan Statistical Area */
"05101" = '25460' /*Harrison, AR Micropolitan Statistical Area */
"05103" = '15780' /*Camden, AR Micropolitan Statistical Area */
"05105" = '30780' /*Little Rock-North Little Rock, AR Metropolitan Statistical Area */
"05107" = '48340' /*West Helena, AR Micropolitan Statistical Area */
"05111" = '27860' /*Jonesboro, AR Metropolitan Statistical Area */
"05115" = '40780' /*Russellville, AR Micropolitan Statistical Area */
"05119" = '30780' /*Little Rock-North Little Rock, AR Metropolitan Statistical Area */
"05123" = '22620' /*Forrest City, AR Micropolitan Statistical Area */
"05125" = '30780' /*Little Rock-North Little Rock, AR Metropolitan Statistical Area */
"05131" = '22900' /*Fort Smith, AR-OK Metropolitan Statistical Area */
"05139" = '20980' /*El Dorado, AR Micropolitan Statistical Area */
"05143" = '22220' /*Fayetteville-Springdale-Rogers, AR-MO Metropolitan Statistical Area */
"05145" = '42620' /*Searcy, AR Micropolitan Statistical Area */
"05149" = '40780' /*Russellville, AR Micropolitan Statistical Area */
"06001" = '41860' /*San Francisco-Oakland-Fremont, CA Metropolitan Statistical Area */
"06007" = '17020' /*Chico, CA Metropolitan Statistical Area */
"06013" = '41860' /*San Francisco-Oakland-Fremont, CA Metropolitan Statistical Area */
"06015" = '18860' /*Crescent City North, CA Micropolitan Statistical Area */
"06017" = '40900' /*Sacramento—Arden-Arcade—Roseville, CA Metropolitan Statistical Area */
"06019" = '23420' /*Fresno, CA Metropolitan Statistical Area */
"06023" = '21700' /*Eureka-Arcata-Fortuna, CA Micropolitan Statistical Area */
"06025" = '20940' /*El Centro, CA Metropolitan Statistical Area */
"06027" = '13860' /*Bishop, CA Micropolitan Statistical Area */
"06029" = '12540' /*Bakersfield, CA Metropolitan Statistical Area */
"06031" = '25260' /*Hanford-Corcoran, CA Metropolitan Statistical Area */
"06033" = '17340' /*Clearlake, CA Micropolitan Statistical Area */
"06035" = '45000' /*Susanville, CA Micropolitan Statistical Area */
"06037" = '31100' /*Los Angeles-Long Beach-Santa Ana, CA Metropolitan Statistical Area */
"06039" = '31460' /*Madera, CA Metropolitan Statistical Area */
"06041" = '41860' /*San Francisco-Oakland-Fremont, CA Metropolitan Statistical Area */
"06045" = '46380' /*Ukiah, CA Micropolitan Statistical Area */
"06047" = '32900' /*Merced, CA Metropolitan Statistical Area */
"06053" = '41500' /*Salinas, CA Metropolitan Statistical Area */
"06055" = '34900' /*Napa, CA Metropolitan Statistical Area */
"06057" = '46020' /*Truckee-Grass Valley, CA Micropolitan Statistical Area */
"06059" = '31100' /*Los Angeles-Long Beach-Santa Ana, CA Metropolitan Statistical Area */
"06061" = '40900' /*Sacramento—Arden-Arcade—Roseville, CA Metropolitan Statistical Area */
"06065" = '40140' /*Riverside-San Bernardino-Ontario, CA Metropolitan Statistical Area */
"06067" = '40900' /*Sacramento—Arden-Arcade—Roseville, CA Metropolitan Statistical Area */
"06069" = '41940' /*San Jose-Sunnyvale-Santa Clara, CA Metropolitan Statistical Area */
"06071" = '40140' /*Riverside-San Bernardino-Ontario, CA Metropolitan Statistical Area */
"06073" = '41740' /*San Diego-Carlsbad-San Marcos, CA Metropolitan Statistical Area */
"06075" = '41860' /*San Francisco-Oakland-Fremont, CA Metropolitan Statistical Area */
"06077" = '44700' /*Stockton, CA Metropolitan Statistical Area */
"06079" = '42020' /*San Luis Obispo-Paso Robles, CA Metropolitan Statistical Area */
"06081" = '41860' /*San Francisco-Oakland-Fremont, CA Metropolitan Statistical Area */
"06083" = '42060' /*Santa Barbara-Santa Maria-Goleta, CA Metropolitan Statistical Area */
"06085" = '41940' /*San Jose-Sunnyvale-Santa Clara, CA Metropolitan Statistical Area */
"06087" = '42100' /*Santa Cruz-Watsonville, CA Metropolitan Statistical Area */
"06089" = '39820' /*Redding, CA Metropolitan Statistical Area */
"06095" = '46700' /*Vallejo-Fairfield, CA Metropolitan Statistical Area */
"06097" = '42220' /*Santa Rosa-Petaluma, CA Metropolitan Statistical Area */
"06099" = '33700' /*Modesto, CA Metropolitan Statistical Area */
"06101" = '49700' /*Yuba City-Marysville, CA Metropolitan Statistical Area */
"06103" = '39780' /*Red Bluff, CA Micropolitan Statistical Area */
"06107" = '47300' /*Visalia-Porterville, CA Metropolitan Statistical Area */
"06109" = '38020' /*Phoenix Lake-Cedar Ridge, CA Micropolitan Statistical Area */
"06111" = '37100' /*Oxnard-Thousand Oaks-Ventura, CA Metropolitan Statistical Area */
"06113" = '40900' /*Sacramento—Arden-Arcade—Roseville, CA Metropolitan Statistical Area */
"06115" = '49700' /*Yuba City-Marysville, CA Metropolitan Statistical Area */
"08001" = '19740' /*Denver-Aurora, CO Metropolitan Statistical Area */
"08005" = '19740' /*Denver-Aurora, CO Metropolitan Statistical Area */
"08013" = '14500' /*Boulder, CO Metropolitan Statistical Area */
"08014" = '19740' /*Denver-Aurora, CO Metropolitan Statistical Area */
"08019" = '19740' /*Denver-Aurora, CO Metropolitan Statistical Area */
"08031" = '19740' /*Denver-Aurora, CO Metropolitan Statistical Area */
"08035" = '19740' /*Denver-Aurora, CO Metropolitan Statistical Area */
"08037" = '20780' /*Edwards, CO Micropolitan Statistical Area */
"08039" = '19740' /*Denver-Aurora, CO Metropolitan Statistical Area */
"08041" = '17820' /*Colorado Springs, CO Metropolitan Statistical Area */
"08043" = '15860' /*Canon City, CO Micropolitan Statistical Area */
"08047" = '19740' /*Denver-Aurora, CO Metropolitan Statistical Area */
"08059" = '19740' /*Denver-Aurora, CO Metropolitan Statistical Area */
"08065" = '20780' /*Edwards, CO Micropolitan Statistical Area */
"08067" = '20420' /*Durango, CO Micropolitan Statistical Area */
"08069" = '22660' /*Fort Collins-Loveland, CO Metropolitan Statistical Area */
"08075" = '44540' /*Sterling, CO Micropolitan Statistical Area */
"08077" = '24300' /*Grand Junction, CO Metropolitan Statistical Area */
"08085" = '33940' /*Montrose, CO Micropolitan Statistical Area */
"08087" = '22820' /*Fort Morgan, CO Micropolitan Statistical Area */
"08093" = '19740' /*Denver-Aurora, CO Metropolitan Statistical Area */
"08101" = '39380' /*Pueblo, CO Metropolitan Statistical Area */
"08117" = '43540' /*Silverthorne, CO Micropolitan Statistical Area */
"08119" = '17820' /*Colorado Springs, CO Metropolitan Statistical Area */
"08123" = '24540' /*Greeley, CO Metropolitan Statistical Area */
"09001" = '14860' /*Bridgeport-Stamford-Norwalk, CT Metropolitan Statistical Area */
"09003" = '25540' /*Hartford-West Hartford-East Hartford, CT Metropolitan Statistical Area */
"09005" = '45860' /*Torrington, CT Micropolitan Statistical Area */
"09007" = '25540' /*Hartford-West Hartford-East Hartford, CT Metropolitan Statistical Area */
"09009" = '35300' /*New Haven-Milford, CT Metropolitan Statistical Area */
"09011" = '35980' /*Norwich-New London, CT Metropolitan Statistical Area */
"09013" = '25540' /*Hartford-West Hartford-East Hartford, CT Metropolitan Statistical Area */
"09015" = '48740' /*Willimantic, CT Micropolitan Statistical Area */
"10001" = '20100' /*Dover, DE Metropolitan Statistical Area */
"10003" = '37980' /*Philadelphia-Camden-Wilmington, PA-NJ-DE-MD Metropolitan Statistical Area */
"10005" = '42580' /*Seaford, DE Micropolitan Statistical Area */
"11001" = '47900' /*Washington-Arlington-Alexandria, DC-VA-MD-WV Metropolitan Statistical Area */
"12001" = '23540' /*Gainesville, FL Metropolitan Statistical Area */
"12003" = '27260' /*Jacksonville, FL Metropolitan Statistical Area */
"12005" = '37460' /*Panama City-Lynn Haven, FL Metropolitan Statistical Area */
"12009" = '37340' /*Palm Bay-Melbourne-Titusville, FL Metropolitan Statistical Area */
"12011" = '33100' /*Miami-Fort Lauderdale-Miami Beach, FL Metropolitan Statistical Area */
"12015" = '39460' /*Punta Gorda, FL Metropolitan Statistical Area */
"12017" = '26140' /*Homosassa Springs, FL Micropolitan Statistical Area */
"12019" = '27260' /*Jacksonville, FL Metropolitan Statistical Area */
"12021" = '34940' /*Naples-Marco Island, FL Metropolitan Statistical Area */
"12023" = '29380' /*Lake City, FL Micropolitan Statistical Area */
"12027" = '11580' /*Arcadia, FL Micropolitan Statistical Area */
"12031" = '27260' /*Jacksonville, FL Metropolitan Statistical Area */
"12033" = '37860' /*Pensacola-Ferry Pass-Brent, FL Metropolitan Statistical Area */
"12035" = '37380' /*Palm Coast, FL Micropolitan Statistical Area */
"12039" = '45220' /*Tallahassee, FL Metropolitan Statistical Area */
"12041" = '23540' /*Gainesville, FL Metropolitan Statistical Area */
"12049" = '48100' /*Wauchula, FL Micropolitan Statistical Area */
"12051" = '17500' /*Clewiston, FL Micropolitan Statistical Area */
"12053" = '45300' /*Tampa-St. Petersburg-Clearwater, FL Metropolitan Statistical Area */
"12055" = '42700' /*Sebring, FL Micropolitan Statistical Area */
"12057" = '45300' /*Tampa-St. Petersburg-Clearwater, FL Metropolitan Statistical Area */
"12061" = '46940' /*Vero Beach, FL Metropolitan Statistical Area */
"12065" = '45220' /*Tallahassee, FL Metropolitan Statistical Area */
"12069" = '36740' /*Orlando, FL Metropolitan Statistical Area */
"12071" = '15980' /*Cape Coral-Fort Myers, FL Metropolitan Statistical Area */
"12073" = '45220' /*Tallahassee, FL Metropolitan Statistical Area */
"12081" = '42260' /*Sarasota-Bradenton-Venice, FL Metropolitan Statistical Area */
"12083" = '36100' /*Ocala, FL Metropolitan Statistical Area */
"12085" = '38940' /*Port St. Lucie-Fort Pierce, FL Metropolitan Statistical Area */
"12086" = '33100' /*Miami-Fort Lauderdale-Miami Beach, FL Metropolitan Statistical Area */
"12087" = '28580' /*Key West-Marathon, FL Micropolitan Statistical Area */
"12089" = '27260' /*Jacksonville, FL Metropolitan Statistical Area */
"12091" = '23020' /*Fort Walton Beach-Crestview-Destin, FL Metropolitan Statistical Area */
"12093" = '36380' /*Okeechobee, FL Micropolitan Statistical Area */
"12095" = '36740' /*Orlando, FL Metropolitan Statistical Area */
"12097" = '36740' /*Orlando, FL Metropolitan Statistical Area */
"12099" = '33100' /*Miami-Fort Lauderdale-Miami Beach, FL Metropolitan Statistical Area */
"12101" = '45300' /*Tampa-St. Petersburg-Clearwater, FL Metropolitan Statistical Area */
"12103" = '45300' /*Tampa-St. Petersburg-Clearwater, FL Metropolitan Statistical Area */
"12105" = '29460' /*Lakeland-Winter Haven, FL Metropolitan Statistical Area */
"12107" = '37260' /*Palatka, FL Micropolitan Statistical Area */
"12109" = '27260' /*Jacksonville, FL Metropolitan Statistical Area */
"12111" = '38940' /*Port St. Lucie-Fort Pierce, FL Metropolitan Statistical Area */
"12113" = '37860' /*Pensacola-Ferry Pass-Brent, FL Metropolitan Statistical Area */
"12115" = '42260' /*Sarasota-Bradenton-Venice, FL Metropolitan Statistical Area */
"12117" = '36740' /*Orlando, FL Metropolitan Statistical Area */
"12119" = '45540' /*The Villages, FL Micropolitan Statistical Area */
"12127" = '19660' /*Deltona-Daytona Beach-Ormond Beach, FL Metropolitan Statistical Area */
"12129" = '45220' /*Tallahassee, FL Metropolitan Statistical Area */
"13003" = '20060' /*Douglas, GA Micropolitan Statistical Area */
"13007" = '10500' /*Albany, GA Metropolitan Statistical Area */
"13009" = '33300' /*Milledgeville, GA Micropolitan Statistical Area */
"13013" = '12060' /*Atlanta-Sandy Springs-Marietta, GA Metropolitan Statistical Area */
"13015" = '12060' /*Atlanta-Sandy Springs-Marietta, GA Metropolitan Statistical Area */
"13017" = '22340' /*Fitzgerald, GA Micropolitan Statistical Area */
"13021" = '31420' /*Macon, GA Metropolitan Statistical Area */
"13025" = '15260' /*Brunswick, GA Metropolitan Statistical Area */
"13027" = '46660' /*Valdosta, GA Metropolitan Statistical Area */
"13029" = '42340' /*Savannah, GA Metropolitan Statistical Area */
"13031" = '44340' /*Statesboro, GA Micropolitan Statistical Area */
"13033" = '12260' /*Augusta-Richmond County, GA-SC Metropolitan Statistical Area */
"13035" = '12060' /*Atlanta-Sandy Springs-Marietta, GA Metropolitan Statistical Area */
"13039" = '41220' /*St. Marys, GA Micropolitan Statistical Area */
"13045" = '12060' /*Atlanta-Sandy Springs-Marietta, GA Metropolitan Statistical Area */
"13047" = '16860' /*Chattanooga, TN-GA Metropolitan Statistical Area */
"13051" = '42340' /*Savannah, GA Metropolitan Statistical Area */
"13053" = '17980' /*Columbus, GA-AL Metropolitan Statistical Area */
"13055" = '44900' /*Summerville, GA Micropolitan Statistical Area */
"13057" = '12060' /*Atlanta-Sandy Springs-Marietta, GA Metropolitan Statistical Area */
"13059" = '12020' /*Athens-Clarke County, GA Metropolitan Statistical Area */
"13063" = '12060' /*Atlanta-Sandy Springs-Marietta, GA Metropolitan Statistical Area */
"13067" = '12060' /*Atlanta-Sandy Springs-Marietta, GA Metropolitan Statistical Area */
"13069" = '20060' /*Douglas, GA Micropolitan Statistical Area */
"13071" = '34220' /*Moultrie, GA Micropolitan Statistical Area */
"13073" = '12260' /*Augusta-Richmond County, GA-SC Metropolitan Statistical Area */
"13077" = '12060' /*Atlanta-Sandy Springs-Marietta, GA Metropolitan Statistical Area */
"13079" = '31420' /*Macon, GA Metropolitan Statistical Area */
"13081" = '18380' /*Cordele, GA Micropolitan Statistical Area */
"13083" = '16860' /*Chattanooga, TN-GA Metropolitan Statistical Area */
"13085" = '12060' /*Atlanta-Sandy Springs-Marietta, GA Metropolitan Statistical Area */
"13087" = '12460' /*Bainbridge, GA Micropolitan Statistical Area */
"13089" = '12060' /*Atlanta-Sandy Springs-Marietta, GA Metropolitan Statistical Area */
"13095" = '10500' /*Albany, GA Metropolitan Statistical Area */
"13097" = '12060' /*Atlanta-Sandy Springs-Marietta, GA Metropolitan Statistical Area */
"13101" = '46660' /*Valdosta, GA Metropolitan Statistical Area */
"13103" = '42340' /*Savannah, GA Metropolitan Statistical Area */
"13113" = '12060' /*Atlanta-Sandy Springs-Marietta, GA Metropolitan Statistical Area */
"13115" = '40660' /*Rome, GA Metropolitan Statistical Area */
"13117" = '12060' /*Atlanta-Sandy Springs-Marietta, GA Metropolitan Statistical Area */
"13121" = '12060' /*Atlanta-Sandy Springs-Marietta, GA Metropolitan Statistical Area */
"13127" = '15260' /*Brunswick, GA Metropolitan Statistical Area */
"13129" = '15660' /*Calhoun, GA Micropolitan Statistical Area */
"13135" = '12060' /*Atlanta-Sandy Springs-Marietta, GA Metropolitan Statistical Area */
"13137" = '18460' /*Cornelia, GA Micropolitan Statistical Area */
"13139" = '23580' /*Gainesville, GA Metropolitan Statistical Area */
"13141" = '33300' /*Milledgeville, GA Micropolitan Statistical Area */
"13143" = '12060' /*Atlanta-Sandy Springs-Marietta, GA Metropolitan Statistical Area */
"13145" = '17980' /*Columbus, GA-AL Metropolitan Statistical Area */
"13149" = '12060' /*Atlanta-Sandy Springs-Marietta, GA Metropolitan Statistical Area */
"13151" = '12060' /*Atlanta-Sandy Springs-Marietta, GA Metropolitan Statistical Area */
"13153" = '47580' /*Warner Robins, GA Metropolitan Statistical Area */
"13155" = '22340' /*Fitzgerald, GA Micropolitan Statistical Area */
"13159" = '12060' /*Atlanta-Sandy Springs-Marietta, GA Metropolitan Statistical Area */
"13167" = '20140' /*Dublin, GA Micropolitan Statistical Area */
"13169" = '31420' /*Macon, GA Metropolitan Statistical Area */
"13171" = '12060' /*Atlanta-Sandy Springs-Marietta, GA Metropolitan Statistical Area */
"13173" = '46660' /*Valdosta, GA Metropolitan Statistical Area */
"13175" = '20140' /*Dublin, GA Micropolitan Statistical Area */
"13177" = '10500' /*Albany, GA Metropolitan Statistical Area */
"13179" = '25980' /*Hinesville-Fort Stewart, GA Metropolitan Statistical Area */
"13183" = '25980' /*Hinesville-Fort Stewart, GA Metropolitan Statistical Area */
"13185" = '46660' /*Valdosta, GA Metropolitan Statistical Area */
"13189" = '12260' /*Augusta-Richmond County, GA-SC Metropolitan Statistical Area */
"13191" = '15260' /*Brunswick, GA Metropolitan Statistical Area */
"13195" = '12020' /*Athens-Clarke County, GA Metropolitan Statistical Area */
"13197" = '17980' /*Columbus, GA-AL Metropolitan Statistical Area */
"13199" = '12060' /*Atlanta-Sandy Springs-Marietta, GA Metropolitan Statistical Area */
"13207" = '31420' /*Macon, GA Metropolitan Statistical Area */
"13209" = '47080' /*Vidalia, GA Micropolitan Statistical Area */
"13213" = '19140' /*Dalton, GA Metropolitan Statistical Area */
"13215" = '17980' /*Columbus, GA-AL Metropolitan Statistical Area */
"13217" = '12060' /*Atlanta-Sandy Springs-Marietta, GA Metropolitan Statistical Area */
"13219" = '12020' /*Athens-Clarke County, GA Metropolitan Statistical Area */
"13221" = '12020' /*Athens-Clarke County, GA Metropolitan Statistical Area */
"13223" = '12060' /*Atlanta-Sandy Springs-Marietta, GA Metropolitan Statistical Area */
"13225" = '22980' /*Fort Valley, GA Micropolitan Statistical Area */
"13227" = '12060' /*Atlanta-Sandy Springs-Marietta, GA Metropolitan Statistical Area */
"13229" = '48180' /*Waycross, GA Micropolitan Statistical Area */
"13231" = '12060' /*Atlanta-Sandy Springs-Marietta, GA Metropolitan Statistical Area */
"13233" = '16340' /*Cedartown, GA Micropolitan Statistical Area */
"13239" = '21640' /*Eufaula, AL-GA Micropolitan Statistical Area */
"13245" = '12260' /*Augusta-Richmond County, GA-SC Metropolitan Statistical Area */
"13247" = '12060' /*Atlanta-Sandy Springs-Marietta, GA Metropolitan Statistical Area */
"13249" = '11140' /*Americus, GA Micropolitan Statistical Area */
"13255" = '12060' /*Atlanta-Sandy Springs-Marietta, GA Metropolitan Statistical Area */
"13257" = '45740' /*Toccoa, GA Micropolitan Statistical Area */
"13261" = '11140' /*Americus, GA Micropolitan Statistical Area */
"13273" = '10500' /*Albany, GA Metropolitan Statistical Area */
"13275" = '45620' /*Thomasville, GA Micropolitan Statistical Area */
"13277" = '45700' /*Tifton, GA Micropolitan Statistical Area */
"13279" = '47080' /*Vidalia, GA Micropolitan Statistical Area */
"13285" = '29300' /*LaGrange, GA Micropolitan Statistical Area */
"13289" = '31420' /*Macon, GA Metropolitan Statistical Area */
"13293" = '45580' /*Thomaston, GA Micropolitan Statistical Area */
"13295" = '16860' /*Chattanooga, TN-GA Metropolitan Statistical Area */
"13297" = '12060' /*Atlanta-Sandy Springs-Marietta, GA Metropolitan Statistical Area */
"13299" = '48180' /*Waycross, GA Micropolitan Statistical Area */
"13305" = '27700' /*Jesup, GA Micropolitan Statistical Area */
"13313" = '19140' /*Dalton, GA Metropolitan Statistical Area */
"13321" = '10500' /*Albany, GA Metropolitan Statistical Area */
"15001" = '25900' /*Hilo, HI Micropolitan Statistical Area */
"15003" = '26180' /*Honolulu, HI Metropolitan Statistical Area */
"15007" = '28180' /*Kapaa, HI Micropolitan Statistical Area */
"15009" = '27980' /*Kahului-Wailuku, HI Micropolitan Statistical Area */
"16001" = '14260' /*Boise City-Nampa, ID Metropolitan Statistical Area */
"16005" = '38540' /*Pocatello, ID Metropolitan Statistical Area */
"16011" = '13940' /*Blackfoot, ID Micropolitan Statistical Area */
"16015" = '14260' /*Boise City-Nampa, ID Metropolitan Statistical Area */
"16019" = '26820' /*Idaho Falls, ID Metropolitan Statistical Area */
"16027" = '14260' /*Boise City-Nampa, ID Metropolitan Statistical Area */
"16031" = '15420' /*Burley, ID Micropolitan Statistical Area */
"16039" = '34300' /*Mountain Home, ID Micropolitan Statistical Area */
"16041" = '30860' /*Logan, UT-ID Metropolitan Statistical Area */
"16043" = '39940' /*Rexburg, ID Micropolitan Statistical Area */
"16045" = '14260' /*Boise City-Nampa, ID Metropolitan Statistical Area */
"16051" = '26820' /*Idaho Falls, ID Metropolitan Statistical Area */
"16053" = '46300' /*Twin Falls, ID Micropolitan Statistical Area */
"16055" = '17660' /*Coeur d'Alene, ID Metropolitan Statistical Area */
"16057" = '34140' /*Moscow, ID Micropolitan Statistical Area */
"16065" = '39940' /*Rexburg, ID Micropolitan Statistical Area */
"16067" = '15420' /*Burley, ID Micropolitan Statistical Area */
"16069" = '30300' /*Lewiston, ID-WA Metropolitan Statistical Area */
"16073" = '14260' /*Boise City-Nampa, ID Metropolitan Statistical Area */
"16075" = '36620' /*Ontario, OR-ID Micropolitan Statistical Area */
"16077" = '38540' /*Pocatello, ID Metropolitan Statistical Area */
"16081" = '27220' /*Jackson, WY-ID Micropolitan Statistical Area */
"16083" = '46300' /*Twin Falls, ID Micropolitan Statistical Area */
"17001" = '39500' /*Quincy, IL-MO Micropolitan Statistical Area */
"17003" = '16020' /*Cape Girardeau-Jackson, MO-IL Micropolitan Statistical Area */
"17005" = '41180' /*St. Louis, MO-IL Metropolitan Statistical Area */
"17007" = '40420' /*Rockford, IL Metropolitan Statistical Area */
"17011" = '36860' /*Ottawa-Streator, IL Micropolitan Statistical Area */
"17013" = '41180' /*St. Louis, MO-IL Metropolitan Statistical Area */
"17019" = '16580' /*Champaign-Urbana, IL Metropolitan Statistical Area */
"17021" = '45380' /*Taylorville, IL Micropolitan Statistical Area */
"17027" = '41180' /*St. Louis, MO-IL Metropolitan Statistical Area */
"17029" = '16660' /*Charleston-Mattoon, IL Micropolitan Statistical Area */
"17031" = '16980' /*Chicago-Naperville-Joliet, IL-IN-WI Metropolitan Statistical Area */
"17035" = '16660' /*Charleston-Mattoon, IL Micropolitan Statistical Area */
"17037" = '16980' /*Chicago-Naperville-Joliet, IL-IN-WI Metropolitan Statistical Area */
"17043" = '16980' /*Chicago-Naperville-Joliet, IL-IN-WI Metropolitan Statistical Area */
"17049" = '20820' /*Effingham, IL Micropolitan Statistical Area */
"17053" = '16580' /*Champaign-Urbana, IL Metropolitan Statistical Area */
"17057" = '15900' /*Canton, IL Micropolitan Statistical Area */
"17063" = '16980' /*Chicago-Naperville-Joliet, IL-IN-WI Metropolitan Statistical Area */
"17065" = '34500' /*Mount Vernon, IL Micropolitan Statistical Area */
"17071" = '15460' /*Burlington, IA -IL Micropolitan Statistical Area */
"17073" = '19340' /*Davenport-Moline-Rock Island, IA-IL Metropolitan Statistical Area */
"17077" = '16060' /*Carbondale, IL Micropolitan Statistical Area */
"17081" = '34500' /*Mount Vernon, IL Micropolitan Statistical Area */
"17083" = '41180' /*St. Louis, MO-IL Metropolitan Statistical Area */
"17089" = '16980' /*Chicago-Naperville-Joliet, IL-IN-WI Metropolitan Statistical Area */
"17091" = '28100' /*Kankakee-Bradley, IL Metropolitan Statistical Area */
"17093" = '16980' /*Chicago-Naperville-Joliet, IL-IN-WI Metropolitan Statistical Area */
"17095" = '23660' /*Galesburg, IL Micropolitan Statistical Area */
"17097" = '16980' /*Chicago-Naperville-Joliet, IL-IN-WI Metropolitan Statistical Area */
"17099" = '36860' /*Ottawa-Streator, IL Micropolitan Statistical Area */
"17103" = '19940' /*Dixon, IL Micropolitan Statistical Area */
"17105" = '38700' /*Pontiac, IL Micropolitan Statistical Area */
"17107" = '30660' /*Lincoln, IL Micropolitan Statistical Area */
"17109" = '31380' /*Macomb, IL Micropolitan Statistical Area */
"17111" = '16980' /*Chicago-Naperville-Joliet, IL-IN-WI Metropolitan Statistical Area */
"17113" = '14060' /*Bloomington-Normal, IL Metropolitan Statistical Area */
"17115" = '19500' /*Decatur, IL Metropolitan Statistical Area */
"17117" = '41180' /*St. Louis, MO-IL Metropolitan Statistical Area */
"17119" = '41180' /*St. Louis, MO-IL Metropolitan Statistical Area */
"17121" = '16460' /*Centralia, IL Micropolitan Statistical Area */
"17123" = '37900' /*Peoria, IL Metropolitan Statistical Area */
"17127" = '37140' /*Paducah, KY-IL Micropolitan Statistical Area */
"17129" = '44100' /*Springfield, IL Metropolitan Statistical Area */
"17131" = '19340' /*Davenport-Moline-Rock Island, IA-IL Metropolitan Statistical Area */
"17133" = '41180' /*St. Louis, MO-IL Metropolitan Statistical Area */
"17137" = '27300' /*Jacksonville, IL Micropolitan Statistical Area */
"17141" = '40300' /*Rochelle, IL Micropolitan Statistical Area */
"17143" = '37900' /*Peoria, IL Metropolitan Statistical Area */
"17147" = '16580' /*Champaign-Urbana, IL Metropolitan Statistical Area */
"17155" = '36860' /*Ottawa-Streator, IL Micropolitan Statistical Area */
"17161" = '19340' /*Davenport-Moline-Rock Island, IA-IL Metropolitan Statistical Area */
"17163" = '41180' /*St. Louis, MO-IL Metropolitan Statistical Area */
"17165" = '25380' /*Harrisburg, IL Micropolitan Statistical Area */
"17167" = '44100' /*Springfield, IL Metropolitan Statistical Area */
"17171" = '27300' /*Jacksonville, IL Micropolitan Statistical Area */
"17175" = '37900' /*Peoria, IL Metropolitan Statistical Area */
"17177" = '23300' /*Freeport, IL Micropolitan Statistical Area */
"17179" = '37900' /*Peoria, IL Metropolitan Statistical Area */
"17183" = '19180' /*Danville, IL Metropolitan Statistical Area */
"17187" = '23660' /*Galesburg, IL Micropolitan Statistical Area */
"17195" = '44580' /*Sterling, IL Micropolitan Statistical Area */
"17197" = '16980' /*Chicago-Naperville-Joliet, IL-IN-WI Metropolitan Statistical Area */
"17199" = '32060' /*Marion-Herrin, IL Micropolitan Statistical Area */
"17201" = '40420' /*Rockford, IL Metropolitan Statistical Area */
"17203" = '37900' /*Peoria, IL Metropolitan Statistical Area */
"18001" = '19540' /*Decatur, IN Micropolitan Statistical Area */
"18003" = '23060' /*Fort Wayne, IN Metropolitan Statistical Area */
"18005" = '18020' /*Columbus, IN Metropolitan Statistical Area */
"18007" = '29140' /*Lafayette, IN Metropolitan Statistical Area */
"18011" = '26900' /*Indianapolis, IN Metropolitan Statistical Area */
"18013" = '26900' /*Indianapolis, IN Metropolitan Statistical Area */
"18015" = '29140' /*Lafayette, IN Metropolitan Statistical Area */
"18017" = '30900' /*Logansport, IN Micropolitan Statistical Area */
"18019" = '31140' /*Louisville, KY-IN Metropolitan Statistical Area */
"18021" = '45460' /*Terre Haute, IN Metropolitan Statistical Area */
"18023" = '23140' /*Frankfort, IN Micropolitan Statistical Area */
"18027" = '47780' /*Washington, IN Micropolitan Statistical Area */
"18029" = '17140' /*Cincinnati-Middletown, OH-KY-IN Metropolitan Statistical Area */
"18031" = '24700' /*Greensburg, IN Micropolitan Statistical Area */
"18033" = '12140' /*Auburn, IN Micropolitan Statistical Area */
"18035" = '34620' /*Muncie, IN Metropolitan Statistical Area */
"18037" = '27540' /*Jasper, IN Micropolitan Statistical Area */
"18039" = '21140' /*Elkhart-Goshen, IN Metropolitan Statistical Area */
"18041" = '18220' /*Connersville, IN Micropolitan Statistical Area */
"18043" = '31140' /*Louisville, KY-IN Metropolitan Statistical Area */
"18047" = '17140' /*Cincinnati-Middletown, OH-KY-IN Metropolitan Statistical Area */
"18051" = '21780' /*Evansville, IN-KY Metropolitan Statistical Area */
"18053" = '31980' /*Marion, IN Micropolitan Statistical Area */
"18055" = '14020' /*Bloomington, IN Metropolitan Statistical Area */
"18057" = '26900' /*Indianapolis, IN Metropolitan Statistical Area */
"18059" = '26900' /*Indianapolis, IN Metropolitan Statistical Area */
"18061" = '31140' /*Louisville, KY-IN Metropolitan Statistical Area */
"18063" = '26900' /*Indianapolis, IN Metropolitan Statistical Area */
"18065" = '35220' /*New Castle, IN Micropolitan Statistical Area */
"18067" = '29020' /*Kokomo, IN Metropolitan Statistical Area */
"18069" = '26540' /*Huntington, IN Micropolitan Statistical Area */
"18071" = '42980' /*Seymour, IN Micropolitan Statistical Area */
"18073" = '16980' /*Chicago-Naperville-Joliet, IL-IN-WI Metropolitan Statistical Area */
"18077" = '31500' /*Madison, IN Micropolitan Statistical Area */
"18079" = '35860' /*North Vernon, IN Micropolitan Statistical Area */
"18081" = '26900' /*Indianapolis, IN Metropolitan Statistical Area */
"18083" = '47180' /*Vincennes, IN Micropolitan Statistical Area */
"18085" = '47700' /*Warsaw, IN Micropolitan Statistical Area */
"18089" = '16980' /*Chicago-Naperville-Joliet, IL-IN-WI Metropolitan Statistical Area */
"18091" = '33140' /*Michigan City-La Porte, IN Metropolitan Statistical Area */
"18093" = '13260' /*Bedford, IN Micropolitan Statistical Area */
"18095" = '11300' /*Anderson, IN Metropolitan Statistical Area */
"18097" = '26900' /*Indianapolis, IN Metropolitan Statistical Area */
"18099" = '38500' /*Plymouth, IN Micropolitan Statistical Area */
"18103" = '37940' /*Peru, IN Micropolitan Statistical Area */
"18105" = '14020' /*Bloomington, IN Metropolitan Statistical Area */
"18107" = '18820' /*Crawfordsville, IN Micropolitan Statistical Area */
"18109" = '26900' /*Indianapolis, IN Metropolitan Statistical Area */
"18111" = '16980' /*Chicago-Naperville-Joliet, IL-IN-WI Metropolitan Statistical Area */
"18113" = '28340' /*Kendallville, IN Micropolitan Statistical Area */
"18115" = '17140' /*Cincinnati-Middletown, OH-KY-IN Metropolitan Statistical Area */
"18119" = '14020' /*Bloomington, IN Metropolitan Statistical Area */
"18125" = '27540' /*Jasper, IN Micropolitan Statistical Area */
"18127" = '16980' /*Chicago-Naperville-Joliet, IL-IN-WI Metropolitan Statistical Area */
"18129" = '21780' /*Evansville, IN-KY Metropolitan Statistical Area */
"18133" = '26900' /*Indianapolis, IN Metropolitan Statistical Area */
"18141" = '43780' /*South Bend-Mishawaka, IN-MI Metropolitan Statistical Area */
"18143" = '42500' /*Scottsburg, IN Micropolitan Statistical Area */
"18145" = '26900' /*Indianapolis, IN Metropolitan Statistical Area */
"18151" = '11420' /*Angola, IN Micropolitan Statistical Area */
"18153" = '45460' /*Terre Haute, IN Metropolitan Statistical Area */
"18157" = '29140' /*Lafayette, IN Metropolitan Statistical Area */
"18159" = '29020' /*Kokomo, IN Metropolitan Statistical Area */
"18163" = '21780' /*Evansville, IN-KY Metropolitan Statistical Area */
"18165" = '45460' /*Terre Haute, IN Metropolitan Statistical Area */
"18167" = '45460' /*Terre Haute, IN Metropolitan Statistical Area */
"18169" = '47340' /*Wabash, IN Micropolitan Statistical Area */
"18173" = '21780' /*Evansville, IN-KY Metropolitan Statistical Area */
"18175" = '31140' /*Louisville, KY-IN Metropolitan Statistical Area */
"18177" = '39980' /*Richmond, IN Micropolitan Statistical Area */
"18179" = '23060' /*Fort Wayne, IN Metropolitan Statistical Area */
"18183" = '23060' /*Fort Wayne, IN Metropolitan Statistical Area */
"19011" = '16300' /*Cedar Rapids, IA Metropolitan Statistical Area */
"19013" = '47940' /*Waterloo-Cedar Falls, IA Metropolitan Statistical Area */
"19015" = '14340' /*Boone, IA Micropolitan Statistical Area */
"19017" = '47940' /*Waterloo-Cedar Falls, IA Metropolitan Statistical Area */
"19021" = '44740' /*Storm Lake, IA Micropolitan Statistical Area */
"19033" = '32380' /*Mason City, IA Micropolitan Statistical Area */
"19041" = '43980' /*Spencer, IA Micropolitan Statistical Area */
"19045" = '17540' /*Clinton, IA Micropolitan Statistical Area */
"19049" = '19780' /*Des Moines, IA Metropolitan Statistical Area */
"19057" = '15460' /*Burlington, IA -IL Micropolitan Statistical Area */
"19059" = '44020' /*Spirit Lake, IA Micropolitan Statistical Area */
"19061" = '20220' /*Dubuque, IA Metropolitan Statistical Area */
"19075" = '47940' /*Waterloo-Cedar Falls, IA Metropolitan Statistical Area */
"19077" = '19780' /*Des Moines, IA Metropolitan Statistical Area */
"19085" = '36540' /*Omaha-Council Bluffs, NE-IA Metropolitan Statistical Area */
"19099" = '35500' /*Newton, IA Micropolitan Statistical Area */
"19103" = '26980' /*Iowa City, IA Metropolitan Statistical Area */
"19105" = '16300' /*Cedar Rapids, IA Metropolitan Statistical Area */
"19111" = '28460' /*Keokuk-Fort Madison, IA-MO Micropolitan Statistical Area */
"19113" = '16300' /*Cedar Rapids, IA Metropolitan Statistical Area */
"19115" = '34700' /*Muscatine, IA Micropolitan Statistical Area */
"19121" = '19780' /*Des Moines, IA Metropolitan Statistical Area */
"19123" = '36820' /*Oskaloosa, IA Micropolitan Statistical Area */
"19125" = '37800' /*Pella, IA Micropolitan Statistical Area */
"19127" = '32260' /*Marshalltown, IA Micropolitan Statistical Area */
"19129" = '36540' /*Omaha-Council Bluffs, NE-IA Metropolitan Statistical Area */
"19139" = '34700' /*Muscatine, IA Micropolitan Statistical Area */
"19153" = '19780' /*Des Moines, IA Metropolitan Statistical Area */
"19155" = '36540' /*Omaha-Council Bluffs, NE-IA Metropolitan Statistical Area */
"19163" = '19340' /*Davenport-Moline-Rock Island, IA-IL Metropolitan Statistical Area */
"19169" = '11180' /*Ames, IA Metropolitan Statistical Area */
"19179" = '36900' /*Ottumwa, IA Micropolitan Statistical Area */
"19181" = '19780' /*Des Moines, IA Metropolitan Statistical Area */
"19183" = '26980' /*Iowa City, IA Metropolitan Statistical Area */
"19187" = '22700' /*Fort Dodge, IA Micropolitan Statistical Area */
"19193" = '43580' /*Sioux City, IA-NE-SD Metropolitan Statistical Area */
"19195" = '32380' /*Mason City, IA Micropolitan Statistical Area */
"20005" = '11860' /*Atchison, KS Micropolitan Statistical Area */
"20009" = '24460' /*Great Bend, KS Micropolitan Statistical Area */
"20015" = '48620' /*Wichita, KS Metropolitan Statistical Area */
"20017" = '21380' /*Emporia, KS Micropolitan Statistical Area */
"20035" = '49060' /*Winfield, KS Micropolitan Statistical Area */
"20037" = '38260' /*Pittsburg, KS Micropolitan Statistical Area */
"20043" = '41140' /*St. Joseph, MO-KS Metropolitan Statistical Area */
"20045" = '29940' /*Lawrence, KS Metropolitan Statistical Area */
"20051" = '25700' /*Hays, KS Micropolitan Statistical Area */
"20055" = '23780' /*Garden City, KS Micropolitan Statistical Area */
"20057" = '19980' /*Dodge City, KS Micropolitan Statistical Area */
"20059" = '28140' /*Kansas City, MO-KS Metropolitan Statistical Area */
"20061" = '31740' /*Manhattan, KS Micropolitan Statistical Area */
"20079" = '48620' /*Wichita, KS Metropolitan Statistical Area */
"20085" = '45820' /*Topeka, KS Metropolitan Statistical Area */
"20087" = '45820' /*Topeka, KS Metropolitan Statistical Area */
"20091" = '28140' /*Kansas City, MO-KS Metropolitan Statistical Area */
"20099" = '37660' /*Parsons, KS Micropolitan Statistical Area */
"20103" = '28140' /*Kansas City, MO-KS Metropolitan Statistical Area */
"20107" = '28140' /*Kansas City, MO-KS Metropolitan Statistical Area */
"20111" = '21380' /*Emporia, KS Micropolitan Statistical Area */
"20113" = '32700' /*McPherson, KS Micropolitan Statistical Area */
"20121" = '28140' /*Kansas City, MO-KS Metropolitan Statistical Area */
"20125" = '17700' /*Coffeyville, KS Micropolitan Statistical Area */
"20139" = '45820' /*Topeka, KS Metropolitan Statistical Area */
"20143" = '41460' /*Salina, KS Micropolitan Statistical Area */
"20149" = '31740' /*Manhattan, KS Micropolitan Statistical Area */
"20155" = '26740' /*Hutchinson, KS Micropolitan Statistical Area */
"20161" = '31740' /*Manhattan, KS Micropolitan Statistical Area */
"20169" = '41460' /*Salina, KS Micropolitan Statistical Area */
"20173" = '48620' /*Wichita, KS Metropolitan Statistical Area */
"20175" = '30580' /*Liberal, KS Micropolitan Statistical Area */
"20177" = '45820' /*Topeka, KS Metropolitan Statistical Area */
"20191" = '48620' /*Wichita, KS Metropolitan Statistical Area */
"20197" = '45820' /*Topeka, KS Metropolitan Statistical Area */
"20209" = '28140' /*Kansas City, MO-KS Metropolitan Statistical Area */
"21005" = '23180' /*Frankfort, KY Micropolitan Statistical Area */
"21007" = '37140' /*Paducah, KY-IL Micropolitan Statistical Area */
"21009" = '23980' /*Glasgow, KY Micropolitan Statistical Area */
"21011" = '34460' /*Mount Sterling, KY Micropolitan Statistical Area */
"21013" = '33180' /*Middlesborough, KY Micropolitan Statistical Area */
"21015" = '17140' /*Cincinnati-Middletown, OH-KY-IN Metropolitan Statistical Area */
"21017" = '30460' /*Lexington-Fayette, KY Metropolitan Statistical Area */
"21019" = '26580' /*Huntington-Ashland, WV-KY-OH Metropolitan Statistical Area */
"21021" = '19220' /*Danville, KY Micropolitan Statistical Area */
"21023" = '17140' /*Cincinnati-Middletown, OH-KY-IN Metropolitan Statistical Area */
"21029" = '31140' /*Louisville, KY-IN Metropolitan Statistical Area */
"21035" = '34660' /*Murray, KY Micropolitan Statistical Area */
"21037" = '17140' /*Cincinnati-Middletown, OH-KY-IN Metropolitan Statistical Area */
"21047" = '17300' /*Clarksville, TN-KY Metropolitan Statistical Area */
"21049" = '30460' /*Lexington-Fayette, KY Metropolitan Statistical Area */
"21059" = '36980' /*Owensboro, KY Metropolitan Statistical Area */
"21061" = '14540' /*Bowling Green, KY Metropolitan Statistical Area */
"21067" = '30460' /*Lexington-Fayette, KY Metropolitan Statistical Area */
"21073" = '23180' /*Frankfort, KY Micropolitan Statistical Area */
"21075" = '46460' /*Union City, TN-KY Micropolitan Statistical Area */
"21077" = '17140' /*Cincinnati-Middletown, OH-KY-IN Metropolitan Statistical Area */
"21081" = '17140' /*Cincinnati-Middletown, OH-KY-IN Metropolitan Statistical Area */
"21083" = '32460' /*Mayfield, KY Micropolitan Statistical Area */
"21089" = '26580' /*Huntington-Ashland, WV-KY-OH Metropolitan Statistical Area */
"21091" = '36980' /*Owensboro, KY Metropolitan Statistical Area */
"21093" = '21060' /*Elizabethtown, KY Metropolitan Statistical Area */
"21101" = '21780' /*Evansville, IN-KY Metropolitan Statistical Area */
"21103" = '31140' /*Louisville, KY-IN Metropolitan Statistical Area */
"21107" = '31580' /*Madisonville, KY Micropolitan Statistical Area */
"21111" = '31140' /*Louisville, KY-IN Metropolitan Statistical Area */
"21113" = '30460' /*Lexington-Fayette, KY Metropolitan Statistical Area */
"21117" = '17140' /*Cincinnati-Middletown, OH-KY-IN Metropolitan Statistical Area */
"21123" = '21060' /*Elizabethtown, KY Metropolitan Statistical Area */
"21125" = '30940' /*London, KY Micropolitan Statistical Area */
"21135" = '32500' /*Maysville, KY Micropolitan Statistical Area */
"21137" = '19220' /*Danville, KY Micropolitan Statistical Area */
"21139" = '37140' /*Paducah, KY-IL Micropolitan Statistical Area */
"21145" = '37140' /*Paducah, KY-IL Micropolitan Statistical Area */
"21149" = '36980' /*Owensboro, KY Metropolitan Statistical Area */
"21151" = '40080' /*Richmond-Berea, KY Micropolitan Statistical Area */
"21161" = '32500' /*Maysville, KY Micropolitan Statistical Area */
"21163" = '31140' /*Louisville, KY-IN Metropolitan Statistical Area */
"21165" = '34460' /*Mount Sterling, KY Micropolitan Statistical Area */
"21169" = '23980' /*Glasgow, KY Micropolitan Statistical Area */
"21173" = '34460' /*Mount Sterling, KY Micropolitan Statistical Area */
"21177" = '16420' /*Central City, KY Micropolitan Statistical Area */
"21179" = '31140' /*Louisville, KY-IN Metropolitan Statistical Area */
"21185" = '31140' /*Louisville, KY-IN Metropolitan Statistical Area */
"21191" = '17140' /*Cincinnati-Middletown, OH-KY-IN Metropolitan Statistical Area */
"21199" = '43700' /*Somerset, KY Micropolitan Statistical Area */
"21203" = '40080' /*Richmond-Berea, KY Micropolitan Statistical Area */
"21209" = '30460' /*Lexington-Fayette, KY Metropolitan Statistical Area */
"21211" = '31140' /*Louisville, KY-IN Metropolitan Statistical Area */
"21215" = '31140' /*Louisville, KY-IN Metropolitan Statistical Area */
"21217" = '15820' /*Campbellsville, KY Micropolitan Statistical Area */
"21221" = '17300' /*Clarksville, TN-KY Metropolitan Statistical Area */
"21223" = '31140' /*Louisville, KY-IN Metropolitan Statistical Area */
"21227" = '14540' /*Bowling Green, KY Metropolitan Statistical Area */
"21233" = '21780' /*Evansville, IN-KY Metropolitan Statistical Area */
"21235" = '18340' /*Corbin, KY Micropolitan Statistical Area */
"21239" = '30460' /*Lexington-Fayette, KY Metropolitan Statistical Area */
"22001" = '18940' /*Crowley, LA Micropolitan Statistical Area */
"22005" = '12940' /*Baton Rouge, LA Metropolitan Statistical Area */
"22007" = '38200' /*Pierre Part, LA Micropolitan Statistical Area */
"22011" = '19760' /*De Ridder, LA Micropolitan Statistical Area */
"22015" = '43340' /*Shreveport-Bossier City, LA Metropolitan Statistical Area */
"22017" = '43340' /*Shreveport-Bossier City, LA Metropolitan Statistical Area */
"22019" = '29340' /*Lake Charles, LA Metropolitan Statistical Area */
"22023" = '29340' /*Lake Charles, LA Metropolitan Statistical Area */
"22029" = '35020' /*Natchez, MS-LA Micropolitan Statistical Area */
"22031" = '43340' /*Shreveport-Bossier City, LA Metropolitan Statistical Area */
"22033" = '12940' /*Baton Rouge, LA Metropolitan Statistical Area */
"22037" = '12940' /*Baton Rouge, LA Metropolitan Statistical Area */
"22043" = '10780' /*Alexandria, LA Metropolitan Statistical Area */
"22045" = '35340' /*New Iberia, LA Micropolitan Statistical Area */
"22047" = '12940' /*Baton Rouge, LA Metropolitan Statistical Area */
"22049" = '40820' /*Ruston, LA Micropolitan Statistical Area */
"22051" = '35380' /*New Orleans -Metairie-Kenner, LA Metropolitan Statistical Area */
"22053" = '27660' /*Jennings, LA Micropolitan Statistical Area */
"22055" = '29180' /*Lafayette, LA Metropolitan Statistical Area */
"22057" = '26380' /*Houma-Bayou Cane-Thibodaux, LA Metropolitan Statistical Area */
"22061" = '40820' /*Ruston, LA Micropolitan Statistical Area */
"22063" = '12940' /*Baton Rouge, LA Metropolitan Statistical Area */
"22065" = '45260' /*Tallulah, LA Micropolitan Statistical Area */
"22067" = '12820' /*Bastrop, LA Micropolitan Statistical Area */
"22069" = '35060' /*Natchitoches, LA Micropolitan Statistical Area */
"22071" = '35380' /*New Orleans -Metairie-Kenner, LA Metropolitan Statistical Area */
"22073" = '33740' /*Monroe, LA Metropolitan Statistical Area */
"22075" = '35380' /*New Orleans -Metairie-Kenner, LA Metropolitan Statistical Area */
"22077" = '12940' /*Baton Rouge, LA Metropolitan Statistical Area */
"22079" = '10780' /*Alexandria, LA Metropolitan Statistical Area */
"22087" = '35380' /*New Orleans -Metairie-Kenner, LA Metropolitan Statistical Area */
"22089" = '35380' /*New Orleans -Metairie-Kenner, LA Metropolitan Statistical Area */
"22091" = '12940' /*Baton Rouge, LA Metropolitan Statistical Area */
"22095" = '35380' /*New Orleans -Metairie-Kenner, LA Metropolitan Statistical Area */
"22097" = '36660' /*Opelousas-Eunice, LA Micropolitan Statistical Area */
"22099" = '29180' /*Lafayette, LA Metropolitan Statistical Area */
"22101" = '34020' /*Morgan City, LA Micropolitan Statistical Area */
"22103" = '35380' /*New Orleans -Metairie-Kenner, LA Metropolitan Statistical Area */
"22105" = '25220' /*Hammond, LA Micropolitan Statistical Area */
"22109" = '26380' /*Houma-Bayou Cane-Thibodaux, LA Metropolitan Statistical Area */
"22111" = '33740' /*Monroe, LA Metropolitan Statistical Area */
"22113" = '10020' /*Abbeville, LA Micropolitan Statistical Area */
"22115" = '22860' /*Fort Polk South, LA Micropolitan Statistical Area */
"22117" = '14220' /*Bogalusa, LA Micropolitan Statistical Area */
"22119" = '33380' /*Minden, LA Micropolitan Statistical Area */
"22121" = '12940' /*Baton Rouge, LA Metropolitan Statistical Area */
"22125" = '12940' /*Baton Rouge, LA Metropolitan Statistical Area */
"23001" = '30340' /*Lewiston-Auburn, ME Metropolitan Statistical Area */
"23005" = '38860' /*Portland-South Portland, ME Metropolitan Statistical Area */
"23011" = '12300' /*Augusta-Waterville, ME Micropolitan Statistical Area */
"23013" = '40500' /*Rockland, ME Micropolitan Statistical Area */
"23019" = '12620' /*Bangor, ME Metropolitan Statistical Area */
"23023" = '38860' /*Portland-South Portland, ME Metropolitan Statistical Area */
"23031" = '38860' /*Portland-South Portland, ME Metropolitan Statistical Area */
"24001" = '19060' /*Cumberland, MD-WV Metropolitan Statistical Area */
"24003" = '12580' /*Baltimore-Towson, MD Metropolitan Statistical Area */
"24005" = '12580' /*Baltimore-Towson, MD Metropolitan Statistical Area */
"24009" = '47900' /*Washington-Arlington-Alexandria, DC-VA-MD-WV Metropolitan Statistical Area */
"24013" = '12580' /*Baltimore-Towson, MD Metropolitan Statistical Area */
"24015" = '37980' /*Philadelphia-Camden-Wilmington, PA-NJ-DE-MD Metropolitan Statistical Area */
"24017" = '47900' /*Washington-Arlington-Alexandria, DC-VA-MD-WV Metropolitan Statistical Area */
"24019" = '15700' /*Cambridge, MD Micropolitan Statistical Area */
"24021" = '47900' /*Washington-Arlington-Alexandria, DC-VA-MD-WV Metropolitan Statistical Area */
"24025" = '12580' /*Baltimore-Towson, MD Metropolitan Statistical Area */
"24027" = '12580' /*Baltimore-Towson, MD Metropolitan Statistical Area */
"24031" = '47900' /*Washington-Arlington-Alexandria, DC-VA-MD-WV Metropolitan Statistical Area */
"24033" = '47900' /*Washington-Arlington-Alexandria, DC-VA-MD-WV Metropolitan Statistical Area */
"24035" = '12580' /*Baltimore-Towson, MD Metropolitan Statistical Area */
"24037" = '30500' /*Lexington Park, MD Micropolitan Statistical Area */
"24039" = '41540' /*Salisbury, MD Metropolitan Statistical Area */
"24041" = '20660' /*Easton, MD Micropolitan Statistical Area */
"24043" = '25180' /*Hagerstown-Martinsburg, MD-WV Metropolitan Statistical Area */
"24045" = '41540' /*Salisbury, MD Metropolitan Statistical Area */
"24047" = '36180' /*Ocean Pines, MD Micropolitan Statistical Area */
"24510" = '12580' /*Baltimore-Towson, MD Metropolitan Statistical Area */
"25001" = '12700' /*Barnstable Town, MA Metropolitan Statistical Area */
"25003" = '38340' /*Pittsfield, MA Metropolitan Statistical Area */
"25005" = '39300' /*Providence-New Bedford-Fall River, RI-MA Metropolitan Statistical Area */
"25009" = '14460' /*Boston-Cambridge-Quincy, MA-NH Metropolitan Statistical Area */
"25011" = '44140' /*Springfield, MA Metropolitan Statistical Area */
"25013" = '44140' /*Springfield, MA Metropolitan Statistical Area */
"25015" = '44140' /*Springfield, MA Metropolitan Statistical Area */
"25017" = '14460' /*Boston-Cambridge-Quincy, MA-NH Metropolitan Statistical Area */
"25021" = '14460' /*Boston-Cambridge-Quincy, MA-NH Metropolitan Statistical Area */
"25023" = '14460' /*Boston-Cambridge-Quincy, MA-NH Metropolitan Statistical Area */
"25025" = '14460' /*Boston-Cambridge-Quincy, MA-NH Metropolitan Statistical Area */
"25027" = '49340' /*Worcester, MA Metropolitan Statistical Area */
"26005" = '10880' /*Allegan, MI Micropolitan Statistical Area */
"26007" = '10980' /*Alpena, MI Micropolitan Statistical Area */
"26015" = '24340' /*Grand Rapids-Wyoming, MI Metropolitan Statistical Area */
"26017" = '13020' /*Bay City, MI Metropolitan Statistical Area */
"26019" = '45900' /*Traverse City, MI Micropolitan Statistical Area */
"26021" = '35660' /*Niles-Benton Harbor, MI Metropolitan Statistical Area */
"26023" = '17740' /*Coldwater, MI Micropolitan Statistical Area */
"26025" = '12980' /*Battle Creek, MI Metropolitan Statistical Area */
"26027" = '43780' /*South Bend-Mishawaka, IN-MI Metropolitan Statistical Area */
"26033" = '42300' /*Sault Ste. Marie, MI Micropolitan Statistical Area */
"26037" = '29620' /*Lansing-East Lansing, MI Metropolitan Statistical Area */
"26041" = '21540' /*Escanaba, MI Micropolitan Statistical Area */
"26043" = '27020' /*Iron Mountain, MI-WI Micropolitan Statistical Area */
"26045" = '29620' /*Lansing-East Lansing, MI Metropolitan Statistical Area */
"26049" = '22420' /*Flint, MI Metropolitan Statistical Area */
"26055" = '45900' /*Traverse City, MI Micropolitan Statistical Area */
"26057" = '10940' /*Alma, MI Micropolitan Statistical Area */
"26061" = '26340' /*Houghton, MI Micropolitan Statistical Area */
"26065" = '29620' /*Lansing-East Lansing, MI Metropolitan Statistical Area */
"26067" = '24340' /*Grand Rapids-Wyoming, MI Metropolitan Statistical Area */
"26073" = '34380' /*Mount Pleasant, MI Micropolitan Statistical Area */
"26075" = '27100' /*Jackson, MI Metropolitan Statistical Area */
"26077" = '28020' /*Kalamazoo-Portage, MI Metropolitan Statistical Area */
"26079" = '45900' /*Traverse City, MI Micropolitan Statistical Area */
"26081" = '24340' /*Grand Rapids-Wyoming, MI Metropolitan Statistical Area */
"26083" = '26340' /*Houghton, MI Micropolitan Statistical Area */
"26087" = '19820' /*Detroit-Warren-Livonia, MI Metropolitan Statistical Area */
"26089" = '45900' /*Traverse City, MI Micropolitan Statistical Area */
"26091" = '10300' /*Adrian, MI Micropolitan Statistical Area */
"26093" = '19820' /*Detroit-Warren-Livonia, MI Metropolitan Statistical Area */
"26099" = '19820' /*Detroit-Warren-Livonia, MI Metropolitan Statistical Area */
"26103" = '32100' /*Marquette, MI Micropolitan Statistical Area */
"26107" = '13660' /*Big Rapids, MI Micropolitan Statistical Area */
"26109" = '31940' /*Marinette, WI-MI Micropolitan Statistical Area */
"26111" = '33220' /*Midland, MI Micropolitan Statistical Area */
"26113" = '15620' /*Cadillac, MI Micropolitan Statistical Area */
"26115" = '33780' /*Monroe, MI Metropolitan Statistical Area */
"26121" = '34740' /*Muskegon-Norton Shores, MI Metropolitan Statistical Area */
"26123" = '24340' /*Grand Rapids-Wyoming, MI Metropolitan Statistical Area */
"26125" = '19820' /*Detroit-Warren-Livonia, MI Metropolitan Statistical Area */
"26139" = '26100' /*Holland-Grand Haven, MI Metropolitan Statistical Area */
"26145" = '40980' /*Saginaw-Saginaw Township North, MI Metropolitan Statistical Area */
"26147" = '19820' /*Detroit-Warren-Livonia, MI Metropolitan Statistical Area */
"26149" = '44780' /*Sturgis, MI Micropolitan Statistical Area */
"26155" = '37020' /*Owosso, MI Micropolitan Statistical Area */
"26159" = '28020' /*Kalamazoo-Portage, MI Metropolitan Statistical Area */
"26161" = '11460' /*Ann Arbor, MI Metropolitan Statistical Area */
"26163" = '19820' /*Detroit-Warren-Livonia, MI Metropolitan Statistical Area */
"26165" = '15620' /*Cadillac, MI Micropolitan Statistical Area */
"27003" = '33460' /*Minneapolis-St. Paul-Bloomington, MN-WI Metropolitan Statistical Area */
"27007" = '13420' /*Bemidji, MN Micropolitan Statistical Area */
"27009" = '41060' /*St. Cloud, MN Metropolitan Statistical Area */
"27013" = '31860' /*Mankato-North Mankato, MN Micropolitan Statistical Area */
"27015" = '35580' /*New Ulm, MN Micropolitan Statistical Area */
"27017" = '20260' /*Duluth, MN-WI Metropolitan Statistical Area */
"27019" = '33460' /*Minneapolis-St. Paul-Bloomington, MN-WI Metropolitan Statistical Area */
"27021" = '14660' /*Brainerd, MN Micropolitan Statistical Area */
"27025" = '33460' /*Minneapolis-St. Paul-Bloomington, MN-WI Metropolitan Statistical Area */
"27027" = '22020' /*Fargo, ND-MN Metropolitan Statistical Area */
"27035" = '14660' /*Brainerd, MN Micropolitan Statistical Area */
"27037" = '33460' /*Minneapolis-St. Paul-Bloomington, MN-WI Metropolitan Statistical Area */
"27039" = '40340' /*Rochester, MN Metropolitan Statistical Area */
"27041" = '10820' /*Alexandria, MN Micropolitan Statistical Area */
"27047" = '10660' /*Albert Lea, MN Micropolitan Statistical Area */
"27049" = '39860' /*Red Wing, MN Micropolitan Statistical Area */
"27053" = '33460' /*Minneapolis-St. Paul-Bloomington, MN-WI Metropolitan Statistical Area */
"27055" = '29100' /*La Crosse, WI-MN Metropolitan Statistical Area */
"27059" = '33460' /*Minneapolis-St. Paul-Bloomington, MN-WI Metropolitan Statistical Area */
"27067" = '48820' /*Willmar, MN Micropolitan Statistical Area */
"27083" = '32140' /*Marshall, MN Micropolitan Statistical Area */
"27085" = '26780' /*Hutchinson, MN Micropolitan Statistical Area */
"27091" = '21860' /*Fairmont, MN Micropolitan Statistical Area */
"27099" = '12380' /*Austin, MN Micropolitan Statistical Area */
"27103" = '31860' /*Mankato-North Mankato, MN Micropolitan Statistical Area */
"27105" = '49380' /*Worthington, MN Micropolitan Statistical Area */
"27109" = '40340' /*Rochester, MN Metropolitan Statistical Area */
"27111" = '22260' /*Fergus Falls, MN Micropolitan Statistical Area */
"27119" = '24220' /*Grand Forks, ND-MN Metropolitan Statistical Area */
"27123" = '33460' /*Minneapolis-St. Paul-Bloomington, MN-WI Metropolitan Statistical Area */
"27131" = '22060' /*Faribault-Northfield, MN Micropolitan Statistical Area */
"27137" = '20260' /*Duluth, MN-WI Metropolitan Statistical Area */
"27139" = '33460' /*Minneapolis-St. Paul-Bloomington, MN-WI Metropolitan Statistical Area */
"27141" = '33460' /*Minneapolis-St. Paul-Bloomington, MN-WI Metropolitan Statistical Area */
"27145" = '41060' /*St. Cloud, MN Metropolitan Statistical Area */
"27147" = '36940' /*Owatonna, MN Micropolitan Statistical Area */
"27157" = '40340' /*Rochester, MN Metropolitan Statistical Area */
"27163" = '33460' /*Minneapolis-St. Paul-Bloomington, MN-WI Metropolitan Statistical Area */
"27167" = '47420' /*Wahpeton, ND-MN Micropolitan Statistical Area */
"27169" = '49100' /*Winona, MN Micropolitan Statistical Area */
"27171" = '33460' /*Minneapolis-St. Paul-Bloomington, MN-WI Metropolitan Statistical Area */
"28001" = '35020' /*Natchez, MS-LA Micropolitan Statistical Area */
"28003" = '18420' /*Corinth, MS Micropolitan Statistical Area */
"28005" = '32620' /*McComb, MS Micropolitan Statistical Area */
"28011" = '17380' /*Cleveland, MS Micropolitan Statistical Area */
"28015" = '24900' /*Greenwood, MS Micropolitan Statistical Area */
"28023" = '32940' /*Meridian, MS Micropolitan Statistical Area */
"28025" = '48500' /*West Point, MS Micropolitan Statistical Area */
"28027" = '17260' /*Clarksdale, MS Micropolitan Statistical Area */
"28029" = '27140' /*Jackson, MS Metropolitan Statistical Area */
"28033" = '32820' /*Memphis, TN -MS-AR Metropolitan Statistical Area */
"28035" = '25620' /*Hattiesburg, MS Metropolitan Statistical Area */
"28039" = '37700' /*Pascagoula, MS Metropolitan Statistical Area */
"28043" = '24980' /*Grenada, MS Micropolitan Statistical Area */
"28045" = '25060' /*Gulfport-Biloxi, MS Metropolitan Statistical Area */
"28047" = '25060' /*Gulfport-Biloxi, MS Metropolitan Statistical Area */
"28049" = '27140' /*Jackson, MS Metropolitan Statistical Area */
"28057" = '46180' /*Tupelo, MS Micropolitan Statistical Area */
"28059" = '37700' /*Pascagoula, MS Metropolitan Statistical Area */
"28061" = '29860' /*Laurel, MS Micropolitan Statistical Area */
"28067" = '29860' /*Laurel, MS Micropolitan Statistical Area */
"28069" = '32940' /*Meridian, MS Micropolitan Statistical Area */
"28071" = '37060' /*Oxford, MS Micropolitan Statistical Area */
"28073" = '25620' /*Hattiesburg, MS Metropolitan Statistical Area */
"28075" = '32940' /*Meridian, MS Micropolitan Statistical Area */
"28081" = '46180' /*Tupelo, MS Micropolitan Statistical Area */
"28083" = '24900' /*Greenwood, MS Micropolitan Statistical Area */
"28085" = '15020' /*Brookhaven, MS Micropolitan Statistical Area */
"28087" = '18060' /*Columbus, MS Micropolitan Statistical Area */
"28089" = '27140' /*Jackson, MS Metropolitan Statistical Area */
"28093" = '32820' /*Memphis, TN -MS-AR Metropolitan Statistical Area */
"28105" = '44260' /*Starkville, MS Micropolitan Statistical Area */
"28109" = '38100' /*Picayune, MS Micropolitan Statistical Area */
"28111" = '25620' /*Hattiesburg, MS Metropolitan Statistical Area */
"28113" = '32620' /*McComb, MS Micropolitan Statistical Area */
"28115" = '46180' /*Tupelo, MS Micropolitan Statistical Area */
"28121" = '27140' /*Jackson, MS Metropolitan Statistical Area */
"28127" = '27140' /*Jackson, MS Metropolitan Statistical Area */
"28131" = '25060' /*Gulfport-Biloxi, MS Metropolitan Statistical Area */
"28133" = '26940' /*Indianola, MS Micropolitan Statistical Area */
"28137" = '32820' /*Memphis, TN -MS-AR Metropolitan Statistical Area */
"28143" = '32820' /*Memphis, TN -MS-AR Metropolitan Statistical Area */
"28149" = '46980' /*Vicksburg, MS Micropolitan Statistical Area */
"28151" = '24740' /*Greenville, MS Micropolitan Statistical Area */
"28163" = '49540' /*Yazoo City, MS Micropolitan Statistical Area */
"29001" = '28860' /*Kirksville, MO Micropolitan Statistical Area */
"29003" = '41140' /*St. Joseph, MO-KS Metropolitan Statistical Area */
"29007" = '33020' /*Mexico, MO Micropolitan Statistical Area */
"29013" = '28140' /*Kansas City, MO-KS Metropolitan Statistical Area */
"29017" = '16020' /*Cape Girardeau-Jackson, MO-IL Micropolitan Statistical Area */
"29019" = '17860' /*Columbia, MO Metropolitan Statistical Area */
"29021" = '41140' /*St. Joseph, MO-KS Metropolitan Statistical Area */
"29023" = '38740' /*Poplar Bluff, MO Micropolitan Statistical Area */
"29025" = '28140' /*Kansas City, MO-KS Metropolitan Statistical Area */
"29027" = '27620' /*Jefferson City, MO Metropolitan Statistical Area */
"29031" = '16020' /*Cape Girardeau-Jackson, MO-IL Micropolitan Statistical Area */
"29037" = '28140' /*Kansas City, MO-KS Metropolitan Statistical Area */
"29043" = '44180' /*Springfield, MO Metropolitan Statistical Area */
"29045" = '28460' /*Keokuk-Fort Madison, IA-MO Micropolitan Statistical Area */
"29047" = '28140' /*Kansas City, MO-KS Metropolitan Statistical Area */
"29049" = '28140' /*Kansas City, MO-KS Metropolitan Statistical Area */
"29051" = '27620' /*Jefferson City, MO Metropolitan Statistical Area */
"29059" = '44180' /*Springfield, MO Metropolitan Statistical Area */
"29063" = '41140' /*St. Joseph, MO-KS Metropolitan Statistical Area */
"29069" = '28380' /*Kennett, MO Micropolitan Statistical Area */
"29071" = '41180' /*St. Louis, MO-IL Metropolitan Statistical Area */
"29077" = '44180' /*Springfield, MO Metropolitan Statistical Area */
"29089" = '17860' /*Columbia, MO Metropolitan Statistical Area */
"29091" = '48460' /*West Plains, MO Micropolitan Statistical Area */
"29095" = '28140' /*Kansas City, MO-KS Metropolitan Statistical Area */
"29097" = '27900' /*Joplin, MO Metropolitan Statistical Area */
"29099" = '41180' /*St. Louis, MO-IL Metropolitan Statistical Area */
"29101" = '47660' /*Warrensburg, MO Micropolitan Statistical Area */
"29105" = '30060' /*Lebanon, MO Micropolitan Statistical Area */
"29107" = '28140' /*Kansas City, MO-KS Metropolitan Statistical Area */
"29111" = '39500' /*Quincy, IL-MO Micropolitan Statistical Area */
"29113" = '41180' /*St. Louis, MO-IL Metropolitan Statistical Area */
"29119" = '22220' /*Fayetteville-Springdale-Rogers, AR-MO Metropolitan Statistical Area */
"29127" = '25300' /*Hannibal, MO Micropolitan Statistical Area */
"29135" = '27620' /*Jefferson City, MO Metropolitan Statistical Area */
"29145" = '27900' /*Joplin, MO Metropolitan Statistical Area */
"29147" = '32340' /*Maryville, MO Micropolitan Statistical Area */
"29151" = '27620' /*Jefferson City, MO Metropolitan Statistical Area */
"29159" = '42740' /*Sedalia, MO Micropolitan Statistical Area */
"29161" = '40620' /*Rolla, MO Micropolitan Statistical Area */
"29165" = '28140' /*Kansas City, MO-KS Metropolitan Statistical Area */
"29167" = '44180' /*Springfield, MO Metropolitan Statistical Area */
"29169" = '22780' /*Fort Leonard Wood, MO Micropolitan Statistical Area */
"29173" = '25300' /*Hannibal, MO Micropolitan Statistical Area */
"29175" = '33620' /*Moberly, MO Micropolitan Statistical Area */
"29177" = '28140' /*Kansas City, MO-KS Metropolitan Statistical Area */
"29183" = '41180' /*St. Louis, MO-IL Metropolitan Statistical Area */
"29187" = '22100' /*Farmington, MO Micropolitan Statistical Area */
"29189" = '41180' /*St. Louis, MO-IL Metropolitan Statistical Area */
"29195" = '32180' /*Marshall, MO Micropolitan Statistical Area */
"29197" = '28860' /*Kirksville, MO Micropolitan Statistical Area */
"29201" = '43460' /*Sikeston, MO Micropolitan Statistical Area */
"29209" = '14700' /*Branson, MO Micropolitan Statistical Area */
"29213" = '14700' /*Branson, MO Micropolitan Statistical Area */
"29219" = '41180' /*St. Louis, MO-IL Metropolitan Statistical Area */
"29221" = '41180' /*St. Louis, MO-IL Metropolitan Statistical Area */
"29225" = '44180' /*Springfield, MO Metropolitan Statistical Area */
"29510" = '41180' /*St. Louis, MO-IL Metropolitan Statistical Area */
"30009" = '13740' /*Billings, MT Metropolitan Statistical Area */
"30013" = '24500' /*Great Falls, MT Metropolitan Statistical Area */
"30029" = '28060' /*Kalispell, MT Micropolitan Statistical Area */
"30031" = '14580' /*Bozeman, MT Micropolitan Statistical Area */
"30041" = '25660' /*Havre, MT Micropolitan Statistical Area */
"30043" = '25740' /*Helena, MT Micropolitan Statistical Area */
"30049" = '25740' /*Helena, MT Micropolitan Statistical Area */
"30063" = '33540' /*Missoula, MT Metropolitan Statistical Area */
"30093" = '15580' /*Butte-Silver Bow, MT Micropolitan Statistical Area */
"30111" = '13740' /*Billings, MT Metropolitan Statistical Area */
"31001" = '25580' /*Hastings, NE Micropolitan Statistical Area */
"31007" = '42420' /*Scottsbluff, NE Micropolitan Statistical Area */
"31019" = '28260' /*Kearney, NE Micropolitan Statistical Area */
"31025" = '36540' /*Omaha-Council Bluffs, NE-IA Metropolitan Statistical Area */
"31035" = '25580' /*Hastings, NE Micropolitan Statistical Area */
"31043" = '43580' /*Sioux City, IA-NE-SD Metropolitan Statistical Area */
"31047" = '30420' /*Lexington, NE Micropolitan Statistical Area */
"31051" = '43580' /*Sioux City, IA-NE-SD Metropolitan Statistical Area */
"31053" = '23340' /*Fremont, NE Micropolitan Statistical Area */
"31055" = '36540' /*Omaha-Council Bluffs, NE-IA Metropolitan Statistical Area */
"31067" = '13100' /*Beatrice, NE Micropolitan Statistical Area */
"31073" = '30420' /*Lexington, NE Micropolitan Statistical Area */
"31079" = '24260' /*Grand Island, NE Micropolitan Statistical Area */
"31093" = '24260' /*Grand Island, NE Micropolitan Statistical Area */
"31099" = '28260' /*Kearney, NE Micropolitan Statistical Area */
"31109" = '30700' /*Lincoln, NE Metropolitan Statistical Area */
"31111" = '35820' /*North Platte, NE Micropolitan Statistical Area */
"31113" = '35820' /*North Platte, NE Micropolitan Statistical Area */
"31117" = '35820' /*North Platte, NE Micropolitan Statistical Area */
"31119" = '35740' /*Norfolk, NE Micropolitan Statistical Area */
"31121" = '24260' /*Grand Island, NE Micropolitan Statistical Area */
"31139" = '35740' /*Norfolk, NE Micropolitan Statistical Area */
"31141" = '18100' /*Columbus, NE Micropolitan Statistical Area */
"31153" = '36540' /*Omaha-Council Bluffs, NE-IA Metropolitan Statistical Area */
"31155" = '36540' /*Omaha-Council Bluffs, NE-IA Metropolitan Statistical Area */
"31157" = '42420' /*Scottsbluff, NE Micropolitan Statistical Area */
"31159" = '30700' /*Lincoln, NE Metropolitan Statistical Area */
"31167" = '35740' /*Norfolk, NE Micropolitan Statistical Area */
"31177" = '36540' /*Omaha-Council Bluffs, NE-IA Metropolitan Statistical Area */
"32001" = '21980' /*Fallon, NV Micropolitan Statistical Area */
"32003" = '29820' /*Las Vegas-Paradise, NV Metropolitan Statistical Area */
"32005" = '23820' /*Gardnerville Ranchos, NV Micropolitan Statistical Area */
"32007" = '21220' /*Elko, NV Micropolitan Statistical Area */
"32011" = '21220' /*Elko, NV Micropolitan Statistical Area */
"32023" = '37220' /*Pahrump, NV Micropolitan Statistical Area */
"32029" = '39900' /*Reno-Sparks, NV Metropolitan Statistical Area */
"32031" = '39900' /*Reno-Sparks, NV Metropolitan Statistical Area */
"32510" = '16180' /*Carson City, NV Metropolitan Statistical Area */
"33001" = '29060' /*Laconia, NH Micropolitan Statistical Area */
"33005" = '28300' /*Keene, NH Micropolitan Statistical Area */
"33007" = '13620' /*Berlin, NH-VT Micropolitan Statistical Area */
"33009" = '30100' /*Lebanon, NH-VT Micropolitan Statistical Area */
"33011" = '31700' /*Manchester-Nashua, NH Metropolitan Statistical Area */
"33013" = '18180' /*Concord, NH Micropolitan Statistical Area */
"33015" = '14460' /*Boston-Cambridge-Quincy, MA-NH Metropolitan Statistical Area */
"33017" = '14460' /*Boston-Cambridge-Quincy, MA-NH Metropolitan Statistical Area */
"33019" = '17200' /*Claremont, NH Micropolitan Statistical Area */
"34001" = '12100' /*Atlantic City, NJ Metropolitan Statistical Area */
"34003" = '35620' /*New York-Newark-Edison, NY-NJ-PA Metropolitan Statistical Area */
"34005" = '37980' /*Philadelphia-Camden-Wilmington, PA-NJ-DE-MD Metropolitan Statistical Area */
"34007" = '37980' /*Philadelphia-Camden-Wilmington, PA-NJ-DE-MD Metropolitan Statistical Area */
"34009" = '36140' /*Ocean City, NJ Metropolitan Statistical Area */
"34011" = '47220' /*Vineland-Millville-Bridgeton, NJ Metropolitan Statistical Area */
"34013" = '35620' /*New York-Newark-Edison, NY-NJ-PA Metropolitan Statistical Area */
"34015" = '37980' /*Philadelphia-Camden-Wilmington, PA-NJ-DE-MD Metropolitan Statistical Area */
"34017" = '35620' /*New York-Newark-Edison, NY-NJ-PA Metropolitan Statistical Area */
"34019" = '35620' /*New York-Newark-Edison, NY-NJ-PA Metropolitan Statistical Area */
"34021" = '45940' /*Trenton-Ewing, NJ Metropolitan Statistical Area */
"34023" = '35620' /*New York-Newark-Edison, NY-NJ-PA Metropolitan Statistical Area */
"34025" = '35620' /*New York-Newark-Edison, NY-NJ-PA Metropolitan Statistical Area */
"34027" = '35620' /*New York-Newark-Edison, NY-NJ-PA Metropolitan Statistical Area */
"34029" = '35620' /*New York-Newark-Edison, NY-NJ-PA Metropolitan Statistical Area */
"34031" = '35620' /*New York-Newark-Edison, NY-NJ-PA Metropolitan Statistical Area */
"34033" = '37980' /*Philadelphia-Camden-Wilmington, PA-NJ-DE-MD Metropolitan Statistical Area */
"34035" = '35620' /*New York-Newark-Edison, NY-NJ-PA Metropolitan Statistical Area */
"34037" = '35620' /*New York-Newark-Edison, NY-NJ-PA Metropolitan Statistical Area */
"34039" = '35620' /*New York-Newark-Edison, NY-NJ-PA Metropolitan Statistical Area */
"34041" = '10900' /*Allentown-Bethlehem-Easton, PA-NJ Metropolitan Statistical Area */
"35001" = '10740' /*Albuquerque, NM Metropolitan Statistical Area */
"35005" = '40740' /*Roswell, NM Micropolitan Statistical Area */
"35006" = '24380' /*Grants, NM Micropolitan Statistical Area */
"35009" = '17580' /*Clovis, NM Micropolitan Statistical Area */
"35013" = '29740' /*Las Cruces, NM Metropolitan Statistical Area */
"35015" = '16100' /*Carlsbad-Artesia, NM Micropolitan Statistical Area */
"35017" = '43500' /*Silver City, NM Micropolitan Statistical Area */
"35025" = '26020' /*Hobbs, NM Micropolitan Statistical Area */
"35028" = '31060' /*Los Alamos, NM Micropolitan Statistical Area */
"35029" = '19700' /*Deming, NM Micropolitan Statistical Area */
"35031" = '23700' /*Gallup, NM Micropolitan Statistical Area */
"35035" = '10460' /*Alamogordo, NM Micropolitan Statistical Area */
"35039" = '21580' /*Espanola, NM Micropolitan Statistical Area */
"35041" = '38780' /*Portales, NM Micropolitan Statistical Area */
"35043" = '10740' /*Albuquerque, NM Metropolitan Statistical Area */
"35045" = '22140' /*Farmington, NM Metropolitan Statistical Area */
"35047" = '29780' /*Las Vegas, NM Micropolitan Statistical Area */
"35049" = '42140' /*Santa Fe, NM Metropolitan Statistical Area */
"35055" = '45340' /*Taos, NM Micropolitan Statistical Area */
"35057" = '10740' /*Albuquerque, NM Metropolitan Statistical Area */
"35061" = '10740' /*Albuquerque, NM Metropolitan Statistical Area */
"36001" = '10580' /*Albany-Schenectady-Troy, NY Metropolitan Statistical Area */
"36005" = '35620' /*New York-Newark-Edison, NY-NJ-PA Metropolitan Statistical Area */
"36007" = '13780' /*Binghamton, NY Metropolitan Statistical Area */
"36009" = '36460' /*Olean, NY Micropolitan Statistical Area */
"36011" = '12180' /*Auburn, NY Micropolitan Statistical Area */
"36013" = '27460' /*Jamestown-Dunkirk -Fredonia, NY Micropolitan Statistical Area */
"36015" = '21300' /*Elmira, NY Metropolitan Statistical Area */
"36019" = '38460' /*Plattsburgh, NY Micropolitan Statistical Area */
"36021" = '26460' /*Hudson, NY Micropolitan Statistical Area */
"36023" = '18660' /*Cortland, NY Micropolitan Statistical Area */
"36027" = '39100' /*Poughkeepsie-Newburgh-Middletown, NY Metropolitan Statistical Area */
"36029" = '15380' /*Buffalo-Cheektowaga-Tonawanda, NY Metropolitan Statistical Area */
"36033" = '31660' /*Malone, NY Micropolitan Statistical Area */
"36035" = '24100' /*Gloversville, NY Micropolitan Statistical Area */
"36037" = '12860' /*Batavia, NY Micropolitan Statistical Area */
"36043" = '46540' /*Utica-Rome, NY Metropolitan Statistical Area */
"36045" = '48060' /*Watertown-Fort Drum, NY Micropolitan Statistical Area */
"36047" = '35620' /*New York-Newark-Edison, NY-NJ-PA Metropolitan Statistical Area */
"36051" = '40380' /*Rochester, NY Metropolitan Statistical Area */
"36053" = '45060' /*Syracuse, NY Metropolitan Statistical Area */
"36055" = '40380' /*Rochester, NY Metropolitan Statistical Area */
"36057" = '11220' /*Amsterdam, NY Micropolitan Statistical Area */
"36059" = '35620' /*New York-Newark-Edison, NY-NJ-PA Metropolitan Statistical Area */
"36061" = '35620' /*New York-Newark-Edison, NY-NJ-PA Metropolitan Statistical Area */
"36063" = '15380' /*Buffalo-Cheektowaga-Tonawanda, NY Metropolitan Statistical Area */
"36065" = '46540' /*Utica-Rome, NY Metropolitan Statistical Area */
"36067" = '45060' /*Syracuse, NY Metropolitan Statistical Area */
"36069" = '40380' /*Rochester, NY Metropolitan Statistical Area */
"36071" = '39100' /*Poughkeepsie-Newburgh-Middletown, NY Metropolitan Statistical Area */
"36073" = '40380' /*Rochester, NY Metropolitan Statistical Area */
"36075" = '45060' /*Syracuse, NY Metropolitan Statistical Area */
"36077" = '36580' /*Oneonta, NY Micropolitan Statistical Area */
"36079" = '35620' /*New York-Newark-Edison, NY-NJ-PA Metropolitan Statistical Area */
"36081" = '35620' /*New York-Newark-Edison, NY-NJ-PA Metropolitan Statistical Area */
"36083" = '10580' /*Albany-Schenectady-Troy, NY Metropolitan Statistical Area */
"36085" = '35620' /*New York-Newark-Edison, NY-NJ-PA Metropolitan Statistical Area */
"36087" = '35620' /*New York-Newark-Edison, NY-NJ-PA Metropolitan Statistical Area */
"36089" = '36300' /*Ogdensburg-Massena, NY Micropolitan Statistical Area */
"36091" = '10580' /*Albany-Schenectady-Troy, NY Metropolitan Statistical Area */
"36093" = '10580' /*Albany-Schenectady-Troy, NY Metropolitan Statistical Area */
"36095" = '10580' /*Albany-Schenectady-Troy, NY Metropolitan Statistical Area */
"36099" = '42900' /*Seneca Falls, NY Micropolitan Statistical Area */
"36101" = '18500' /*Corning, NY Micropolitan Statistical Area */
"36103" = '35620' /*New York-Newark-Edison, NY-NJ-PA Metropolitan Statistical Area */
"36107" = '13780' /*Binghamton, NY Metropolitan Statistical Area */
"36109" = '27060' /*Ithaca, NY Metropolitan Statistical Area */
"36111" = '28740' /*Kingston, NY Metropolitan Statistical Area */
"36113" = '24020' /*Glens Falls, NY Metropolitan Statistical Area */
"36115" = '24020' /*Glens Falls, NY Metropolitan Statistical Area */
"36117" = '40380' /*Rochester, NY Metropolitan Statistical Area */
"36119" = '35620' /*New York-Newark-Edison, NY-NJ-PA Metropolitan Statistical Area */
"37001" = '15500' /*Burlington, NC Metropolitan Statistical Area */
"37003" = '25860' /*Hickory-Morganton-Lenoir, NC Metropolitan Statistical Area */
"37007" = '16740' /*Charlotte-Gastonia-Concord, NC-SC Metropolitan Statistical Area */
"37013" = '47820' /*Washington, NC Micropolitan Statistical Area */
"37019" = '48900' /*Wilmington, NC Metropolitan Statistical Area */
"37021" = '11700' /*Asheville, NC Metropolitan Statistical Area */
"37023" = '25860' /*Hickory-Morganton-Lenoir, NC Metropolitan Statistical Area */
"37025" = '16740' /*Charlotte-Gastonia-Concord, NC-SC Metropolitan Statistical Area */
"37027" = '25860' /*Hickory-Morganton-Lenoir, NC Metropolitan Statistical Area */
"37029" = '21020' /*Elizabeth City, NC Micropolitan Statistical Area */
"37031" = '33980' /*Morehead City, NC Micropolitan Statistical Area */
"37035" = '25860' /*Hickory-Morganton-Lenoir, NC Metropolitan Statistical Area */
"37037" = '20500' /*Durham, NC Metropolitan Statistical Area */
"37045" = '43140' /*Shelby, NC Micropolitan Statistical Area */
"37049" = '35100' /*New Bern, NC Micropolitan Statistical Area */
"37051" = '22180' /*Fayetteville, NC Metropolitan Statistical Area */
"37053" = '47260' /*Virginia Beach-Norfolk-Newport News, VA-NC Metropolitan Statistical Area */
"37055" = '28620' /*Kill Devil Hills, NC Micropolitan Statistical Area */
"37057" = '45640' /*Thomasville-Lexington, NC Micropolitan Statistical Area */
"37059" = '49180' /*Winston-Salem, NC Metropolitan Statistical Area */
"37063" = '20500' /*Durham, NC Metropolitan Statistical Area */
"37065" = '40580' /*Rocky Mount, NC Metropolitan Statistical Area */
"37067" = '49180' /*Winston-Salem, NC Metropolitan Statistical Area */
"37069" = '39580' /*Raleigh-Cary, NC Metropolitan Statistical Area */
"37071" = '16740' /*Charlotte-Gastonia-Concord, NC-SC Metropolitan Statistical Area */
"37079" = '24780' /*Greenville, NC Metropolitan Statistical Area */
"37081" = '24660' /*Greensboro-High Point, NC Metropolitan Statistical Area */
"37083" = '40260' /*Roanoke Rapids, NC Micropolitan Statistical Area */
"37085" = '20380' /*Dunn, NC Micropolitan Statistical Area */
"37087" = '11700' /*Asheville, NC Metropolitan Statistical Area */
"37089" = '11700' /*Asheville, NC Metropolitan Statistical Area */
"37093" = '22180' /*Fayetteville, NC Metropolitan Statistical Area */
"37097" = '44380' /*Statesville-Mooresville, NC Micropolitan Statistical Area */
"37101" = '39580' /*Raleigh-Cary, NC Metropolitan Statistical Area */
"37103" = '35100' /*New Bern, NC Micropolitan Statistical Area */
"37105" = '41820' /*Sanford, NC Micropolitan Statistical Area */
"37107" = '28820' /*Kinston, NC Micropolitan Statistical Area */
"37109" = '30740' /*Lincolnton, NC Micropolitan Statistical Area */
"37115" = '11700' /*Asheville, NC Metropolitan Statistical Area */
"37119" = '16740' /*Charlotte-Gastonia-Concord, NC-SC Metropolitan Statistical Area */
"37125" = '43860' /*Southern Pines, NC Micropolitan Statistical Area */
"37127" = '40580' /*Rocky Mount, NC Metropolitan Statistical Area */
"37129" = '48900' /*Wilmington, NC Metropolitan Statistical Area */
"37131" = '40260' /*Roanoke Rapids, NC Micropolitan Statistical Area */
"37133" = '27340' /*Jacksonville, NC Metropolitan Statistical Area */
"37135" = '20500' /*Durham, NC Metropolitan Statistical Area */
"37137" = '35100' /*New Bern, NC Micropolitan Statistical Area */
"37139" = '21020' /*Elizabeth City, NC Micropolitan Statistical Area */
"37141" = '48900' /*Wilmington, NC Metropolitan Statistical Area */
"37143" = '21020' /*Elizabeth City, NC Micropolitan Statistical Area */
"37145" = '20500' /*Durham, NC Metropolitan Statistical Area */
"37147" = '24780' /*Greenville, NC Metropolitan Statistical Area */
"37151" = '24660' /*Greensboro-High Point, NC Metropolitan Statistical Area */
"37153" = '40460' /*Rockingham, NC Micropolitan Statistical Area */
"37155" = '31300' /*Lumberton, NC Micropolitan Statistical Area */
"37157" = '24660' /*Greensboro-High Point, NC Metropolitan Statistical Area */
"37159" = '41580' /*Salisbury, NC Micropolitan Statistical Area */
"37161" = '22580' /*Forest City, NC Micropolitan Statistical Area */
"37165" = '29900' /*Laurinburg, NC Micropolitan Statistical Area */
"37167" = '10620' /*Albemarle, NC Micropolitan Statistical Area */
"37169" = '49180' /*Winston-Salem, NC Metropolitan Statistical Area */
"37171" = '34340' /*Mount Airy, NC Micropolitan Statistical Area */
"37175" = '14820' /*Brevard, NC Micropolitan Statistical Area */
"37179" = '16740' /*Charlotte-Gastonia-Concord, NC-SC Metropolitan Statistical Area */
"37181" = '25780' /*Henderson, NC Micropolitan Statistical Area */
"37183" = '39580' /*Raleigh-Cary, NC Metropolitan Statistical Area */
"37189" = '14380' /*Boone, NC Micropolitan Statistical Area */
"37191" = '24140' /*Goldsboro, NC Metropolitan Statistical Area */
"37193" = '35900' /*North Wilkesboro, NC Micropolitan Statistical Area */
"37195" = '48980' /*Wilson, NC Micropolitan Statistical Area */
"37197" = '49180' /*Winston-Salem, NC Metropolitan Statistical Area */
"38007" = '19860' /*Dickinson, ND Micropolitan Statistical Area */
"38015" = '13900' /*Bismarck, ND Metropolitan Statistical Area */
"38017" = '22020' /*Fargo, ND-MN Metropolitan Statistical Area */
"38035" = '24220' /*Grand Forks, ND-MN Metropolitan Statistical Area */
"38049" = '33500' /*Minot, ND Micropolitan Statistical Area */
"38059" = '13900' /*Bismarck, ND Metropolitan Statistical Area */
"38075" = '33500' /*Minot, ND Micropolitan Statistical Area */
"38077" = '47420' /*Wahpeton, ND-MN Micropolitan Statistical Area */
"38089" = '19860' /*Dickinson, ND Micropolitan Statistical Area */
"38093" = '27420' /*Jamestown, ND Micropolitan Statistical Area */
"38101" = '33500' /*Minot, ND Micropolitan Statistical Area */
"38105" = '48780' /*Williston, ND Micropolitan Statistical Area */
"39003" = '30620' /*Lima, OH Metropolitan Statistical Area */
"39005" = '11740' /*Ashland, OH Micropolitan Statistical Area */
"39007" = '11780' /*Ashtabula, OH Micropolitan Statistical Area */
"39009" = '11900' /*Athens, OH Micropolitan Statistical Area */
"39011" = '47540' /*Wapakoneta, OH Micropolitan Statistical Area */
"39013" = '48540' /*Wheeling, WV-OH Metropolitan Statistical Area */
"39015" = '17140' /*Cincinnati-Middletown, OH-KY-IN Metropolitan Statistical Area */
"39017" = '17140' /*Cincinnati-Middletown, OH-KY-IN Metropolitan Statistical Area */
"39019" = '15940' /*Canton-Massillon, OH Metropolitan Statistical Area */
"39021" = '46500' /*Urbana, OH Micropolitan Statistical Area */
"39023" = '44220' /*Springfield, OH Metropolitan Statistical Area */
"39025" = '17140' /*Cincinnati-Middletown, OH-KY-IN Metropolitan Statistical Area */
"39027" = '48940' /*Wilmington, OH Micropolitan Statistical Area */
"39029" = '20620' /*East Liverpool-Salem, OH Micropolitan Statistical Area */
"39031" = '18740' /*Coshocton, OH Micropolitan Statistical Area */
"39033" = '15340' /*Bucyrus, OH Micropolitan Statistical Area */
"39035" = '17460' /*Cleveland-Elyria-Mentor, OH Metropolitan Statistical Area */
"39037" = '24820' /*Greenville, OH Micropolitan Statistical Area */
"39039" = '19580' /*Defiance, OH Micropolitan Statistical Area */
"39041" = '18140' /*Columbus, OH Metropolitan Statistical Area */
"39043" = '41780' /*Sandusky, OH Metropolitan Statistical Area */
"39045" = '18140' /*Columbus, OH Metropolitan Statistical Area */
"39047" = '47860' /*Washington, OH Micropolitan Statistical Area */
"39049" = '18140' /*Columbus, OH Metropolitan Statistical Area */
"39051" = '45780' /*Toledo, OH Metropolitan Statistical Area */
"39053" = '38580' /*Point Pleasant, WV-OH Micropolitan Statistical Area */
"39055" = '17460' /*Cleveland-Elyria-Mentor, OH Metropolitan Statistical Area */
"39057" = '19380' /*Dayton, OH Metropolitan Statistical Area */
"39059" = '15740' /*Cambridge, OH Micropolitan Statistical Area */
"39061" = '17140' /*Cincinnati-Middletown, OH-KY-IN Metropolitan Statistical Area */
"39063" = '22300' /*Findlay, OH Micropolitan Statistical Area */
"39077" = '35940' /*Norwalk, OH Micropolitan Statistical Area */
"39081" = '48260' /*Weirton-Steubenville, WV-OH Metropolitan Statistical Area */
"39083" = '34540' /*Mount Vernon, OH Micropolitan Statistical Area */
"39085" = '17460' /*Cleveland-Elyria-Mentor, OH Metropolitan Statistical Area */
"39087" = '26580' /*Huntington-Ashland, WV-KY-OH Metropolitan Statistical Area */
"39089" = '18140' /*Columbus, OH Metropolitan Statistical Area */
"39091" = '13340' /*Bellefontaine, OH Micropolitan Statistical Area */
"39093" = '17460' /*Cleveland-Elyria-Mentor, OH Metropolitan Statistical Area */
"39095" = '45780' /*Toledo, OH Metropolitan Statistical Area */
"39097" = '18140' /*Columbus, OH Metropolitan Statistical Area */
"39099" = '49660' /*Youngstown-Warren-Boardman, OH-PA Metropolitan Statistical Area */
"39101" = '32020' /*Marion, OH Micropolitan Statistical Area */
"39103" = '17460' /*Cleveland-Elyria-Mentor, OH Metropolitan Statistical Area */
"39107" = '16380' /*Celina, OH Micropolitan Statistical Area */
"39109" = '19380' /*Dayton, OH Metropolitan Statistical Area */
"39113" = '19380' /*Dayton, OH Metropolitan Statistical Area */
"39117" = '18140' /*Columbus, OH Metropolitan Statistical Area */
"39119" = '49780' /*Zanesville, OH Micropolitan Statistical Area */
"39123" = '45780' /*Toledo, OH Metropolitan Statistical Area */
"39129" = '18140' /*Columbus, OH Metropolitan Statistical Area */
"39133" = '10420' /*Akron, OH Metropolitan Statistical Area */
"39135" = '19380' /*Dayton, OH Metropolitan Statistical Area */
"39139" = '31900' /*Mansfield, OH Metropolitan Statistical Area */
"39141" = '17060' /*Chillicothe, OH Micropolitan Statistical Area */
"39143" = '23380' /*Fremont, OH Micropolitan Statistical Area */
"39145" = '39020' /*Portsmouth, OH Micropolitan Statistical Area */
"39147" = '45660' /*Tiffin-Fostoria, OH Micropolitan Statistical Area */
"39149" = '43380' /*Sidney, OH Micropolitan Statistical Area */
"39151" = '15940' /*Canton-Massillon, OH Metropolitan Statistical Area */
"39153" = '10420' /*Akron, OH Metropolitan Statistical Area */
"39155" = '49660' /*Youngstown-Warren-Boardman, OH-PA Metropolitan Statistical Area */
"39157" = '35420' /*New Philadelphia-Dover, OH Micropolitan Statistical Area */
"39159" = '18140' /*Columbus, OH Metropolitan Statistical Area */
"39161" = '46780' /*Van Wert, OH Micropolitan Statistical Area */
"39165" = '17140' /*Cincinnati-Middletown, OH-KY-IN Metropolitan Statistical Area */
"39167" = '37620' /*Parkersburg-Marietta, WV-OH Metropolitan Statistical Area */
"39169" = '49300' /*Wooster, OH Micropolitan Statistical Area */
"39173" = '45780' /*Toledo, OH Metropolitan Statistical Area */
"40009" = '21120' /*Elk City, OK Micropolitan Statistical Area */
"40013" = '20460' /*Durant, OK Micropolitan Statistical Area */
"40017" = '36420' /*Oklahoma City, OK Metropolitan Statistical Area */
"40019" = '11620' /*Ardmore, OK Micropolitan Statistical Area */
"40021" = '45140' /*Tahlequah, OK Micropolitan Statistical Area */
"40027" = '36420' /*Oklahoma City, OK Metropolitan Statistical Area */
"40031" = '30020' /*Lawton, OK Metropolitan Statistical Area */
"40037" = '46140' /*Tulsa, OK Metropolitan Statistical Area */
"40047" = '21420' /*Enid, OK Micropolitan Statistical Area */
"40051" = '36420' /*Oklahoma City, OK Metropolitan Statistical Area */
"40065" = '11060' /*Altus, OK Micropolitan Statistical Area */
"40071" = '38620' /*Ponca City, OK Micropolitan Statistical Area */
"40079" = '22900' /*Fort Smith, AR-OK Metropolitan Statistical Area */
"40081" = '36420' /*Oklahoma City, OK Metropolitan Statistical Area */
"40083" = '36420' /*Oklahoma City, OK Metropolitan Statistical Area */
"40085" = '11620' /*Ardmore, OK Micropolitan Statistical Area */
"40087" = '36420' /*Oklahoma City, OK Metropolitan Statistical Area */
"40101" = '34780' /*Muskogee, OK Micropolitan Statistical Area */
"40109" = '36420' /*Oklahoma City, OK Metropolitan Statistical Area */
"40111" = '46140' /*Tulsa, OK Metropolitan Statistical Area */
"40113" = '46140' /*Tulsa, OK Metropolitan Statistical Area */
"40115" = '33060' /*Miami, OK Micropolitan Statistical Area */
"40117" = '46140' /*Tulsa, OK Metropolitan Statistical Area */
"40119" = '44660' /*Stillwater, OK Micropolitan Statistical Area */
"40121" = '32540' /*McAlester, OK Micropolitan Statistical Area */
"40123" = '10220' /*Ada, OK Micropolitan Statistical Area */
"40125" = '43060' /*Shawnee, OK Micropolitan Statistical Area */
"40131" = '46140' /*Tulsa, OK Metropolitan Statistical Area */
"40135" = '22900' /*Fort Smith, AR-OK Metropolitan Statistical Area */
"40137" = '20340' /*Duncan, OK Micropolitan Statistical Area */
"40139" = '25100' /*Guymon, OK Micropolitan Statistical Area */
"40143" = '46140' /*Tulsa, OK Metropolitan Statistical Area */
"40145" = '46140' /*Tulsa, OK Metropolitan Statistical Area */
"40147" = '12780' /*Bartlesville, OK Micropolitan Statistical Area */
"40153" = '49260' /*Woodward, OK Micropolitan Statistical Area */
"41003" = '18700' /*Corvallis, OR Metropolitan Statistical Area */
"41005" = '38900' /*Portland-Vancouver-Beaverton, OR-WA Metropolitan Statistical Area */
"41007" = '11820' /*Astoria, OR Micropolitan Statistical Area */
"41009" = '38900' /*Portland-Vancouver-Beaverton, OR-WA Metropolitan Statistical Area */
"41011" = '18300' /*Coos Bay, OR Micropolitan Statistical Area */
"41013" = '39260' /*Prineville, OR Micropolitan Statistical Area */
"41015" = '15060' /*Brookings, OR Micropolitan Statistical Area */
"41017" = '13460' /*Bend, OR Metropolitan Statistical Area */
"41019" = '40700' /*Roseburg, OR Micropolitan Statistical Area */
"41027" = '26220' /*Hood River, OR Micropolitan Statistical Area */
"41029" = '32780' /*Medford, OR Metropolitan Statistical Area */
"41033" = '24420' /*Grants Pass, OR Micropolitan Statistical Area */
"41035" = '28900' /*Klamath Falls, OR Micropolitan Statistical Area */
"41039" = '21660' /*Eugene-Springfield, OR Metropolitan Statistical Area */
"41043" = '10540' /*Albany-Lebanon, OR Micropolitan Statistical Area */
"41045" = '36620' /*Ontario, OR-ID Micropolitan Statistical Area */
"41047" = '41420' /*Salem, OR Metropolitan Statistical Area */
"41049" = '37820' /*Pendleton-Hermiston, OR Micropolitan Statistical Area */
"41051" = '38900' /*Portland-Vancouver-Beaverton, OR-WA Metropolitan Statistical Area */
"41053" = '41420' /*Salem, OR Metropolitan Statistical Area */
"41059" = '37820' /*Pendleton-Hermiston, OR Micropolitan Statistical Area */
"41061" = '29260' /*La Grande, OR Micropolitan Statistical Area */
"41065" = '17180' /*City of The Dalles, OR Micropolitan Statistical Area */
"41067" = '38900' /*Portland-Vancouver-Beaverton, OR-WA Metropolitan Statistical Area */
"41071" = '38900' /*Portland-Vancouver-Beaverton, OR-WA Metropolitan Statistical Area */
"42001" = '23900' /*Gettysburg, PA Micropolitan Statistical Area */
"42003" = '38300' /*Pittsburgh, PA Metropolitan Statistical Area */
"42005" = '38300' /*Pittsburgh, PA Metropolitan Statistical Area */
"42007" = '38300' /*Pittsburgh, PA Metropolitan Statistical Area */
"42011" = '39740' /*Reading, PA Metropolitan Statistical Area */
"42013" = '11020' /*Altoona, PA Metropolitan Statistical Area */
"42015" = '42380' /*Sayre, PA Micropolitan Statistical Area */
"42017" = '37980' /*Philadelphia-Camden-Wilmington, PA-NJ-DE-MD Metropolitan Statistical Area */
"42019" = '38300' /*Pittsburgh, PA Metropolitan Statistical Area */
"42021" = '27780' /*Johnstown, PA Metropolitan Statistical Area */
"42025" = '10900' /*Allentown-Bethlehem-Easton, PA-NJ Metropolitan Statistical Area */
"42027" = '44300' /*State College, PA Metropolitan Statistical Area */
"42029" = '37980' /*Philadelphia-Camden-Wilmington, PA-NJ-DE-MD Metropolitan Statistical Area */
"42033" = '20180' /*DuBois, PA Micropolitan Statistical Area */
"42035" = '30820' /*Lock Haven, PA Micropolitan Statistical Area */
"42037" = '14100' /*Bloomsburg-Berwick, PA Micropolitan Statistical Area */
"42039" = '32740' /*Meadville, PA Micropolitan Statistical Area */
"42041" = '25420' /*Harrisburg-Carlisle, PA Metropolitan Statistical Area */
"42043" = '25420' /*Harrisburg-Carlisle, PA Metropolitan Statistical Area */
"42045" = '37980' /*Philadelphia-Camden-Wilmington, PA-NJ-DE-MD Metropolitan Statistical Area */
"42047" = '41260' /*St. Marys, PA Micropolitan Statistical Area */
"42049" = '21500' /*Erie, PA Metropolitan Statistical Area */
"42051" = '38300' /*Pittsburgh, PA Metropolitan Statistical Area */
"42055" = '16540' /*Chambersburg, PA Micropolitan Statistical Area */
"42061" = '26500' /*Huntingdon, PA Micropolitan Statistical Area */
"42063" = '26860' /*Indiana, PA Micropolitan Statistical Area */
"42069" = '42540' /*Scranton—Wilkes-Barre, PA Metropolitan Statistical Area */
"42071" = '29540' /*Lancaster, PA Metropolitan Statistical Area */
"42073" = '35260' /*New Castle, PA Micropolitan Statistical Area */
"42075" = '30140' /*Lebanon, PA Metropolitan Statistical Area */
"42077" = '10900' /*Allentown-Bethlehem-Easton, PA-NJ Metropolitan Statistical Area */
"42079" = '42540' /*Scranton—Wilkes-Barre, PA Metropolitan Statistical Area */
"42081" = '48700' /*Williamsport, PA Metropolitan Statistical Area */
"42083" = '14620' /*Bradford, PA Micropolitan Statistical Area */
"42085" = '49660' /*Youngstown-Warren-Boardman, OH-PA Metropolitan Statistical Area */
"42087" = '30380' /*Lewistown, PA Micropolitan Statistical Area */
"42089" = '20700' /*East Stroudsburg, PA Micropolitan Statistical Area */
"42091" = '37980' /*Philadelphia-Camden-Wilmington, PA-NJ-DE-MD Metropolitan Statistical Area */
"42093" = '14100' /*Bloomsburg-Berwick, PA Micropolitan Statistical Area */
"42095" = '10900' /*Allentown-Bethlehem-Easton, PA-NJ Metropolitan Statistical Area */
"42097" = '44980' /*Sunbury, PA Micropolitan Statistical Area */
"42099" = '25420' /*Harrisburg-Carlisle, PA Metropolitan Statistical Area */
"42101" = '37980' /*Philadelphia-Camden-Wilmington, PA-NJ-DE-MD Metropolitan Statistical Area */
"42103" = '35620' /*New York-Newark-Edison, NY-NJ-PA Metropolitan Statistical Area */
"42107" = '39060' /*Pottsville, PA Micropolitan Statistical Area */
"42109" = '42780' /*Selinsgrove, PA Micropolitan Statistical Area */
"42111" = '43740' /*Somerset, PA Micropolitan Statistical Area */
"42119" = '30260' /*Lewisburg, PA Micropolitan Statistical Area */
"42121" = '36340' /*Oil City, PA Micropolitan Statistical Area */
"42123" = '47620' /*Warren, PA Micropolitan Statistical Area */
"42125" = '38300' /*Pittsburgh, PA Metropolitan Statistical Area */
"42129" = '38300' /*Pittsburgh, PA Metropolitan Statistical Area */
"42131" = '42540' /*Scranton—Wilkes-Barre, PA Metropolitan Statistical Area */
"42133" = '49620' /*York-Hanover, PA Metropolitan Statistical Area */
"44001" = '39300' /*Providence-New Bedford-Fall River, RI-MA Metropolitan Statistical Area */
"44003" = '39300' /*Providence-New Bedford-Fall River, RI-MA Metropolitan Statistical Area */
"44005" = '39300' /*Providence-New Bedford-Fall River, RI-MA Metropolitan Statistical Area */
"44007" = '39300' /*Providence-New Bedford-Fall River, RI-MA Metropolitan Statistical Area */
"44009" = '39300' /*Providence-New Bedford-Fall River, RI-MA Metropolitan Statistical Area */
"45003" = '12260' /*Augusta-Richmond County, GA-SC Metropolitan Statistical Area */
"45007" = '11340' /*Anderson, SC Metropolitan Statistical Area */
"45013" = '25940' /*Hilton Head Island-Beaufort, SC Micropolitan Statistical Area */
"45015" = '16700' /*Charleston-North Charleston, SC Metropolitan Statistical Area */
"45017" = '17900' /*Columbia, SC Metropolitan Statistical Area */
"45019" = '16700' /*Charleston-North Charleston, SC Metropolitan Statistical Area */
"45021" = '23500' /*Gaffney, SC Micropolitan Statistical Area */
"45023" = '16900' /*Chester, SC Micropolitan Statistical Area */
"45029" = '47500' /*Walterboro, SC Micropolitan Statistical Area */
"45031" = '22500' /*Florence, SC Metropolitan Statistical Area */
"45033" = '19900' /*Dillon, SC Micropolitan Statistical Area */
"45035" = '16700' /*Charleston-North Charleston, SC Metropolitan Statistical Area */
"45037" = '12260' /*Augusta-Richmond County, GA-SC Metropolitan Statistical Area */
"45039" = '17900' /*Columbia, SC Metropolitan Statistical Area */
"45041" = '22500' /*Florence, SC Metropolitan Statistical Area */
"45043" = '23860' /*Georgetown, SC Micropolitan Statistical Area */
"45045" = '24860' /*Greenville, SC Metropolitan Statistical Area */
"45047" = '24940' /*Greenwood, SC Micropolitan Statistical Area */
"45051" = '34820' /*Myrtle Beach-Conway-North Myrtle Beach, SC Metropolitan Statistical Area */
"45053" = '25940' /*Hilton Head Island-Beaufort, SC Micropolitan Statistical Area */
"45055" = '17900' /*Columbia, SC Metropolitan Statistical Area */
"45057" = '29580' /*Lancaster, SC Micropolitan Statistical Area */
"45059" = '24860' /*Greenville, SC Metropolitan Statistical Area */
"45063" = '17900' /*Columbia, SC Metropolitan Statistical Area */
"45069" = '13500' /*Bennettsville, SC Micropolitan Statistical Area */
"45071" = '35140' /*Newberry, SC Micropolitan Statistical Area */
"45073" = '42860' /*Seneca, SC Micropolitan Statistical Area */
"45075" = '36700' /*Orangeburg, SC Micropolitan Statistical Area */
"45077" = '24860' /*Greenville, SC Metropolitan Statistical Area */
"45079" = '17900' /*Columbia, SC Metropolitan Statistical Area */
"45081" = '17900' /*Columbia, SC Metropolitan Statistical Area */
"45083" = '43900' /*Spartanburg, SC Metropolitan Statistical Area */
"45085" = '44940' /*Sumter, SC Metropolitan Statistical Area */
"45087" = '46420' /*Union, SC Micropolitan Statistical Area */
"45091" = '16740' /*Charlotte-Gastonia-Concord, NC-SC Metropolitan Statistical Area */
"46005" = '26700' /*Huron, SD Micropolitan Statistical Area */
"46011" = '15100' /*Brookings, SD Micropolitan Statistical Area */
"46013" = '10100' /*Aberdeen, SD Micropolitan Statistical Area */
"46027" = '46820' /*Vermillion, SD Micropolitan Statistical Area */
"46029" = '47980' /*Watertown, SD Micropolitan Statistical Area */
"46035" = '33580' /*Mitchell, SD Micropolitan Statistical Area */
"46045" = '10100' /*Aberdeen, SD Micropolitan Statistical Area */
"46057" = '47980' /*Watertown, SD Micropolitan Statistical Area */
"46061" = '33580' /*Mitchell, SD Micropolitan Statistical Area */
"46065" = '38180' /*Pierre, SD Micropolitan Statistical Area */
"46081" = '43940' /*Spearfish, SD Micropolitan Statistical Area */
"46083" = '43620' /*Sioux Falls, SD Metropolitan Statistical Area */
"46087" = '43620' /*Sioux Falls, SD Metropolitan Statistical Area */
"46093" = '39660' /*Rapid City, SD Metropolitan Statistical Area */
"46099" = '43620' /*Sioux Falls, SD Metropolitan Statistical Area */
"46103" = '39660' /*Rapid City, SD Metropolitan Statistical Area */
"46117" = '38180' /*Pierre, SD Micropolitan Statistical Area */
"46125" = '43620' /*Sioux Falls, SD Metropolitan Statistical Area */
"46127" = '43580' /*Sioux City, IA-NE-SD Metropolitan Statistical Area */
"46135" = '49460' /*Yankton, SD Micropolitan Statistical Area */
"47001" = '28940' /*Knoxville, TN Metropolitan Statistical Area */
"47003" = '43180' /*Shelbyville, TN Micropolitan Statistical Area */
"47009" = '28940' /*Knoxville, TN Metropolitan Statistical Area */
"47011" = '17420' /*Cleveland, TN Metropolitan Statistical Area */
"47013" = '29220' /*La Follette, TN Micropolitan Statistical Area */
"47015" = '34980' /*Nashville-Davidson—Murfreesboro, TN Metropolitan Statistical Area */
"47019" = '27740' /*Johnson City, TN Metropolitan Statistical Area */
"47021" = '34980' /*Nashville-Davidson—Murfreesboro, TN Metropolitan Statistical Area */
"47023" = '27180' /*Jackson, TN Metropolitan Statistical Area */
"47029" = '35460' /*Newport, TN Micropolitan Statistical Area */
"47031" = '46100' /*Tullahoma, TN Micropolitan Statistical Area */
"47035" = '18900' /*Crossville, TN Micropolitan Statistical Area */
"47037" = '34980' /*Nashville-Davidson—Murfreesboro, TN Metropolitan Statistical Area */
"47043" = '34980' /*Nashville-Davidson—Murfreesboro, TN Metropolitan Statistical Area */
"47045" = '20540' /*Dyersburg, TN Micropolitan Statistical Area */
"47047" = '32820' /*Memphis, TN -MS-AR Metropolitan Statistical Area */
"47051" = '46100' /*Tullahoma, TN Micropolitan Statistical Area */
"47053" = '26480' /*Humboldt, TN Micropolitan Statistical Area */
"47057" = '34100' /*Morristown, TN Metropolitan Statistical Area */
"47059" = '24620' /*Greeneville, TN Micropolitan Statistical Area */
"47063" = '34100' /*Morristown, TN Metropolitan Statistical Area */
"47065" = '16860' /*Chattanooga, TN-GA Metropolitan Statistical Area */
"47073" = '28700' /*Kingsport-Bristol, TN-VA Metropolitan Statistical Area */
"47075" = '15140' /*Brownsville, TN Micropolitan Statistical Area */
"47079" = '37540' /*Paris, TN Micropolitan Statistical Area */
"47081" = '34980' /*Nashville-Davidson—Murfreesboro, TN Metropolitan Statistical Area */
"47087" = '18260' /*Cookevi lle, TN Micropolitan Statistical Area */
"47089" = '34100' /*Morristown, TN Metropolitan Statistical Area */
"47093" = '28940' /*Knoxville, TN Metropolitan Statistical Area */
"47099" = '29980' /*Lawrenceburg, TN Micropolitan Statistical Area */
"47105" = '28940' /*Knoxville, TN Metropolitan Statistical Area */
"47107" = '11940' /*Athens, TN Micropolitan Statistical Area */
"47111" = '34980' /*Nashville-Davidson—Murfreesboro, TN Metropolitan Statistical Area */
"47113" = '27180' /*Jackson, TN Metropolitan Statistical Area */
"47115" = '16860' /*Chattanooga, TN-GA Metropolitan Statistical Area */
"47117" = '30280' /*Lewisburg, TN Micropolitan Statistical Area */
"47119" = '17940' /*Columbia, TN Micropolitan Statistical Area */
"47125" = '17300' /*Clarksville, TN-KY Metropolitan Statistical Area */
"47127" = '46100' /*Tullahoma, TN Micropolitan Statistical Area */
"47131" = '46460' /*Union City, TN-KY Micropolitan Statistical Area */
"47133" = '18260' /*Cookevi lle, TN Micropolitan Statistical Area */
"47139" = '17420' /*Cleveland, TN Metropolitan Statistical Area */
"47141" = '18260' /*Cookevi lle, TN Micropolitan Statistical Area */
"47145" = '25340' /*Harriman, TN Micropolitan Statistical Area */
"47147" = '34980' /*Nashville-Davidson—Murfreesboro, TN Metropolitan Statistical Area */
"47149" = '34980' /*Nashville-Davidson—Murfreesboro, TN Metropolitan Statistical Area */
"47153" = '16860' /*Chattanooga, TN-GA Metropolitan Statistical Area */
"47155" = '42940' /*Sevierville, TN Micropolitan Statistical Area */
"47157" = '32820' /*Memphis, TN -MS-AR Metropolitan Statistical Area */
"47159" = '34980' /*Nashville-Davidson—Murfreesboro, TN Metropolitan Statistical Area */
"47161" = '17300' /*Clarksville, TN-KY Metropolitan Statistical Area */
"47163" = '28700' /*Kingsport-Bristol, TN-VA Metropolitan Statistical Area */
"47165" = '34980' /*Nashville-Davidson—Murfreesboro, TN Metropolitan Statistical Area */
"47167" = '32820' /*Memphis, TN -MS-AR Metropolitan Statistical Area */
"47169" = '34980' /*Nashville-Davidson—Murfreesboro, TN Metropolitan Statistical Area */
"47171" = '27740' /*Johnson City, TN Metropolitan Statistical Area */
"47173" = '28940' /*Knoxville, TN Metropolitan Statistical Area */
"47177" = '32660' /*McMinnville, TN Micropolitan Statistical Area */
"47179" = '27740' /*Johnson City, TN Metropolitan Statistical Area */
"47183" = '32280' /*Martin, TN Micropolitan Statistical Area */
"47187" = '34980' /*Nashville-Davidson—Murfreesboro, TN Metropolitan Statistical Area */
"47189" = '34980' /*Nashville-Davidson—Murfreesboro, TN Metropolitan Statistical Area */
"48001" = '37300' /*Palestine, TX Micropolitan Statistical Area */
"48003" = '11380' /*Andrews, TX Micropolitan Statistical Area */
"48005" = '31260' /*Lufkin, TX Micropolitan Statistical Area */
"48007" = '18580' /*Corpus Christi, TX Metropolitan Statistical Area */
"48009" = '48660' /*Wichita Falls, TX Metropolitan Statistical Area */
"48011" = '11100' /*Amarillo, TX Metropolitan Statistical Area */
"48013" = '41700' /*San Antonio, TX Metropolitan Statistical Area */
"48015" = '26420' /*Houston-Baytown-Sugar Land, TX Metropolitan Statistical Area */
"48019" = '41700' /*San Antonio, TX Metropolitan Statistical Area */
"48021" = '12420' /*Austin-Round Rock, TX Metropolitan Statistical Area */
"48025" = '13300' /*Beeville, TX Micropolitan Statistical Area */
"48027" = '28660' /*Killeen-Temple-Fort Hood, TX Metropolitan Statistical Area */
"48029" = '41700' /*San Antonio, TX Metropolitan Statistical Area */
"48037" = '45500' /*Texarkana, TX-Texarkana, AR Metropolitan Statistical Area */
"48039" = '26420' /*Houston-Baytown-Sugar Land, TX Metropolitan Statistical Area */
"48041" = '17780' /*College Station-Bryan, TX Metropolitan Statistical Area */
"48049" = '15220' /*Brownwood, TX Micropolitan Statistical Area */
"48051" = '17780' /*College Station-Bryan, TX Metropolitan Statistical Area */
"48055" = '12420' /*Austin-Round Rock, TX Metropolitan Statistical Area */
"48057" = '47020' /*Victoria, TX Metropolitan Statistical Area */
"48059" = '10180' /*Abilene, TX Metropolitan Statistical Area */
"48061" = '15180' /*Brownsville-Harlingen, TX Metropolitan Statistical Area */
"48065" = '11100' /*Amarillo, TX Metropolitan Statistical Area */
"48071" = '26420' /*Houston-Baytown-Sugar Land, TX Metropolitan Statistical Area */
"48073" = '27380' /*Jacksonville, TX Micropolitan Statistical Area */
"48077" = '48660' /*Wichita Falls, TX Metropolitan Statistical Area */
"48085" = '19100' /*Dallas -Fort Worth-Arlington, TX Metropolitan Statistical Area */
"48091" = '41700' /*San Antonio, TX Metropolitan Statistical Area */
"48097" = '23620' /*Gainesville, TX Micropolitan Statistical Area */
"48099" = '28660' /*Killeen-Temple-Fort Hood, TX Metropolitan Statistical Area */
"48107" = '31180' /*Lubbock, TX Metropolitan Statistical Area */
"48113" = '19100' /*Dallas -Fort Worth-Arlington, TX Metropolitan Statistical Area */
"48115" = '29500' /*Lamesa, TX Micropolitan Statistical Area */
"48117" = '25820' /*Hereford, TX Micropolitan Statistical Area */
"48119" = '19100' /*Dallas -Fort Worth-Arlington, TX Metropolitan Statistical Area */
"48121" = '19100' /*Dallas -Fort Worth-Arlington, TX Metropolitan Statistical Area */
"48135" = '36220' /*Odessa, TX Metropolitan Statistical Area */
"48139" = '19100' /*Dallas -Fort Worth-Arlington, TX Metropolitan Statistical Area */
"48141" = '21340' /*El Paso, TX Metropolitan Statistical Area */
"48143" = '44500' /*Stephenville, TX Micropolitan Statistical Area */
"48147" = '14300' /*Bonham, TX Micropolitan Statistical Area */
"48157" = '26420' /*Houston-Baytown-Sugar Land, TX Metropolitan Statistical Area */
"48167" = '26420' /*Houston-Baytown-Sugar Land, TX Metropolitan Statistical Area */
"48175" = '47020' /*Victoria, TX Metropolitan Statistical Area */
"48179" = '37420' /*Pampa, TX Micropolitan Statistical Area */
"48181" = '43300' /*Sherman-Denison, TX Metropolitan Statistical Area */
"48183" = '30980' /*Longview, TX Metropolitan Statistical Area */
"48187" = '41700' /*San Antonio, TX Metropolitan Statistical Area */
"48189" = '38380' /*Plainview, TX Micropolitan Statistical Area */
"48199" = '13140' /*Beaumont-Port Arthur, TX Metropolitan Statistical Area */
"48201" = '26420' /*Houston-Baytown-Sugar Land, TX Metropolitan Statistical Area */
"48203" = '32220' /*Marshall, TX Micropolitan Statistical Area */
"48209" = '12420' /*Austin-Round Rock, TX Metropolitan Statistical Area */
"48213" = '11980' /*Athens, TX Micropolitan Statistical Area */
"48215" = '32580' /*McAllen-Edinburg-Pharr, TX Metropolitan Statistical Area */
"48219" = '30220' /*Levelland, TX Micropolitan Statistical Area */
"48221" = '24180' /*Granbury, TX Micropolitan Statistical Area */
"48223" = '44860' /*Sulphur Springs, TX Micropolitan Statistical Area */
"48227" = '13700' /*Big Spring, TX Micropolitan Statistical Area */
"48231" = '19100' /*Dallas -Fort Worth-Arlington, TX Metropolitan Statistical Area */
"48233" = '14420' /*Borger, TX Micropolitan Statistical Area */
"48235" = '41660' /*San Angelo, TX Metropolitan Statistical Area */
"48245" = '13140' /*Beaumont-Port Arthur, TX Metropolitan Statistical Area */
"48249" = '10860' /*Alice, TX Micropolitan Statistical Area */
"48251" = '19100' /*Dallas -Fort Worth-Arlington, TX Metropolitan Statistical Area */
"48253" = '10180' /*Abilene, TX Metropolitan Statistical Area */
"48257" = '19100' /*Dallas -Fort Worth-Arlington, TX Metropolitan Statistical Area */
"48259" = '41700' /*San Antonio, TX Metropolitan Statistical Area */
"48261" = '28780' /*Kingsville, TX Micropolitan Statistical Area */
"48265" = '28500' /*Kerrville, TX Micropolitan Statistical Area */
"48273" = '28780' /*Kingsville, TX Micropolitan Statistical Area */
"48277" = '37580' /*Paris, TX Micropolitan Statistical Area */
"48281" = '28660' /*Killeen-Temple-Fort Hood, TX Metropolitan Statistical Area */
"48291" = '26420' /*Houston-Baytown-Sugar Land, TX Metropolitan Statistical Area */
"48303" = '31180' /*Lubbock, TX Metropolitan Statistical Area */
"48309" = '47380' /*Waco, TX Metropolitan Statistical Area */
"48321" = '13060' /*Bay City, TX Micropolitan Statistical Area */
"48323" = '20580' /*Eagle Pass, TX Micropolitan Statistical Area */
"48325" = '41700' /*San Antonio, TX Metropolitan Statistical Area */
"48329" = '33260' /*Midland, TX Metropolitan Statistical Area */
"48339" = '26420' /*Houston-Baytown-Sugar Land, TX Metropolitan Statistical Area */
"48341" = '20300' /*Dumas, TX Micropolitan Statistical Area */
"48347" = '34860' /*Nacogdoches, TX Micropolitan Statistical Area */
"48349" = '18620' /*Corsicana, TX Micropolitan Statistical Area */
"48353" = '45020' /*Sweetwater, TX Micropolitan Statistical Area */
"48355" = '18580' /*Corpus Christi, TX Metropolitan Statistical Area */
"48361" = '13140' /*Beaumont-Port Arthur, TX Metropolitan Statistical Area */
"48363" = '33420' /*Mineral Wells, TX Micropolitan Statistical Area */
"48367" = '19100' /*Dallas -Fort Worth-Arlington, TX Metropolitan Statistical Area */
"48375" = '11100' /*Amarillo, TX Metropolitan Statistical Area */
"48381" = '11100' /*Amarillo, TX Metropolitan Statistical Area */
"48389" = '37780' /*Pecos, TX Micropolitan Statistical Area */
"48393" = '37420' /*Pampa, TX Micropolitan Statistical Area */
"48395" = '17780' /*College Station-Bryan, TX Metropolitan Statistical Area */
"48397" = '19100' /*Dallas -Fort Worth-Arlington, TX Metropolitan Statistical Area */
"48401" = '30980' /*Longview, TX Metropolitan Statistical Area */
"48407" = '26420' /*Houston-Baytown-Sugar Land, TX Metropolitan Statistical Area */
"48409" = '18580' /*Corpus Christi, TX Metropolitan Statistical Area */
"48415" = '43660' /*Snyder, TX Micropolitan Statistical Area */
"48423" = '46340' /*Tyler, TX Metropolitan Statistical Area */
"48425" = '24180' /*Granbury, TX Micropolitan Statistical Area */
"48427" = '40100' /*Rio Grande City, TX Micropolitan Statistical Area */
"48439" = '19100' /*Dallas -Fort Worth-Arlington, TX Metropolitan Statistical Area */
"48441" = '10180' /*Abilene, TX Metropolitan Statistical Area */
"48449" = '34420' /*Mount Pleasant, TX Micropolitan Statistical Area */
"48451" = '41660' /*San Angelo, TX Metropolitan Statistical Area */
"48453" = '12420' /*Austin-Round Rock, TX Metropolitan Statistical Area */
"48459" = '30980' /*Longview, TX Metropolitan Statistical Area */
"48463" = '46620' /*Uvalde, TX Micropolitan Statistical Area */
"48465" = '19620' /*Del Rio, TX Micropolitan Statistical Area */
"48469" = '47020' /*Victoria, TX Metropolitan Statistical Area */
"48471" = '26660' /*Huntsville, TX Micropolitan Statistical Area */
"48473" = '26420' /*Houston-Baytown-Sugar Land, TX Metropolitan Statistical Area */
"48477" = '14780' /*Brenham, TX Micropolitan Statistical Area */
"48479" = '29700' /*Laredo, TX Metropolitan Statistical Area */
"48481" = '20900' /*El Campo, TX Micropolitan Statistical Area */
"48485" = '48660' /*Wichita Falls, TX Metropolitan Statistical Area */
"48487" = '46900' /*Vernon, TX Micropolitan Statistical Area */
"48489" = '39700' /*Raymondville, TX Micropolitan Statistical Area */
"48491" = '12420' /*Austin-Round Rock, TX Metropolitan Statistical Area */
"48493" = '41700' /*San Antonio, TX Metropolitan Statistical Area */
"48497" = '19100' /*Dallas -Fort Worth-Arlington, TX Metropolitan Statistical Area */
"49003" = '14940' /*Brigham City, UT Micropolitan Statistical Area */
"49005" = '30860' /*Logan, UT-ID Metropolitan Statistical Area */
"49007" = '39220' /*Price, UT Micropolitan Statistical Area */
"49011" = '36260' /*Ogden-Clearfield, UT Metropolitan Statistical Area */
"49021" = '16260' /*Cedar City, UT Micropolitan Statistical Area */
"49023" = '39340' /*Provo-Orem, UT Metropolitan Statistical Area */
"49029" = '36260' /*Ogden-Clearfield, UT Metropolitan Statistical Area */
"49035" = '41620' /*Salt Lake City, UT Metropolitan Statistical Area */
"49043" = '41620' /*Salt Lake City, UT Metropolitan Statistical Area */
"49045" = '41620' /*Salt Lake City, UT Metropolitan Statistical Area */
"49047" = '46860' /*Vernal, UT Micropolitan Statistical Area */
"49049" = '39340' /*Provo-Orem, UT Metropolitan Statistical Area */
"49051" = '25720' /*Heber, UT Micropolitan Statistical Area */
"49053" = '41100' /*St. George, UT Metropolitan Statistical Area */
"49057" = '36260' /*Ogden-Clearfield, UT Metropolitan Statistical Area */
"50003" = '13540' /*Bennington, VT Micropolitan Statistical Area */
"50007" = '15540' /*Burlington-South Burlington, VT Metropolitan Statistical Area */
"50009" = '13620' /*Berlin, NH-VT Micropolitan Statistical Area */
"50011" = '15540' /*Burlington-South Burlington, VT Metropolitan Statistical Area */
"50013" = '15540' /*Burlington-South Burlington, VT Metropolitan Statistical Area */
"50017" = '30100' /*Lebanon, NH-VT Micropolitan Statistical Area */
"50021" = '40860' /*Rutland, VT Micropolitan Statistical Area */
"50023" = '12740' /*Barre, VT Micropolitan Statistical Area */
"50027" = '30100' /*Lebanon, NH-VT Micropolitan Statistical Area */
"51003" = '16820' /*Charlottesville, VA Metropolitan Statistical Area */
"51007" = '40060' /*Richmond, VA Metropolitan Statistical Area */
"51009" = '31340' /*Lynchburg, VA Metropolitan Statistical Area */
"51011" = '31340' /*Lynchburg, VA Metropolitan Statistical Area */
"51013" = '47900' /*Washington-Arlington-Alexandria, DC-VA-MD-WV Metropolitan Statistical Area */
"51015" = '44420' /*Staunton-Waynesboro, VA Micropolitan Statistical Area */
"51019" = '31340' /*Lynchburg, VA Metropolitan Statistical Area */
"51023" = '40220' /*Roanoke, VA Metropolitan Statistical Area */
"51031" = '31340' /*Lynchburg, VA Metropolitan Statistical Area */
"51033" = '40060' /*Richmond, VA Metropolitan Statistical Area */
"51036" = '40060' /*Richmond, VA Metropolitan Statistical Area */
"51041" = '40060' /*Richmond, VA Metropolitan Statistical Area */
"51043" = '47900' /*Washington-Arlington-Alexandria, DC-VA-MD-WV Metropolitan Statistical Area */
"51045" = '40220' /*Roanoke, VA Metropolitan Statistical Area */
"51047" = '19020' /*Culpeper, VA Micropolitan Statistical Area */
"51049" = '40060' /*Richmond, VA Metropolitan Statistical Area */
"51053" = '40060' /*Richmond, VA Metropolitan Statistical Area */
"51059" = '47900' /*Washington-Arlington-Alexandria, DC-VA-MD-WV Metropolitan Statistical Area */
"51061" = '47900' /*Washington-Arlington-Alexandria, DC-VA-MD-WV Metropolitan Statistical Area */
"51065" = '16820' /*Charlottesville, VA Metropolitan Statistical Area */
"51067" = '40220' /*Roanoke, VA Metropolitan Statistical Area */
"51069" = '49020' /*Winchester, VA-WV Metropolitan Statistical Area */
"51071" = '13980' /*Blacksburg-Christiansburg-Radford, VA Metropolitan Statistical Area */
"51073" = '47260' /*Virginia Beach-Norfolk-Newport News, VA-NC Metropolitan Statistical Area */
"51075" = '40060' /*Richmond, VA Metropolitan Statistical Area */
"51079" = '16820' /*Charlottesville, VA Metropolitan Statistical Area */
"51085" = '40060' /*Richmond, VA Metropolitan Statistical Area */
"51087" = '40060' /*Richmond, VA Metropolitan Statistical Area */
"51089" = '32300' /*Martinsville, VA Micropolitan Statistical Area */
"51093" = '47260' /*Virginia Beach-Norfolk-Newport News, VA-NC Metropolitan Statistical Area */
"51095" = '47260' /*Virginia Beach-Norfolk-Newport News, VA-NC Metropolitan Statistical Area */
"51097" = '40060' /*Richmond, VA Metropolitan Statistical Area */
"51101" = '40060' /*Richmond, VA Metropolitan Statistical Area */
"51107" = '47900' /*Washington-Arlington-Alexandria, DC-VA-MD-WV Metropolitan Statistical Area */
"51109" = '40060' /*Richmond, VA Metropolitan Statistical Area */
"51115" = '47260' /*Virginia Beach-Norfolk-Newport News, VA-NC Metropolitan Statistical Area */
"51121" = '13980' /*Blacksburg-Christiansburg-Radford, VA Metropolitan Statistical Area */
"51125" = '16820' /*Charlottesville, VA Metropolitan Statistical Area */
"51127" = '40060' /*Richmond, VA Metropolitan Statistical Area */
"51143" = '19260' /*Danville, VA Metropolitan Statistical Area */
"51145" = '40060' /*Richmond, VA Metropolitan Statistical Area */
"51149" = '40060' /*Richmond, VA Metropolitan Statistical Area */
"51153" = '47900' /*Washington-Arlington-Alexandria, DC-VA-MD-WV Metropolitan Statistical Area */
"51155" = '13980' /*Blacksburg-Christiansburg-Radford, VA Metropolitan Statistical Area */
"51161" = '40220' /*Roanoke, VA Metropolitan Statistical Area */
"51165" = '25500' /*Harrisonburg, VA Metropolitan Statistical Area */
"51169" = '28700' /*Kingsport-Bristol, TN-VA Metropolitan Statistical Area */
"51177" = '47900' /*Washington-Arlington-Alexandria, DC-VA-MD-WV Metropolitan Statistical Area */
"51179" = '47900' /*Washington-Arlington-Alexandria, DC-VA-MD-WV Metropolitan Statistical Area */
"51181" = '47260' /*Virginia Beach-Norfolk-Newport News, VA-NC Metropolitan Statistical Area */
"51183" = '40060' /*Richmond, VA Metropolitan Statistical Area */
"51185" = '14140' /*Bluefield, WV-VA Micropolitan Statistical Area */
"51187" = '47900' /*Washington-Arlington-Alexandria, DC-VA-MD-WV Metropolitan Statistical Area */
"51191" = '28700' /*Kingsport-Bristol, TN-VA Metropolitan Statistical Area */
"51199" = '47260' /*Virginia Beach-Norfolk-Newport News, VA-NC Metropolitan Statistical Area */
"51510" = '47900' /*Washington-Arlington-Alexandria, DC-VA-MD-WV Metropolitan Statistical Area */
"51515" = '31340' /*Lynchburg, VA Metropolitan Statistical Area */
"51520" = '28700' /*Kingsport-Bristol, TN-VA Metropolitan Statistical Area */
"51540" = '16820' /*Charlottesville, VA Metropolitan Statistical Area */
"51550" = '47260' /*Virginia Beach-Norfolk-Newport News, VA-NC Metropolitan Statistical Area */
"51570" = '40060' /*Richmond, VA Metropolitan Statistical Area */
"51590" = '19260' /*Danville, VA Metropolitan Statistical Area */
"51600" = '47900' /*Washington-Arlington-Alexandria, DC-VA-MD-WV Metropolitan Statistical Area */
"51610" = '47900' /*Washington-Arlington-Alexandria, DC-VA-MD-WV Metropolitan Statistical Area */
"51630" = '47900' /*Washington-Arlington-Alexandria, DC-VA-MD-WV Metropolitan Statistical Area */
"51650" = '47260' /*Virginia Beach-Norfolk-Newport News, VA-NC Metropolitan Statistical Area */
"51660" = '25500' /*Harrisonburg, VA Metropolitan Statistical Area */
"51670" = '40060' /*Richmond, VA Metropolitan Statistical Area */
"51680" = '31340' /*Lynchburg, VA Metropolitan Statistical Area */
"51683" = '47900' /*Washington-Arlington-Alexandria, DC-VA-MD-WV Metropolitan Statistical Area */
"51685" = '47900' /*Washington-Arlington-Alexandria, DC-VA-MD-WV Metropolitan Statistical Area */
"51690" = '32300' /*Martinsville, VA Micropolitan Statistical Area */
"51700" = '47260' /*Virginia Beach-Norfolk-Newport News, VA-NC Metropolitan Statistical Area */
"51710" = '47260' /*Virginia Beach-Norfolk-Newport News, VA-NC Metropolitan Statistical Area */
"51730" = '40060' /*Richmond, VA Metropolitan Statistical Area */
"51735" = '47260' /*Virginia Beach-Norfolk-Newport News, VA-NC Metropolitan Statistical Area */
"51740" = '47260' /*Virginia Beach-Norfolk-Newport News, VA-NC Metropolitan Statistical Area */
"51750" = '13980' /*Blacksburg-Christiansburg-Radford, VA Metropolitan Statistical Area */
"51760" = '40060' /*Richmond, VA Metropolitan Statistical Area */
"51770" = '40220' /*Roanoke, VA Metropolitan Statistical Area */
"51775" = '40220' /*Roanoke, VA Metropolitan Statistical Area */
"51790" = '44420' /*Staunton-Waynesboro, VA Micropolitan Statistical Area */
"51800" = '47260' /*Virginia Beach-Norfolk-Newport News, VA-NC Metropolitan Statistical Area */
"51810" = '47260' /*Virginia Beach-Norfolk-Newport News, VA-NC Metropolitan Statistical Area */
"51820" = '44420' /*Staunton-Waynesboro, VA Micropolitan Statistical Area */
"51830" = '47260' /*Virginia Beach-Norfolk-Newport News, VA-NC Metropolitan Statistical Area */
"51840" = '49020' /*Winchester, VA-WV Metropolitan Statistical Area */
"53003" = '30300' /*Lewiston, ID-WA Metropolitan Statistical Area */
"53005" = '28420' /*Kennewick-Richland-Pasco, WA Metropolitan Statistical Area */
"53007" = '48300' /*Wenatchee, WA Metropolitan Statistical Area */
"53009" = '38820' /*Port Angeles, WA Micropolitan Statistical Area */
"53011" = '38900' /*Portland-Vancouver-Beaverton, OR-WA Metropolitan Statistical Area */
"53015" = '31020' /*Longview-Kelso, WA Metropolitan Statistical Area */
"53017" = '48300' /*Wenatchee, WA Metropolitan Statistical Area */
"53021" = '28420' /*Kennewick-Richland-Pasco, WA Metropolitan Statistical Area */
"53025" = '34180' /*Moses Lake, WA Micropolitan Statistical Area */
"53027" = '10140' /*Aberdeen, WA Micropolitan Statistical Area */
"53029" = '36020' /*Oak Harbor, WA Micropolitan Statistical Area */
"53033" = '42660' /*Seattle-Tacoma-Bellevue, WA Metropolitan Statistical Area */
"53035" = '14740' /*Bremerton-Silverdale, WA Metropolitan Statistical Area */
"53037" = '21260' /*Ellensburg, WA Micropolitan Statistical Area */
"53041" = '16500' /*Centralia, WA Micropolitan Statistical Area */
"53045" = '43220' /*Shelton, WA Micropolitan Statistical Area */
"53053" = '42660' /*Seattle-Tacoma-Bellevue, WA Metropolitan Statistical Area */
"53057" = '34580' /*Mount Vernon-Anacortes, WA Metropolitan Statistical Area */
"53059" = '38900' /*Portland-Vancouver-Beaverton, OR-WA Metropolitan Statistical Area */
"53061" = '42660' /*Seattle-Tacoma-Bellevue, WA Metropolitan Statistical Area */
"53063" = '44060' /*Spokane, WA Metropolitan Statistical Area */
"53067" = '36500' /*Olympia, WA Metropolitan Statistical Area */
"53071" = '47460' /*Walla Walla, WA Micropolitan Statistical Area */
"53073" = '13380' /*Bellingham, WA Metropolitan Statistical Area */
"53075" = '39420' /*Pullman, WA Micropolitan Statistical Area */
"53077" = '49420' /*Yakima, WA Metropolitan Statistical Area */
"54003" = '25180' /*Hagerstown-Martinsburg, MD-WV Metropolitan Statistical Area */
"54005" = '16620' /*Charleston, WV Metropolitan Statistical Area */
"54009" = '48260' /*Weirton-Steubenville, WV-OH Metropolitan Statistical Area */
"54011" = '26580' /*Huntington-Ashland, WV-KY-OH Metropolitan Statistical Area */
"54015" = '16620' /*Charleston, WV Metropolitan Statistical Area */
"54017" = '17220' /*Clarksburg, WV Micropolitan Statistical Area */
"54019" = '36060' /*Oak Hill, WV Micropolitan Statistical Area */
"54027" = '49020' /*Winchester, VA-WV Metropolitan Statistical Area */
"54029" = '48260' /*Weirton-Steubenville, WV-OH Metropolitan Statistical Area */
"54033" = '17220' /*Clarksburg, WV Micropolitan Statistical Area */
"54037" = '47900' /*Washington-Arlington-Alexandria, DC-VA-MD-WV Metropolitan Statistical Area */
"54039" = '16620' /*Charleston, WV Metropolitan Statistical Area */
"54043" = '16620' /*Charleston, WV Metropolitan Statistical Area */
"54049" = '21900' /*Fairmont, WV Micropolitan Statistical Area */
"54051" = '48540' /*Wheeling, WV-OH Metropolitan Statistical Area */
"54053" = '38580' /*Point Pleasant, WV-OH Micropolitan Statistical Area */
"54055" = '14140' /*Bluefield, WV-VA Micropolitan Statistical Area */
"54057" = '19060' /*Cumberland, MD-WV Metropolitan Statistical Area */
"54061" = '34060' /*Morgantown, WV Metropolitan Statistical Area */
"54065" = '25180' /*Hagerstown-Martinsburg, MD-WV Metropolitan Statistical Area */
"54069" = '48540' /*Wheeling, WV-OH Metropolitan Statistical Area */
"54073" = '37620' /*Parkersburg-Marietta, WV-OH Metropolitan Statistical Area */
"54077" = '34060' /*Morgantown, WV Metropolitan Statistical Area */
"54079" = '16620' /*Charleston, WV Metropolitan Statistical Area */
"54081" = '13220' /*Beckley, WV Micropolitan Statistical Area */
"54091" = '17220' /*Clarksburg, WV Micropolitan Statistical Area */
"54099" = '26580' /*Huntington-Ashland, WV-KY-OH Metropolitan Statistical Area */
"54105" = '37620' /*Parkersburg-Marietta, WV-OH Metropolitan Statistical Area */
"54107" = '37620' /*Parkersburg-Marietta, WV-OH Metropolitan Statistical Area */
"55009" = '24580' /*Green Bay, WI Metropolitan Statistical Area */
"55015" = '11540' /*Appleton, WI Metropolitan Statistical Area */
"55017" = '20740' /*Eau Claire, WI Metropolitan Statistical Area */
"55021" = '31540' /*Madison, WI Metropolitan Statistical Area */
"55025" = '31540' /*Madison, WI Metropolitan Statistical Area */
"55027" = '13180' /*Beaver Dam, WI Micropolitan Statistical Area */
"55031" = '20260' /*Duluth, MN-WI Metropolitan Statistical Area */
"55033" = '32860' /*Menomonie, WI Micropolitan Statistical Area */
"55035" = '20740' /*Eau Claire, WI Metropolitan Statistical Area */
"55037" = '27020' /*Iron Mountain, MI-WI Micropolitan Statistical Area */
"55039" = '22540' /*Fond du Lac, WI Metropolitan Statistical Area */
"55043" = '38420' /*Platteville, WI Micropolitan Statistical Area */
"55045" = '33820' /*Monroe, WI Micropolitan Statistical Area */
"55049" = '31540' /*Madison, WI Metropolitan Statistical Area */
"55055" = '48020' /*Watertown-Fort Atkinson, WI Micropolitan Statistical Area */
"55059" = '16980' /*Chicago-Naperville-Joliet, IL-IN-WI Metropolitan Statistical Area */
"55061" = '24580' /*Green Bay, WI Metropolitan Statistical Area */
"55063" = '29100' /*La Crosse, WI-MN Metropolitan Statistical Area */
"55069" = '32980' /*Merrill, WI Micropolitan Statistical Area */
"55071" = '31820' /*Manitowoc, WI Micropolitan Statistical Area */
"55073" = '48140' /*Wausau, WI Metropolitan Statistical Area */
"55075" = '31940' /*Marinette, WI-MI Micropolitan Statistical Area */
"55079" = '33340' /*Milwaukee-Waukesha-West Allis, WI Metropolitan Statistical Area */
"55083" = '24580' /*Green Bay, WI Metropolitan Statistical Area */
"55087" = '11540' /*Appleton, WI Metropolitan Statistical Area */
"55089" = '33340' /*Milwaukee-Waukesha-West Allis, WI Metropolitan Statistical Area */
"55093" = '33460' /*Minneapolis-St. Paul-Bloomington, MN-WI Metropolitan Statistical Area */
"55097" = '44620' /*Stevens Point, WI Micropolitan Statistical Area */
"55101" = '39540' /*Racine, WI Metropolitan Statistical Area */
"55105" = '27500' /*Janesville, WI Metropolitan Statistical Area */
"55109" = '33460' /*Minneapolis-St. Paul-Bloomington, MN-WI Metropolitan Statistical Area */
"55111" = '12660' /*Baraboo, WI Micropolitan Statistical Area */
"55117" = '43100' /*Sheboygan, WI Metropolitan Statistical Area */
"55127" = '48580' /*Whitewater, WI Micropolitan Statistical Area */
"55131" = '33340' /*Milwaukee-Waukesha-West Allis, WI Metropolitan Statistical Area */
"55133" = '33340' /*Milwaukee-Waukesha-West Allis, WI Metropolitan Statistical Area */
"55139" = '36780' /*Oshkosh-Neenah, WI Metropolitan Statistical Area */
"55141" = '49220' /*Wisconsin Rapids-Marshfield, WI Micropolitan Statistical Area */
"56001" = '29660' /*Laramie, WY Micropolitan Statistical Area */
"56005" = '23940' /*Gillette, WY Micropolitan Statistical Area */
"56013" = '40180' /*Riverton, WY Micropolitan Statistical Area */
"56021" = '16940' /*Cheyenne, WY Metropolitan Statistical Area */
"56025" = '16220' /*Casper, WY Metropolitan Statistical Area */
"56033" = '43260' /*Sheridan, WY Micropolitan Statistical Area */
"56037" = '40540' /*Rock Springs, WY Micropolitan Statistical Area */
"56039" = '27220' /*Jackson, WY-ID Micropolitan Statistical Area */
"56041" = '21740' /*Evanston, WY Micropolitan Statistical Area */
;

/* FORMAT FOR MS-DRG (V25) TO MDC */
Value MDCF2T
001 = 77
002 = 77
003 = 77
004 = 77
005 = 77
006 = 77
007 = 77
008 = 77
009 = 77
010 = 77
011 = 77
012 = 77
013 = 77
014 = 77
015 = 77
016 = 77
017 = 77
020 = 01
021 = 01
022 = 01
023 = 01
024 = 01
025 = 01
026 = 01
027 = 01
028 = 01
029 = 01
030 = 01
031 = 01
032 = 01
033 = 01
034 = 01
035 = 01
036 = 01
037 = 01
038 = 01
039 = 01
040 = 01
041 = 01
042 = 01
052 = 01
053 = 01
054 = 01
055 = 01
056 = 01
057 = 01
058 = 01
059 = 01
060 = 01
061 = 01
062 = 01
063 = 01
064 = 01
065 = 01
066 = 01
067 = 01
068 = 01
069 = 01
070 = 01
071 = 01
072 = 01
073 = 01
074 = 01
075 = 01
076 = 01
077 = 01
078 = 01
079 = 01
080 = 01
081 = 01
082 = 01
083 = 01
084 = 01
085 = 01
086 = 01
087 = 01
088 = 01
089 = 01
090 = 01
091 = 01
092 = 01
093 = 01
094 = 01
095 = 01
096 = 01
097 = 01
098 = 01
099 = 01
100 = 01
101 = 01
102 = 01
103 = 01
113 = 02
114 = 02
115 = 02
116 = 02
117 = 02
121 = 02
122 = 02
123 = 02
124 = 02
125 = 02
129 = 03
130 = 03
131 = 03
132 = 03
133 = 03
134 = 03
135 = 03
136 = 03
137 = 03
138 = 03
139 = 03
146 = 03
147 = 03
148 = 03
149 = 03
150 = 03
151 = 03
152 = 03
153 = 03
154 = 03
155 = 03
156 = 03
157 = 03
158 = 03
159 = 03
163 = 04
164 = 04
165 = 04
166 = 04
167 = 04
168 = 04
175 = 04
176 = 04
177 = 04
178 = 04
179 = 04
180 = 04
181 = 04
182 = 04
183 = 04
184 = 04
185 = 04
186 = 04
187 = 04
188 = 04
189 = 04
190 = 04
191 = 04
192 = 04
193 = 04
194 = 04
195 = 04
196 = 04
197 = 04
198 = 04
199 = 04
200 = 04
201 = 04
202 = 04
203 = 04
204 = 04
205 = 04
206 = 04
207 = 04
208 = 04
215 = 05
216 = 05
217 = 05
218 = 05
219 = 05
220 = 05
221 = 05
222 = 05
223 = 05
224 = 05
225 = 05
226 = 05
227 = 05
228 = 05
229 = 05
230 = 05
231 = 05
232 = 05
233 = 05
234 = 05
235 = 05
236 = 05
237 = 05
238 = 05
239 = 05
240 = 05
241 = 05
242 = 05
243 = 05
244 = 05
245 = 05
246 = 05
247 = 05
248 = 05
249 = 05
250 = 05
251 = 05
252 = 05
253 = 05
254 = 05
255 = 05
256 = 05
257 = 05
258 = 05
259 = 05
260 = 05
261 = 05
262 = 05
263 = 05
264 = 05
265 = 05
266 = 05
267 = 05
268 = 05
269 = 05
270 = 05
271 = 05
272 = 05
273 = 05
274 = 05
280 = 05
281 = 05
282 = 05
283 = 05
284 = 05
285 = 05
286 = 05
287 = 05
288 = 05
289 = 05
290 = 05
291 = 05
292 = 05
293 = 05
294 = 05
295 = 05
296 = 05
297 = 05
298 = 05
299 = 05
300 = 05
301 = 05
302 = 05
303 = 05
304 = 05
305 = 05
306 = 05
307 = 05
308 = 05
309 = 05
310 = 05
311 = 05
312 = 05
313 = 05
314 = 05
315 = 05
316 = 05
326 = 06
327 = 06
328 = 06
329 = 06
330 = 06
331 = 06
332 = 06
333 = 06
334 = 06
335 = 06
336 = 06
337 = 06
338 = 06
339 = 06
340 = 06
341 = 06
342 = 06
343 = 06
344 = 06
345 = 06
346 = 06
347 = 06
348 = 06
349 = 06
350 = 06
351 = 06
352 = 06
353 = 06
354 = 06
355 = 06
356 = 06
357 = 06
358 = 06
368 = 06
369 = 06
370 = 06
371 = 06
372 = 06
373 = 06
374 = 06
375 = 06
376 = 06
377 = 06
378 = 06
379 = 06
380 = 06
381 = 06
382 = 06
383 = 06
384 = 06
385 = 06
386 = 06
387 = 06
388 = 06
389 = 06
390 = 06
391 = 06
392 = 06
393 = 06
394 = 06
395 = 06
405 = 07
406 = 07
407 = 07
408 = 07
409 = 07
410 = 07
411 = 07
412 = 07
413 = 07
414 = 07
415 = 07
416 = 07
417 = 07
418 = 07
419 = 07
420 = 07
421 = 07
422 = 07
423 = 07
424 = 07
425 = 07
432 = 07
433 = 07
434 = 07
435 = 07
436 = 07
437 = 07
438 = 07
439 = 07
440 = 07
441 = 07
442 = 07
443 = 07
444 = 07
445 = 07
446 = 07
453 = 08
454 = 08
455 = 08
456 = 08
457 = 08
458 = 08
459 = 08
460 = 08
461 = 08
462 = 08
463 = 08
464 = 08
465 = 08
466 = 08
467 = 08
468 = 08
469 = 08
470 = 08
471 = 08
472 = 08
473 = 08
474 = 08
475 = 08
476 = 08
477 = 08
478 = 08
479 = 08
480 = 08
481 = 08
482 = 08
483 = 08
484 = 08
485 = 08
486 = 08
487 = 08
488 = 08
489 = 08
490 = 08
491 = 08
492 = 08
493 = 08
494 = 08
495 = 08
496 = 08
497 = 08
498 = 08
499 = 08
500 = 08
501 = 08
502 = 08
503 = 08
504 = 08
505 = 08
506 = 08
507 = 08
508 = 08
509 = 08
510 = 08
511 = 08
512 = 08
513 = 08
514 = 08
515 = 08
516 = 08
517 = 08
518 = 08
519 = 08
520 = 08
533 = 08
534 = 08
535 = 08
536 = 08
537 = 08
538 = 08
539 = 08
540 = 08
541 = 08
542 = 08
543 = 08
544 = 08
545 = 08
546 = 08
547 = 08
548 = 08
549 = 08
550 = 08
551 = 08
552 = 08
553 = 08
554 = 08
555 = 08
556 = 08
557 = 08
558 = 08
559 = 08
560 = 08
561 = 08
562 = 08
563 = 08
564 = 08
565 = 08
566 = 08
570 = 09
571 = 09
572 = 09
573 = 09
574 = 09
575 = 09
576 = 09
577 = 09
578 = 09
579 = 09
580 = 09
581 = 09
582 = 09
583 = 09
584 = 09
585 = 09
592 = 09
593 = 09
594 = 09
595 = 09
596 = 09
597 = 09
598 = 09
599 = 09
600 = 09
601 = 09
602 = 09
603 = 09
604 = 09
605 = 09
606 = 09
607 = 09
614 = 10
615 = 10
616 = 10
617 = 10
618 = 10
619 = 10
620 = 10
621 = 10
622 = 10
623 = 10
624 = 10
625 = 10
626 = 10
627 = 10
628 = 10
629 = 10
630 = 10
637 = 10
638 = 10
639 = 10
640 = 10
641 = 10
642 = 10
643 = 10
644 = 10
645 = 10
652 = 11
653 = 11
654 = 11
655 = 11
656 = 11
657 = 11
658 = 11
659 = 11
660 = 11
661 = 11
662 = 11
663 = 11
664 = 11
665 = 11
666 = 11
667 = 11
668 = 11
669 = 11
670 = 11
671 = 11
672 = 11
673 = 11
674 = 11
675 = 11
682 = 11
683 = 11
684 = 11
685 = 11
686 = 11
687 = 11
688 = 11
689 = 11
690 = 11
691 = 11
692 = 11
693 = 11
694 = 11
695 = 11
696 = 11
697 = 11
698 = 11
699 = 11
700 = 11
707 = 12
708 = 12
709 = 12
710 = 12
711 = 12
712 = 12
713 = 12
714 = 12
715 = 12
716 = 12
717 = 12
718 = 12
722 = 12
723 = 12
724 = 12
725 = 12
726 = 12
727 = 12
728 = 12
729 = 12
730 = 12
734 = 13
735 = 13
736 = 13
737 = 13
738 = 13
739 = 13
740 = 13
741 = 13
742 = 13
743 = 13
744 = 13
745 = 13
746 = 13
747 = 13
748 = 13
749 = 13
750 = 13
754 = 13
755 = 13
756 = 13
757 = 13
758 = 13
759 = 13
760 = 13
761 = 13
765 = 14
766 = 14
767 = 14
768 = 14
769 = 14
770 = 14
774 = 14
775 = 14
776 = 14
777 = 14
778 = 14
779 = 14
780 = 14
781 = 14
782 = 14
789 = 15
790 = 15
791 = 15
792 = 15
793 = 15
794 = 15
795 = 15
799 = 16
800 = 16
801 = 16
802 = 16
803 = 16
804 = 16
808 = 16
809 = 16
810 = 16
811 = 16
812 = 16
813 = 16
814 = 16
815 = 16
816 = 16
820 = 17
821 = 17
822 = 17
823 = 17
824 = 17
825 = 17
826 = 17
827 = 17
828 = 17
829 = 17
830 = 17
834 = 17
835 = 17
836 = 17
837 = 17
838 = 17
839 = 17
840 = 17
841 = 17
842 = 17
843 = 17
844 = 17
845 = 17
846 = 17
847 = 17
848 = 17
849 = 17
853 = 18
854 = 18
855 = 18
856 = 18
857 = 18
858 = 18
862 = 18
863 = 18
864 = 18
865 = 18
866 = 18
867 = 18
868 = 18
869 = 18
870 = 18
871 = 18
872 = 18
876 = 19
880 = 19
881 = 19
882 = 19
883 = 19
884 = 19
885 = 19
886 = 19
887 = 19
894 = 20
895 = 20
896 = 20
897 = 20
901 = 21
902 = 21
903 = 21
904 = 21
905 = 21
906 = 21
907 = 21
908 = 21
909 = 21
913 = 21
914 = 21
915 = 21
916 = 21
917 = 21
918 = 21
919 = 21
920 = 21
921 = 21
922 = 21
923 = 21
927 = 22
928 = 22
929 = 22
933 = 22
934 = 22
935 = 22
939 = 23
940 = 23
941 = 23
945 = 23
946 = 23
947 = 23
948 = 23
949 = 23
950 = 23
951 = 23
955 = 24
956 = 24
957 = 24
958 = 24
959 = 24
963 = 24
964 = 24
965 = 24
969 = 25
970 = 25
974 = 25
975 = 25
976 = 25
977 = 25
981 = 88
982 = 88
983 = 88
984 = 88
985 = 88
986 = 88
987 = 88
988 = 88
989 = 88
998 = 88
999 = 88
OTHER = 99
;

/* FORMAT FOR Heart failure diagnosis codes */
Value $MRTCHFD
"I0981" = '1' /*Rheumatic heart failure */
"I110" = '1' /*Hypertensive heart disease with heart failure */
"I130" = '1' /*Hypertensive heart and chronic kidney diseasewith heart failure and stage 1 through stage 4chronic kidney disease, or unspecified chronickidney disease */
"I132" = '1' /*Hypertensive heart and chronic kidney diseasewith heart failure and with stage 5 chronickidney disease, or end stage renal disease */
"I501" = '1' /*Left ventricular failure, unspecified */
"I5020" = '1' /*Unspecified systolic (congestive) heart failure */
"I5021" = '1' /*Acute systolic (congestive) heart failure */
"I5022" = '1' /*Chronic systolic (congestive) heart failure */
"I5023" = '1' /*Acute on chronic systolic (congestive) heartfailure */
"I5030" = '1' /*Unspecified diastolic (congestive) heart failure */
"I5031" = '1' /*Acute diastolic (congestive) heart failure */
"I5032" = '1' /*Chronic diastolic (congestive) heart failure */
"I5033" = '1' /*Acute on chronic diastolic (congestive) heartfailure */
"I5040" = '1' /*Unspecified combined systolic (congestive) anddiastolic (congestive) heart failure */
"I5041" = '1' /*Acute combined systolic (congestive) anddiastolic (congestive) heart failure */
"I5042" = '1' /*Chronic combined systolic (congestive) anddiastolic (congestive) heart failure */
"I5043" = '1' /*Acute on chronic combined systolic (congestive)and diastolic (congestive) heart failure */
"I50810" = '1' /*Right heart failure, unspecified */
"I50811" = '1' /*Acute right heart failure */
"I50812" = '1' /*Chronic right heart failure */
"I50813" = '1' /*Acute on chronic right heart failure */
"I50814" = '1' /*Right heart failure due to left heart failure */
"I5082" = '1' /*Biventricular heart failure */
"I5083" = '1' /*High output heart failure */
"I5084" = '1' /*End stage heart failure */
"I5089" = '1' /*Other heart failure */
"I509" = '1' /*Heart failure, unspecified */
OTHER = '0'
;

/* FORMAT FOR Acute kidney (renal) failure diagnosis codes */
Value $PHYSIDB
"N170" = '1' /*Acute kidney failure with tubular necrosis */
"N171" = '1' /*Acute kidney failure with acute cortical necrosis */
"N172" = '1' /*Acute kidney failure with medullary necrosis */
"N178" = '1' /*Other acute kidney failure */
"N179" = '1' /*Acute kidney failure, unspecified */
"N19" = '1' /*Unspecified kidney failure */
"N990" = '1' /*Postprocedural (acute) (chronic) kidney failure */
OTHER = '0'
;

/* FORMAT FOR Race/ethnicity categories */
Value RACECAT
1 = 'White' /*White */
2 = 'Black' /*Black */
3 = 'Hispanic' /*Hispanic */
4 = 'Asian and NH/PI' /*Asian and NH/PI */
5 = 'Amer Indian/AN' /*American Indian /AN */
6 = 'Other' /*Other */
;

/* FORMAT FOR Cystic fibrosis and anomalies of respiratory system diagnosis codes */
Value $RESPAN
"E840" = '1' /*Cystic fibrosis with pulmonary manifestations */
"E8411" = '1' /*Meconium ileus in cystic fibrosis */
"E8419" = '1' /*Cystic fibrosis with other intestinal manifestations */
"E848" = '1' /*Cystic fibrosis with other manifestations */
"E849" = '1' /*Cystic fibrosis, unspecified */
"J8483" = '1' /*Surfactant mutations of the lung */
"J84841" = '1' /*Neuroendocrine cell hyperplasia of infancy */
"J84842" = '1' /*Pulmonary interstitial glycogenosis */
"J84843" = '1' /*Alveolar capillary dysplasia with vein misalignment */
"J84848" = '1' /*Other interstitial  lung diseases of childhood */
"P270" = '1' /*Wilson-Mikity syndrome */
"P271" = '1' /*Bronchopulmonary dysplasia originating in the perinatal period */
"P278" = '1' /*Other chronic respiratory diseases originating in the perinatal period */
"P279" = '1' /*Unspecified chronic respiratory disease originating in the perinatalperiod */
"Q254" = '1' /*Other congenital malformations of aorta */
"Q2545" = '1' /*Double aortic arch */
"Q2547" = '1' /*Right aortic arch */
"Q2548" = '1' /*Anomalous origin of subclavian artery */
"Q311" = '1' /*Congenital subglottic stenosis */
"Q312" = '1' /*Laryngeal hypoplasia */
"Q313" = '1' /*Laryngocele */
"Q315" = '1' /*Congenital laryngomalacia */
"Q318" = '1' /*Other congenital malformations of larynx */
"Q319" = '1' /*Congenital malformation of larynx, unspecified */
"Q320" = '1' /*Congenital tracheomalacia */
"Q321" = '1' /*Other congenital malformations of trachea */
"Q322" = '1' /*Congenital bronchomalacia */
"Q323" = '1' /*Congenital stenosis of bronchus */
"Q324" = '1' /*Other congenital malformations of bronchus */
"Q330" = '1' /*Congenital cystic lung */
"Q331" = '1' /*Accessory lobe of lung */
"Q332" = '1' /*Sequestration of lung */
"Q333" = '1' /*Agenesis of lung */
"Q334" = '1' /*Congenital bronchiectasis */
"Q335" = '1' /*Ectopic tissue in lung */
"Q336" = '1' /*Congenital hypoplasia and dysplasia of lung */
"Q338" = '1' /*Other congenital malformations of lung */
"Q339" = '1' /*Congenital malformation of lung, unspecified */
"Q340" = '1' /*Anomaly of pleura */
"Q341" = '1' /*Congenital cyst of mediastinum */
"Q348" = '1' /*Other specified congenital malformations of respiratory system */
"Q349" = '1' /*Congenital malformation of respiratory system, unspecified */
"Q390" = '1' /*Atresia of esophagus without fistula */
"Q391" = '1' /*Atresia of esophagus with tracheo-esophageal fistula */
"Q392" = '1' /*Congenital tracheo-esophageal fistula without atresia */
"Q393" = '1' /*Congenital stenosis and stricture of esophagus */
"Q394" = '1' /*Esophageal web */
"Q893" = '1' /*Situs inversus */
OTHER = '0'
;

/* FORMAT FOR Sex categories */
Value SEXCAT
1 = 'Male' /*Male */
2 = 'Female' /*Female */
;

run;

*Restore source option to setting used prior to formats;
option &orgoptionValue;
